@@ -4,13 +4,13 @@
  *
  *      Description:  The interface to dynamically load ptt files
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tg), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -62,7 +62,52 @@
 #include <isa_ppc64.h>
 #endif
 
-static int registerMapLength(RegisterMap* map)
+static const RegisterMap StreamPatterns[] = {
+    {"STR0", "ARG2"},
+    {"STR1", "ARG3"},
+    {"STR2", "ARG4"},
+    {"STR3", "ARG5"},
+    {"STR4", "ARG6"},
+    {"STR5", "[rbp+16]"},
+    {"STR6", "[rbp+24]"},
+    {"STR7", "[rbp+32]"},
+    {"STR8", "[rbp+40]"},
+    {"STR9", "[rbp+48]"},
+    {"STR10", "[rbp+56]"},
+    {"STR11", "[rbp+64]"},
+    {"STR12", "[rbp+72]"},
+    {"STR13", "[rbp+80]"},
+    {"STR14", "[rbp+88]"},
+    {"STR15", "[rbp+96]"},
+    {"STR16", "[rbp+104]"},
+    {"STR17", "[rbp+112]"},
+    {"STR18", "[rbp+120]"},
+    {"STR19", "[rbp+128]"},
+    {"STR20", "[rbp+136]"},
+    {"STR21", "[rbp+144]"},
+    {"STR22", "[rbp+152]"},
+    {"STR23", "[rbp+160]"},
+    {"STR24", "[rbp+168]"},
+    {"STR25", "[rbp+176]"},
+    {"STR26", "[rbp+184]"},
+    {"STR27", "[rbp+192]"},
+    {"STR28", "[rbp+200]"},
+    {"STR29", "[rbp+208]"},
+    {"STR30", "[rbp+216]"},
+    {"STR31", "[rbp+224]"},
+    {"STR32", "[rbp+232]"},
+    {"STR33", "[rbp+240]"},
+    {"STR34", "[rbp+248]"},
+    {"STR35", "[rbp+256]"},
+    {"STR36", "[rbp+264]"},
+    {"STR37", "[rbp+272]"},
+    {"STR38", "[rbp+280]"},
+    {"STR39", "[rbp+288]"},
+    {"STR40", "[rbp+296]"},
+    {"", ""},
+};
+
+static int registerMapLength(const RegisterMap* map)
 {
     int i = 0;
     while (strlen(map[i].pattern) > 0)
@@ -72,10 +117,10 @@ static int registerMapLength(RegisterMap* map)
     return i;
 }
 
-static int registerMapMaxPattern(RegisterMap* map)
+static int registerMapMaxPattern(const RegisterMap* map)
 {
     int i = 0;
-    int max = 0;
+    size_t max = 0;
     while (strlen(map[i].pattern) > 0)
     {
         if (strlen(map[i].pattern) > max)
@@ -87,11 +132,11 @@ static int registerMapMaxPattern(RegisterMap* map)
 
 static struct bstrList* read_ptt(bstring pttfile)
 {
-    int ret = 0;
     FILE* fp = NULL;
     char buf[BUFSIZ];
     struct bstrList* l = NULL;
 
+#pragma GCC diagnostic ignored "-Wnonnull"
     if (access(bdata(pttfile), R_OK))
     {
         return NULL;
@@ -100,20 +145,15 @@ static struct bstrList* read_ptt(bstring pttfile)
     bstring content = bfromcstr("");
     fp = fopen(bdata(pttfile), "r");
     if (fp == NULL) {
-        fprintf(stderr, "fopen(%s): errno=%d\n", pttfile, errno);
+        perror("fopen");
         return NULL;
     }
     for (;;) {
         /* Read another chunk */
-        ret = fread(buf, 1, sizeof(buf), fp);
-        if (ret < 0) {
-            fprintf(stderr, "fread(%p, 1, %lu, %p): %d, errno=%d\n", buf, sizeof(buf), fp, ret, errno);
-            return NULL;
-        }
-        else if (ret == 0) {
+        size_t bytes_read = fread(buf, 1, sizeof(buf), fp);
+        if (bytes_read == 0)
             break;
-        }
-        bcatblk(content, buf, ret);
+        bcatblk(content, buf, (size_t)bytes_read);
     }
     btrimws(content);
 
@@ -306,26 +346,6 @@ static struct bstrList* analyse_ptt(bstring pttfile, TestCase** testcase)
     return code;
 }
 
-static int set_testname(char *pttfile, TestCase* testcase)
-{
-    if ((!testcase)||(!pttfile))
-    {
-        return -EINVAL;
-    }
-    bstring ptt = bfromcstr(basename(pttfile));
-    int dot = bstrrchrp(ptt, '.', blength(ptt)-1);
-    btrunc(ptt, dot);
-    testcase->name = malloc((blength(ptt)+2) * sizeof(char));
-    int ret = snprintf(testcase->name, blength(ptt)+1, "%s", bdata(ptt));
-    if (ret > 0)
-    {
-        testcase->name[ret] = '\0';
-    }
-    bdestroy(ptt);
-    return 0;
-}
-
-
 static struct bstrList* parse_asm(TestCase* testcase, struct bstrList* input)
 {
     struct bstrList* output = NULL;
@@ -381,7 +401,7 @@ static struct bstrList* parse_asm(TestCase* testcase, struct bstrList* input)
     return output;
 }
 
-static int searchreplace(bstring line, RegisterMap* map)
+static int searchreplace(bstring line, const RegisterMap* map)
 {
     int maxlen = registerMapMaxPattern(map);
     int size = registerMapLength(map);
@@ -390,7 +410,7 @@ static int searchreplace(bstring line, RegisterMap* map)
         int c = 0;
         for (int j = 0; j < size; j++)
         {
-            if (strlen(map[j].pattern) == s)
+            if (strlen(map[j].pattern) == (size_t)s)
             {
                 bstring pat = bfromcstr(map[j].pattern);
                 bstring reg = bfromcstr(map[j].reg);
@@ -476,18 +496,16 @@ static int dynbench_getall_folder(char *path, struct bstrList** benchmarks)
 
 struct bstrList* dynbench_getall()
 {
-    int totalfiles = 0;
-
     struct bstrList* list = bstrListCreate();
 
     bstring home = bformat("%s/.likwid/bench/%s", getenv("HOME"), ARCHNAME);
-    totalfiles += dynbench_getall_folder(bdata(home), &list);
+    dynbench_getall_folder(bdata(home), &list);
     bdestroy(home);
 
     char cwd[200];
     if (getcwd(cwd, 200) != NULL)
     {
-        totalfiles += dynbench_getall_folder(cwd, &list);
+        dynbench_getall_folder(cwd, &list);
     }
     return list;
 }
@@ -571,7 +589,6 @@ static int compile_file(bstring compiler, bstring flags, bstring asmfile, bstrin
 
 static int open_function(bstring location, TestCase *testcase)
 {
-    void* handle;
     char *error;
     void* (*owndlsym)(void*, const char*) = dlsym;
 
@@ -611,12 +628,15 @@ int dynbench_test(bstring testname)
         return exist;
     }
     path = bformat("%s/.likwid/bench/%s/%s.ptt", home, ARCHNAME, bdata(testname));
+
+#pragma GCC diagnostic ignored "-Wnonnull"
     if (!access(bdata(path), R_OK))
     {
         exist = 1;
     }
     bdestroy(path);
     path = bformat("%s/%s.ptt", pwd, bdata(testname));
+#pragma GCC diagnostic ignored "-Wnonnull"
     if (!access(bdata(path), R_OK))
     {
         exist = 1;
@@ -631,7 +651,6 @@ int dynbench_load(bstring testname, TestCase **testcase, char* tmpfolder, char *
     TestCase *test = NULL;
     char* home = getenv("HOME");
     char pwd[100];
-    bstring folder = NULL;
     if (!home)
     {
         fprintf(stderr, "Failed to get $HOME from environment\n");
@@ -644,10 +663,12 @@ int dynbench_load(bstring testname, TestCase **testcase, char* tmpfolder, char *
     }
 
     bstring pttfile = bformat("%s/%s.ptt", pwd, bdata(testname));
+#pragma GCC diagnostic ignored "-Wnonnull"
     if (access(bdata(pttfile), R_OK))
     {
         bdestroy(pttfile);
         pttfile = bformat("%s/.likwid/bench/%s/%s.ptt", home, ARCHNAME, bdata(testname));
+#pragma GCC diagnostic ignored "-Wnonnull"
         if (access(bdata(pttfile), R_OK))
         {
             fprintf(stderr, "Cannot open ptt file %s.ptt in CWD or %s/.likwid/bench/%s\n", bdata(testname), home, ARCHNAME);
@@ -673,6 +694,7 @@ int dynbench_load(bstring testname, TestCase **testcase, char* tmpfolder, char *
             {
                 pid_t pid = getpid();
                 bstring buildfolder = bformat("%s/%ld", tmpfolder, pid);
+#pragma GCC diagnostic ignored "-Wnonnull"
                 if (mkdir(bdata(buildfolder), 0700) == 0)
                 {
                     int asm_written = 0;
@@ -796,6 +818,7 @@ int dynbench_close(TestCase* testcase, char* tmpfolder)
             bstring asmfile = bformat("%s/%s.S", bdata(buildfolder), testcase->name);
             bstring objfile = bformat("%s/%s.o", bdata(buildfolder), testcase->name);
 
+#pragma GCC diagnostic ignored "-Wnonnull"
             if (!access(bdata(asmfile), R_OK)) unlink(bdata(asmfile));
             if (!access(bdata(objfile), R_OK)) unlink(bdata(objfile));
             if (!access(bdata(buildfolder), R_OK)) rmdir(bdata(buildfolder));
@@ -814,7 +837,7 @@ int dynbench_close(TestCase* testcase, char* tmpfolder)
     return 0;
 }
 
-int dynbench_asm(bstring testname, char* tmpfolder, bstring outfile)
+void dynbench_asm(bstring testname, char* tmpfolder, bstring outfile)
 {
     if (blength(testname) > 0 && tmpfolder && blength(outfile) > 0)
     {
