@@ -5,13 +5,13 @@
  *
  *      Description:  Utility string routines building upon bstrlib
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com.
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -61,73 +61,119 @@ str2int(const char* str)
     return (int) val;
 }
 
+static int
+str2uint64_t(const char* str, uint64_t* result)
+{
+    char* endptr;
+    errno = 0;
+    unsigned long long val;
+    val = strtoull(str, &endptr, 10);
+
+    if ((errno == ERANGE && val == ULLONG_MAX)
+        || (errno != 0 && val == 0))
+    {
+        fprintf(stderr, "Value in string %s out of range\n", str);
+        return -EINVAL;
+    }
+
+    if (endptr == str)
+    {
+        fprintf(stderr, "No digits were found in %s\n", str);
+        return -EINVAL;
+    }
+
+    // long long could be larger than 64 bits
+    if (val > 0xFFFFFFFFFFFFFFFF)
+    {
+        fprintf(stderr, "Value in string %s out of range for uint64_t\n", str);
+        return -EINVAL;
+    }
+
+    *result = val;
+    return 1;
+}
+
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
 uint64_t
 bstr_to_doubleSize(const_bstring str, DataType type)
 {
-    int ret;
-    bstring unit = bmidstr(str, blength(str)-2, 2);
-    bstring single_unit = bmidstr(str, blength(str)-1, 1);
-    bstring sizeStr = bmidstr(str, 0, blength(str)-2);
-    bstring single_sizeStr = bmidstr(str, 0, blength(str)-1);
-    uint64_t sizeU = 0;
-    uint64_t single_sizeU = 0;
-    uint64_t junk = 0;
-    uint64_t bytesize = 0;
-    if (blength(sizeStr) == 0)
-    {
-        return 0;
+    int ret = 0;
+    int unitlen = 0;
+    uint64_t sizeU = 0x0ULL;
+    uint64_t junk = 0x0ULL;
+    size_t bytesize = 0;
+
+    for (int i = blength(str)-1; ((i >= 0) && (!isdigit(bchar(str, i)))); i--) {
+        unitlen++;
     }
-    ret = str2int(bdata(sizeStr));
-    if (ret >= 0)
-    {
-        sizeU = str2int(bdata(sizeStr));
+    bstring unitStr = bmidstr(str, blength(str)-unitlen, unitlen);
+    bstring sizeStr = bmidstr(str, 0, blength(str)-unitlen);
+
+    if (blength(unitStr) == 0) {
+        bconchar(unitStr, 'B');
     }
-    else
-    {
-        return 0;
+
+    ret = 0;
+    for (int i = 0; i < blength(sizeStr); i++) {
+        if (!isdigit(bchar(sizeStr, i))) {
+            ret = -EINVAL;
+            break;
+        }
     }
-    ret = str2int(bdata(single_sizeStr));
-    if (ret >= 0)
-    {
-        single_sizeU = str2int(bdata(single_sizeStr));
+    if (ret != 0) {
+        bdestroy(unitStr);
+        bdestroy(sizeStr);
+        return ret;
     }
-    else
-    {
+
+    ret = str2uint64_t(bdata(sizeStr), &sizeU);
+    if ((ret < 0) || (sizeU == 0)) {
+        bdestroy(unitStr);
+        bdestroy(sizeStr);
         return 0;
     }
 
     bytesize = allocator_dataTypeLength(type);
 
-    if ((biseqcstr(unit, "kB"))||(biseqcstr(unit, "KB")))
+    if ((bisstemeqblk(unitStr, "kB", 2))||(bisstemeqblk(unitStr, "KB", 2)))
     {
         junk = (sizeU *1000)/bytesize;
     }
-    else if (biseqcstr(unit, "MB"))
+    else if (bisstemeqblk(unitStr, "MB", 2))
     {
         junk = (sizeU *1000000)/bytesize;
     }
-    else if (biseqcstr(unit, "GB"))
+    else if (bisstemeqblk(unitStr, "GB",2 ))
     {
         junk = (sizeU *1000000000)/bytesize;
     }
-    else if (biseqcstr(single_unit, "B"))
+    else if ((bisstemeqblk(unitStr, "kiB", 3))||(bisstemeqblk(unitStr, "KiB", 3)))
     {
-        junk = (single_sizeU)/bytesize;
+        junk = (sizeU *1024)/bytesize;
     }
-    bdestroy(unit);
-    bdestroy(single_unit);
+    else if (bisstemeqblk(unitStr, "MiB", 3))
+    {
+        junk = (sizeU *1024*1024)/bytesize;
+    }
+    else if (bisstemeqblk(unitStr, "GiB", 3))
+    {
+        junk = (sizeU *1024*1024*1024)/bytesize;
+    }
+    else if (bisstemeqblk(unitStr, "B", 1))
+    {
+        junk = (sizeU)/bytesize;
+    }
+
+    bdestroy(unitStr);
     bdestroy(sizeStr);
-    bdestroy(single_sizeStr);
+
     return junk;
 }
 
 bstring
 parse_workgroup(Workgroup* group, const_bstring str, DataType type)
 {
-    CpuTopology_t topo;
-    AffinityDomains_t doms;
     struct bstrList* tokens;
     bstring cpustr;
     int numThreads = 0;
@@ -137,12 +183,12 @@ parse_workgroup(Workgroup* group, const_bstring str, DataType type)
     if (tokens->qty == 2)
     {
         int domidx = -1;
-        topo = get_cpuTopology();
-        doms = get_affinityDomains();
+        AffinityDomains_t doms = get_affinityDomains();
 
-        for (int i = 0; i < doms->numberOfAffinityDomains; i++)
+        for (int i = 0; i < (int)doms->numberOfAffinityDomains; i++)
         {
-            if (strncmp(doms->domains[i].tag, bdata(tokens->entry[0]), strlen(doms->domains[i].tag)) == 0)
+#pragma GCC diagnostic ignored "-Wnonnull"
+            if (strcmp(doms->domains[i].tag, bdata(tokens->entry[0])) == 0)
             {
                 domidx = i;
                 break;
