@@ -5,13 +5,13 @@
  *
  *      Description:  High level interface to pthreads
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:  Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -72,16 +72,17 @@ count_characters(const char *str, char character)
 void*
 dummy_function(void* arg)
 {
-    return 0;
+    (void)arg;
+    return NULL;
 }
 
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
+// TODO threads_test isn't used anymore. Can we just remove it?
 int
 threads_test()
 {
     int cnt = 0;
-    int err;
     pthread_t pid;
     int likwid_pin = count_characters(getenv("LIKWID_PIN"), ',');
     int max_cpus = sysconf(_SC_NPROCESSORS_CONF);
@@ -91,7 +92,7 @@ threads_test()
         max = max_cpus;
     }
     while (cnt < max) {
-        err = pthread_create(&pid, NULL, dummy_function, NULL);
+        pthread_create(&pid, NULL, dummy_function, NULL);
         cnt++;
     }
     return cnt;
@@ -266,6 +267,8 @@ threads_join(void)
 void
 threads_destroy(int numberOfGroups, int numberOfStreams)
 {
+    (void)numberOfStreams;
+
     int i = 0, j = 0;
     pthread_attr_destroy(&attr);
     pthread_barrier_destroy(&threads_barrier);
