@@ -1,7 +1,8 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 
 use strict;
 use warnings;
+use File::Basename;
 
 my $arch;
 my $key;
@@ -60,6 +61,7 @@ while (<INFILE>) {
             {
                 my @tmplist = split("=", $opt);
                 $defaultopts = $defaultopts."{".$tmplist[0].",".$tmplist[1]."},";
+                $opts = $opts."|".$tmplist[0]."_MASK";
                 $nropts++;
             }
         }
@@ -97,6 +99,7 @@ while (<INFILE>) {
             {
                 my @tmplist = split("=", $opt);
                 $defaultopts = $defaultopts."{".$tmplist[0].",".$tmplist[1]."},";
+                $opts = $opts."|".$tmplist[0]."_MASK";
                 $nropts++;
             }
         }
@@ -122,7 +125,7 @@ while (<INFILE>) {
     elsif (/DEFAULT_OPTIONS_([A-Z0-9_]*)[ ]*([xA-Z0-9_=,]*)/) {
         $defoptkey = $1;
         $defopts = $2;
-    } elsif (/OPTIONS_([A-Z0-9_]*)[ ]*([A-Z0-9_\|]+)/) {
+    } elsif (/^OPTIONS_([A-Z0-9_]*)[ ]*([A-Z0-9_\|]+)/) {
         $optkey = $1;
         $opts = $2;
     }
@@ -133,9 +136,14 @@ my $ucArch = uc($arch);
 my $delim;
 $delim = "";
 
+my $INCLUDE_GUARD = basename($OUT_filename);
+$INCLUDE_GUARD =~ s/[^a-zA-Z0-9_]/_/g;
+$INCLUDE_GUARD = uc $INCLUDE_GUARD;
 
 open OUTFILE,">$OUT_filename";
 print OUTFILE "/* DONT TOUCH: GENERATED FILE! */\n\n";
+print OUTFILE "#ifndef $INCLUDE_GUARD\n";
+print OUTFILE "#define $INCLUDE_GUARD\n\n";
 print OUTFILE "#define NUM_ARCH_EVENTS_$ucArch $num_events\n\n";
 print OUTFILE "static PerfmonEvent  ".$arch."_arch_events[NUM_ARCH_EVENTS_$ucArch] = {\n";
 
@@ -146,6 +154,7 @@ END
     $delim = ',';
 }
 
-print  OUTFILE "};\n";
+print OUTFILE "};\n\n";
+print OUTFILE "#endif // $INCLUDE_GUARD\n";
 close OUTFILE;
 
