@@ -10,15 +10,15 @@ my $cc = ' *';
 my $fc = '!';
 my $lc = ' *';
 
-#my $VERSION   = '<VERSION>';
-#my $DATE   = '<DATE>';
-my $VERSION   = '5.4.0';
-my $DATE   = '15.11.2024';
-my $YEAR  = '2024';
+my $VERSION   = '<VERSION>';
+my $DATE   = '<DATE>';
+#my $VERSION   = '4.0';
+#my $DATE   = '16.6.2015';
+my $YEAR  = '2016';
 my $AUTHOR = 'RRZE, University Erlangen-Nuremberg';
 my $LICENSE = 'gpl';
 
-my @SKIPLIST = ('ghash.c','ghash.h','loadData.S','loadDataARM.S','bstrlib.c','bstrlib.h', 'calculator_stack.h', 'calculator_stack.c', 'voltage.c', 'voltage.h', 'likwid-benchmark.sh', 'calculator.c', 'calculator.h');
+my @SKIPLIST = ('ghash.c','ghash.h','loadData.S','loadDataARM.S','bstrlib.c','bstrlib.h', 'calculator_stack.h', 'calculator_stack.c', 'voltage.c', 'voltage.h', 'likwid-benchmark.sh', 'calculator.c', 'calculator.h', 'amd_hsmp.h');
 
 sub print_copyright
 {
