@@ -6,13 +6,13 @@
  *      Description:  Implementation a interface library to hook into applications
  *                    using the GOTCHA library
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -38,6 +38,7 @@
 #include <pthread.h>
 #include <unistd.h>
 #include <time.h>
+#include <bstrlib.h>
 
 #include <likwid.h>
 #include <error.h>
@@ -52,7 +53,7 @@ static FILE* output_file = NULL;
 
 // Timeline mode
 static int stopIssued = 0;
-static pthread_mutex_t stopMutex;
+static pthread_mutex_t stopMutex = PTHREAD_MUTEX_INITIALIZER;
 
 static int appdaemon_register_exit(appdaemon_exit_func f)
 {
@@ -87,7 +88,6 @@ static void prepare_ldpreload()
     char* ldpreload = getenv("LD_PRELOAD");
     if (ldpreload)
     {
-        printf("Old LD_PRELOAD=%s\n", ldpreload);
         bstring bldpre = bfromcstr(ldpreload);
         bstring new_bldpre = bfromcstr("");
         struct bstrList *liblist = bsplit(bldpre, ':');
@@ -99,7 +99,6 @@ static void prepare_ldpreload()
                 bconchar(new_bldpre, ':');
             }
         }
-        printf("New LD_PRELOAD=%s\n", bdata(new_bldpre));
         mysetenv("LD_PRELOAD", bdata(new_bldpre), 1);
         bstrListDestroy(liblist);
         bdestroy(new_bldpre);
@@ -143,6 +142,59 @@ static int parse_gpustr(char* gpuStr, int* numGpus, int** gpuIds)
     return 0;
 }
 
+typedef struct {
+    int numDevices;
+    int *devices;
+    int numGroups;
+    int *groups;
+    double (*getTime)(int group);
+    int (*numEvents)(int group);
+    double (*getResult)(int gpu, int group, int event);
+} appdaemon_output_data;
+
+static int appdaemon_write_output_file(const char* markerfile, appdaemon_output_data* data) {
+
+    /* MarkerAPI File format
+     * 1 numberOfGPUs numberOfRegions numberOfGpuGroups
+     * 2 regionID:regionTag0
+     * 3 regionID:regionTag1
+     * 4 regionID groupID gpuID callCount timeActive numEvents countersvalues(space separated)
+     * 5 regionID groupID gpuID callCount timeActive numEvents countersvalues(space separated)
+    */
+    /* Here we use it to hand over the results to likwid-perfctr */
+
+    // Open file in write mode
+    FILE* file = fopen(markerfile,"w");
+    if (file == NULL)
+    {
+        int ret = errno;
+        fprintf(stderr, "Cannot open file %s\n", markerfile);
+        fprintf(stderr, "%s", strerror(errno));
+        return -ret;
+    }
+    fprintf(file,"%d 1 %d\n", data->numDevices, data->numGroups);
+    int regionId = 0;
+    for (int i = 0; i < data->numGroups; i++) {
+        fprintf(file, "%d:appdaemon-%d\n", regionId, data->groups[i]);
+    }
+    for (int i = 0; i < data->numGroups; i++) {
+        int groupId = data->groups[i];
+        int numEvents = data->numEvents(groupId);
+        double time = data->getTime(groupId);
+        for (int j = 0; j < data->numDevices; j++) {
+            fprintf(file, "%d %d %d %u %e %d ", regionId, groupId, data->devices[j], 1, time, numEvents);
+            for (int k = 0; k < numEvents; k++) {
+                fprintf(file, "%e ", data->getResult(groupId, k, j));
+            }
+            fprintf(file, "\n");
+        }
+    }
+    fflush(file);
+    fclose(file);
+    return 0;
+}
+
+
 /*
 Nvmon
 */
@@ -152,18 +204,19 @@ static int* nvmon_gpulist = NULL;
 static int  nvmon_numgpus = 0;
 static int* nvmon_gids = NULL;
 static int  nvmon_numgids = 0;
+int likwid_nvmon_verbosity = 0;
 
 static int appdaemon_setup_nvmon(char* gpuStr, char* eventStr)
 {
     int ret = 0;
-    printf("Nvmon GPU string: %s\n", gpuStr);
-    printf("Nvmon Event string: %s\n", eventStr);
+    GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "Nvmon GPU string: %s", gpuStr);
+    GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "Nvmon Event string: %s", eventStr);
 
     // Parse gpu string
     ret = parse_gpustr(gpuStr, &nvmon_numgpus, &nvmon_gpulist);
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to get nvmon gpulist from '%s', gpuStr);
+        ERROR_PRINT("Failed to get nvmon gpulist from '%s'", gpuStr);
         goto appdaemon_setup_nvmon_cleanup;
     }
 
@@ -174,7 +227,7 @@ static int appdaemon_setup_nvmon(char* gpuStr, char* eventStr)
     nvmon_gids = malloc(nvmon_eventlist->qty * sizeof(int));
     if (!nvmon_gids)
     {
-        ERROR_PRINT(Failed to allocate space for nvmon group IDs);
+        ERROR_PRINT("Failed to allocate space for nvmon group IDs");
         goto appdaemon_setup_nvmon_cleanup;
     }
 
@@ -182,7 +235,7 @@ static int appdaemon_setup_nvmon(char* gpuStr, char* eventStr)
     ret = nvmon_init(nvmon_numgpus, nvmon_gpulist);
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to initialize nvmon);
+        ERROR_PRINT("Failed to initialize nvmon");
         goto appdaemon_setup_nvmon_cleanup;
     }
     nvmon_initialized = 1;
@@ -193,14 +246,14 @@ static int appdaemon_setup_nvmon(char* gpuStr, char* eventStr)
         ret = nvmon_addEventSet(bdata(nvmon_eventlist->entry[i]));
         if (ret < 0)
         {
-            ERROR_PRINT(Failed to add nvmon group: %s, bdata(nvmon_eventlist->entry[i]));
+            ERROR_PRINT("Failed to add nvmon group: %s", bdata(nvmon_eventlist->entry[i]));
             continue;
         }
         nvmon_gids[nvmon_numgids++] = ret;
     }
     if (nvmon_numgids == 0)
     {
-        ERROR_PRINT(Failed to add any events to nvmon);
+        ERROR_PRINT("Failed to add any events to nvmon");
         goto appdaemon_setup_nvmon_cleanup;
     }
 
@@ -208,7 +261,7 @@ static int appdaemon_setup_nvmon(char* gpuStr, char* eventStr)
     ret = nvmon_setupCounters(nvmon_gids[0]);
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to setup nvmon);
+        ERROR_PRINT("Failed to setup nvmon");
         goto appdaemon_setup_nvmon_cleanup;
     }
 
@@ -216,7 +269,7 @@ static int appdaemon_setup_nvmon(char* gpuStr, char* eventStr)
     ret = nvmon_startCounters();
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to start nvmon);
+        ERROR_PRINT("Failed to start nvmon");
         goto appdaemon_setup_nvmon_cleanup;
     }
     return 0;
@@ -252,22 +305,39 @@ static void appdaemon_close_nvmon(void)
     int ret = nvmon_stopCounters();
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to stop nvmon);
+        ERROR_PRINT("Failed to stop nvmon");
     }
 
     // Print results
-    for (int g = 0; g < nvmon_numgids; g++)
+    if (getenv("LIKWID_NVMON_MARKER_FORMAT") == NULL)
     {
-        int gid = nvmon_gids[g];
-        for (int i = 0; i < nvmon_getNumberOfEvents(gid); i++)
+        for (int g = 0; g < nvmon_numgids; g++)
         {
-            for (int j = 0; j < nvmon_numgpus; j++)
+            int gid = nvmon_gids[g];
+            for (int i = 0; i < nvmon_getNumberOfEvents(gid); i++)
             {
-                fprintf(output_file, "Nvmon, %d, %f, %s, %f, %f\n", nvmon_gpulist[j], nvmon_getTimeOfGroup(nvmon_gpulist[j]), nvmon_getEventName(gid, i), nvmon_getResult(gid, i, j), nvmon_getLastResult(gid, i, j));
+                for (int j = 0; j < nvmon_numgpus; j++)
+                {
+                    fprintf(output_file, "Nvmon, %d, %f, %s, %f, %f\n", nvmon_gpulist[j], nvmon_getTimeOfGroup(gid), nvmon_getEventName(gid, i), nvmon_getResult(gid, i, j), nvmon_getLastResult(gid, i, j));
+                }
             }
         }
+        fflush(output_file);
+    } else {
+        appdaemon_output_data data = {
+            .numDevices = nvmon_numgpus,
+            .devices = nvmon_gpulist,
+            .numGroups = nvmon_numgids,
+            .groups = nvmon_gids,
+            .getTime = nvmon_getTimeOfGroup,
+            .getResult = nvmon_getResult,
+            .numEvents = nvmon_getNumberOfEvents,
+        };
+        ret = appdaemon_write_output_file(getenv("LIKWID_NVMON_OUTPUTFILE"), &data);
+        if (ret < 0) {
+            ERROR_PRINT("Failed to write appdaemon data to %s", getenv("LIKWID_NVMON_OUTPUTFILE"));
+        }
     }
-    fflush(output_file);
 
     // Cleanup
     if (nvmon_initialized)
@@ -307,7 +377,7 @@ static void appdaemon_read_nvmon(void)
         {
             for (int j = 0; j < nvmon_numgpus; j++)
             {
-                fprintf(output_file, "Nvmon, %d, %f, %s, %f, %f\n", nvmon_gpulist[j], nvmon_getTimeToLastReadOfGroup(nvmon_gpulist[j]), nvmon_getEventName(gid, i), nvmon_getResult(gid, i, j), nvmon_getLastResult(gid, i, j));
+                fprintf(output_file, "Nvmon, %d, %f, %s, %f, %f\n", nvmon_gpulist[j], nvmon_getTimeToLastReadOfGroup(gid), nvmon_getEventName(gid, i), nvmon_getResult(gid, i, j), nvmon_getLastResult(gid, i, j));
             }
         }
     }
@@ -327,14 +397,14 @@ static int  rocmon_numgids = 0;
 static int appdaemon_setup_rocmon(char* gpuStr, char* eventStr)
 {
     int ret = 0;
-    printf("Rocmon GPU string: %s\n", gpuStr);
-    printf("Rocmon Event string: %s\n", eventStr);
+    ROCMON_DEBUG_PRINT(DEBUGLEV_DEVELOP, "Rocmon GPU string: %s\n", gpuStr);
+    ROCMON_DEBUG_PRINT(DEBUGLEV_DEVELOP, "Rocmon Event string: %s\n", eventStr);
 
     // Parse gpu string
     ret = parse_gpustr(gpuStr, &rocmon_numgpus, &rocmon_gpulist);
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to get rocmon gpulist from '%s', gpuStr);
+        ERROR_PRINT("Failed to get rocmon gpulist from '%s'", gpuStr);
         goto appdaemon_setup_rocmon_cleanup;
     }
 
@@ -345,7 +415,7 @@ static int appdaemon_setup_rocmon(char* gpuStr, char* eventStr)
     rocmon_gids = malloc(rocmon_eventlist->qty * sizeof(int));
     if (!rocmon_gids)
     {
-        ERROR_PRINT(Failed to allocate space for rocmon group IDs);
+        ERROR_PRINT("Failed to allocate space for rocmon group IDs");
         goto appdaemon_setup_rocmon_cleanup;
     }
 
@@ -353,7 +423,7 @@ static int appdaemon_setup_rocmon(char* gpuStr, char* eventStr)
     ret = rocmon_init(rocmon_numgpus, rocmon_gpulist);
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to initialize rocmon);
+        ERROR_PRINT("Failed to initialize rocmon");
         goto appdaemon_setup_rocmon_cleanup;
     }
     rocmon_initialized = 1;
@@ -364,12 +434,12 @@ static int appdaemon_setup_rocmon(char* gpuStr, char* eventStr)
         ret = rocmon_addEventSet(bdata(rocmon_eventlist->entry[i]), &rocmon_gids[rocmon_numgids++]);
         if (ret < 0)
         {
-            ERROR_PRINT(Failed to add rocmon group: %s, bdata(rocmon_eventlist->entry[i]));
+            ERROR_PRINT("Failed to add rocmon group: %s", bdata(rocmon_eventlist->entry[i]));
         }
     }
     if (rocmon_numgids == 0)
     {
-        ERROR_PRINT(Failed to add any events to rocmon);
+        ERROR_PRINT("Failed to add any events to rocmon");
         goto appdaemon_setup_rocmon_cleanup;
     }
 
@@ -377,7 +447,7 @@ static int appdaemon_setup_rocmon(char* gpuStr, char* eventStr)
     ret = rocmon_setupCounters(rocmon_gids[0]);
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to setup rocmon);
+        ERROR_PRINT("Failed to setup rocmon");
         goto appdaemon_setup_rocmon_cleanup;
     }
 
@@ -385,7 +455,7 @@ static int appdaemon_setup_rocmon(char* gpuStr, char* eventStr)
     ret = rocmon_startCounters();
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to start rocmon);
+        ERROR_PRINT("Failed to start rocmon");
         goto appdaemon_setup_rocmon_cleanup;
     }
     return 0;
@@ -421,20 +491,37 @@ static void appdaemon_close_rocmon(void)
     int ret = rocmon_stopCounters();
     if (ret < 0)
     {
-        ERROR_PRINT(Failed to stop rocmon);
+        ERROR_PRINT("Failed to stop rocmon");
     }
 
-    // Print results
-    for (int g = 0; g < rocmon_numgids; g++)
+    if (getenv("LIKWID_ROCMON_MARKER_FORMAT") == NULL)
     {
-        int gid = rocmon_gids[g];
-        for (int i = 0; i < rocmon_getNumberOfEvents(gid); i++)
+        // Print results
+        for (int g = 0; g < rocmon_numgids; g++)
         {
-            for (int j = 0; j < rocmon_numgpus; j++)
+            int gid = rocmon_gids[g];
+            for (int i = 0; i < rocmon_getNumberOfEvents(gid); i++)
             {
-                fprintf(output_file, "Rocmon, %d, %f, %s, %f, %f\n", rocmon_gpulist[j], rocmon_getTimeOfGroup(rocmon_gpulist[j]), rocmon_getEventName(gid, i), rocmon_getResult(j, gid, i), rocmon_getLastResult(j, gid, i));
+                for (int j = 0; j < rocmon_numgpus; j++)
+                {
+                    fprintf(output_file, "Rocmon, %d, %f, %s, %f, %f\n", rocmon_gpulist[j], rocmon_getTimeOfGroup(rocmon_gpulist[j]), rocmon_getEventName(gid, i), rocmon_getResult(j, gid, i), rocmon_getLastResult(j, gid, i));
+                }
             }
         }
+    } else {
+        appdaemon_output_data data = {
+            .numDevices = rocmon_numgpus,
+            .devices = rocmon_gpulist,
+            .numGroups = rocmon_numgids,
+            .groups = rocmon_gids,
+            .getTime = rocmon_getTimeOfGroup,
+            .getResult = rocmon_getResult,
+            .numEvents = rocmon_getNumberOfEvents,
+        };
+        ret = appdaemon_write_output_file(getenv("LIKWID_ROCMON_OUTPUTFILE"), &data);
+        if (ret < 0) {
+            ERROR_PRINT("Failed to write appdaemon data to %s", getenv("LIKWID_ROCMON_OUTPUTFILE"));
+        }
     }
 
     // Cleanup
@@ -483,25 +570,63 @@ static void appdaemon_read_rocmon(void)
 #endif
 
 
+
 /*
 Timeline mode
 */
 static void* appdaemon_timeline_main(void* arg)
 {
+    int ret = 0;
     int stop = 0;
     int target_delay_ms = *((int*)arg);
-    ;
 
-    while (1)
+#ifdef LIKWID_NVMON
+    char* nvEventStr = getenv("LIKWID_NVMON_EVENTS");
+    char* nvGpuStr = getenv("LIKWID_NVMON_GPUS");
+    if (nvEventStr && nvGpuStr)
     {
-        usleep(target_delay_ms * 1E3);
+        char *nvVerbosity = getenv("LIKWID_NVMON_VERBOSITY");
+        if (nvVerbosity) {
+            likwid_nvmon_verbosity = atoi(nvVerbosity);
+            nvmon_setVerbosity(likwid_nvmon_verbosity);
+            GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "Setting verbosity to %d", likwid_nvmon_verbosity);
+        }
+        ret = appdaemon_setup_nvmon(nvGpuStr, nvEventStr);
+        if (!ret)
+        {
+            appdaemon_register_exit(appdaemon_close_nvmon);
+        } else {
+            fprintf(stderr, "Failed to setup NVMON: %d\n", ret);
+        }
+    }
+    printf("NVMON initialized\n");
+    GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "NVMON initialized");
+#endif
+
+#ifdef LIKWID_ROCMON
+    char* rocmonEventStr = getenv("LIKWID_ROCMON_EVENTS");
+    char* rocmonGpuStr = getenv("LIKWID_ROCMON_GPUS");
+    if (rocmonEventStr && rocmonGpuStr)
+    {
+        ret = appdaemon_setup_rocmon(rocmonGpuStr, rocmonEventStr);
+        if (!ret)
+        {
+            appdaemon_register_exit(appdaemon_close_rocmon);
+        }
+    }
+#endif
+
+    while (stop == 0)
+    {
+        printf("Thread sleeps for %d ms\n", target_delay_ms);
+        usleep(target_delay_ms / 1000);
 
         // Check stop status
         pthread_mutex_lock(&stopMutex);
         stop = stopIssued;
         pthread_mutex_unlock(&stopMutex);
         if (stop > 0) break;
-        
+        printf("Thread Reads\n");
 #ifdef LIKWID_NVMON
         appdaemon_read_nvmon();
 #endif
@@ -509,6 +634,13 @@ static void* appdaemon_timeline_main(void* arg)
         appdaemon_read_rocmon();
 #endif
     }
+
+#ifdef LIKWID_NVMON
+    appdaemon_close_nvmon();
+#endif
+#ifdef LIKWID_ROCMON
+    appdaemon_close_rocmon();
+#endif
 }
 
 
@@ -542,11 +674,13 @@ int __libc_start_main(int (*main) (int,char **,char **),
     // Get timeline mode info
     char* timelineStr = getenv("LIKWID_INTERVAL");
     int timelineInterval = -1; // in ms
+    int gotTimelineInterval = 0;
     if (timelineStr != NULL)
     {
         timelineInterval = atoi(timelineStr);
+        gotTimelineInterval = 1;
     }
-    if (timelineInterval == 0)
+    if (gotTimelineInterval && timelineInterval <= 0)
     {
         fprintf(stderr, "Invalid timeline interval\n");
         return -1;
@@ -567,37 +701,16 @@ int __libc_start_main(int (*main) (int,char **,char **),
         fprintf(stderr, "%s", strerror(errno));
         return -1;
     }
-    fprintf(output_file, "Backend, GPU, Time, Event, Full Value, Last Value\n");
-
-#ifdef LIKWID_NVMON
-    char* nvEventStr = getenv("LIKWID_NVMON_EVENTS");
-    char* nvGpuStr = getenv("LIKWID_NVMON_GPUS");
-    if (nvEventStr && nvGpuStr)
-    {
-        ret = appdaemon_setup_nvmon(nvGpuStr, nvEventStr);
-        if (!ret)
-        {
-            appdaemon_register_exit(appdaemon_close_nvmon);
-        }
+    if ((getenv("LIKWID_NVMON_MARKER_FORMAT") == NULL) && (getenv("LIKWID_ROCMON_MARKER_FORMAT") == NULL)) {
+        fprintf(output_file, "Backend, GPU, Time, Event, Full Value, Last Value\n");
     }
-#endif
 
-#ifdef LIKWID_ROCMON
-    char* rocmonEventStr = getenv("LIKWID_ROCMON_EVENTS");
-    char* rocmonGpuStr = getenv("LIKWID_ROCMON_GPUS");
-    if (rocmonEventStr && rocmonGpuStr)
-    {
-        ret = appdaemon_setup_rocmon(rocmonGpuStr, rocmonEventStr);
-        if (!ret)
-        {
-            appdaemon_register_exit(appdaemon_close_rocmon);
-        }
-    }
-#endif
+
 
     // Start timeline thread
-    if (timelineInterval >= 0)
+    if (timelineInterval > 0)
     {
+        //printf("Start thread with interval %d\n", timelineInterval);
         pthread_t tid;
         ret = pthread_create(&tid, NULL, &appdaemon_timeline_main, &timelineInterval);
         if (ret < 0)
@@ -605,6 +718,42 @@ int __libc_start_main(int (*main) (int,char **,char **),
             fprintf(stderr, "Failed to create timeline thread\n");
             return -1;
         }
+    } else {
+#ifdef LIKWID_NVMON
+        char* nvEventStr = getenv("LIKWID_NVMON_EVENTS");
+        char* nvGpuStr = getenv("LIKWID_NVMON_GPUS");
+        if (nvEventStr && nvGpuStr)
+        {
+            char *nvVerbosity = getenv("LIKWID_NVMON_VERBOSITY");
+            if (nvVerbosity) {
+                likwid_nvmon_verbosity = atoi(nvVerbosity);
+                nvmon_setVerbosity(likwid_nvmon_verbosity);
+                GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "Setting verbosity to %d", likwid_nvmon_verbosity);
+            }
+            ret = appdaemon_setup_nvmon(nvGpuStr, nvEventStr);
+            if (!ret)
+            {
+                appdaemon_register_exit(appdaemon_close_nvmon);
+            }
+        }
+#endif
+
+#ifdef LIKWID_ROCMON
+        char* rocmonEventStr = getenv("LIKWID_ROCMON_EVENTS");
+        char* rocmonGpuStr = getenv("LIKWID_ROCMON_GPUS");
+        if (rocmonEventStr && rocmonGpuStr)
+        {
+            char *rocmomVerbosity = getenv("LIKWID_ROCMON_VERBOSITY");
+            if (rocmomVerbosity) {
+                rocmon_setVerbosity(atoi(rocmomVerbosity));
+            }
+            ret = appdaemon_setup_rocmon(rocmonGpuStr, rocmonEventStr);
+            if (!ret)
+            {
+                appdaemon_register_exit(appdaemon_close_rocmon);
+            }
+        }
+#endif
     }
 
     return original__libc_start_main(main,argc,ubp_av,
