@@ -5,13 +5,13 @@
  *
  *      Description:  Interface for the different register access modules.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -43,6 +43,7 @@
 #include <sys/un.h>
 #include <pthread.h>
 
+#include <lw_alloc.h>
 #include <types.h>
 #include <error.h>
 #include <topology.h>
@@ -52,17 +53,18 @@
 #include <access.h>
 #include <access_client.h>
 #include <access_x86.h>
+#include <lock.h>
 
 
 /* #####   VARIABLES  -  LOCAL TO THIS SOURCE FILE   ###################### */
 
 static int registeredCpus = 0;
 static int *registeredCpuList = NULL;
-static int (*access_read)(PciDeviceIndex dev, const int cpu, uint32_t reg, uint64_t *data) = NULL;
-static int (*access_write)(PciDeviceIndex dev, const int cpu, uint32_t reg, uint64_t data) = NULL;
-static int (*access_init) (int cpu_id) = NULL;
-static void (*access_finalize) (int cpu_id) = NULL;
-static int (*access_check) (PciDeviceIndex dev, int cpu_id) = NULL;
+static int (*access_read)(PciDeviceIndex dev, uint32_t cpu, uint32_t reg, uint64_t *data) = NULL;
+static int (*access_write)(PciDeviceIndex dev, uint32_t cpu, uint32_t reg, uint64_t data) = NULL;
+static int (*access_init) (uint32_t cpu_id) = NULL;
+static void (*access_finalize) (uint32_t cpu_id) = NULL;
+static int (*access_check) (PciDeviceIndex dev, uint32_t cpu_id) = NULL;
 
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
@@ -79,38 +81,57 @@ int
 HPMinit(void)
 {
     int ret = 0;
-    topology_init();
+    Configuration_t config = NULL;
+    ret = topology_init();
+    if (ret < 0)
+    {
+        errno = -ret;
+        ERROR_PRINT("Failed to initialize topology");
+        return ret;
+    }
+    ret = init_configuration();
+    if (ret < 0)
+    {
+        errno = -ret;
+        ERROR_PRINT("Failed to initialize configuration");
+        return ret;
+    }
+    config = get_configuration();
     if (registeredCpuList == NULL)
     {
-        registeredCpuList = malloc(cpuid_topology.numHWThreads* sizeof(int));
+        registeredCpuList = lw_malloc(cpuid_topology.numHWThreads* sizeof(int));
         memset(registeredCpuList, 0, cpuid_topology.numHWThreads* sizeof(int));
         registeredCpus = 0;
     }
     if (access_init == NULL)
     {
 #if defined(__x86_64__) || defined(__i386__)
-        if (config.daemonMode == -1)
+        if (config->daemonMode == -2)
         {
-            config.daemonMode = ACCESSMODE_DAEMON;
+            config->daemonMode = ACCESSMODE_DAEMON;
         }
-        if (config.daemonMode == ACCESSMODE_DAEMON)
+        if (config->daemonMode == ACCESSMODE_DAEMON)
         {
-            DEBUG_PLAIN_PRINT(DEBUGLEV_DEVELOP, Adjusting functions for x86 architecture in daemon mode);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Adjusting functions for x86 architecture in daemon mode");
             access_init = &access_client_init;
             access_read = &access_client_read;
             access_write = &access_client_write;
             access_finalize = &access_client_finalize;
             access_check = &access_client_check;
         }
-        else if (config.daemonMode == ACCESSMODE_DIRECT)
+        else if (config->daemonMode == ACCESSMODE_DIRECT)
         {
-            DEBUG_PLAIN_PRINT(DEBUGLEV_DEVELOP, Adjusting functions for x86 architecture in direct mode);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Adjusting functions for x86 architecture in direct mode");
             access_init = &access_x86_init;
             access_read = &access_x86_read;
             access_write = &access_x86_write;
             access_finalize = &access_x86_finalize;
             access_check = &access_x86_check;
         }
+        else
+        {
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "HPMinit called in perf_event mode");
+        }
 #endif
     }
 
@@ -124,12 +145,12 @@ HPMinitialized(void)
 }
 
 int
-HPMaddThread(int cpu_id)
+HPMaddThread(uint32_t cpu_id)
 {
     int ret;
     if (registeredCpuList == NULL)
     {
-        registeredCpuList = malloc(cpuid_topology.numHWThreads* sizeof(int));
+        registeredCpuList = lw_malloc(cpuid_topology.numHWThreads* sizeof(int));
         memset(registeredCpuList, 0, cpuid_topology.numHWThreads* sizeof(int));
         registeredCpus = 0;
     }
@@ -140,7 +161,7 @@ HPMaddThread(int cpu_id)
             ret = access_init(cpu_id);
             if (ret == 0)
             {
-                DEBUG_PRINT(DEBUGLEV_DETAIL, Adding CPU %d to access module, cpu_id);
+                DEBUG_PRINT(DEBUGLEV_DETAIL, "Adding CPU %d to access module", cpu_id);
                 registeredCpus++;
                 registeredCpuList[cpu_id] = 1;
             }
@@ -158,16 +179,16 @@ HPMaddThread(int cpu_id)
 }
 
 void
-HPMfinalize()
+HPMfinalize(void)
 {
     topology_init();
     if (registeredCpuList)
     {
-        for (int i = 0; i < cpuid_topology.numHWThreads && registeredCpus > 0; i++)
+        for (uint32_t i = 0; i < cpuid_topology.numHWThreads && registeredCpus > 0; i++)
         {
             if (registeredCpuList[i] == 1)
             {
-                DEBUG_PRINT(DEBUGLEV_DETAIL, Removing CPU %d from access module, i);
+                DEBUG_PRINT(DEBUGLEV_DETAIL, "Removing CPU %d from access module", i);
                 access_finalize(i);
                 registeredCpus--;
                 registeredCpuList[i] = 0;
@@ -191,7 +212,7 @@ HPMfinalize()
 }
 
 int
-HPMread(int cpu_id, PciDeviceIndex dev, uint32_t reg, uint64_t* data)
+HPMread(uint32_t cpu_id, PciDeviceIndex dev, uint32_t reg, uint64_t* data)
 {
     uint64_t tmp = 0x0ULL;
     *data = 0x0ULL;
@@ -200,7 +221,7 @@ HPMread(int cpu_id, PciDeviceIndex dev, uint32_t reg, uint64_t* data)
     {
         return -EFAULT;
     }
-    if ((cpu_id < 0) || (cpu_id >= cpuid_topology.numHWThreads))
+    if ((cpu_id >= cpuid_topology.numHWThreads))
     {
         return -ERANGE;
     }
@@ -214,16 +235,16 @@ HPMread(int cpu_id, PciDeviceIndex dev, uint32_t reg, uint64_t* data)
 }
 
 int
-HPMwrite(int cpu_id, PciDeviceIndex dev, uint32_t reg, uint64_t data)
+HPMwrite(uint32_t cpu_id, PciDeviceIndex dev, uint32_t reg, uint64_t data)
 {
     int err = 0;
     if (dev >= MAX_NUM_PCI_DEVICES)
     {
         return -EFAULT;
     }
-    if ((cpu_id < 0) || (cpu_id >= cpuid_topology.numHWThreads))
+    if ((cpu_id >= cpuid_topology.numHWThreads))
     {
-        ERROR_PRINT(MSR WRITE C %d OUT OF RANGE, cpu_id);
+        ERROR_PRINT("MSR WRITE C %d OUT OF RANGE", cpu_id);
         return -ERANGE;
     }
     if (registeredCpuList[cpu_id] == 0)
@@ -235,7 +256,7 @@ HPMwrite(int cpu_id, PciDeviceIndex dev, uint32_t reg, uint64_t data)
 }
 
 int
-HPMcheck(PciDeviceIndex dev, int cpu_id)
+HPMcheck(PciDeviceIndex dev, uint32_t cpu_id)
 {
     if ((registeredCpuList[cpu_id] == 0) || (!access_check))
     {
