@@ -5,13 +5,13 @@
  *
  *      Description:  Interface to the access daemon for the access module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -52,6 +52,8 @@
 #include <access_client.h>
 #include <configuration.h>
 #include <affinity.h>
+#include <lock.h>
+#include <lw_alloc.h>
 
 #if defined(__x86_64__) || defined(__i386__)
 #include <access_x86_rdpmc.h>
@@ -74,7 +76,7 @@ static pthread_mutex_t *cpuLocks = NULL;
 /* #####   FUNCTION DEFINITIONS  -  LOCAL TO THIS SOURCE FILE   ########### */
 void __attribute__((destructor (104))) close_access_client(void);
 
-static char*
+static const char*
 access_client_strerror(AccessErrorType det)
 {
     switch (det)
@@ -107,28 +109,32 @@ access_client_errno(AccessErrorType det)
     }
 }
 
-static void access_client_signal_catcher(int sig) {
-    close_access_client();
-}
+// TODO do we still need these functions?
+// When I commented this out, they were not used anywhere.
+//
+//static void access_client_signal_catcher(int sig) {
+//    (void)sig;
+//    close_access_client();
+//}
+//
+//static int
+//access_client_catch_signal()
+//{
+//    struct sigaction sia;
+//    sia.sa_handler = access_client_signal_catcher;
+//    sigemptyset(&sia.sa_mask);
+//    sia.sa_flags = SA_ONSTACK;
+//    sigaction(SIGCHLD, &sia, NULL);
+//    return 0;
+//}
 
 static int
-access_client_catch_signal()
-{
-    struct sigaction sia;
-    sia.sa_handler = access_client_signal_catcher;
-    sigemptyset(&sia.sa_mask);
-    sia.sa_flags = SA_ONSTACK;
-    sigaction(SIGCHLD, &sia, NULL);
-    return 0;
-}
-
-static int
-access_client_startDaemon_direct(int cpu_id, struct sockaddr_un *address)
+access_client_startDaemon_direct(uint32_t cpu_id, struct sockaddr_un *address)
 {
     /* Check the function of the daemon here */
     char *newargv[] = { NULL };
     char *newenv[] = { NULL };
-    char *safeexeprog = TOSTRING(ACCESSDAEMON);
+    const char *safeexeprog = TOSTRING(ACCESSDAEMON);
     char exeprog[1024];
     int  ret;
     pid_t pid;
@@ -144,10 +150,10 @@ access_client_startDaemon_direct(int cpu_id, struct sockaddr_un *address)
 
     if (access(exeprog, X_OK))
     {
-        ERROR_PRINT(Failed to find the daemon '%s'\n, exeprog);
+        ERROR_PRINT("Failed to find the daemon '%s'\n", exeprog);
         return -1;
     }
-    DEBUG_PRINT(DEBUGLEV_INFO, Starting daemon %s, exeprog);
+    DEBUG_PRINT(DEBUGLEV_INFO, "Starting daemon %s", exeprog);
     pid = fork();
 
     if (pid == 0)
@@ -166,13 +172,13 @@ access_client_startDaemon_direct(int cpu_id, struct sockaddr_un *address)
         if (ret < 0)
         {
             //ERRNO_PRINT;
-            ERROR_PRINT(Failed to execute the daemon '%s'\n, exeprog);
+            ERROR_PRINT("Failed to execute the daemon '%s'\n", exeprog);
             return ret;
         }
     }
     else if (pid < 0)
     {
-        ERROR_PRINT(Failed to fork access daemon for CPU %d, cpu_id);
+        ERROR_PRINT("Failed to fork access daemon for CPU %d", cpu_id);
         return pid;
     }
 
@@ -185,7 +191,7 @@ access_client_startDaemon_direct(int cpu_id, struct sockaddr_un *address)
 }
 
 static int
-access_client_startDaemon_bridge(int cpu_id, const char *bridge_path, struct sockaddr_un *daemon_address) {
+access_client_startDaemon_bridge(uint32_t cpu_id, const char *bridge_path, struct sockaddr_un *daemon_address) {
     struct sockaddr_un bridge_address;
     int socket_fd = -1;
     int address_length;
@@ -202,13 +208,13 @@ access_client_startDaemon_bridge(int cpu_id, const char *bridge_path, struct soc
     socket_fd = socket(AF_LOCAL, SOCK_STREAM, 0);
     if (socket_fd < 0)
     {
-        ERROR_PRINT(socket() failed);
+        ERROR_PRINT("socket() failed");
         return -1;
     }
 
     address_length = sizeof(struct sockaddr_un);
-    filepath = strdup(bridge_address.sun_path);
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Waiting for bridge socket file %s, bridge_address.sun_path);
+    filepath = lw_strdup(bridge_address.sun_path);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Waiting for bridge socket file %s", bridge_address.sun_path);
     while (access(bridge_address.sun_path, F_OK) && timeout > 0)
     {
         usleep(2500);
@@ -216,7 +222,7 @@ access_client_startDaemon_bridge(int cpu_id, const char *bridge_path, struct soc
     }
     if (!access(bridge_address.sun_path, F_OK))
     {
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Bridge socket file %s exists, bridge_address.sun_path);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Bridge socket file %s exists", bridge_address.sun_path);
     }
     timeout = 1000;
 
@@ -232,7 +238,7 @@ access_client_startDaemon_bridge(int cpu_id, const char *bridge_path, struct soc
         }
 
         timeout--;
-        DEBUG_PRINT(DEBUGLEV_INFO, Still waiting for bridge socket %s for CPU %d..., filepath, cpu_id);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Still waiting for bridge socket %s for CPU %d...", filepath, cpu_id);
     }
 
     if (timeout <= 0)
@@ -247,7 +253,7 @@ access_client_startDaemon_bridge(int cpu_id, const char *bridge_path, struct soc
         close(socket_fd);
         return -1;
     }
-    DEBUG_PRINT(DEBUGLEV_INFO, Successfully opened bridge socket %s to daemon for CPU %d, filepath, cpu_id);
+    DEBUG_PRINT(DEBUGLEV_INFO, "Successfully opened bridge socket %s to daemon for CPU %d", filepath, cpu_id);
     free(filepath);
 
     // request socket creation via the connected bridge
@@ -255,7 +261,7 @@ access_client_startDaemon_bridge(int cpu_id, const char *bridge_path, struct soc
     io_count = send(socket_fd, (char*) &io_buf, sizeof(io_buf), 0);
 
     if (io_count != sizeof(io_buf)) {
-        ERROR_PRINT(Failed to send msg to the bridge socket)
+        ERROR_PRINT("Failed to send msg to the bridge socket");
         close(socket_fd);
         return -1;
     }
@@ -263,7 +269,7 @@ access_client_startDaemon_bridge(int cpu_id, const char *bridge_path, struct soc
     io_count = recv(socket_fd, (char*) &io_buf, sizeof(io_buf), 0);
 
     if (io_count != sizeof(io_buf)) {
-        ERROR_PRINT(Failed to recv msg from the bridge socket)
+        ERROR_PRINT("Failed to recv msg from the bridge socket");
         close(socket_fd);
         return -1;
     }
@@ -278,7 +284,7 @@ access_client_startDaemon_bridge(int cpu_id, const char *bridge_path, struct soc
 }
 
 static int
-access_client_daemon_connect(int cpu_id, struct sockaddr_un *address) {
+access_client_daemon_connect(uint32_t cpu_id, struct sockaddr_un *address) {
     int res = 0;
     char* filepath;
     size_t address_length;
@@ -288,13 +294,13 @@ access_client_daemon_connect(int cpu_id, struct sockaddr_un *address) {
     socket_fd = socket(AF_LOCAL, SOCK_STREAM, 0);
     if (socket_fd < 0)
     {
-        ERROR_PRINT(socket() failed);
+        ERROR_PRINT("socket() failed");
         return -1;
     }
 
     address_length = sizeof(struct sockaddr_un);
-    filepath = strdup(address->sun_path);
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Waiting for socket file %s, address->sun_path);
+    filepath = lw_strdup(address->sun_path);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Waiting for socket file %s", address->sun_path);
     while (access(address->sun_path, F_OK) && timeout > 0)
     {
         usleep(2500);
@@ -302,7 +308,7 @@ access_client_daemon_connect(int cpu_id, struct sockaddr_un *address) {
     }
     if (!access(address->sun_path, F_OK))
     {
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Socket file %s exists, address->sun_path);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Socket file %s exists", address->sun_path);
     }
     timeout = 1000;
 
@@ -318,7 +324,7 @@ access_client_daemon_connect(int cpu_id, struct sockaddr_un *address) {
         }
 
         timeout--;
-        DEBUG_PRINT(DEBUGLEV_INFO, Still waiting for socket %s for CPU %d..., filepath, cpu_id);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Still waiting for socket %s for CPU %d...", filepath, cpu_id);
     }
 
     if (timeout <= 0)
@@ -328,17 +334,18 @@ access_client_daemon_connect(int cpu_id, struct sockaddr_un *address) {
         fprintf(stderr, "opened within 10 seconds. Consult the error message above\n");
         fprintf(stderr, "this to find out why. If the error is 'no such file or directoy',\n");
         fprintf(stderr, "it usually means that likwid-accessD just failed to start.\n");
+        fprintf(stderr, "likwid-accessD prints only to syslog. Check there for details\n");
         free(filepath);
         close(socket_fd);
         return -1;
     }
-    DEBUG_PRINT(DEBUGLEV_INFO, Successfully opened socket %s to daemon for CPU %d, filepath, cpu_id);
+    DEBUG_PRINT(DEBUGLEV_INFO, "Successfully opened socket %s to daemon for CPU %d", filepath, cpu_id);
     free(filepath);
     return socket_fd;
 }
 
 static int
-access_client_startDaemon(int cpu_id) {
+access_client_startDaemon(uint32_t cpu_id) {
     const char *bridge_path;
     struct sockaddr_un address;
     int daemon_ret_code;
@@ -363,33 +370,45 @@ access_client_startDaemon(int cpu_id) {
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
 int
-access_client_init(int cpu_id)
+access_client_init(uint32_t cpu_id)
 {
+    if (!lock_check())
+    {
+        ERROR_PRINT("Access to performance monitoring registers locked");
+        return -EPERM;
+    }
     topology_init();
     numa_init();
     affinity_init();
     if (!cpuSockets)
     {
-        cpuSockets = malloc(cpuid_topology.numHWThreads * sizeof(int));
+        cpuSockets = lw_malloc(cpuid_topology.numHWThreads * sizeof(int));
         memset(cpuSockets, -1, cpuid_topology.numHWThreads * sizeof(int));
     }
     if (!daemon_pids)
     {
-        daemon_pids = malloc(cpuid_topology.numHWThreads * sizeof(int));
+        daemon_pids = lw_malloc(cpuid_topology.numHWThreads * sizeof(int));
         memset(daemon_pids, 0, cpuid_topology.numHWThreads * sizeof(int));
-        daemon_pinned = malloc(cpuid_topology.numHWThreads * sizeof(int));
+        daemon_pinned = lw_malloc(cpuid_topology.numHWThreads * sizeof(int));
         memset(daemon_pinned, 0, cpuid_topology.numHWThreads * sizeof(int));
     }
     if (!cpuLocks)
     {
-        cpuLocks = malloc(cpuid_topology.numHWThreads * sizeof(pthread_mutex_t));
-        for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+        cpuLocks = lw_malloc(cpuid_topology.numHWThreads * sizeof(pthread_mutex_t));
+        for (unsigned i = 0; i < cpuid_topology.numHWThreads; i++)
         {
             pthread_mutex_init(&cpuLocks[i], NULL);
         }
     }
 #if defined(__x86_64__) || defined(__i386__)
-    access_x86_rdpmc_init(cpu_id);
+    if (getenv("LIKWID_NO_RDPMC") == NULL)
+    {
+        access_x86_rdpmc_init(cpu_id);
+    }
+    else
+    {
+        DEBUG_PRINT(DEBUGLEV_INFO, "No initialization of RDPMC access module");
+    }
 #endif
     if (masterPid != 0 && gettid() == masterPid)
     {
@@ -401,7 +420,7 @@ access_client_init(int cpu_id)
         cpuSockets[cpu_id] = access_client_startDaemon(cpu_id);
         if (cpuSockets[cpu_id] < 0)
         {
-            //ERROR_PRINT(Start of access daemon failed for CPU %d, cpu_id);
+            //ERROR_PRINT("Start of access daemon failed for CPU %d", cpu_id);
             pthread_mutex_unlock(&cpuLocks[cpu_id]);
             return cpuSockets[cpu_id];
         }
@@ -420,9 +439,8 @@ access_client_init(int cpu_id)
 }
 
 int
-access_client_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t *data)
+access_client_read(PciDeviceIndex dev, uint32_t cpu_id, uint32_t reg, uint64_t *data)
 {
-    int ret;
     int socket = globalSocket;
     pthread_mutex_t* lockptr = &globalLock;
     AccessDataRecord record;
@@ -446,7 +464,7 @@ access_client_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
             cpu_set_t cpuset;
             CPU_ZERO(&cpuset);
             CPU_SET(cpu_id, &cpuset);
-            DEBUG_PRINT(DEBUGLEV_INFO, Pinning daemon %d to CPU %d, daemon_pids[cpu_id], cpu_id);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Pinning daemon %d to CPU %d", daemon_pids[cpu_id], cpu_id);
             sched_setaffinity(daemon_pids[cpu_id], sizeof(cpu_set_t), &cpuset);
             daemon_pinned[cpu_id] = 1;
         }
@@ -458,7 +476,7 @@ access_client_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
         cpu_set_t cpuset;
         CPU_ZERO(&cpuset);
         CPU_SET(cpu_id, &cpuset);
-        DEBUG_PRINT(DEBUGLEV_INFO, Pinning master daemon %d to CPU %d, daemon_pids[cpu_id], cpu_id);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Pinning master daemon %d to CPU %d", daemon_pids[cpu_id], cpu_id);
         sched_setaffinity(daemon_pids[cpu_id], sizeof(cpu_set_t), &cpuset);
         daemon_pinned[cpu_id] = 1;
     }
@@ -487,8 +505,8 @@ access_client_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
         record.type = DAEMON_READ;
 
         pthread_mutex_lock(lockptr);
-        CHECK_ERROR(write(socket, &record, sizeof(AccessDataRecord)), socket write failed);
-        CHECK_ERROR(read(socket, &record, sizeof(AccessDataRecord)), socket read failed);
+        CHECK_ERROR(write(socket, &record, sizeof(AccessDataRecord)), "socket write failed");
+        CHECK_ERROR(read(socket, &record, sizeof(AccessDataRecord)), "socket read failed");
         *data = record.data;
         pthread_mutex_unlock(lockptr);
 
@@ -496,12 +514,12 @@ access_client_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
         {
             if (dev == MSR_DEV)
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Got error '%s' from access daemon reading reg 0x%X at CPU %d,
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Got error '%s' from access daemon reading reg 0x%X at CPU %d",
                             access_client_strerror(record.errorcode), reg, record.cpu);
             }
             else
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Got error '%s' from access daemon reading reg 0x%X on socket %d,
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Got error '%s' from access daemon reading reg 0x%X on socket %d",
                             access_client_strerror(record.errorcode), reg, record.cpu);
             }
             *data = 0;
@@ -517,10 +535,9 @@ access_client_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
 }
 
 int
-access_client_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t data)
+access_client_write(PciDeviceIndex dev, uint32_t cpu_id, uint32_t reg, uint64_t data)
 {
     int socket = globalSocket;
-    int ret;
     AccessDataRecord record;
     memset(&record, 0, sizeof(AccessDataRecord));
     record.cpu = cpu_id;
@@ -543,7 +560,7 @@ access_client_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
             cpu_set_t cpuset;
             CPU_ZERO(&cpuset);
             CPU_SET(cpu_id, &cpuset);
-            DEBUG_PRINT(DEBUGLEV_INFO, Pinning daemon %d to CPU %d, daemon_pids[cpu_id], cpu_id);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Pinning daemon %d to CPU %d", daemon_pids[cpu_id], cpu_id);
             sched_setaffinity(daemon_pids[cpu_id], sizeof(cpu_set_t), &cpuset);
             daemon_pinned[cpu_id] = 1;
         }
@@ -555,7 +572,7 @@ access_client_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
         cpu_set_t cpuset;
         CPU_ZERO(&cpuset);
         CPU_SET(cpu_id, &cpuset);
-        DEBUG_PRINT(DEBUGLEV_INFO, Pinning master daemon %d to CPU %d, daemon_pids[cpu_id], cpu_id);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Pinning master daemon %d to CPU %d", daemon_pids[cpu_id], cpu_id);
         sched_setaffinity(daemon_pids[cpu_id], sizeof(cpu_set_t), &cpuset);
         daemon_pinned[cpu_id] = 1;
     }
@@ -578,20 +595,20 @@ access_client_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
         record.type = DAEMON_WRITE;
 
         pthread_mutex_lock(lockptr);
-        CHECK_ERROR(write(socket, &record, sizeof(AccessDataRecord)), socket write failed);
-        CHECK_ERROR(read(socket, &record, sizeof(AccessDataRecord)), socket read failed);
+        CHECK_ERROR(write(socket, &record, sizeof(AccessDataRecord)), "socket write failed");
+        CHECK_ERROR(read(socket, &record, sizeof(AccessDataRecord)), "socket read failed");
         pthread_mutex_unlock(lockptr);
 
         if (record.errorcode != ERR_NOERROR)
         {
             if (dev == MSR_DEV)
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Got error '%s' from access daemon writing reg 0x%X at CPU %d,
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Got error '%s' from access daemon writing reg 0x%X at CPU %d",
                             access_client_strerror(record.errorcode), reg, record.cpu);
             }
             else
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Got error '%s' from access daemon writing reg 0x%X on socket %d,
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Got error '%s' from access daemon writing reg 0x%X on socket %d",
                             access_client_strerror(record.errorcode), reg, record.cpu);
             }
             return access_client_errno(record.errorcode);
@@ -605,7 +622,7 @@ access_client_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
 }
 
 void
-access_client_finalize(int cpu_id)
+access_client_finalize(uint32_t cpu_id)
 {
     AccessDataRecord record;
     if (cpuSockets && cpuSockets[cpu_id] > 0)
@@ -613,12 +630,12 @@ access_client_finalize(int cpu_id)
         memset(&record, 0, sizeof(AccessDataRecord));
         record.type = DAEMON_EXIT;
         record.cpu = cpu_id;
-        CHECK_ERROR(write(cpuSockets[cpu_id], &record, sizeof(AccessDataRecord)),socket write failed);
+        CHECK_ERROR(write(cpuSockets[cpu_id], &record, sizeof(AccessDataRecord)), "socket write failed");
         if (cpuSockets[cpu_id] == globalSocket)
         {
             globalSocket = -1;
         }
-        CHECK_ERROR(close(cpuSockets[cpu_id]),socket close failed);
+        CHECK_ERROR(close(cpuSockets[cpu_id]), "socket close failed");
         cpuSockets[cpu_id] = -1;
         if (daemon_pids[cpu_id] != 0)
         {
@@ -641,7 +658,7 @@ access_client_finalize(int cpu_id)
 }
 
 int
-access_client_check(PciDeviceIndex dev, int cpu_id)
+access_client_check(PciDeviceIndex dev, uint32_t cpu_id)
 {
     int socket = globalSocket;
     pthread_mutex_t* lockptr = &globalLock;
@@ -664,8 +681,8 @@ access_client_check(PciDeviceIndex dev, int cpu_id)
     if ((cpuSockets[cpu_id] > 0) || ((cpuSockets_open == 1) && (globalSocket > 0)))
     {
         pthread_mutex_lock(lockptr);
-        CHECK_ERROR(write(socket, &record, sizeof(AccessDataRecord)), socket write failed);
-        CHECK_ERROR(read(socket, &record, sizeof(AccessDataRecord)), socket read failed);
+        CHECK_ERROR(write(socket, &record, sizeof(AccessDataRecord)), "socket write failed");
+        CHECK_ERROR(read(socket, &record, sizeof(AccessDataRecord)), "socket read failed");
         pthread_mutex_unlock(lockptr);
         if (record.errorcode == ERR_NOERROR )
         {
@@ -675,12 +692,12 @@ access_client_check(PciDeviceIndex dev, int cpu_id)
         {
             if (dev == MSR_DEV)
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Device check for dev %d on CPU %d with accessDaemon failed,
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Device check for dev %d on CPU %d with accessDaemon failed: %s",
                             dev, record.cpu, access_client_strerror(record.errorcode));
             }
             else
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Device check for dev %d on socket %d with accessDaemon failed,
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Device check for dev %d on socket %d with accessDaemon failed: %s",
                             dev, record.cpu, access_client_strerror(record.errorcode));
             }
         }
@@ -692,7 +709,7 @@ void __attribute__((destructor (104))) close_access_client(void)
 {
     if (cpuSockets)
     {
-        for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+        for (unsigned i = 0; i < cpuid_topology.numHWThreads; i++)
         {
             if (cpuSockets[i] > 0)
             {
@@ -707,7 +724,7 @@ void __attribute__((destructor (104))) close_access_client(void)
     }
     if (daemon_pids)
     {
-        for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+        for (unsigned i = 0; i < cpuid_topology.numHWThreads; i++)
         {
             if (daemon_pids[i] != 0)
             {
@@ -725,7 +742,7 @@ void __attribute__((destructor (104))) close_access_client(void)
     }
     if (cpuLocks)
     {
-        for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+        for (unsigned i = 0; i < cpuid_topology.numHWThreads; i++)
         {
             pthread_mutex_destroy(&cpuLocks[i]);
         }
