@@ -5,13 +5,13 @@
  *
  *      Description:  Interface to x86 related functions for the access module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -50,45 +50,60 @@
 #include <access_x86_translate.h>
 #include <affinity.h>
 
-#define ARCH_SPR_GNR_SRF ((cpuid_info.family == P6_FAMILY) && (cpuid_info.model == SAPPHIRERAPIDS || cpuid_info.model == GRANITERAPIDS || cpuid_info.model == SIERRAFORREST))
+#define ARCH_SPR_GNR_SRF ((cpuid_info.family == P6_FAMILY) && (cpuid_info.model == SAPPHIRERAPIDS || cpuid_info.model == GRANITERAPIDS || cpuid_info.model == SIERRAFORREST || cpuid_info.model == EMERALDRAPIDS))
 
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
 int
-access_x86_init(int cpu_id)
+access_x86_init(uint32_t cpu_id)
 {
     int ret = access_x86_msr_init(cpu_id);
     if (ret == 0)
     {
         if (cpuid_info.supportUncore)
         {
-            if (!(ARCH_SPR_GNR_SRF))
+            if (cpuid_info.family == P6_FAMILY)
             {
-                ret = access_x86_pci_init(affinity_thread2socket_lookup[cpu_id]);
-            }
-            if ((cpuid_info.family == P6_FAMILY) && ((cpuid_info.model == ICELAKEX1) || (cpuid_info.model == ICELAKEX2)))
-            {
-                ret = access_x86_mmio_init(affinity_thread2socket_lookup[cpu_id]);
-                if (ret < 0)
+                if ((cpuid_info.model == ICELAKEX1) || (cpuid_info.model == ICELAKEX2))
                 {
-                    ERROR_PRINT(Initialization of MMIO access failed);
+                    ret = access_x86_mmio_init(affinity_thread2socket_lookup[cpu_id]);
+                    if (ret < 0)
+                    {
+                        ERROR_PRINT("Initialization of MMIO access failed");
+                    }
+                }
+                if (ARCH_SPR_GNR_SRF)
+                {
+                    ret = access_x86_translate_init(cpu_id);
+                    if (ret < 0)
+                    {
+                        ERROR_PRINT("Initialization of translated-register access failed");
+                    }
+                }
+                else
+                {
+                    ret = access_x86_pci_init(affinity_thread2socket_lookup[cpu_id]);
+                    if (ret < 0)
+                    {
+                        ERROR_PRINT("Initialization of PCI access failed");
+                    }
                 }
-            }
-            else if (ARCH_SPR_GNR_SRF)
-            {
-                ret = access_x86_translate_init(cpu_id);
             }
         }
         else if (cpuid_info.supportClientmem)
         {
             ret = access_x86_clientmem_init(affinity_thread2socket_lookup[cpu_id]);
+            if (ret < 0)
+            {
+                ERROR_PRINT("Initialization of MMIO clientmem access failed");
+            }
         }
     }
     return ret;
 }
 
 int
-access_x86_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t *data)
+access_x86_read(PciDeviceIndex dev, uint32_t cpu_id, uint32_t reg, uint64_t *data)
 {
     int err = -EINVAL;
     uint64_t tmp = 0x0ULL;
@@ -140,7 +155,7 @@ access_x86_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t *da
 }
 
 int
-access_x86_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t data)
+access_x86_write(PciDeviceIndex dev, uint32_t cpu_id, uint32_t reg, uint64_t data)
 {
     int err = -EINVAL;
     if (dev == MSR_DEV)
@@ -186,7 +201,7 @@ access_x86_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t da
 }
 
 void
-access_x86_finalize(int cpu_id)
+access_x86_finalize(uint32_t cpu_id)
 {
     access_x86_msr_finalize(cpu_id);
     if (cpuid_info.supportUncore)
@@ -197,12 +212,12 @@ access_x86_finalize(int cpu_id)
         }
         if (cpuid_info.family == P6_FAMILY && ((cpuid_info.model == ICELAKEX1) || (cpuid_info.model == ICELAKEX2)))
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Finalize of MMIO access);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Finalize of MMIO access");
             access_x86_mmio_finalize(affinity_thread2socket_lookup[cpu_id]);
         }
         else if (ARCH_SPR_GNR_SRF)
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Finalize of Fake access);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Finalize of Fake access");
             access_x86_translate_finalize(cpu_id);
         }
     }
@@ -213,7 +228,7 @@ access_x86_finalize(int cpu_id)
 }
 
 int
-access_x86_check(PciDeviceIndex dev, int cpu_id)
+access_x86_check(PciDeviceIndex dev, uint32_t cpu_id)
 {
     if (dev == MSR_DEV)
     {
