@@ -8,14 +8,14 @@
  *                   performance monitoring registers in PCI Cfg space
  *                   for Intel Sandy Bridge Processors.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -84,20 +84,20 @@ clientmem_getStartAddr(uint64_t* startAddr)
     int pcihandle = open("/proc/bus/pci/00/00.0", O_RDONLY);
     if (pcihandle < 0)
     {
-        ERROR_PLAIN_PRINT(Cannot get start address: failed to open /proc/bus/pci/00/00.0);
+        ERROR_PRINT("Cannot get start address: failed to open /proc/bus/pci/00/00.0");
         return -1;
     }
 
     ssize_t ret = pread(pcihandle, &imcbar, sizeof(uint64_t), PCM_CLIENT_IMC_BAR_OFFSET);
     if (ret < 0)
     {
-        ERROR_PLAIN_PRINT(Cannot get start address: mmap failed);
+        ERROR_PRINT("Cannot get start address: mmap failed");
         close(pcihandle);
         return -1;
     }
     if (!imcbar)
     {
-        ERROR_PLAIN_PRINT(Cannot get start address: imcbar is zero);
+        ERROR_PRINT("Cannot get start address: imcbar is zero");
         close(pcihandle);
         return -1;
     }
@@ -112,8 +112,11 @@ clientmem_getStartAddr(uint64_t* startAddr)
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
 int
-access_x86_clientmem_init(const int socket)
+access_x86_clientmem_init(uint32_t socket)
 {
+    // TODO: Do we really need the socket argument?
+    (void)socket;
+
     uint64_t startAddr = 0;
 
     if (!access_clientmem_initialized)
@@ -121,14 +124,14 @@ access_x86_clientmem_init(const int socket)
         int ret = clientmem_getStartAddr(&startAddr);
         if (ret < 0)
         {
-            ERROR_PLAIN_PRINT(Failed to get clientmem start address);
+            ERROR_PRINT("Failed to get clientmem start address");
             return -1;
         }
         
         clientmem_handle = open("/dev/mem", O_RDONLY);
         if (clientmem_handle < 0)
         {
-            ERROR_PLAIN_PRINT(Unable to open /dev/mem for clientmem);
+            ERROR_PRINT("Unable to open /dev/mem for clientmem");
             return -1;
         }
 
@@ -136,7 +139,7 @@ access_x86_clientmem_init(const int socket)
         if (clientmem_addr == MAP_FAILED)
         {
             close(clientmem_handle);
-            ERROR_PLAIN_PRINT(Mapping of clientmem device failed);
+            ERROR_PRINT("Mapping of clientmem device failed");
             clientmem_addr = NULL;
             return -1;
         }
@@ -146,8 +149,11 @@ access_x86_clientmem_init(const int socket)
 }
 
 void
-access_x86_clientmem_finalize(const int socket)
+access_x86_clientmem_finalize(uint32_t socket)
 {
+    // TODO, do we really need the socket argument?
+    (void)socket;
+
     if (access_clientmem_initialized)
     {
         if (clientmem_handle >= 0)
@@ -163,8 +169,11 @@ access_x86_clientmem_finalize(const int socket)
 }
 
 int
-access_x86_clientmem_read(PciDeviceIndex dev, const int socket, uint32_t reg, uint64_t *data)
+access_x86_clientmem_read(PciDeviceIndex dev, uint32_t socket, uint32_t reg, uint64_t *data)
 {
+    // TODO, do we really need the socket argument?
+    (void)socket;
+
     uint64_t d = 0;
     if (dev != PCI_IMC_DEVICE_0_CH_0)
     {
@@ -195,7 +204,7 @@ access_x86_clientmem_read(PciDeviceIndex dev, const int socket, uint32_t reg, ui
             d = d & 0xFF;
             break;
         default:
-            ERROR_PRINT(Read from clientmem device at reg 0x%X failed, reg);
+            ERROR_PRINT("Read from clientmem device at reg 0x%X failed", reg);
             break;
     }
     *data = d;
@@ -205,14 +214,23 @@ access_x86_clientmem_read(PciDeviceIndex dev, const int socket, uint32_t reg, ui
 
 
 int
-access_x86_clientmem_write(PciDeviceIndex dev, const int socket, uint32_t reg, uint64_t data)
+access_x86_clientmem_write(PciDeviceIndex dev, uint32_t socket, uint32_t reg, uint64_t data)
 {
+    // TODO: Why do we need this function if it always fails?
+    // If this is ever implemented? Do we need all the arguments?
+    (void)dev;
+    (void)socket;
+    (void)reg;
+    (void)data;
     return -EACCES;
 }
 
 int
-access_x86_clientmem_check(PciDeviceIndex dev, int socket)
+access_x86_clientmem_check(PciDeviceIndex dev, uint32_t socket)
 {
+    // TODO: Do we really need the socket argument?
+    (void)socket;
+
     if (dev != PCI_IMC_DEVICE_0_CH_0)
     {
         return 0;
