@@ -5,13 +5,13 @@
  *
  *      Description:  Interface to x86 related functions for the access module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -63,37 +63,36 @@ static
 int access_x86_translate_open_unit(PerfmonDiscoveryUnit* unit)
 {
     int err = 0;
-    int PAGE_SIZE = sysconf (_SC_PAGESIZE);
     int pcihandle = open("/dev/mem", O_RDWR);
     if (pcihandle < 0)
     {
         err = errno;
-        ERROR_PRINT(Failed to open /dev/mem);
+        ERROR_PRINT("Failed to open /dev/mem");
         return -err;
     }
     if (unit->access_type == ACCESS_TYPE_MMIO)
     {
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Opening /dev/mem at 0x%X, unit->mmap_addr);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Opening /dev/mem at 0x%lX", unit->mmap_addr);
         void* io_addr = mmap(NULL, unit->mmap_size, PROT_READ|PROT_WRITE, MAP_SHARED, pcihandle, unit->mmap_addr);
         if (io_addr == MAP_FAILED)
         {
             err = errno;
             close(pcihandle);
-            ERROR_PRINT(Failed to mmap offset 0x%lX (MMIO), unit->box_ctl);
+            ERROR_PRINT("Failed to mmap offset 0x%lX (MMIO)", unit->box_ctl);
             return -err;
         }
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Opening /dev/mem at 0x%X -> 0x%X, unit->mmap_addr, io_addr);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Opening /dev/mem at 0x%lX -> 0x%p", unit->mmap_addr, io_addr);
         unit->io_addr = io_addr;
     }
     else if (unit->access_type == ACCESS_TYPE_PCI)
     {
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Opening /dev/mem at 0x%X, unit->mmap_addr);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Opening /dev/mem at 0x%lX", unit->mmap_addr);
         void* io_addr = mmap(NULL, unit->mmap_size, PROT_READ|PROT_WRITE, MAP_SHARED, pcihandle, unit->mmap_addr );
         if (io_addr == MAP_FAILED)
         {
             err = errno;
             close(pcihandle);
-            ERROR_PRINT(Failed to mmap offset 0x%lX (PCI), unit->box_ctl);
+            ERROR_PRINT("Failed to mmap offset 0x%lX (PCI)", unit->box_ctl);
             return -err;
         }
         unit->io_addr = io_addr;
@@ -131,6 +130,8 @@ int access_x86_translate_get_ctl_register_offset(PerfmonDiscoveryUnit* unit)
                 return 8;
             }
             break;
+        default:
+            ACCESS_TYPE_ERROR(unit->access_type);
     }
     return 0;
 }
@@ -139,15 +140,17 @@ int access_x86_translate_get_ctl_register_offset(PerfmonDiscoveryUnit* unit)
 
 
 int
-access_x86_translate_init(const int cpu_id)
+access_x86_translate_init(uint32_t cpu_id)
 {
+    (void)cpu_id;
+
     if (!perfmon_discovery)
     {
-        DEBUG_PLAIN_PRINT(DEBUGLEV_DEVELOP, Running Perfmon Discovery to populate counter lists);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Running Perfmon Discovery to populate counter lists");
         int ret = perfmon_uncore_discovery(cpuid_info.model, &perfmon_discovery);
         if (ret != 0)
         {
-            ERROR_PRINT(Failed to run Perfmon Discovery);
+            ERROR_PRINT("Failed to run Perfmon Discovery");
             return ret;
         }
     }
@@ -156,12 +159,12 @@ access_x86_translate_init(const int cpu_id)
 }
 
 int
-access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t *data)
+access_x86_translate_read(PciDeviceIndex dev, uint32_t cpu_id, uint32_t reg, uint64_t *data)
 {
     int err = 0;
     uint64_t offset = 0;
     uint64_t reg_offset = 0;
-    if ((!perfmon_discovery) || (cpu_id < 0) || (!data))
+    if ((!perfmon_discovery) || (!data))
     {
         return -EINVAL;
     }
@@ -181,7 +184,7 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
                 newreg = cur->global.global_ctl + cur->global.status_offset + ((reg - FAKE_UNC_GLOBAL_STATUS0));
             }
             uint64_t tmp = 0x0;
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Read Uncore counter 0x%X (%s) on CPU %d (socket %d), newreg, pci_device_names[dev], cpu_id, socket_id);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Read Uncore counter 0x%lX (%s) on CPU %d (socket %d)", newreg, pci_device_names[dev], cpu_id, socket_id);
             err = access_x86_msr_read(cpu_id, newreg, &tmp);
             if (err == 0)
             {
@@ -192,7 +195,7 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
     else
     {
         PerfmonDiscoverySocket* cur = &perfmon_discovery->sockets[socket_id];
-        if (cur->units && cur->socket_id == socket_id && cur->units[dev].num_regs > 0)
+        if (cur->socket_id == socket_id && cur->units[dev].num_regs > 0)
         {
             PerfmonDiscoveryUnit* unit = &cur->units[dev];
             if ((!unit->io_addr) && (unit->mmap_addr))
@@ -200,16 +203,16 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
                 int err = access_x86_translate_open_unit(unit);
                 if (err < 0)
                 {
-                    ERROR_PRINT(Failed to open unit %s, pci_device_names[dev]);
+                    ERROR_PRINT("Failed to open unit %s", pci_device_names[dev]);
                     return -ENODEV;
                 }
             }
             else if (!unit->mmap_addr)
             {
-                ERROR_PRINT(Failed to find unit %s, pci_device_names[dev]);
+                ERROR_PRINT("Failed to find unit %s", pci_device_names[dev]);
                 return -ENODEV;
             }
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Read Uncore counter 0x%X (%s) on CPU %d (socket %d, access %s), reg, pci_device_names[dev], cpu_id, socket_id, AccessTypeNames[unit->access_type]);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Read Uncore counter 0x%X (%s) on CPU %d (socket %d, access %s)", reg, pci_device_names[dev], cpu_id, socket_id, AccessTypeNames[unit->access_type]);
             switch(reg)
             {
                 case FAKE_UNC_UNIT_CTRL:
@@ -237,6 +240,8 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
                         case ACCESS_TYPE_MSR:
                             err = access_x86_msr_read(cpu_id, unit->box_ctl, data);
                             break;
+                        default:
+                            ACCESS_TYPE_ERROR(unit->access_type);
                     }
                     break;
                 case FAKE_UNC_UNIT_STATUS:
@@ -263,6 +268,8 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
                         case ACCESS_TYPE_MSR:
                             err = access_x86_msr_read(cpu_id, unit->box_ctl + unit->status_offset, data);
                             break;
+                        default:
+                            ACCESS_TYPE_ERROR(unit->access_type);
                     }
                     break;
                 case FAKE_UNC_CTRL0:
@@ -278,12 +285,12 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
                             if ((dev >= MMIO_IMC_DEVICE_0_CH_0 && dev <= MMIO_IMC_DEVICE_1_CH_7) ||
                                 (dev >= MMIO_HBM_DEVICE_0 && dev <= MMIO_HBM_DEVICE_31))
                             {
-                                DEBUG_PRINT(DEBUGLEV_DEVELOP, 0x%X + 0x%X + 0x%X + (%d * %d), unit->io_addr, unit->mmap_offset, unit->ctrl_offset, sizeof(uint32_t), offset);
+                                DEBUG_PRINT(DEBUGLEV_DEVELOP, "0x%lX + 0x%lX + 0x%lX + (%zu * %lu)", (uint64_t)unit->io_addr, unit->mmap_offset, unit->ctrl_offset, sizeof(uint32_t), offset);
                                 *data = (uint32_t)*((uint32_t *)(unit->io_addr + unit->mmap_offset + unit->ctrl_offset + (sizeof(uint32_t) * offset)));
                             }
                             else
                             {
-                                DEBUG_PRINT(DEBUGLEV_DEVELOP, 0x%X + 0x%X + 0x%X + (%d * %d), unit->io_addr, unit->mmap_offset, unit->ctrl_offset, reg_offset, offset);
+                                DEBUG_PRINT(DEBUGLEV_DEVELOP, "0x%lX + 0x%lX + 0x%lX + (%lu * %lu)", (uint64_t)unit->io_addr, unit->mmap_offset, unit->ctrl_offset, reg_offset, offset);
                                 *data = (uint64_t)*((uint64_t *)(unit->io_addr + unit->mmap_offset + unit->ctrl_offset + (reg_offset * offset)));
                             }
                             break;
@@ -305,6 +312,8 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
                         case ACCESS_TYPE_MSR:
                             err = access_x86_msr_read(cpu_id, unit->box_ctl + unit->ctrl_offset + (reg_offset * offset), data);
                             break;
+                        default:
+                            ACCESS_TYPE_ERROR(unit->access_type);
                     }
                     break;
                 case FAKE_UNC_CTR0:
@@ -337,6 +346,8 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
                         case ACCESS_TYPE_MSR:
                             err = access_x86_msr_read(cpu_id, unit->box_ctl + unit->ctr_offset + (reg_offset * offset), data);
                             break;
+                        default:
+                            ACCESS_TYPE_ERROR(unit->access_type);
                     }
                     break;
                 case FAKE_UNC_FILTER0:
@@ -383,12 +394,11 @@ access_x86_translate_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, ui
 }
 
 int
-access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t data)
+access_x86_translate_write(PciDeviceIndex dev, uint32_t cpu_id, uint32_t reg, uint64_t data)
 {
-    int err = 0;
     uint64_t offset = 0;
     uint64_t reg_offset = 0;
-    if ((!perfmon_discovery) || (cpu_id < 0))
+    if ((!perfmon_discovery))
     {
         return -EINVAL;
     }
@@ -409,8 +419,10 @@ access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, u
             }
             if (newreg != 0x0)
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Write Uncore counter 0x%X (%s) on CPU %d (socket %d): 0x%lX, newreg, pci_device_names[dev], cpu_id, socket_id, data);
-                err = access_x86_msr_write(cpu_id, newreg, data);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Write Uncore counter 0x%lX (%s) on CPU %d (socket %d): 0x%lX", newreg, pci_device_names[dev], cpu_id, socket_id, data);
+                int err = access_x86_msr_write(cpu_id, newreg, data);
+                if (err < 0)
+                    return err;
             }
         }
       
@@ -418,24 +430,25 @@ access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, u
     else
     {
         PerfmonDiscoverySocket* cur = &perfmon_discovery->sockets[socket_id];
-        if (cur->units && cur->socket_id == socket_id && cur->units[dev].num_regs > 0)
+        if (cur->socket_id == socket_id && cur->units[dev].num_regs > 0)
         {
+            int err;
             PerfmonDiscoveryUnit* unit = &cur->units[dev];
             if ((!unit->io_addr) && (unit->mmap_addr))
             {
-                int err = access_x86_translate_open_unit(unit);
+                err = access_x86_translate_open_unit(unit);
                 if (err < 0)
                 {
-                    ERROR_PRINT(Failed to open unit %s, pci_device_names[dev]);
+                    ERROR_PRINT("Failed to open unit %s", pci_device_names[dev]);
                     return -ENODEV;
                 }
             }
             else if (!unit->mmap_addr)
             {
-                ERROR_PRINT(Failed to find unit %s, pci_device_names[dev]);
+                ERROR_PRINT("Failed to find unit %s", pci_device_names[dev]);
                 return -ENODEV;
             }
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Write Uncore counter 0x%X (%s) on CPU %d (socket %d, access %s): 0x%lX, reg, pci_device_names[dev], cpu_id, socket_id, AccessTypeNames[unit->access_type], data);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Write Uncore counter 0x%X (%s) on CPU %d (socket %d, access %s): 0x%lX", reg, pci_device_names[dev], cpu_id, socket_id, AccessTypeNames[unit->access_type], data);
             switch(reg)
             {
                 case FAKE_UNC_UNIT_CTRL:
@@ -460,7 +473,11 @@ access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, u
                             break;
                         case ACCESS_TYPE_MSR:
                             err = access_x86_msr_write(cpu_id, unit->box_ctl, data);
+                            if (err < 0)
+                                return err;
                             break;
+                        default:
+                            ACCESS_TYPE_ERROR(unit->access_type);
                     }
                     break;
                 case FAKE_UNC_UNIT_STATUS:
@@ -486,6 +503,8 @@ access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, u
                         case ACCESS_TYPE_MSR:
                             err = access_x86_msr_write(cpu_id, unit->box_ctl + unit->status_offset, data);
                             break;
+                        default:
+                            ACCESS_TYPE_ERROR(unit->access_type);
                     }
                     break;
                 case FAKE_UNC_CTRL0:
@@ -501,12 +520,12 @@ access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, u
                             if ((dev >= MMIO_IMC_DEVICE_0_CH_0 && dev <= MMIO_IMC_DEVICE_1_CH_7) ||
                                 (dev >= MMIO_HBM_DEVICE_0 && dev <= MMIO_HBM_DEVICE_31))
                             {
-                                DEBUG_PRINT(DEBUGLEV_DEVELOP, 0x%X + 0x%X + 0x%X + (%d * %d) = 0x%X, unit->io_addr, unit->mmap_offset, unit->ctrl_offset, sizeof(uint32_t), offset, (uint32_t)data);
+                                DEBUG_PRINT(DEBUGLEV_DEVELOP, "0x%lX + 0x%lX + 0x%lX + (%zu * %lu) = 0x%X", (uint64_t)unit->io_addr, unit->mmap_offset, unit->ctrl_offset, sizeof(uint32_t), offset, (uint32_t)data);
                                 *((uint32_t *)(unit->io_addr + unit->mmap_offset + unit->ctrl_offset + (sizeof(uint32_t) * offset))) = (uint32_t)data;
                             }
                             else
                             {
-                                DEBUG_PRINT(DEBUGLEV_DEVELOP, 0x%X + 0x%X + 0x%X + (%d * %d) = 0x%X, unit->io_addr, unit->mmap_offset, unit->ctrl_offset, reg_offset, offset, (uint64_t)data);
+                                DEBUG_PRINT(DEBUGLEV_DEVELOP, "0x%lX + 0x%lX + 0x%lX + (%lu * %lu) = 0x%lX", (uint64_t)unit->io_addr, unit->mmap_offset, unit->ctrl_offset, reg_offset, offset, (uint64_t)data);
                                 *((uint64_t *)(unit->io_addr + unit->mmap_offset + unit->ctrl_offset + (reg_offset * offset))) = (uint64_t)data;
                             }
                             break;
@@ -526,6 +545,8 @@ access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, u
                         case ACCESS_TYPE_MSR:
                             err = access_x86_msr_write(cpu_id, unit->box_ctl + unit->ctrl_offset + (reg_offset * offset), data);
                             break;
+                        default:
+                            ACCESS_TYPE_ERROR(unit->access_type);
                     }
                     break;
                 case FAKE_UNC_CTR0:
@@ -555,6 +576,8 @@ access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, u
                         case ACCESS_TYPE_MSR:
                             err = access_x86_msr_write(cpu_id, unit->box_ctl + unit->ctr_offset + (reg_offset * offset), data);
                             break;
+                        default:
+                            ACCESS_TYPE_ERROR(unit->access_type);
                     }
                     break;
                 case FAKE_UNC_FILTER0:
@@ -598,8 +621,10 @@ access_x86_translate_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, u
 }
 
 int
-access_x86_translate_finalize(int cpu_id)
+access_x86_translate_finalize(uint32_t cpu_id)
 {
+    (void)cpu_id;
+
     perfmon_discovery_inits--;
     if (perfmon_discovery_inits == 0 && perfmon_discovery != NULL)
     {
@@ -610,11 +635,11 @@ access_x86_translate_finalize(int cpu_id)
 }
 
 int
-access_x86_translate_check(PciDeviceIndex dev, int cpu_id)
+access_x86_translate_check(PciDeviceIndex dev, uint32_t cpu_id)
 {
-    if (cpu_id < 0 || (!perfmon_discovery))
+    if ((!perfmon_discovery))
     {
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, CPU < 0 or no perfmon_initialization)
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "CPU < 0 or no perfmon_initialization");
         return 0;
     }
     int socket_id = affinity_thread2socket_lookup[cpu_id];
@@ -625,11 +650,11 @@ access_x86_translate_check(PciDeviceIndex dev, int cpu_id)
     PerfmonDiscoverySocket* cur = &perfmon_discovery->sockets[socket_id];
     if (cur)
     {
-        if (cur->units && cur->socket_id == socket_id && cur->units[dev].num_regs > 0)
+        if (cur->socket_id == socket_id && cur->units[dev].num_regs > 0)
         {
             return 1;
         }
-        if (dev == MSR_UBOX_DEVICE && cur->units)
+        if (dev == MSR_UBOX_DEVICE)
         {
             return 1;
         }
