@@ -49,18 +49,20 @@ end
 
 function usage()
     version()
-    print_stdout("A tool list and modify the states of CPU features.\n")
+    print_stdout()
+    print_stdout("A tool list and modify the states of CPU features.")
+    print_stdout()
     print_stdout("Options:")
-    print_stdout("-h, --help\t\t Help message")
-    print_stdout("-v, --version\t\t Version information")
-    print_stdout("-a, --all\t\t List all available features")
-    print_stdout("-l, --list\t\t List features and state for given hardware threads")
-    print_stdout("-c, --cpus <list>\t Perform operations on given hardware threads")
-    print_stdout("-e, --enable <list>\t List of features that should be enabled")
-    print_stdout("-d, --disable <list>\t List of features that should be disabled")
+    print_stdout("  -h, --help           Help message")
+    print_stdout("  -v, --version        Version information")
+    print_stdout("  -a, --all            List all available features")
+    print_stdout("  -l, --list           List features and state for given hardware threads")
+    print_stdout("  -c, --cpus <list>    Perform operations on given hardware threads")
+    print_stdout("  -e, --enable <list>  List of features that should be enabled")
+    print_stdout("  -d, --disable <list> List of features that should be disabled")
     print_stdout()
     print_stdout("Currently modifiable features:")
-    print_stdout(table.concat(FEATURES, ", "))
+    print_stdout("  " .. table.concat(FEATURES, ", "))
 end
 
 if #arg == 0 then
@@ -169,7 +171,7 @@ if listFeatures and #cpulist > 0 then
             print_stdout(str)
         end
     end
-    os.exit(1)
+    os.exit(0)
 elseif #cpulist == 0 then
     print_stderr("Need HWThread to list current feature state")
     os.exit(1)
