@@ -49,82 +49,88 @@ local function version()
 end
 
 local function examples()
-    io.stdout:write("Examples:\n")
-    io.stdout:write("List all performance groups:\n")
-    io.stdout:write("likwid-perfctr -a\n")
-    io.stdout:write("List all events and counters:\n")
-    io.stdout:write("likwid-perfctr -e\n")
-    io.stdout:write("List all events and suitable counters for events with 'L2' in them:\n")
-    io.stdout:write("likwid-perfctr -E L2\n")
-    io.stdout:write("Run command on CPU 2 and measure performance group CLOCK:\n")
-    io.stdout:write("likwid-perfctr -C 2 -g CLOCK ./a.out\n")
+    print("Examples:")
+    print("  List all performance groups:")
+    print("    $ likwid-perfctr -a")
+    print()
+    print("  List all events and counters:")
+    print("    $ likwid-perfctr -e")
+    print()
+    print("  List all events and suitable counters for events with 'L2' in them:")
+    print("    $ likwid-perfctr -E L2")
+    print()
+    print("  Run command on CPU 2 and measure performance group CLOCK:")
+    print("    $ likwid-perfctr -C 2 -g CLOCK ./a.out")
     if libinfo["nvidiaSupport"] then
-        io.stdout:write("Run command and measure on GPU 1 the performance group FLOPS_DP (Only with NVMarkerAPI):\n")
-        io.stdout:write("likwid-perfctr -G 1 -W FLOPS_DP -m ./a.out\n")
-        io.stdout:write("It is possible to combine CPU and GPU measurements (with MarkerAPI and NVMarkerAPI):\n")
-        io.stdout:write("likwid-perfctr -C 2 -g CLOCK -G 1 -W FLOPS_DP -m ./a.out\n")
+        print("  Run command and measure on GPU 1 the performance group FLOPS_DP (Only with NVMarkerAPI):")
+        print("     $ likwid-perfctr -G 1 -W FLOPS_DP -m ./a.out")
+        print()
+        print("  It is possible to combine CPU and GPU measurements (with MarkerAPI and NVMarkerAPI):")
+        print("    $ likwid-perfctr -C 2 -g CLOCK -G 1 -W FLOPS_DP -m ./a.out")
     end
     if libinfo["rocmSupport"] then
-        io.stdout:write("Run command and measure on GPU 1 the performance group PCI (Only with ROCmMarkerAPI):\n")
-        io.stdout:write("likwid-perfctr -I 1 -R PCI -m ./a.out\n")
-        io.stdout:write("It is possible to combine CPU and GPU measurements (with MarkerAPI and ROCmMarkerAPI):\n")
-        io.stdout:write("likwid-perfctr -C 2 -g CLOCK -I 1 -R PCI -m ./a.out\n")
+        print("  Run command and measure on GPU 1 the performance group PCI (Only with ROCmMarkerAPI):")
+        print("    $ likwid-perfctr -I 1 -R PCI -m ./a.out")
+        print("  It is possible to combine CPU and GPU measurements (with MarkerAPI and ROCmMarkerAPI):")
+        print("    $ likwid-perfctr -C 2 -g CLOCK -I 1 -R PCI -m ./a.out")
     end
 end
 
 local function usage(config)
     version()
-    io.stdout:write("A tool to read out performance counter registers on x86, ARM and POWER processors\n\n")
-    io.stdout:write("Options:\n")
-    io.stdout:write("-h, --help\t\t Help message\n")
-    io.stdout:write("-v, --version\t\t Version information\n")
-    io.stdout:write("-V, --verbose <level>\t Verbose output, 0 (only errors), 1 (info), 2 (details), 3 (developer)\n")
-    io.stdout:write("-c <list>\t\t Processor ids to measure (required), e.g. 1,2-4,8\n")
-    io.stdout:write("-C <list>\t\t Processor ids to pin threads and measure, e.g. 1,2-4,8\n")
-    io.stdout:write("\t\t\t For information about the <list> syntax, see likwid-pin\n")
+    print()
+    print("A tool to read out performance counter registers on x86, ARM and POWER processors")
+    print()
+    print("General Options:")
+    print("  -h, --help               Help message")
+    print("  -v, --version            Version information")
+    print("  -V, --verbose <level>    Verbose output, 0 (only errors), 1 (info), 2 (details), 3 (developer)")
+    print("  -c <list>                Processor ids to measure (required), e.g. 1,2-4,8")
+    print("  -C <list>                Processor ids to pin threads and measure, e.g. 1,2-4,8")
+    print("                           For information about the <list> syntax, see likwid-pin")
     if libinfo["nvidiaSupport"] then
-        io.stdout:write("-G, --gpus <list>\t List of CUDA GPUs to monitor\n")
+        print("  -G, --gpus <list>        List of CUDA GPUs to monitor")
     end
     if libinfo["rocmSupport"] then
-        io.stdout:write("-I <list>\t\t List of ROCm GPUs to monitor\n")
+        print("  -I <list>                List of ROCm GPUs to monitor")
     end
-    io.stdout:write("-g, --group <string>\t Performance group or custom event set string for CPU monitoring\n")
+    print("  -g, --group <string>     Performance group or custom event set string for CPU monitoring")
     if libinfo["nvidiaSupport"] then
-        io.stdout:write("-W, --cudagroup <string>\t Performance group or custom event set string for GPU monitoring\n")
+        print("  -W, --cudagroup <string> Performance group or custom event set string for GPU monitoring")
     end
     if libinfo["rocmSupport"] then
-        io.stdout:write("-R, --rocmgroup <string>\t\t Performance group or custom event set string for ROCm GPU monitoring\n")
+        print("  -R, --rocmgroup <string> Performance group or custom event set string for ROCm GPU monitoring")
     end
-    io.stdout:write("-H\t\t\t Get group help (together with -g switch)\n")
-    io.stdout:write("-s, --skip <hex>\t Bitmask with threads to skip\n")
-    io.stdout:write("-M <0|1>\t\t Set how MSR registers are accessed, 0=direct, 1=accessDaemon\n")
-    io.stdout:write("-a\t\t\t List available performance groups\n")
-    io.stdout:write("-e\t\t\t List available events and counter registers\n")
-    io.stdout:write("-E <string>\t\t List available events and corresponding counters that match <string>\n")
-    io.stdout:write("-i, --info\t\t Print CPU info\n")
-    io.stdout:write("-T <time>\t\t Switch eventsets with given frequency\n")
-    io.stdout:write("-f, --force\t\t Force overwrite of registers if they are in use\n")
-    io.stdout:write("Modes:\n")
-    io.stdout:write("-S <time>\t\t Stethoscope mode with duration in s, ms or us, e.g 20ms\n")
-    io.stdout:write("-t <time>\t\t Timeline mode with frequency in s, ms or us, e.g. 300ms\n")
-    io.stdout:write("\t\t\t The output format (to stderr) is:\n")
-    io.stdout:write(
-    "\t\t\t <groupID> <nrEvents> <nrThreads> <Timestamp> <Event1_Thread1> <Event1_Thread2> ... <EventN_ThreadN>\n")
-    io.stdout:write("\t\t\t or\n")
-    io.stdout:write(
-    "\t\t\t <groupID> <nrEvents> <nrThreads> <Timestamp> <Metric1_Thread1> <Metric1_Thread2> ... <MetricN_ThreadN>\n")
-    io.stdout:write("-m, --marker\t\t Use Marker API inside code\n")
-    io.stdout:write("Output options:\n")
-    io.stdout:write(
-    "-o, --output <file>\t Store output to file. (Optional: Apply text filter according to filename suffix)\n")
-    io.stdout:write("-O\t\t\t Output easily parseable CSV instead of fancy tables\n")
-    io.stdout:write("--stats\t\t\t Always print statistics table\n")
+    print("  -H                       Get group help (together with -g switch)")
+    print("  -s, --skip <hex>         Bitmask with threads to skip")
+    print("  -M <0|1>                 Set how MSR registers are accessed, 0=direct, 1=accessDaemon")
+    print("  -a                       List available performance groups")
+    print("  -e                       List available events and counter registers")
+    print("  -E <string>              List available events and corresponding counters that match <string>")
+    print("  -i, --info               Print CPU info")
+    print("  -T <time>                Switch eventsets with given frequency")
+    print("  -f, --force              Force overwrite of registers if they are in use")
+    print()
+    print("Mode Options:")
+    print("  -S <time>                Stethoscope mode with duration in s, ms or us, e.g 20ms")
+    print("  -t <time>                Timeline mode with frequency in s, ms or us, e.g. 300ms")
+    print("                           The output format (to stderr) is:")
+    print("                             <groupID> <nrEvents> <nrThreads> <Timestamp> <Event1_Thread1> <Event1_Thread2> ... <EventN_ThreadN>")
+    print("                           or")
+    print("                             <groupID> <nrEvents> <nrThreads> <Timestamp> <Metric1_Thread1> <Metric1_Thread2> ... <MetricN_ThreadN>")
+    print("  -m, --marker             Use Marker API inside code")
+    print()
+    print("Output options:")
+    print("  -o, --output <file>      Store output to file. (Optional: Apply text filter according to filename suffix)")
+    print("  -O                       Output easily parseable CSV instead of fancy tables")
+    print("  --stats                  Always print statistics table")
     if config and config["daemonMode"] == -1 then
-        io.stdout:write("perf_event specific options:\n")
-        io.stdout:write("--perfpid <pid>\t\t Measure given PID\n")
-        io.stdout:write("--execpid\t\t Use the PID of wrapped application for measurements\n")
+        print()
+        print("perf_event specific options:")
+        print("  --perfpid <pid>          Measure given PID")
+        print("  --execpid                Use the PID of wrapped application for measurements")
     end
-    io.stdout:write("\n")
+    print("")
     examples()
 end
 
