@@ -126,28 +126,30 @@ end
 
 local function examples()
     print_stdout("Examples:")
-    print_stdout("Run command on CPU 2 and measure performance group TEST:")
-    print_stdout("likwid-perfscope -C 2 -g TEST -f 1s ./a.out")
+    print_stdout("  Run command on CPU 2 and measure performance group TEST:")
+    print_stdout("    $ likwid-perfscope -C 2 -g TEST -f 1s ./a.out")
 end
 
 local function usage()
     version()
-    print_stdout("A tool to generate pictures on-the-fly from likwid-perfctr measurements\n")
+    print_stdout()
+    print_stdout("A tool to generate pictures on-the-fly from likwid-perfctr measurements")
+    print_stdout()
     print_stdout("Options:")
-    print_stdout("-h, --help\t\t Help message")
-    print_stdout("-v, --version\t\t Version information")
-    print_stdout("-V, --verbose <level>\t Verbose output, 0 (only errors), 1 (info), 2 (details), 3 (developer)")
-    print_stdout("-a\t\t\t Print all preconfigured plot configurations for the current system.")
-    print_stdout("-c <list>\t\t Processor ids to measure, e.g. 1,2-4,8")
-    print_stdout("-C <list>\t\t Processor ids to pin threads and measure, e.g. 1,2-4,8")
-    print_stdout("-g, --group <string>\t Preconfigured plot group or custom event set string with plot config. See man page for information.")
-    print_stdout("-t, --time <time>\t Frequency in s, ms or us, e.g. 300ms, for the timeline mode of likwid-perfctr")
-    print_stdout("-f, --force\t\t Overwrite counter configuration although already in use")
-    print_stdout("-d, --dump\t\t Print output as it is send to feedGnuplot.")
-    print_stdout("-p, --plotdump\t\t Use dump functionality of feedGnuplot. Plots out plot configurations plus data to directly submit to gnuplot")
-    print_stdout("--host <host>\t\t Run likwid-perfctr on the selected host using SSH. Evaluation and plotting is done locally.")
-    print_stdout("\t\t\t This can be used for machines that have no gnuplot installed. All paths must be similar to the local machine.")
-    print_stdout("\n")
+    print_stdout("  -h, --help            Help message")
+    print_stdout("  -v, --version         Version information")
+    print_stdout("  -V, --verbose <level> Verbose output, 0 (only errors), 1 (info), 2 (details), 3 (developer)")
+    print_stdout("  -a                    Print all preconfigured plot configurations for the current system.")
+    print_stdout("  -c <list>             Processor ids to measure, e.g. 1,2-4,8")
+    print_stdout("  -C <list>             Processor ids to pin threads and measure, e.g. 1,2-4,8")
+    print_stdout("  -g, --group <string>  Preconfigured plot group or custom event set string with plot config. See man page for information.")
+    print_stdout("  -t, --time <time>     Frequency in s, ms or us, e.g. 300ms, for the timeline mode of likwid-perfctr")
+    print_stdout("  -f, --force           Overwrite counter configuration although already in use")
+    print_stdout("  -d, --dump            Print output as it is send to feedGnuplot.")
+    print_stdout("  -p, --plotdump        Use dump functionality of feedGnuplot. Plots out plot configurations plus data to directly submit to gnuplot")
+    print_stdout("  --host <host>         Run likwid-perfctr on the selected host using SSH. Evaluation and plotting is done locally.")
+    print_stdout("                        This can be used for machines that have no gnuplot installed. All paths must be similar to the local machine.")
+    print_stdout()
     examples()
 end
 
