@@ -41,52 +41,71 @@ end
 
 local function examples()
     print_stdout("Examples:")
-    print_stdout("There are three possibilities to provide a thread to processor list:")
-    print_stdout("1. Thread list with physical thread IDs")
-    print_stdout("Example: likwid-pin.lua -c 0,4-6 ./myApp")
-    print_stdout("Pins the application to hardware threads 0,4,5 and 6")
-    print_stdout("2. Thread list with logical thread numberings in physical cores first sorted list.")
-    print_stdout("Example usage thread list: likwid-pin.lua -c N:0,4-6 ./myApp")
-    print_stdout("You can pin with the following numberings:")
-    print_stdout("\t2. Logical numbering inside node.\n\t   e.g. -c N:0,1,2,3 for the first 4 physical cores of the node")
-    print_stdout("\t3. Logical numbering inside socket.\n\t   e.g. -c S0:0-1 for the first 2 physical cores of the socket")
-    print_stdout("\t4. Logical numbering inside last level cache group.\n\t   e.g. -c C0:0-3  for the first 4 physical cores in the first LLC")
-    print_stdout("\t5. Logical numbering inside NUMA domain.\n\t   e.g. -c M0:0-3 for the first 4 physical cores in the first NUMA domain")
-    print_stdout("\tYou can also mix domains separated by  @,\n\te.g. -c S0:0-3@S1:0-3 for the 4 first physical cores on both sockets.")
-    print_stdout("3. Expressions based thread list generation with compact processor numbering.")
-    print_stdout("Example usage expression: likwid-pin.lua -c E:N:8 ./myApp")
-    print_stdout("This will generate a compact list of thread to processor mapping for the node domain")
-    print_stdout("with eight threads.")
-    print_stdout("The following syntax variants are available:")
-    print_stdout("\t1. -c E:<thread domain>:<number of threads>")
-    print_stdout("\t2. -c E:<thread domain>:<number of threads>:<chunk size>:<stride>")
-    print_stdout("\tFor two hardware threads per core on a SMT4 machine use e.g. -c E:N:122:2:4")
-    print_stdout("4. Scatter policy among thread domain type.")
-    print_stdout("Example usage scatter: likwid-pin.lua -c M:scatter ./myApp")
-    print_stdout("This will generate a thread to processor mapping scattered among all memory domains")
-    print_stdout("with physical hardware threads first.")
-    print_stdout("")
-    print_stdout("likwid-pin sets OMP_NUM_THREADS with as many threads as specified")
-    print_stdout("in your pin expression if OMP_NUM_THREADS is not present in your environment.")
+    print_stdout("  There are three possibilities to provide a thread to processor list:")
+    print_stdout("  1. Thread list with physical thread IDs")
+    print_stdout("    Pin the application to hardware threads 0,4,5 and 6:")
+    print_stdout("    $ likwid-pin.lua -c 0,4-6 ./myApp")
+    print_stdout()
+    print_stdout("  2. Thread list with logical thread numberings in physical cores first sorted list.")
+    print_stdout("    Example usage thread list:")
+    print_stdout("    $ likwid-pin.lua -c N:0,4-6 ./myApp")
+    print_stdout()
+    print_stdout("    You can pin with the following numberings:")
+    print_stdout("    1. Logical numbering inside node.")
+    print_stdout("       e.g. -c N:0,1,2,3 for the first 4 physical cores of the node")
+    print_stdout("    2. Logical numbering inside socket.")
+    print_stdout("       e.g. -c S0:0-1 for the first 2 physical cores of the first socket")
+    print_stdout("    3. Logical numbering inside last level cache group.")
+    print_stdout("       e.g. -c C0:0-3  for the first 4 physical cores of the first last level cache domain")
+    print_stdout("    4. Logical numbering inside NUMA domain.")
+    print_stdout("       e.g. -c M0:0-3 for the first 4 physical cores of the first NUMA domain")
+    print_stdout()
+    print_stdout("    You can also mix domains separated by '@',")
+    print_stdout("    e.g. -c S0:0-3@S1:0-3 for the 4 first physical cores of the first two sockets.")
+    print_stdout()
+    print_stdout("  3. Expressions based thread list generation with compact processor numbering.")
+    print_stdout("    Example usage expression:")
+    print_stdout("    $ likwid-pin.lua -c E:N:8 ./myApp")
+    print_stdout()
+    print_stdout("    This will generate a compact list of thread to processor mapping for the node domain")
+    print_stdout("    with eight threads.")
+    print_stdout()
+    print_stdout("    The following syntax variants are available:")
+    print_stdout("    1. -c E:<thread domain>:<number of threads>")
+    print_stdout("    2. -c E:<thread domain>:<number of threads>:<chunk size>:<stride>")
+    print_stdout()
+    print_stdout("    For two hardware threads per core on a SMT4 machine use e.g. -c E:N:122:2:4")
+    print_stdout()
+    print_stdout("  4. Scatter policy among thread domain type.")
+    print_stdout("    Example usage scatter:")
+    print_stdout("    $ likwid-pin.lua -c M:scatter ./myApp")
+    print_stdout()
+    print_stdout("    This will generate a thread to processor mapping scattered among all memory domains")
+    print_stdout("    with physical hardware threads first.")
+    print_stdout()
+    print_stdout("  likwid-pin sets OMP_NUM_THREADS with as many threads as specified")
+    print_stdout("  in your pin expression if OMP_NUM_THREADS is not present in your environment.")
 end
 
 local function usage()
     version()
-    print_stdout("An application to pin a program including threads.\n")
+    print_stdout()
+    print_stdout("An application to pin a program including threads.")
+    print_stdout()
     print_stdout("Options:")
-    print_stdout("-h, --help\t\t Help message")
-    print_stdout("-v, --version\t\t Version information")
-    print_stdout("-V, --verbose <level>\t Verbose output, 0 (only errors), 1 (info), 2 (details), 3 (developer)")
-    print_stdout("-i\t\t\t Set numa interleave policy with all involved numa nodes")
-    print_stdout("-m\t\t\t Set numa membind policy with all involved numa nodes")
-    print_stdout("-S, --sweep\t\t Sweep memory and LLC of involved NUMA nodes")
-    print_stdout("-c/-C <list>\t\t Comma separated processor IDs or expression")
-    print_stdout("-s, --skip <hex>\t Bitmask with threads to skip")
-    print_stdout("-p\t\t\t Print available domains with mapping on physical IDs")
-    print_stdout("\t\t\t If used together with -c option outputs the list of physical processor IDs.")
-    print_stdout("-d <string>\t\t Delimiter used for using -p to output physical processor list, default is comma.")
-    print_stdout("-q, --quiet\t\t Silent without output")
-    print_stdout("\n")
+    print_stdout("  -h, --help            Help message")
+    print_stdout("  -v, --version         Version information")
+    print_stdout("  -V, --verbose <level> Verbose output, 0 (only errors), 1 (info), 2 (details), 3 (developer)")
+    print_stdout("  -i                    Set numa interleave policy with all involved numa nodes")
+    print_stdout("  -m                    Set numa membind policy with all involved numa nodes")
+    print_stdout("  -S, --sweep           Sweep memory and LLC of involved NUMA nodes")
+    print_stdout("  -c/-C <list>          Comma separated processor IDs or expression")
+    print_stdout("  -s, --skip <hex>      Bitmask with threads to skip")
+    print_stdout("  -p                    Print available domains with mapping on physical IDs")
+    print_stdout("                        If used together with -c option outputs the list of physical processor IDs.")
+    print_stdout("  -d <string>           Delimiter used for using -p to output physical processor list, default is comma.")
+    print_stdout("  -q, --quiet           Silent without output")
+    print_stdout()
     examples()
 end
 
