@@ -42,28 +42,30 @@ end
 
 local function examples()
     print_stdout("Examples:")
-    print_stdout("Measure the power consumption for 4 seconds on socket 1")
-    print_stdout("likwid-powermeter -s 4 -c 1")
-    print_stdout("")
-    print_stdout("Use it as wrapper for an application to measure the energy for the whole execution")
-    print_stdout("likwid-powermeter -c 1 ./a.out")
+    print_stdout("  Measure the power consumption for 4 seconds on socket 1")
+    print_stdout("  $ likwid-powermeter -s 4 -c 1")
+    print_stdout()
+    print_stdout("  Use it as wrapper for an application to measure the energy for the whole execution")
+    print_stdout("  $ likwid-powermeter -c 1 ./a.out")
 end
 
 local function usage()
     version()
-    print_stdout("A tool to print power and clocking information on x86 CPUs.\n")
+    print_stdout()
+    print_stdout("A tool to print power and clocking information on x86 CPUs.")
+    print_stdout()
     print_stdout("Options:")
-    print_stdout("-h, --help\t Help message")
-    print_stdout("-v, --version\t Version information")
-    print_stdout("-V, --verbose <level>\t Verbose output, 0 (only errors), 1 (info), 2 (details), 3 (developer)")
-    print_stdout("-M <0|1>\t\t Set how MSR registers are accessed, 0=direct, 1=accessDaemon")
-    print_stdout("-c <list>\t\t Specify sockets to measure")
-    print_stdout("-i, --info\t Print information from MSR_PKG_POWER_INFO register and Turbo mode")
-    print_stdout("-s <duration>\t Set measure duration in us, ms or s. (default 2s)")
-    print_stdout("-p\t\t Print dynamic clocking and CPI values, uses likwid-perfctr")
-    print_stdout("-t\t\t Print current temperatures of all hardware threads")
-    print_stdout("-f\t\t Print current temperatures in Fahrenheit")
-    print_stdout("")
+    print_stdout("  -h, --help            Help message")
+    print_stdout("  -v, --version         Version information")
+    print_stdout("  -V, --verbose <level> Verbose output, 0 (only errors), 1 (info), 2 (details), 3 (developer)")
+    print_stdout("  -M <0|1>              Set how MSR registers are accessed, 0=direct, 1=accessDaemon")
+    print_stdout("  -c <list>             Specify sockets to measure")
+    print_stdout("  -i, --info            Print information from MSR_PKG_POWER_INFO register and Turbo mode")
+    print_stdout("  -s <duration>         Set measure duration in us, ms or s. (default 2s)")
+    print_stdout("  -p                    Print dynamic clocking and CPI values, uses likwid-perfctr")
+    print_stdout("  -t                    Print current temperatures of all hardware threads")
+    print_stdout("  -f                    Print current temperatures in Fahrenheit")
+    print_stdout()
     examples()
 end
 
