@@ -46,46 +46,51 @@ end
 
 function usage()
     version()
-    print_stdout("A tool to adjust frequencies and governors on x86 CPUs.\n")
+    print_stdout()
+    print_stdout("A tool to adjust frequencies and governors on x86 CPUs.")
+    print_stdout()
     print_stdout("Options:")
-    print_stdout("-h\t\t Help message")
-    print_stdout("-v\t\t Version information")
-    print_stdout("-V <0-3>\t Verbosity (0=only_error, 3=developer)")
-    print_stdout("-c dom\t\t CPU selection or LIKWID thread domain")
-    print_stdout("\t\t Default behavior is to apply the frequencies to all CPUs.")
-    print_stdout("\t\t See likwid-pin -h for details")
-    print_stdout("-g gov\t\t Set governor (" .. table.concat(likwid.getAvailGovs(0), ", ") .. ")")
-    print_stdout("-f/--freq freq\t Set minimal and maximal CPU frequency")
-    print_stdout("-p\t\t Print current frequencies (CPUs + Uncore)")
-    print_stdout("-l\t\t List available CPU frequencies")
-    print_stdout("-m\t\t List available CPU governors")
-    print_stdout("-t/--turbo <0|1> De/Activate turbo mode")
-    print_stdout("")
-    print_stdout("-x/--min freq\t Set minimal CPU frequency")
-    print_stdout("-y/--max freq\t Set maximal CPU frequency")
-    print_stdout("--umin freq\t Set minimal Uncore frequency")
-    print_stdout("--umax freq\t Set maximal Uncore frequency")
-    print_stdout("")
-    print_stdout("-reset\tSet governor 'performance', set minimal and maximal frequency to")
-    print_stdout("\tthe CPU limits and deactivate turbo")
-    print_stdout("-ureset\tSet Uncore frequencies to its min and max limits")
-    print_stdout("")
-    print_stdout("For the options -f, -x and -y:")
-    print_stdout("\t acpi-cpufreq driver: set the userspace governor implicitly")
-    print_stdout("\t intel_pstate driver: keep current governor")
-    print_stdout("")
-    print_stdout("In general the min/max Uncore frequency can be set freely, even to 0 or 1E20")
-    print_stdout("but the hardware stays inside its limits. LIKWID reduces the range of possible")
-    print_stdout("frequencies to the minimal core frequency (likwid-setFrequencies -l) and the ")
-    print_stdout("maximally achievable turbo frequency with a single core (C0 value at")
-    print_stdout("likwid-powermeter -i output).")
-    print_stdout("To check whether the set Uncore frequency is really set and fixed, use")
-    print_stdout("likwid-perfctr -g UNCORE_CLOCK:UBOXFIX -C 0 <exec_doing_work>.")
-    print_stdout("Sleeping is commonly not sufficient.")
-    print_stdout("")
-    print_stdout("If you switch governors with the intel_pstate driver, it might be that the driver")
-    print_stdout("changes the frequency settings, please check afterwards and re-set frequencies if")
-    print_stdout("needed.")
+    print_stdout("  -h               Help message")
+    print_stdout("  -v               Version information")
+    print_stdout("  -V <0-3>         Verbosity (0=only_error, 3=developer)")
+    print_stdout("  -c dom           CPU selection or LIKWID thread domain")
+    print_stdout("                   Default behavior is to apply the frequencies to all CPUs.")
+    print_stdout("                   See likwid-pin -h for details")
+    print_stdout("  -g gov           Set governor (" .. table.concat(likwid.getAvailGovs(0), ", ") .. ")")
+    print_stdout("  -f/--freq freq   Set minimal and maximal CPU frequency")
+    print_stdout("  -p               Print current frequencies (CPUs + Uncore)")
+    print_stdout("  -l               List available CPU frequencies")
+    print_stdout("  -m               List available CPU governors")
+    print_stdout("  -t/--turbo <0|1> De/Activate turbo mode")
+    print_stdout()
+    print_stdout("  -x/--min freq    Set minimal CPU frequency")
+    print_stdout("  -y/--max freq    Set maximal CPU frequency")
+    print_stdout("  --umin freq      Set minimal Uncore frequency")
+    print_stdout("  --umax freq      Set maximal Uncore frequency")
+    print_stdout()
+    print_stdout("  -reset           Set governor 'performance', set minimal and maximal frequency to")
+    print_stdout("                   the CPU limits and deactivate turbo.")
+    print_stdout("  -ureset          Set Uncore frequencies to its min and max limits")
+    print_stdout()
+    print_stdout("General Information:")
+    print_stdout("  For the options -f, -x and -y:")
+    print_stdout("    acpi-cpufreq driver: set the userspace governor implicitly")
+    print_stdout("    intel_pstate driver: keep current governor")
+    print_stdout()
+    print_stdout("  In general the min/max Uncore frequency can be set freely, even to 0 or 1E20")
+    print_stdout("  but the hardware stays inside its limits. LIKWID reduces the range of possible")
+    print_stdout("  frequencies to the minimal core frequency (likwid-setFrequencies -l) and the")
+    print_stdout("  maximally achievable turbo frequency with a single core (C0 value at")
+    print_stdout("  likwid-powermeter -i output).")
+    print_stdout()
+    print_stdout("  To check whether the set Uncore frequency is really set and fixed, use:")
+    print_stdout("  $ likwid-perfctr -g UNCORE_CLOCK:UBOXFIX -C 0 <exec_doing_work>.")
+    print_stdout()
+    print_stdout("  Sleeping is commonly not sufficient.")
+    print_stdout()
+    print_stdout("  If you switch governors with the intel_pstate driver, it might be that the driver")
+    print_stdout("  changes the frequency settings, please check afterwards and re-set frequencies if")
+    print_stdout("  needed.")
 end
 
 function round(x)
