@@ -5,13 +5,13 @@
  *
  *      Description:  Lua LIKWID interface library
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -47,7 +47,7 @@ likwid.hline =  string.rep("-",80)
 likwid.sline = string.rep("*",80)
 
 
-
+likwid.getLibInfo = likwid_getLibInfo
 likwid.getConfiguration = likwid_getConfiguration
 likwid.setGroupPath = likwid_setGroupPath
 likwid.putConfiguration = likwid_putConfiguration
@@ -140,6 +140,8 @@ likwid.getRegion = likwid_getRegion
 likwid.resetRegion = likwid_resetRegion
 likwid.initCpuFeatures = likwid_cpuFeaturesInit
 likwid.getCpuFeatures = likwid_cpuFeaturesGet
+likwid.printCpuFeatures = likwid_cpuFeaturesPrint
+likwid.cpuFeaturesName = likwid_cpuFeaturesName
 likwid.enableCpuFeatures = likwid_cpuFeaturesEnable
 likwid.disableCpuFeatures = likwid_cpuFeaturesDisable
 likwid.readMarkerFile = likwid_readMarkerFile
@@ -189,6 +191,7 @@ likwid.finalizeSysFeatures = likwid_finalizeSysFeatures
 likwid.createDevice = likwid_createDevice
 likwid.createDevicesFromString = likwid_createDevicesFromString
 likwid.getAvailableDevices = likwid_getAvailableDevices
+likwid.getAllDevices = likwid_getAllDevices
 
 likwid.getCudaTopology = likwid_getCudaTopology
 likwid.putCudaTopology = likwid_putCudaTopology
@@ -200,7 +203,6 @@ likwid.nvGetNameOfMetric = likwid_nvGetNameOfMetric
 likwid.nvGetNameOfEvent = likwid_nvGetNameOfEvent
 likwid.nvGetNameOfCounter = likwid_nvGetNameOfCounter
 
-likwid.nvSupported = likwid_nvSupported
 likwid.readNvMarkerFile = likwid_readNvMarkerFile
 likwid.destroyNvMarkerFile = likwid_destroyNvMarkerFile
 likwid.nvMarkerNumRegions = likwid_nvMarkerNumRegions
@@ -218,7 +220,6 @@ likwid.nvInit = likwid_nvInit
 likwid.nvAddEventSet = likwid_nvAddEventSet
 likwid.nvFinalize = likwid_nvFinalize
 
-likwid.rocmSupported = likwid_rocmSupported
 likwid.getRocmTopology = likwid_getRocmTopology
 likwid.putRocmTopology = likwid_putRocmTopology
 likwid.getRocmEventsAndCounters = likwid_getRocmEventsAndCounters
