@@ -5,8 +5,8 @@
  *
  *      Description:  Infix calculator
  *
- *      Version:   4.2
- *      Released:  22.12.2016
+ *      Version:  <VERSION>
+ *      Released: <DATE>
  *
  *      Author:   Brandon Mills (bm), mills.brandont@gmail.com
  *      Project:  likwid
@@ -36,11 +36,11 @@
  *
  *      Some changes done for the integration in LIKWID, see inline comments
  *
- *      Version:   4.2
- *      Released:  22.12.2016
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
- *                Thomas Roehl (tr), thomas.roehl@gmail.com
+ *                Thomas Gruber (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
  *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
@@ -67,7 +67,9 @@
 #include <string.h>
 #include <math.h> // Temporary
 #include <getopt.h>
+#include <error.h>
 #include <calculator_stack.h>
+#include <lw_alloc.h>
 
 /* #####   MACROS  -  LOCAL TO THIS SOURCE FILE   ######################### */
 
@@ -76,7 +78,15 @@
 #define false 0
 #define PI 3.141592653589793
 
-/* Added by Thomas Roehl (Thomas.Roehl@fau.de) to reduce reallocs by allocating a temporary
+#ifndef NAN
+#define NAN (0.0/0.0)
+#endif
+
+#ifndef INFINITY
+#define INFINITY (1.0/0.0)
+#endif
+
+/* Added by Thomas Gruber (Thomas.Roehl@fau.de) to reduce reallocs by allocating a temporary
  * token for parsing as well as for transforming a number to a string.
  */
 #define MAXTOKENLENGTH 512
@@ -84,6 +94,7 @@
 #define DEFAULTPRECISION 5
 #define AUTOPRECISION -1
 #define FUNCTIONSEPARATOR "|"
+
 /* #####   VARIABLES  -  LOCAL TO THIS SOURCE FILE   ###################### */
 
 typedef enum
@@ -110,6 +121,7 @@ struct Preferences
     {
         bool tokens;
         bool postfix;
+        bool errors;
     } display;
     struct Mode
     {
@@ -125,6 +137,7 @@ typedef enum
     overflow,
     parenMismatch,
     inputMissing,
+    faultyExpression,
 } Error;
 
 typedef char* token;
@@ -135,7 +148,7 @@ typedef double number;
 
 void raise(Error err)
 {
-    char* msg;
+    const char *msg = "";
     switch(err)
     {
         case divZero:
@@ -150,8 +163,11 @@ void raise(Error err)
         case inputMissing:
             msg = "Function input missing";
             break;
+        case faultyExpression:
+            msg = "Expression invalid";
+            break;
     }
-    //printf("\tError: %s\n", msg);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "\tError: %s\n", msg);
 }
 
 inline unsigned int
@@ -177,7 +193,7 @@ token num2Str(number num)
     int precision = MAXPRECISION;
     if (prefs.precision >= 0 && prefs.precision < precision)
         precision = prefs.precision;
-    token str = (token)malloc(prefs.maxtokenlength*sizeof(char));
+    token str = (token)lw_malloc(prefs.maxtokenlength*sizeof(char));
     len = snprintf(str, prefs.maxtokenlength-1, "%.*f", precision, num);
     if (prefs.precision == AUTOPRECISION)
     {
@@ -202,18 +218,36 @@ toDegrees(number radians)
     return radians * 180.0 / PI;
 }
 
-token doFunc(Stack *s, token function)
+int doFunc(Stack *s, token function)
 {
     if (stackSize(s) == 0)
     {
         raise(inputMissing);
-        return "NaN";
+        stackPush(s, num2Str(NAN));
+        return -EFAULT;
     }
     else if (stackSize(s) == 1 && strcmp(stackTop(s), FUNCTIONSEPARATOR) == 0)
     {
         stackPop(s);
         raise(inputMissing);
-        return "NaN";
+        stackPush(s, num2Str(NAN));
+        return -EFAULT;
+    }
+    else if (stackSize(s) > 2)
+    {
+        if  (!(  (strncmp(function, "min", 3) == 0)
+              || (strncmp(function, "max", 3) == 0)
+              || (strncmp(function, "sum", 3) == 0)
+              || (strncmp(function, "avg", 3) == 0)
+              || (strncmp(function, "mean", 4) == 0)
+              || (strncmp(function, "median", 6) == 0)
+              || (strncmp(function, "var", 3) == 0)))
+        {
+            while (stackSize(s) > 0) stackPop(s);
+            raise(inputMissing);
+            stackPush(s, num2Str(NAN));
+            return -EFAULT;
+        }
     }
     token input = (token)stackPop(s);
     number num = buildNumber(input);
@@ -295,7 +329,7 @@ token doFunc(Stack *s, token function)
     else if(strncmp(function, "median", 6) == 0)
     {
         // needed for sorting
-        Stack tmp, safe;
+        Stack tmp = FRESH_STACK, safe = FRESH_STACK;
         // Result already initialized with first number
         counter = 1;
         stackInit(&tmp, (stackSize(s) > 0 ? stackSize(s) : 1));
@@ -339,7 +373,7 @@ token doFunc(Stack *s, token function)
     }
     else if(strncmp(function, "var", 3) == 0)
     {
-        Stack tmp;
+        Stack tmp = FRESH_STACK;
         counter = 1;
         // second stack to store values during calculation of mean
         stackInit(&tmp, (stackSize(s) > 0 ? stackSize(s) : 1));
@@ -377,11 +411,12 @@ token doFunc(Stack *s, token function)
 
 int doOp(Stack *s, token op)
 {
+    int err = 0;
     token roperand = (token)stackPop(s);
     token loperand = (token)stackPop(s);
     number lside = buildNumber(loperand);
     number rside = buildNumber(roperand);
-    number ret;
+    number ret = NAN;
     switch(*op)
     {
         case '^':
@@ -399,7 +434,11 @@ int doOp(Stack *s, token op)
                 if(rside == 0)
                 {
                     raise(divZero);
-                    return -1;
+                    if (lside == 0)
+                        ret = NAN;
+                    else
+                        ret = INFINITY;
+                    err = -EFAULT;
                 }
                 else
                     ret = lside / rside;
@@ -410,7 +449,11 @@ int doOp(Stack *s, token op)
                 if(rside == 0)
                 {
                     raise(divZero);
-                    return -1;
+                    if (lside == 0)
+                        ret = NAN;
+                    else
+                        ret = INFINITY;
+                    err = -EFAULT;
                 }
                 else
                 {
@@ -431,7 +474,7 @@ int doOp(Stack *s, token op)
             break;
     }
     stackPush(s, num2Str(ret));
-    return 0;
+    return err;
 }
 
 Symbol type(char ch)
@@ -541,29 +584,34 @@ Symbol type(char ch)
 
 bool isFunction(token tk)
 {
-    return (strncmp(tk, "abs", 3) == 0
-        || strncmp(tk, "floor", 5) == 0
-        || strncmp(tk, "ceil", 4) == 0
-        || strncmp(tk, "sin", 3) == 0
-        || strncmp(tk, "cos", 3) == 0
-        || strncmp(tk, "tan", 3) == 0
-        || strncmp(tk, "arcsin", 6) == 0
-        || strncmp(tk, "arccos", 6) == 0
-        || strncmp(tk, "arctan", 6) == 0
-        || strncmp(tk, "asin", 4) == 0
-        || strncmp(tk, "acos", 4) == 0
-        || strncmp(tk, "atan", 4) == 0
-        || strncmp(tk, "sqrt", 4) == 0
-        || strncmp(tk, "cbrt", 4) == 0
-        || strncmp(tk, "log", 3) == 0
-        || strncmp(tk, "min", 3) == 0
-        || strncmp(tk, "max", 3) == 0
-        || strncmp(tk, "sum", 3) == 0
-        || strncmp(tk, "avg", 3) == 0
-        || strncmp(tk, "mean", 4) == 0
-        || strncmp(tk, "median", 6) == 0
-        || strncmp(tk, "var", 3) == 0
-        || strncmp(tk, "exp", 3) == 0);
+    return ((strncmp(tk, "abs", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "floor", 5) == 0 && strlen(tk) == 5)
+        || (strncmp(tk, "ceil", 4) == 0 && strlen(tk) == 4)
+        || (strncmp(tk, "sin", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "cos", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "tan", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "arcsin", 6) == 0 && strlen(tk) == 6)
+        || (strncmp(tk, "arccos", 6) == 0 && strlen(tk) == 6)
+        || (strncmp(tk, "arctan", 6) == 0 && strlen(tk) == 6)
+        || (strncmp(tk, "asin", 4) == 0 && strlen(tk) == 4)
+        || (strncmp(tk, "acos", 4) == 0 && strlen(tk) == 4)
+        || (strncmp(tk, "atan", 4) == 0 && strlen(tk) == 4)
+        || (strncmp(tk, "sqrt", 4) == 0 && strlen(tk) == 4)
+        || (strncmp(tk, "cbrt", 4) == 0 && strlen(tk) == 4)
+        || (strncmp(tk, "log", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "min", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "max", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "sum", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "avg", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "mean", 4) == 0 && strlen(tk) == 4)
+        || (strncmp(tk, "median", 6) == 0 && strlen(tk) == 6)
+        || (strncmp(tk, "var", 3) == 0 && strlen(tk) == 3)
+        || (strncmp(tk, "exp", 3) == 0 && strlen(tk) == 3));
+}
+
+bool isSpecialValue(token tk)
+{
+    return ((strlen(tk) == 3) && ((strncmp(tk, "nan", 3) == 0) || (strncmp(tk, "inf", 3))));
 }
 
 Symbol tokenType(token tk)
@@ -576,6 +624,8 @@ Symbol tokenType(token tk)
         case text:
             if(isFunction(tk))
                 ret = function;
+            else if(isSpecialValue(tk))
+                ret = value;
             else
                 ret = identifier;
             break;
@@ -601,11 +651,23 @@ int tokenize(char *str, char *(**tokensRef))
     char* ptr = str;
     char ch = '\0';
     int numTokens = 0;
+    int lparen_count = 0;
+    int rparen_count = 0;
+    int ops_count = 0;
+    if ((!str) || (!tokensRef))
+    {
+        return -EINVAL;
+    }
+    if (strlen(str) == 0)
+    {
+        raise(faultyExpression);
+        return -EFAULT;
+    }
     char* tmpToken = malloc((prefs.maxtokenlength+1) * sizeof(char));
     if (!tmpToken)
     {
         fprintf(stderr, "Malloc of temporary buffer failed\n");
-        return 0;
+        return -ENOMEM;
     }
     while((ch = *ptr++))
     {
@@ -614,7 +676,8 @@ int tokenize(char *str, char *(**tokensRef))
 
         token newToken = NULL;
         tmpToken[0] = '\0';
-        switch(type(ch))
+        Symbol sym = type(ch);
+        switch(sym)
         {
             case addop:
                 {
@@ -667,11 +730,16 @@ int tokenize(char *str, char *(**tokensRef))
 
                             // Append null-terminator
                             tmpToken[len] = '\0';
+                            if (len > 1)
+                            {
+                                break;
+                            }
                         }
-                        break;
                     }
                     // If it's not part of a number, it's an op - fall through
                 }
+                // The comment below supresses the fallthrough warning.
+                // fall through
             case multop:
             case expop:
             case lparen:
@@ -681,6 +749,9 @@ int tokenize(char *str, char *(**tokensRef))
                 {
                     tmpToken[0] = ch;
                     tmpToken[1] = '\0';
+                    if (sym == lparen) lparen_count++;
+                    else if (sym == rparen) rparen_count++;
+                    else if (sym == multop || sym == expop || sym == addop) ops_count++;
                 }
                 break;
             case digit:
@@ -761,29 +832,46 @@ int tokenize(char *str, char *(**tokensRef))
             tmp = (char**)realloc(tokens, numTokens * sizeof(char*));
             if (tmp == NULL)
             {
-                free(newToken);
                 if (tokens != NULL)
                 {
                     for(i=0;i<numTokens-1;i++)
                     {
                         if (tokens[i] != NULL)
+                        {
                             free(tokens[i]);
+                            tokens[i] = NULL;
+                        }
                     }
                     free(tokens);
+                    tokens = NULL;
                 }
                 *tokensRef = NULL;
                 free(newToken);
                 free(tmpToken);
-                return 0;
+                return -ENOMEM;
             }
             tokens = tmp;
             tmp = NULL;
             tokens[numTokens - 1] = newToken;
         }
     }
-    *tokensRef = tokens; // Send back out
     free(tmpToken);
     tmpToken = NULL;
+    if (lparen_count != rparen_count)
+    {
+        for (int i = 0; i < numTokens; i++) free(tokens[i]);
+        free(tokens);
+        raise(parenMismatch);
+        return -EFAULT;
+    }
+    if (numTokens == lparen_count + rparen_count + ops_count)
+    {
+        for (int i = 0; i < numTokens; i++) free(tokens[i]);
+        free(tokens);
+        raise(faultyExpression);
+        return -EFAULT;
+    }
+    *tokensRef = tokens; // Send back out
     return numTokens;
 }
 
@@ -836,8 +924,9 @@ int precedence(token op1, token op2)
     return ret;
 }
 
-void evalStackPush(Stack *s, token val)
+int evalStackPush(Stack *s, token val)
 {
+    int err = 0;
     if(prefs.display.postfix)
         printf("\t%s\n", val);
 
@@ -845,11 +934,16 @@ void evalStackPush(Stack *s, token val)
     {
         case function:
             {
-                //token res;
-                //operand = (token)stackPop(s);
-                if (doFunc(s, val) < 0)
-                    return;
-                //stackPush(s, res);
+                err = doFunc(s, val);
+                if (err < 0)
+                {
+                    while (stackSize(s) > 0)
+                    {
+                        char* t = stackPop(s);
+                        free(t);
+                    }
+                    return err;
+                }
             }
             break;
         case expop:
@@ -858,14 +952,11 @@ void evalStackPush(Stack *s, token val)
             {
                 if(stackSize(s) >= 2)
                 {
-                    // Pop two operands
-
-                    // Evaluate
-                    if (doOp(s, val) < 0)
-                        return;
-
-                    // Push result
-                    //stackPush(s, res);
+                    err = doOp(s, val);
+                    if (err < 0)
+                    {
+                        return err;
+                    }
                 }
                 else
                 {
@@ -881,13 +972,14 @@ void evalStackPush(Stack *s, token val)
         default:
             break;
     }
+    return 0;
 }
 
-bool postfix(token *tokens, int numTokens, Stack *output)
+int postfix(token *tokens, int numTokens, Stack *output)
 {
-    Stack operators, intermediate;
+    Stack operators = FRESH_STACK, intermediate = FRESH_STACK;
     int i;
-    bool err = false;
+    int err = 0;
     stackInit(&operators, numTokens);
     stackInit(&intermediate, numTokens);
     for(i = 0; i < numTokens; i++)
@@ -899,7 +991,13 @@ bool postfix(token *tokens, int numTokens, Stack *output)
                 {
                     // If the token is a number, then add it to the output queue.
                     //printf("Adding number %s to output stack\n", tokens[i]);
-                    evalStackPush(output, tokens[i]);
+                    err = evalStackPush(output, tokens[i]);
+                    if (err < 0)
+                    {
+                        stackFree(&operators);
+                        stackFree(&intermediate);
+                        return err;
+                    }
                 }
                 break;
             case function:
@@ -909,7 +1007,13 @@ bool postfix(token *tokens, int numTokens, Stack *output)
                         && ((precedence(tokens[i], (char*)stackTop(&operators)) <= 0)))
                     {
                         //printf("Moving operator %s from operator stack to output stack\n", (char*)stackTop(&operators));
-                        evalStackPush(output, stackPop(&operators));
+                        err = evalStackPush(output, stackPop(&operators));
+                        if (err < 0)
+                        {
+                            stackFree(&operators);
+                            stackFree(&intermediate);
+                            return err;
+                        }
                         stackPush(&intermediate, stackTop(output));
                     }
 
@@ -932,7 +1036,13 @@ bool postfix(token *tokens, int numTokens, Stack *output)
                         && stackSize(&operators) > 1)
                     {
                         //printf("Moving operator from operator stack to output stack\n");
-                        evalStackPush(output, stackPop(&operators));
+                        err = evalStackPush(output, stackPop(&operators));
+                        if (err < 0)
+                        {
+                            stackFree(&operators);
+                            stackFree(&intermediate);
+                            return err;
+                        }
                         stackPush(&intermediate, stackTop(output));
                     }
                 }
@@ -955,7 +1065,13 @@ bool postfix(token *tokens, int numTokens, Stack *output)
                             || (!leftAssoc(tokens[i]) && precedence(tokens[i], (char*)stackTop(&operators)) < 0)))
                     {
                         //printf("Moving operator %s from operator stack to output stack\n", (char*)stackTop(&operators));
-                        evalStackPush(output, stackPop(&operators));
+                        err = evalStackPush(output, stackPop(&operators));
+                        if (err < 0)
+                        {
+                            stackFree(&operators);
+                            stackFree(&intermediate);
+                            return err;
+                        }
                         stackPush(&intermediate, stackTop(output));
                     }
                     //printf("Adding operator %s to operator stack\n", tokens[i]);
@@ -984,13 +1100,19 @@ bool postfix(token *tokens, int numTokens, Stack *output)
                         && stackSize(&operators) > 1)
                     {
                         //printf("Moving operator %s from operator stack to output stack\n", (char*)stackTop(&operators));
-                        evalStackPush(output, stackPop(&operators));
+                        err = evalStackPush(output, stackPop(&operators));
+                        if (err < 0)
+                        {
+                            stackFree(&operators);
+                            stackFree(&intermediate);
+                            return err;
+                        }
                         stackPush(&intermediate, stackTop(output));
                     }
                     if(stackSize(&operators) > 0
                         && tokenType((token)stackTop(&operators)) != lparen)
                     {
-                        err = true;
+                        err = -EFAULT;
                         raise(parenMismatch);
                     }
                     //printf("Removing left paren from operator stack\n");
@@ -998,7 +1120,13 @@ bool postfix(token *tokens, int numTokens, Stack *output)
                     while (stackSize(&operators) > 0 && tokenType((token)stackTop(&operators)) == function)
                     {
                         //printf("Removing function from operator stack to output stack\n");
-                        evalStackPush(output, stackPop(&operators));
+                        err = evalStackPush(output, stackPop(&operators));
+                        if (err < 0)
+                        {
+                            stackFree(&operators);
+                            stackFree(&intermediate);
+                            return err;
+                        }
                         stackPush(&intermediate, stackTop(output));
                     }
                 }
@@ -1021,7 +1149,13 @@ bool postfix(token *tokens, int numTokens, Stack *output)
             err = true;
         }
         //printf("Moving operator from operator stack to output stack\n");
-        evalStackPush(output, stackPop(&operators));
+        err = evalStackPush(output, stackPop(&operators));
+        if (err < 0)
+        {
+            stackFree(&operators);
+            stackFree(&intermediate);
+            return err;
+        }
         stackPush(&intermediate, stackTop(output));
     }
     // pop result from intermediate stack
@@ -1029,9 +1163,10 @@ bool postfix(token *tokens, int numTokens, Stack *output)
     // free remaining intermediate results
     while (stackSize(&intermediate) > 0)
     {
-        stackPop(&intermediate);
+        token s = stackPop(&intermediate);
+        free(s);
     }
-    if (err == true)
+    if (err != 0)
     {
         while (stackSize(&operators) > 0)
         {
@@ -1044,41 +1179,76 @@ bool postfix(token *tokens, int numTokens, Stack *output)
     stackFree(&operators);
     return err;
 }
-/* Added by Thomas Roehl (Thomas.Roehl@fau.de) as interface for LIKWID */
+/* Added by Thomas Gruber (Thomas.Roehl@fau.de) as interface for LIKWID */
 int
 calculate_infix(char* finfix, double *result)
 {
     int i;
     int ret = 0;
     *result = 0;
+    double res = 0;
     token* tokens = NULL;
     Stack expr;
     prefs.maxtokenlength = MAXTOKENLENGTH;
     prefs.precision = MAXPRECISION;
     int numTokens = tokenize(finfix, &tokens);
+    if (numTokens < 0)
+    {
+        return numTokens;
+    }
+    if (numTokens == 1)
+    {
+        if (tokenType(tokens[0]) == value)
+        {
+            *result = strtod((char*)tokens[0], NULL);
+        }
+        else
+        {
+            *result = NAN;
+        }
+        goto freeTokens;
+    }
     stackInit(&expr, numTokens);
     ret = postfix(tokens, numTokens, &expr);
-    if ((stackSize(&expr) != 1) || (ret == true))
+    if (ret != 0)
     {
-        *result = NAN;
+        if (stackSize(&expr) > 0)
+        {
+            char* t = stackTop(&expr);
+            res = atof(t);
+            free(t);
+        }
+        if (prefs.display.errors) printf("\tError evaluating expression\n");;
+        goto calcerror;
+    }
+    else if (stackSize(&expr) != 1)
+    {
+        raise(faultyExpression);
+        if (prefs.display.errors) printf("\tError evaluating expression\n");
+        ret = -EFAULT;
         goto calcerror;
     }
     else
     {
+        res = atof((char*)stackTop(&expr));
         for (i=0; i< numTokens; i++)
         {
             if (tokens[i] == stackTop(&expr))
                 tokens[i] = NULL;
         }
-        *result = strtod((char*)stackTop(&expr), NULL);
+        free(stackPop(&expr));
     }
+    *result = res;
     ret = 0;
 calcerror:
+    stackFree(&expr);
+freeTokens:
     for (i=0;i<numTokens;i++)
     {
         if (tokens[i])
         {
             free(tokens[i]);
+            tokens[i] = NULL;
         }
     }
     if (tokens)
@@ -1087,7 +1257,6 @@ calcerror:
         tokens = NULL;
         numTokens = 0;
     }
-    stackFree(&expr);
+
     return ret;
 }
-
