@@ -5,13 +5,13 @@
  *
  *      Description:  Configuration file module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -38,6 +38,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
+#include <lw_alloc.h>
 
 #include <configuration.h>
 
@@ -63,7 +64,7 @@ default_configuration(void)
     filename[0] = '\0';
 
     groupPath_len = strlen(TOSTRING(GROUPPATH))+10;
-    config.groupPath = malloc(groupPath_len+1);
+    config.groupPath = lw_malloc(groupPath_len+1);
     ret = snprintf(config.groupPath, groupPath_len, "%s", TOSTRING(GROUPPATH));
     config.groupPath[ret] = '\0';
 #ifndef LIKWID_USE_PERFEVENT
@@ -90,11 +91,8 @@ default_configuration(void)
     }
     if (!access(fptr, X_OK))
     {
-        config.daemonPath = (char*)malloc((len+1) * sizeof(char));
-        strncpy(config.daemonPath, fptr, len);
-        config.daemonPath[len] = '\0';
-        if (fptr)
-            free(fptr);
+        config.daemonPath = lw_strdup(fptr);
+        free(fptr);
     }
     else
     {
@@ -108,20 +106,21 @@ default_configuration(void)
 #endif
     init_config = 1;
     return 0;
+#ifndef LIKWID_USE_PERFEVENT
 use_hardcoded:
+#endif
     ret = sprintf(filename,"%s", TOSTRING(ACCESSDAEMON));
     filename[ret] = '\0';
     if (!access(filename, X_OK))
     {
-        config.daemonPath = (char*)malloc((strlen(filename)+1) * sizeof(char));
-        strcpy(config.daemonPath, filename);
+        config.daemonPath = lw_strdup(filename);
         init_config = 1;
     }
     else
     {
         if (getenv("LIKWID_NO_ACCESS") == NULL)
         {
-            ERROR_PLAIN_PRINT(Unable to get path to access daemon. Maybe your PATH environment variable does not contain the folder where you installed it or the file was moved away / not copied to that location?);
+            ERROR_PRINT("Unable to get path to access daemon. Maybe your PATH environment variable does not contain the folder where you installed it or the file was moved away / not copied to that location?");
             return -1;
         }
     }
@@ -162,11 +161,10 @@ init_configuration(void)
     {
         if (1023 == strlen(filename) && access(filename, R_OK))
         {
-            ERROR_PLAIN_PRINT(Topology file path too long for internal buffer);
+            ERROR_PRINT("Topology file path too long for internal buffer");
             return -1;
         }
-        config.topologyCfgFileName = (char*)malloc((strlen(filename)+1) * sizeof(char));
-        stpcpy(config.topologyCfgFileName, filename);
+        config.topologyCfgFileName = lw_strdup(filename);
     }
 
     filename[0] = '\0';
@@ -187,19 +185,18 @@ init_configuration(void)
     {
         if (1023 == strlen(filename) && access(filename, R_OK))
         {
-            ERROR_PLAIN_PRINT(Config file path too long for internal buffer);
+            ERROR_PRINT("Config file path too long for internal buffer");
             if (config.topologyCfgFileName) free(config.topologyCfgFileName);
             return -1;
         }
-        config.configFileName = (char*)malloc((strlen(filename)+1) * sizeof(char));
-        stpcpy(config.configFileName, filename);
+        config.configFileName = lw_strdup(filename);
     }
     else
     {
         return default_configuration();
     }
 
-    DEBUG_PRINT(DEBUGLEV_INFO, Reading configuration from %s, config.configFileName)
+    DEBUG_PRINT(DEBUGLEV_INFO, "Reading configuration from %s", config.configFileName);
     fp = fopen(config.configFileName, "r");
     while (fgets(line, 512, fp) != NULL) {
         if (sscanf(line,"%s = %s", name, value) != 2)
@@ -212,18 +209,16 @@ init_configuration(void)
         }
         if (strcmp(name, "topology_file") == 0 && /*don't overrule user request*/!(customtopo && !access(customtopo, R_OK)))
         {
-            config.topologyCfgFileName = (char*)malloc((strlen(value)+1) * sizeof(char));
-            stpcpy(config.topologyCfgFileName, value);
+            config.topologyCfgFileName = lw_strdup(value);
         }
         else if (strcmp(name, "daemon_path") == 0)
         {
-            config.daemonPath = (char*)malloc((strlen(value)+1) * sizeof(char));
-            stpcpy(config.daemonPath, value);
+            config.daemonPath = lw_strdup(value);
             if (access(config.daemonPath, R_OK))
             {
                 if (default_configuration() < 0)
                 {
-                    ERROR_PLAIN_PRINT(Unable to get path to access daemon);
+                    ERROR_PRINT("Unable to get path to access daemon");
                     fclose(fp);
                     if (config.topologyCfgFileName) free(config.topologyCfgFileName);
                     if (config.configFileName) free(config.configFileName);
@@ -238,12 +233,11 @@ init_configuration(void)
             stat(value, &st);
             if (S_ISDIR(st.st_mode))
             {
-                config.groupPath = (char*)malloc((strlen(value)+1) * sizeof(char));
-                stpcpy(config.groupPath, value);
+                config.groupPath = lw_strdup(value);
             }
             else
             {
-                ERROR_PRINT(Path to group files %s is not a directory, value);
+                ERROR_PRINT("Path to group files %s is not a directory", value);
                 fclose(fp);
                 if (config.topologyCfgFileName) free(config.topologyCfgFileName);
                 if (config.configFileName) free(config.configFileName);
@@ -261,6 +255,14 @@ init_configuration(void)
             {
                 config.daemonMode = ACCESSMODE_DIRECT;
             }
+            else if (strcmp(value, "perf_event") == 0)
+            {
+#ifdef LIKWID_USE_PERFEVENT
+                config.daemonMode = ACCESSMODE_PERF;
+#else
+                ERROR_PRINT("Invalid access mode 'perf_event'. Library not built with 'perf_event' support");
+#endif
+            }
         }
         else if (strcmp(name, "max_threads") == 0)
         {
