@@ -9,13 +9,13 @@
  *                  Allows to turn on and off the Hardware prefetcher
  *                  available.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -45,6 +45,7 @@
 #include <textcolor.h>
 #include <likwid.h>
 #include <lock.h>
+#include <lw_alloc.h>
 
 /* #####   EXPORTED VARIABLES   ########################################### */
 
@@ -258,13 +259,10 @@ cpuFeatureNames[CPUFEATURES_MAX] = {
     [FEAT_SPEEDSTEP_LOCK] = "Enhanced Intel SpeedStep Technology Select Lock",
 };
 
-static char*
-cpuFeatureNamesFixed[CPUFEATURES_MAX] = {};
-
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
 void
-cpuFeatures_init()
+cpuFeatures_init(void)
 {
     if (features_initialized)
     {
@@ -279,7 +277,7 @@ cpuFeatures_init()
     topology_init();
     if (!cpuFeatureMask)
     {
-        cpuFeatureMask = malloc(cpuid_topology.numHWThreads*sizeof(uint64_t));
+        cpuFeatureMask = lw_malloc(cpuid_topology.numHWThreads*sizeof(uint64_t));
         memset(cpuFeatureMask, 0, cpuid_topology.numHWThreads*sizeof(uint64_t));
     }
 
@@ -287,16 +285,16 @@ cpuFeatures_init()
     {
         HPMinit();
     }
-    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    for (unsigned i = 0; i < cpuid_topology.numHWThreads; i++)
     {
         int ret = HPMaddThread(cpuid_topology.threadPool[i].apicId);
         if (ret != 0)
         {
-            ERROR_PRINT(Cannot get access to register CPU feature register on CPU %d, cpuid_topology.threadPool[i].apicId);
+            ERROR_PRINT("Cannot get access to register CPU feature register on CPU %d", cpuid_topology.threadPool[i].apicId);
             return;
         }
     }
-    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    for (unsigned i = 0; i < cpuid_topology.numHWThreads; i++)
     {
         cpuFeatures_update(cpuid_topology.threadPool[i].apicId);
     }
@@ -307,7 +305,6 @@ cpuFeatures_init()
 void
 cpuFeatures_print(int cpu)
 {
-    uint64_t flags = 0x0ULL;
     if (!features_initialized)
     {
         return;
