@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of performance group and event set handler
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -45,14 +45,7 @@ typedef enum {
     MAX_GROUP_FILE_SECTIONS
 } GroupFileSections;
 
-static char* groupFileSectionNames[MAX_GROUP_FILE_SECTIONS] = {
-    "NONE",
-    "SHORT",
-    "EVENTSET",
-    "METRICS",
-    "LONG",
-    "LUA"
-};
+extern const char *groupFileSectionNames[MAX_GROUP_FILE_SECTIONS];
 
 typedef struct {
     int counters; /*!< \brief Number of entries in the list */
