@@ -5,13 +5,13 @@
  *
  *      Description:  Counter Header File of perfmon module for ARM A57.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,7 +27,8 @@
  *
  * =======================================================================================
  */
-
+#ifndef PERFMON_A57_COUNTERS_H
+#define PERFMON_A57_COUNTERS_H
 
 #define NUM_COUNTERS_A57 6
 
@@ -41,7 +42,7 @@ static RegisterMap a57_counter_map[NUM_COUNTERS_A57] = {
 };
 
 static BoxMap a57_box_map[NUM_UNITS] = {
-    [PMC] = {A57_PERF_CONTROL_CTRL, A57_OVERFLOW_STATUS, A57_OVERFLOW_FLAGS, 0, 0, 0, 32},
+    [PMC] = {A57_PERF_CONTROL_CTRL, A57_OVERFLOW_STATUS, A57_OVERFLOW_FLAGS, 0, 0, 0, 32, 0, 0},
 };
 
 static char* a57_translate_types[NUM_UNITS] = {
@@ -55,3 +56,5 @@ static char* a72_translate_types[NUM_UNITS] = {
 static char* a53_translate_types[NUM_UNITS] = {
     [PMC] = "/sys/bus/event_source/devices/cpu",
 };
+
+#endif //PERFMON_A57_COUNTERS_H
