@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for Fujitsu A64FX
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,9 +27,13 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_A64FX_H
+#define PERFMON_A64FX_H
 
 #include <perfmon_a64fx_events.h>
 #include <perfmon_a64fx_counters.h>
 
 static int perfmon_numCountersA64FX = NUM_COUNTERS_A64FX;
 static int perfmon_numArchEventsA64FX = NUM_ARCH_EVENTS_A64FX;
+
+#endif //PERFMON_A64FX_H
