@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for Apple M1
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,9 +27,13 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_APPLEM1_H
+#define PERFMON_APPLEM1_H
 
 #include <perfmon_applem1_events.h>
 #include <perfmon_applem1_counters.h>
 
 static int perfmon_numCountersAppleM1 = NUM_COUNTERS_APPLEM1;
 static int perfmon_numArchEventsAppleM1 = NUM_ARCH_EVENTS_APPLEM1;
+
+#endif //PERFMON_APPLEM1_H
