@@ -5,13 +5,13 @@
  *
  *      Description:  Header file of perfmon module for Atom
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,9 +27,12 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_ATOM_H
+#define PERFMON_ATOM_H
 
 #include <perfmon_atom_events.h>
 #include <error.h>
 
 static int perfmon_numArchEventsAtom = NUM_ARCH_EVENTS_ATOM;
 
+#endif //PERFMON_ATOM_H
