@@ -5,13 +5,13 @@
  *
  *      Description:  Counter Header File of perfmon module for Broadwell.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_BROADWELL_COUNTERS_H
+#define PERFMON_BROADWELL_COUNTERS_H
 
 #define NUM_COUNTERS_BROADWELL 33
 #define NUM_COUNTERS_CORE_BROADWELL 12
@@ -73,25 +75,27 @@ static RegisterMap broadwell_counter_map[NUM_COUNTERS_BROADWELL] = {
     {"UBOX0", PMC25, UBOX, MSR_UNC_ARB_PERFEVTSEL0, MSR_UNC_ARB_CTR0, 0, 0, BDW_VALID_OPTIONS_UBOX},
     {"UBOX1", PMC26, UBOX, MSR_UNC_ARB_PERFEVTSEL1, MSR_UNC_ARB_CTR1, 0, 0, BDW_VALID_OPTIONS_UBOX},
     {"UBOXFIX", PMC27, UBOXFIX, MSR_UNC_PERF_FIXED_CTRL, MSR_UNC_PERF_FIXED_CTR, 0, 0, EVENT_OPTION_NONE_MASK},
-    {"MBOX0C0", PMC28, MBOX0, 0x0, 0x0, 0, PCI_IMC_DEVICE_0_CH_0},
-    {"MBOX0C1", PMC29, MBOX0, 0x0, 0x1, 0, PCI_IMC_DEVICE_0_CH_0},
-    {"MBOX0C2", PMC30, MBOX0, 0x0, 0x2, 0, PCI_IMC_DEVICE_0_CH_0},
-    {"MBOX0TMP0", PMC31, MBOX0TMP, 0x0, 0x3, 0, PCI_IMC_DEVICE_0_CH_0},
-    {"MBOX0TMP1", PMC32, MBOX0TMP, 0x0, 0x4, 0, PCI_IMC_DEVICE_0_CH_0},
+    {"MBOX0C0", PMC28, MBOX0, 0x0, 0x0, 0, PCI_IMC_DEVICE_0_CH_0, EVENT_OPTION_NONE_MASK},
+    {"MBOX0C1", PMC29, MBOX0, 0x0, 0x1, 0, PCI_IMC_DEVICE_0_CH_0, EVENT_OPTION_NONE_MASK},
+    {"MBOX0C2", PMC30, MBOX0, 0x0, 0x2, 0, PCI_IMC_DEVICE_0_CH_0, EVENT_OPTION_NONE_MASK},
+    {"MBOX0TMP0", PMC31, MBOX0TMP, 0x0, 0x3, 0, PCI_IMC_DEVICE_0_CH_0, EVENT_OPTION_NONE_MASK},
+    {"MBOX0TMP1", PMC32, MBOX0TMP, 0x0, 0x4, 0, PCI_IMC_DEVICE_0_CH_0, EVENT_OPTION_NONE_MASK},
     
 };
 
 
 static BoxMap broadwell_box_map[NUM_UNITS] = {
-    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, 0, 0, 0, 48},
-    [THERMAL] = {0, 0, 0, 0, 0, 0, 8},
-    [VOLTAGE] = {0, 0, 0, 0, 0, 0, 16},
-    [FIXED] =  {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, 0, 0, 0, 48},
-    [POWER] = {0, 0, 0, 0, 0, 0, 32},
-    [CBOX0] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 3, 0, MSR_DEV, 44},
-    [CBOX1] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 3, 0, MSR_DEV, 44},
-    [CBOX2] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 3, 0, MSR_DEV, 44},
-    [CBOX3] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 3, 0, MSR_DEV, 44},
-    [UBOX] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 1, 0, MSR_DEV, 44},
-    [UBOXFIX] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 0, 0, MSR_DEV, 44},
+    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, 0, 0, 0, 48, 0, 0},
+    [THERMAL] = {0, 0, 0, 0, 0, 0, 8, 0, 0},
+    [VOLTAGE] = {0, 0, 0, 0, 0, 0, 16, 0, 0},
+    [FIXED] =  {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, 0, 0, 0, 48, 0, 0},
+    [POWER] = {0, 0, 0, 0, 0, 0, 32, 0, 0},
+    [CBOX0] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 3, 0, MSR_DEV, 44, 0, 0},
+    [CBOX1] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 3, 0, MSR_DEV, 44, 0, 0},
+    [CBOX2] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 3, 0, MSR_DEV, 44, 0, 0},
+    [CBOX3] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 3, 0, MSR_DEV, 44, 0, 0},
+    [UBOX] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 1, 0, MSR_DEV, 44, 0, 0},
+    [UBOXFIX] = {MSR_UNC_PERF_GLOBAL_CTRL, MSR_UNC_PERF_GLOBAL_STATUS, MSR_UNC_PERF_GLOBAL_OVF_CTRL, 0, 0, MSR_DEV, 44, 0, 0},
 };
+
+#endif //PERFMON_BROADWELL_COUNTERS_H
