@@ -5,14 +5,14 @@
  *
  *      Description:  Header File of perfmon module for Intel CascadeLake.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   4.3.3
+ *      Released:  09.11.2018
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -28,8 +28,11 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_CASCADELAKE_H
+#define PERFMON_CASCADELAKE_H
 
 #include <perfmon_cascadelakeX_events.h>
 
-
 static int perfmon_numArchEventsCascadelakeX = NUM_ARCH_EVENTS_CASCADELAKEX;
+
+#endif //PERFMON_CASCADELAKE_H
