@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for ARM AWS Graviton3
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Carlos Falquez, c.falquez@fz-juelich.de
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2022, Forschungszentrum Juelich, Germany
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,9 +27,13 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_GRAVITON3_H
+#define PERFMON_GRAVITON3_H
 
 #include <perfmon_graviton3_events.h>
 #include <perfmon_graviton3_counters.h>
 
 static int perfmon_numCountersGraviton3   = NUM_COUNTERS_GRAVITON3;
 static int perfmon_numArchEventsGraviton3 = NUM_ARCH_EVENTS_GRAVITON3;
+
+#endif //PERFMON_GRAVITON3_H
