@@ -5,13 +5,13 @@
  *
  *      Description:  Counter Header File of perfmon module for Intel Icelake X.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_ICELAKEX_COUNTERS_H
+#define PERFMON_ICELAKEX_COUNTERS_H
 
 #define NUM_COUNTERS_ICELAKEX 408
 #define NUM_COUNTERS_CORE_ICELAKEX 18
@@ -467,145 +469,145 @@ static RegisterMap icelakeX_counter_map[NUM_COUNTERS_ICELAKEX] = {
 
 
 static BoxMap icelakeX_box_map[NUM_UNITS] = {
-    [FIXED] =  {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48},
-    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48},
-    [THERMAL] = {0, 0, 0, 0, 0, 0, 8},
-    [POWER] = {0, 0, 0, 0, 0, 0, 32},
-    [VOLTAGE] = {0, 0, 0, 0, 0, 0, 16},
-    [METRICS] = {0, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS, 48, 0, 0, 8},
-    [MBOX0] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_0, 48, 0},
-    [MBOX1] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_1, 48, 0},
-    [MBOX2] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_2, 48, 0},
-    [MBOX3] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_3, 48, 0},
-    [MBOX4] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_4, 48, 0},
-    [MBOX5] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_5, 48, 0},
-    [MBOX6] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_6, 48, 0},
-    [MBOX7] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_7, 48, 0},
-    [MBOX0FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_0, 48, 0},
-    [MBOX1FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_1, 48, 0},
-    [MBOX2FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_2, 48, 0},
-    [MBOX3FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_3, 48, 0},
-    [MBOX4FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_4, 48, 0},
-    [MBOX5FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_5, 48, 0},
-    [MBOX6FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_6, 48, 0},
-    [MBOX7FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_7, 48, 0},
-    [MDEV0] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_0_FREERUN, 64},
-    [MDEV1] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_1_FREERUN, 64},
-    [MDEV2] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_2_FREERUN, 64},
-    [MDEV3] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_3_FREERUN, 64},
-    [CBOX0] = {MSR_UNC_ICX_C0_PMON_CTRL, MSR_UNC_ICX_C0_PMON_STATUS, MSR_UNC_ICX_C0_PMON_STATUS, 0, 0, MSR_DEV, 48, MSR_UNC_ICX_C0_PMON_FILTER},
-    [CBOX1] = {MSR_UNC_ICX_C1_PMON_CTRL, MSR_UNC_ICX_C1_PMON_STATUS, MSR_UNC_ICX_C1_PMON_STATUS, 1, 0, MSR_DEV, 48, MSR_UNC_ICX_C1_PMON_FILTER},
-    [CBOX2] = {MSR_UNC_ICX_C2_PMON_CTRL, MSR_UNC_ICX_C2_PMON_STATUS, MSR_UNC_ICX_C2_PMON_STATUS, 2, 0, MSR_DEV, 48, MSR_UNC_ICX_C2_PMON_FILTER},
-    [CBOX3] = {MSR_UNC_ICX_C3_PMON_CTRL, MSR_UNC_ICX_C3_PMON_STATUS, MSR_UNC_ICX_C3_PMON_STATUS, 3, 0, MSR_DEV, 48, MSR_UNC_ICX_C3_PMON_FILTER},
-    [CBOX4] = {MSR_UNC_ICX_C4_PMON_CTRL, MSR_UNC_ICX_C4_PMON_STATUS, MSR_UNC_ICX_C4_PMON_STATUS, 4, 0, MSR_DEV, 48, MSR_UNC_ICX_C4_PMON_FILTER},
-    [CBOX5] = {MSR_UNC_ICX_C5_PMON_CTRL, MSR_UNC_ICX_C5_PMON_STATUS, MSR_UNC_ICX_C5_PMON_STATUS, 5, 0, MSR_DEV, 48, MSR_UNC_ICX_C5_PMON_FILTER},
-    [CBOX6] = {MSR_UNC_ICX_C6_PMON_CTRL, MSR_UNC_ICX_C6_PMON_STATUS, MSR_UNC_ICX_C6_PMON_STATUS, 6, 0, MSR_DEV, 48, MSR_UNC_ICX_C6_PMON_FILTER},
-    [CBOX7] = {MSR_UNC_ICX_C7_PMON_CTRL, MSR_UNC_ICX_C7_PMON_STATUS, MSR_UNC_ICX_C7_PMON_STATUS, 7, 0, MSR_DEV, 48, MSR_UNC_ICX_C7_PMON_FILTER},
-    [CBOX8] = {MSR_UNC_ICX_C8_PMON_CTRL, MSR_UNC_ICX_C8_PMON_STATUS, MSR_UNC_ICX_C8_PMON_STATUS, 8, 0, MSR_DEV, 48, MSR_UNC_ICX_C8_PMON_FILTER},
-    [CBOX9] = {MSR_UNC_ICX_C9_PMON_CTRL, MSR_UNC_ICX_C9_PMON_STATUS, MSR_UNC_ICX_C9_PMON_STATUS, 9, 0, MSR_DEV, 48, MSR_UNC_ICX_C9_PMON_FILTER},
-    [CBOX10] = {MSR_UNC_ICX_C10_PMON_CTRL, MSR_UNC_ICX_C10_PMON_STATUS, MSR_UNC_ICX_C10_PMON_STATUS, 10, 0, MSR_DEV, 48, MSR_UNC_ICX_C10_PMON_FILTER},
-    [CBOX11] = {MSR_UNC_ICX_C11_PMON_CTRL, MSR_UNC_ICX_C11_PMON_STATUS, MSR_UNC_ICX_C11_PMON_STATUS, 11, 0, MSR_DEV, 48, MSR_UNC_ICX_C11_PMON_FILTER},
-    [CBOX12] = {MSR_UNC_ICX_C12_PMON_CTRL, MSR_UNC_ICX_C12_PMON_STATUS, MSR_UNC_ICX_C12_PMON_STATUS, 12, 0, MSR_DEV, 48, MSR_UNC_ICX_C12_PMON_FILTER},
-    [CBOX13] = {MSR_UNC_ICX_C13_PMON_CTRL, MSR_UNC_ICX_C13_PMON_STATUS, MSR_UNC_ICX_C13_PMON_STATUS, 13, 0, MSR_DEV, 48, MSR_UNC_ICX_C13_PMON_FILTER},
-    [CBOX14] = {MSR_UNC_ICX_C14_PMON_CTRL, MSR_UNC_ICX_C14_PMON_STATUS, MSR_UNC_ICX_C14_PMON_STATUS, 14, 0, MSR_DEV, 48, MSR_UNC_ICX_C14_PMON_FILTER},
-    [CBOX15] = {MSR_UNC_ICX_C15_PMON_CTRL, MSR_UNC_ICX_C15_PMON_STATUS, MSR_UNC_ICX_C15_PMON_STATUS, 15, 0, MSR_DEV, 48, MSR_UNC_ICX_C15_PMON_FILTER},
-    [CBOX16] = {MSR_UNC_ICX_C16_PMON_CTRL, MSR_UNC_ICX_C16_PMON_STATUS, MSR_UNC_ICX_C16_PMON_STATUS, 16, 0, MSR_DEV, 48, MSR_UNC_ICX_C16_PMON_FILTER},
-    [CBOX17] = {MSR_UNC_ICX_C17_PMON_CTRL, MSR_UNC_ICX_C17_PMON_STATUS, MSR_UNC_ICX_C17_PMON_STATUS, 17, 0, MSR_DEV, 48, MSR_UNC_ICX_C17_PMON_FILTER},
-    [CBOX18] = {MSR_UNC_ICX_C18_PMON_CTRL, MSR_UNC_ICX_C18_PMON_STATUS, MSR_UNC_ICX_C18_PMON_STATUS, 18, 0, MSR_DEV, 48, MSR_UNC_ICX_C18_PMON_FILTER},
-    [CBOX19] = {MSR_UNC_ICX_C19_PMON_CTRL, MSR_UNC_ICX_C19_PMON_STATUS, MSR_UNC_ICX_C19_PMON_STATUS, 19, 0, MSR_DEV, 48, MSR_UNC_ICX_C19_PMON_FILTER},
-    [CBOX20] = {MSR_UNC_ICX_C20_PMON_CTRL, MSR_UNC_ICX_C20_PMON_STATUS, MSR_UNC_ICX_C20_PMON_STATUS, 20, 0, MSR_DEV, 48, MSR_UNC_ICX_C20_PMON_FILTER},
-    [CBOX21] = {MSR_UNC_ICX_C21_PMON_CTRL, MSR_UNC_ICX_C21_PMON_STATUS, MSR_UNC_ICX_C21_PMON_STATUS, 21, 0, MSR_DEV, 48, MSR_UNC_ICX_C21_PMON_FILTER},
-    [CBOX22] = {MSR_UNC_ICX_C22_PMON_CTRL, MSR_UNC_ICX_C22_PMON_STATUS, MSR_UNC_ICX_C22_PMON_STATUS, 22, 0, MSR_DEV, 48, MSR_UNC_ICX_C22_PMON_FILTER},
-    [CBOX23] = {MSR_UNC_ICX_C23_PMON_CTRL, MSR_UNC_ICX_C23_PMON_STATUS, MSR_UNC_ICX_C23_PMON_STATUS, 23, 0, MSR_DEV, 48, MSR_UNC_ICX_C23_PMON_FILTER},
-    [CBOX24] = {MSR_UNC_ICX_C24_PMON_CTRL, MSR_UNC_ICX_C24_PMON_STATUS, MSR_UNC_ICX_C24_PMON_STATUS, 24, 0, MSR_DEV, 48, MSR_UNC_ICX_C24_PMON_FILTER},
-    [CBOX25] = {MSR_UNC_ICX_C25_PMON_CTRL, MSR_UNC_ICX_C25_PMON_STATUS, MSR_UNC_ICX_C25_PMON_STATUS, 25, 0, MSR_DEV, 48, MSR_UNC_ICX_C25_PMON_FILTER},
-    [CBOX26] = {MSR_UNC_ICX_C26_PMON_CTRL, MSR_UNC_ICX_C26_PMON_STATUS, MSR_UNC_ICX_C26_PMON_STATUS, 26, 0, MSR_DEV, 48, MSR_UNC_ICX_C26_PMON_FILTER},
-    [CBOX27] = {MSR_UNC_ICX_C27_PMON_CTRL, MSR_UNC_ICX_C27_PMON_STATUS, MSR_UNC_ICX_C27_PMON_STATUS, 27, 0, MSR_DEV, 48, MSR_UNC_ICX_C27_PMON_FILTER},
-    [CBOX28] = {MSR_UNC_ICX_C28_PMON_CTRL, MSR_UNC_ICX_C28_PMON_STATUS, MSR_UNC_ICX_C28_PMON_STATUS, 28, 0, MSR_DEV, 48, MSR_UNC_ICX_C28_PMON_FILTER},
-    [CBOX29] = {MSR_UNC_ICX_C29_PMON_CTRL, MSR_UNC_ICX_C29_PMON_STATUS, MSR_UNC_ICX_C29_PMON_STATUS, 29, 0, MSR_DEV, 48, MSR_UNC_ICX_C29_PMON_FILTER},
-    [CBOX30] = {MSR_UNC_ICX_C30_PMON_CTRL, MSR_UNC_ICX_C30_PMON_STATUS, MSR_UNC_ICX_C30_PMON_STATUS, 30, 0, MSR_DEV, 48, MSR_UNC_ICX_C30_PMON_FILTER},
-    [CBOX31] = {MSR_UNC_ICX_C31_PMON_CTRL, MSR_UNC_ICX_C31_PMON_STATUS, MSR_UNC_ICX_C31_PMON_STATUS, 31, 0, MSR_DEV, 48, MSR_UNC_ICX_C31_PMON_FILTER},
-    [CBOX32] = {MSR_UNC_ICX_C32_PMON_CTRL, MSR_UNC_ICX_C32_PMON_STATUS, MSR_UNC_ICX_C32_PMON_STATUS, 32, 0, MSR_DEV, 48, MSR_UNC_ICX_C32_PMON_FILTER},
-    [CBOX33] = {MSR_UNC_ICX_C33_PMON_CTRL, MSR_UNC_ICX_C33_PMON_STATUS, MSR_UNC_ICX_C33_PMON_STATUS, 33, 0, MSR_DEV, 48, MSR_UNC_ICX_C33_PMON_FILTER},
-    [CBOX34] = {MSR_UNC_ICX_C34_PMON_CTRL, MSR_UNC_ICX_C34_PMON_STATUS, MSR_UNC_ICX_C34_PMON_STATUS, 34, 0, MSR_DEV, 48, MSR_UNC_ICX_C34_PMON_FILTER},
-    [CBOX35] = {MSR_UNC_ICX_C35_PMON_CTRL, MSR_UNC_ICX_C35_PMON_STATUS, MSR_UNC_ICX_C35_PMON_STATUS, 35, 0, MSR_DEV, 48, MSR_UNC_ICX_C35_PMON_FILTER},
-    [CBOX36] = {MSR_UNC_ICX_C36_PMON_CTRL, MSR_UNC_ICX_C36_PMON_STATUS, MSR_UNC_ICX_C36_PMON_STATUS, 36, 0, MSR_DEV, 48, MSR_UNC_ICX_C36_PMON_FILTER},
-    [CBOX37] = {MSR_UNC_ICX_C37_PMON_CTRL, MSR_UNC_ICX_C37_PMON_STATUS, MSR_UNC_ICX_C37_PMON_STATUS, 37, 0, MSR_DEV, 48, MSR_UNC_ICX_C37_PMON_FILTER},
-    [CBOX38] = {MSR_UNC_ICX_C38_PMON_CTRL, MSR_UNC_ICX_C38_PMON_STATUS, MSR_UNC_ICX_C38_PMON_STATUS, 38, 0, MSR_DEV, 48, MSR_UNC_ICX_C38_PMON_FILTER},
-    [CBOX39] = {MSR_UNC_ICX_C39_PMON_CTRL, MSR_UNC_ICX_C39_PMON_STATUS, MSR_UNC_ICX_C39_PMON_STATUS, 39, 0, MSR_DEV, 48, MSR_UNC_ICX_C39_PMON_FILTER},
-    [UBOXFIX] = {MSR_V4_UNC_PERF_GLOBAL_CTRL, MSR_V4_UNC_PERF_GLOBAL_STATUS, MSR_V4_UNC_PERF_GLOBAL_STATUS, 0, 0, 0, 48},
-    [UBOX] = {MSR_V4_UNC_PERF_GLOBAL_CTRL, MSR_V4_UNC_PERF_GLOBAL_STATUS, MSR_V4_UNC_PERF_GLOBAL_STATUS, 1, 0, 0, 48},
-    [BBOX0] = {PCI_UNC_ICX_M2M_PMON_CTRL, PCI_UNC_ICX_M2M_PMON_STATUS, PCI_UNC_ICX_M2M_PMON_STATUS, -1, 1, PCI_HA_DEVICE_0, 48},
-    [BBOX1] = {PCI_UNC_ICX_M2M_PMON_CTRL, PCI_UNC_ICX_M2M_PMON_STATUS, PCI_UNC_ICX_M2M_PMON_STATUS, -1, 1, PCI_HA_DEVICE_1, 48},
-    [BBOX2] = {PCI_UNC_ICX_M2M_PMON_CTRL, PCI_UNC_ICX_M2M_PMON_STATUS, PCI_UNC_ICX_M2M_PMON_STATUS, -1, 1, PCI_HA_DEVICE_2, 48},
-    [BBOX3] = {PCI_UNC_ICX_M2M_PMON_CTRL, PCI_UNC_ICX_M2M_PMON_STATUS, PCI_UNC_ICX_M2M_PMON_STATUS, -1, 1, PCI_HA_DEVICE_3, 48},
-    [SBOX0] = {PCI_UNC_ICX_M3UPI_PMON_CTRL, PCI_UNC_ICX_M3UPI_PMON_STATUS, PCI_UNC_ICX_M3UPI_PMON_STATUS, -1, 1, PCI_R3QPI_DEVICE_LINK_0, 48},
-    [SBOX1] = {PCI_UNC_ICX_M3UPI_PMON_CTRL, PCI_UNC_ICX_M3UPI_PMON_STATUS, PCI_UNC_ICX_M3UPI_PMON_STATUS, -1, 1, PCI_R3QPI_DEVICE_LINK_1, 48},
-    [SBOX2] = {PCI_UNC_ICX_M3UPI_PMON_CTRL, PCI_UNC_ICX_M3UPI_PMON_STATUS, PCI_UNC_ICX_M3UPI_PMON_STATUS, -1, 1, PCI_R3QPI_DEVICE_LINK_2, 48},
-    [QBOX0] = {PCI_UNC_ICX_UPI_PMON_CTRL, PCI_UNC_ICX_UPI_PMON_STATUS, PCI_UNC_ICX_UPI_PMON_STATUS, -1, 1, PCI_QPI_DEVICE_PORT_0, 48},
-    [QBOX1] = {PCI_UNC_ICX_UPI_PMON_CTRL, PCI_UNC_ICX_UPI_PMON_STATUS, PCI_UNC_ICX_UPI_PMON_STATUS, -1, 1, PCI_QPI_DEVICE_PORT_1, 48},
-    [QBOX2] = {PCI_UNC_ICX_UPI_PMON_CTRL, PCI_UNC_ICX_UPI_PMON_STATUS, PCI_UNC_ICX_UPI_PMON_STATUS, -1, 1, PCI_QPI_DEVICE_PORT_2, 48},
-    [PBOX] = {MSR_UNC_M2IOSF_M2PCIE0_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE0_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE0_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [PBOX1] = {MSR_UNC_M2IOSF_M2PCIE1_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE1_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE1_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [PBOX2] = {MSR_UNC_M2IOSF_M2PCIE2_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE2_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE2_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [PBOX3] = {MSR_UNC_M2IOSF_M2PCIE3_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE3_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE3_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [PBOX4] = {MSR_UNC_M2IOSF_M2PCIE4_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE4_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE4_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [PBOX5] = {MSR_UNC_M2IOSF_M2PCIE5_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE5_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE5_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [IBOX0] = {MSR_UNC_M2IOSF_IRP0_PMON_CTRL, MSR_UNC_M2IOSF_IRP0_PMON_STATUS, MSR_UNC_M2IOSF_IRP0_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [IBOX1] = {MSR_UNC_M2IOSF_IRP1_PMON_CTRL, MSR_UNC_M2IOSF_IRP1_PMON_STATUS, MSR_UNC_M2IOSF_IRP1_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [IBOX2] = {MSR_UNC_M2IOSF_IRP2_PMON_CTRL, MSR_UNC_M2IOSF_IRP2_PMON_STATUS, MSR_UNC_M2IOSF_IRP2_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [IBOX3] = {MSR_UNC_M2IOSF_IRP3_PMON_CTRL, MSR_UNC_M2IOSF_IRP3_PMON_STATUS, MSR_UNC_M2IOSF_IRP3_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [IBOX4] = {MSR_UNC_M2IOSF_IRP4_PMON_CTRL, MSR_UNC_M2IOSF_IRP4_PMON_STATUS, MSR_UNC_M2IOSF_IRP4_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [IBOX5] = {MSR_UNC_M2IOSF_IRP5_PMON_CTRL, MSR_UNC_M2IOSF_IRP5_PMON_STATUS, MSR_UNC_M2IOSF_IRP5_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [EUBOX0] = {MSR_UNC_M2IOSF_TC0_PMON_CTRL, MSR_UNC_M2IOSF_TC0_PMON_STATUS, MSR_UNC_M2IOSF_TC0_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [EUBOX1] = {MSR_UNC_M2IOSF_TC1_PMON_CTRL, MSR_UNC_M2IOSF_TC1_PMON_STATUS, MSR_UNC_M2IOSF_TC1_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [EUBOX2] = {MSR_UNC_M2IOSF_TC2_PMON_CTRL, MSR_UNC_M2IOSF_TC2_PMON_STATUS, MSR_UNC_M2IOSF_TC2_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [EUBOX3] = {MSR_UNC_M2IOSF_TC3_PMON_CTRL, MSR_UNC_M2IOSF_TC3_PMON_STATUS, MSR_UNC_M2IOSF_TC3_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [EUBOX4] = {MSR_UNC_M2IOSF_TC4_PMON_CTRL, MSR_UNC_M2IOSF_TC4_PMON_STATUS, MSR_UNC_M2IOSF_TC4_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [EUBOX5] = {MSR_UNC_M2IOSF_TC5_PMON_CTRL, MSR_UNC_M2IOSF_TC5_PMON_STATUS, MSR_UNC_M2IOSF_TC5_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [EUBOX0FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [EUBOX1FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [EUBOX2FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [EUBOX3FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [EUBOX4FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [EUBOX5FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [IBOX0FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [IBOX1FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [IBOX2FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [IBOX3FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [IBOX4FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [IBOX5FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48},
-    [WBOX] = {MSR_UNC_ICX_PCU_PMON_CTRL, MSR_UNC_ICX_PCU_PMON_STATUS, MSR_UNC_ICX_PCU_PMON_STATUS, -1, 0, MSR_DEV, 48},
-    [WBOX0FIX] = {0, 0, 0, -1, 0, MSR_DEV, 64},
-    [WBOX1FIX] = {0, 0, 0, -1, 0, MSR_DEV, 64},
-    [WBOX2FIX] = {0, 0, 0, -1, 0, MSR_DEV, 64},
-    [WBOX3FIX] = {0, 0, 0, -1, 0, MSR_DEV, 64},
+    [FIXED] =  {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48, 0, 0},
+    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48, 0, 0},
+    [THERMAL] = {0, 0, 0, 0, 0, 0, 8, 0, 0},
+    [POWER] = {0, 0, 0, 0, 0, 0, 32, 0, 0},
+    [VOLTAGE] = {0, 0, 0, 0, 0, 0, 16, 0, 0},
+    [METRICS] = {0, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS, 48, 0, 0, 8, 0, 0},
+    [MBOX0] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_0, 48, 0, 0},
+    [MBOX1] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_1, 48, 0, 0},
+    [MBOX2] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_2, 48, 0, 0},
+    [MBOX3] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_3, 48, 0, 0},
+    [MBOX4] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_4, 48, 0, 0},
+    [MBOX5] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_5, 48, 0, 0},
+    [MBOX6] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_6, 48, 0, 0},
+    [MBOX7] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_7, 48, 0, 0},
+    [MBOX0FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_0, 48, 0, 0},
+    [MBOX1FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_1, 48, 0, 0},
+    [MBOX2FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_2, 48, 0, 0},
+    [MBOX3FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_3, 48, 0, 0},
+    [MBOX4FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_4, 48, 0, 0},
+    [MBOX5FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_5, 48, 0, 0},
+    [MBOX6FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_6, 48, 0, 0},
+    [MBOX7FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_7, 48, 0, 0},
+    [MDEV0] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_0_FREERUN, 64, 0, 0},
+    [MDEV1] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_1_FREERUN, 64, 0, 0},
+    [MDEV2] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_2_FREERUN, 64, 0, 0},
+    [MDEV3] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_3_FREERUN, 64, 0, 0},
+    [CBOX0] = {MSR_UNC_ICX_C0_PMON_CTRL, MSR_UNC_ICX_C0_PMON_STATUS, MSR_UNC_ICX_C0_PMON_STATUS, 0, 0, MSR_DEV, 48, MSR_UNC_ICX_C0_PMON_FILTER, 0},
+    [CBOX1] = {MSR_UNC_ICX_C1_PMON_CTRL, MSR_UNC_ICX_C1_PMON_STATUS, MSR_UNC_ICX_C1_PMON_STATUS, 1, 0, MSR_DEV, 48, MSR_UNC_ICX_C1_PMON_FILTER, 0},
+    [CBOX2] = {MSR_UNC_ICX_C2_PMON_CTRL, MSR_UNC_ICX_C2_PMON_STATUS, MSR_UNC_ICX_C2_PMON_STATUS, 2, 0, MSR_DEV, 48, MSR_UNC_ICX_C2_PMON_FILTER, 0},
+    [CBOX3] = {MSR_UNC_ICX_C3_PMON_CTRL, MSR_UNC_ICX_C3_PMON_STATUS, MSR_UNC_ICX_C3_PMON_STATUS, 3, 0, MSR_DEV, 48, MSR_UNC_ICX_C3_PMON_FILTER, 0},
+    [CBOX4] = {MSR_UNC_ICX_C4_PMON_CTRL, MSR_UNC_ICX_C4_PMON_STATUS, MSR_UNC_ICX_C4_PMON_STATUS, 4, 0, MSR_DEV, 48, MSR_UNC_ICX_C4_PMON_FILTER, 0},
+    [CBOX5] = {MSR_UNC_ICX_C5_PMON_CTRL, MSR_UNC_ICX_C5_PMON_STATUS, MSR_UNC_ICX_C5_PMON_STATUS, 5, 0, MSR_DEV, 48, MSR_UNC_ICX_C5_PMON_FILTER, 0},
+    [CBOX6] = {MSR_UNC_ICX_C6_PMON_CTRL, MSR_UNC_ICX_C6_PMON_STATUS, MSR_UNC_ICX_C6_PMON_STATUS, 6, 0, MSR_DEV, 48, MSR_UNC_ICX_C6_PMON_FILTER, 0},
+    [CBOX7] = {MSR_UNC_ICX_C7_PMON_CTRL, MSR_UNC_ICX_C7_PMON_STATUS, MSR_UNC_ICX_C7_PMON_STATUS, 7, 0, MSR_DEV, 48, MSR_UNC_ICX_C7_PMON_FILTER, 0},
+    [CBOX8] = {MSR_UNC_ICX_C8_PMON_CTRL, MSR_UNC_ICX_C8_PMON_STATUS, MSR_UNC_ICX_C8_PMON_STATUS, 8, 0, MSR_DEV, 48, MSR_UNC_ICX_C8_PMON_FILTER, 0},
+    [CBOX9] = {MSR_UNC_ICX_C9_PMON_CTRL, MSR_UNC_ICX_C9_PMON_STATUS, MSR_UNC_ICX_C9_PMON_STATUS, 9, 0, MSR_DEV, 48, MSR_UNC_ICX_C9_PMON_FILTER, 0},
+    [CBOX10] = {MSR_UNC_ICX_C10_PMON_CTRL, MSR_UNC_ICX_C10_PMON_STATUS, MSR_UNC_ICX_C10_PMON_STATUS, 10, 0, MSR_DEV, 48, MSR_UNC_ICX_C10_PMON_FILTER, 0},
+    [CBOX11] = {MSR_UNC_ICX_C11_PMON_CTRL, MSR_UNC_ICX_C11_PMON_STATUS, MSR_UNC_ICX_C11_PMON_STATUS, 11, 0, MSR_DEV, 48, MSR_UNC_ICX_C11_PMON_FILTER, 0},
+    [CBOX12] = {MSR_UNC_ICX_C12_PMON_CTRL, MSR_UNC_ICX_C12_PMON_STATUS, MSR_UNC_ICX_C12_PMON_STATUS, 12, 0, MSR_DEV, 48, MSR_UNC_ICX_C12_PMON_FILTER, 0},
+    [CBOX13] = {MSR_UNC_ICX_C13_PMON_CTRL, MSR_UNC_ICX_C13_PMON_STATUS, MSR_UNC_ICX_C13_PMON_STATUS, 13, 0, MSR_DEV, 48, MSR_UNC_ICX_C13_PMON_FILTER, 0},
+    [CBOX14] = {MSR_UNC_ICX_C14_PMON_CTRL, MSR_UNC_ICX_C14_PMON_STATUS, MSR_UNC_ICX_C14_PMON_STATUS, 14, 0, MSR_DEV, 48, MSR_UNC_ICX_C14_PMON_FILTER, 0},
+    [CBOX15] = {MSR_UNC_ICX_C15_PMON_CTRL, MSR_UNC_ICX_C15_PMON_STATUS, MSR_UNC_ICX_C15_PMON_STATUS, 15, 0, MSR_DEV, 48, MSR_UNC_ICX_C15_PMON_FILTER, 0},
+    [CBOX16] = {MSR_UNC_ICX_C16_PMON_CTRL, MSR_UNC_ICX_C16_PMON_STATUS, MSR_UNC_ICX_C16_PMON_STATUS, 16, 0, MSR_DEV, 48, MSR_UNC_ICX_C16_PMON_FILTER, 0},
+    [CBOX17] = {MSR_UNC_ICX_C17_PMON_CTRL, MSR_UNC_ICX_C17_PMON_STATUS, MSR_UNC_ICX_C17_PMON_STATUS, 17, 0, MSR_DEV, 48, MSR_UNC_ICX_C17_PMON_FILTER, 0},
+    [CBOX18] = {MSR_UNC_ICX_C18_PMON_CTRL, MSR_UNC_ICX_C18_PMON_STATUS, MSR_UNC_ICX_C18_PMON_STATUS, 18, 0, MSR_DEV, 48, MSR_UNC_ICX_C18_PMON_FILTER, 0},
+    [CBOX19] = {MSR_UNC_ICX_C19_PMON_CTRL, MSR_UNC_ICX_C19_PMON_STATUS, MSR_UNC_ICX_C19_PMON_STATUS, 19, 0, MSR_DEV, 48, MSR_UNC_ICX_C19_PMON_FILTER, 0},
+    [CBOX20] = {MSR_UNC_ICX_C20_PMON_CTRL, MSR_UNC_ICX_C20_PMON_STATUS, MSR_UNC_ICX_C20_PMON_STATUS, 20, 0, MSR_DEV, 48, MSR_UNC_ICX_C20_PMON_FILTER, 0},
+    [CBOX21] = {MSR_UNC_ICX_C21_PMON_CTRL, MSR_UNC_ICX_C21_PMON_STATUS, MSR_UNC_ICX_C21_PMON_STATUS, 21, 0, MSR_DEV, 48, MSR_UNC_ICX_C21_PMON_FILTER, 0},
+    [CBOX22] = {MSR_UNC_ICX_C22_PMON_CTRL, MSR_UNC_ICX_C22_PMON_STATUS, MSR_UNC_ICX_C22_PMON_STATUS, 22, 0, MSR_DEV, 48, MSR_UNC_ICX_C22_PMON_FILTER, 0},
+    [CBOX23] = {MSR_UNC_ICX_C23_PMON_CTRL, MSR_UNC_ICX_C23_PMON_STATUS, MSR_UNC_ICX_C23_PMON_STATUS, 23, 0, MSR_DEV, 48, MSR_UNC_ICX_C23_PMON_FILTER, 0},
+    [CBOX24] = {MSR_UNC_ICX_C24_PMON_CTRL, MSR_UNC_ICX_C24_PMON_STATUS, MSR_UNC_ICX_C24_PMON_STATUS, 24, 0, MSR_DEV, 48, MSR_UNC_ICX_C24_PMON_FILTER, 0},
+    [CBOX25] = {MSR_UNC_ICX_C25_PMON_CTRL, MSR_UNC_ICX_C25_PMON_STATUS, MSR_UNC_ICX_C25_PMON_STATUS, 25, 0, MSR_DEV, 48, MSR_UNC_ICX_C25_PMON_FILTER, 0},
+    [CBOX26] = {MSR_UNC_ICX_C26_PMON_CTRL, MSR_UNC_ICX_C26_PMON_STATUS, MSR_UNC_ICX_C26_PMON_STATUS, 26, 0, MSR_DEV, 48, MSR_UNC_ICX_C26_PMON_FILTER, 0},
+    [CBOX27] = {MSR_UNC_ICX_C27_PMON_CTRL, MSR_UNC_ICX_C27_PMON_STATUS, MSR_UNC_ICX_C27_PMON_STATUS, 27, 0, MSR_DEV, 48, MSR_UNC_ICX_C27_PMON_FILTER, 0},
+    [CBOX28] = {MSR_UNC_ICX_C28_PMON_CTRL, MSR_UNC_ICX_C28_PMON_STATUS, MSR_UNC_ICX_C28_PMON_STATUS, 28, 0, MSR_DEV, 48, MSR_UNC_ICX_C28_PMON_FILTER, 0},
+    [CBOX29] = {MSR_UNC_ICX_C29_PMON_CTRL, MSR_UNC_ICX_C29_PMON_STATUS, MSR_UNC_ICX_C29_PMON_STATUS, 29, 0, MSR_DEV, 48, MSR_UNC_ICX_C29_PMON_FILTER, 0},
+    [CBOX30] = {MSR_UNC_ICX_C30_PMON_CTRL, MSR_UNC_ICX_C30_PMON_STATUS, MSR_UNC_ICX_C30_PMON_STATUS, 30, 0, MSR_DEV, 48, MSR_UNC_ICX_C30_PMON_FILTER, 0},
+    [CBOX31] = {MSR_UNC_ICX_C31_PMON_CTRL, MSR_UNC_ICX_C31_PMON_STATUS, MSR_UNC_ICX_C31_PMON_STATUS, 31, 0, MSR_DEV, 48, MSR_UNC_ICX_C31_PMON_FILTER, 0},
+    [CBOX32] = {MSR_UNC_ICX_C32_PMON_CTRL, MSR_UNC_ICX_C32_PMON_STATUS, MSR_UNC_ICX_C32_PMON_STATUS, 32, 0, MSR_DEV, 48, MSR_UNC_ICX_C32_PMON_FILTER, 0},
+    [CBOX33] = {MSR_UNC_ICX_C33_PMON_CTRL, MSR_UNC_ICX_C33_PMON_STATUS, MSR_UNC_ICX_C33_PMON_STATUS, 33, 0, MSR_DEV, 48, MSR_UNC_ICX_C33_PMON_FILTER, 0},
+    [CBOX34] = {MSR_UNC_ICX_C34_PMON_CTRL, MSR_UNC_ICX_C34_PMON_STATUS, MSR_UNC_ICX_C34_PMON_STATUS, 34, 0, MSR_DEV, 48, MSR_UNC_ICX_C34_PMON_FILTER, 0},
+    [CBOX35] = {MSR_UNC_ICX_C35_PMON_CTRL, MSR_UNC_ICX_C35_PMON_STATUS, MSR_UNC_ICX_C35_PMON_STATUS, 35, 0, MSR_DEV, 48, MSR_UNC_ICX_C35_PMON_FILTER, 0},
+    [CBOX36] = {MSR_UNC_ICX_C36_PMON_CTRL, MSR_UNC_ICX_C36_PMON_STATUS, MSR_UNC_ICX_C36_PMON_STATUS, 36, 0, MSR_DEV, 48, MSR_UNC_ICX_C36_PMON_FILTER, 0},
+    [CBOX37] = {MSR_UNC_ICX_C37_PMON_CTRL, MSR_UNC_ICX_C37_PMON_STATUS, MSR_UNC_ICX_C37_PMON_STATUS, 37, 0, MSR_DEV, 48, MSR_UNC_ICX_C37_PMON_FILTER, 0},
+    [CBOX38] = {MSR_UNC_ICX_C38_PMON_CTRL, MSR_UNC_ICX_C38_PMON_STATUS, MSR_UNC_ICX_C38_PMON_STATUS, 38, 0, MSR_DEV, 48, MSR_UNC_ICX_C38_PMON_FILTER, 0},
+    [CBOX39] = {MSR_UNC_ICX_C39_PMON_CTRL, MSR_UNC_ICX_C39_PMON_STATUS, MSR_UNC_ICX_C39_PMON_STATUS, 39, 0, MSR_DEV, 48, MSR_UNC_ICX_C39_PMON_FILTER, 0},
+    [UBOXFIX] = {MSR_V4_UNC_PERF_GLOBAL_CTRL, MSR_V4_UNC_PERF_GLOBAL_STATUS, MSR_V4_UNC_PERF_GLOBAL_STATUS, 0, 0, 0, 48, 0, 0},
+    [UBOX] = {MSR_V4_UNC_PERF_GLOBAL_CTRL, MSR_V4_UNC_PERF_GLOBAL_STATUS, MSR_V4_UNC_PERF_GLOBAL_STATUS, 1, 0, 0, 48, 0, 0},
+    [BBOX0] = {PCI_UNC_ICX_M2M_PMON_CTRL, PCI_UNC_ICX_M2M_PMON_STATUS, PCI_UNC_ICX_M2M_PMON_STATUS, -1, 1, PCI_HA_DEVICE_0, 48, 0, 0},
+    [BBOX1] = {PCI_UNC_ICX_M2M_PMON_CTRL, PCI_UNC_ICX_M2M_PMON_STATUS, PCI_UNC_ICX_M2M_PMON_STATUS, -1, 1, PCI_HA_DEVICE_1, 48, 0, 0},
+    [BBOX2] = {PCI_UNC_ICX_M2M_PMON_CTRL, PCI_UNC_ICX_M2M_PMON_STATUS, PCI_UNC_ICX_M2M_PMON_STATUS, -1, 1, PCI_HA_DEVICE_2, 48, 0, 0},
+    [BBOX3] = {PCI_UNC_ICX_M2M_PMON_CTRL, PCI_UNC_ICX_M2M_PMON_STATUS, PCI_UNC_ICX_M2M_PMON_STATUS, -1, 1, PCI_HA_DEVICE_3, 48, 0, 0},
+    [SBOX0] = {PCI_UNC_ICX_M3UPI_PMON_CTRL, PCI_UNC_ICX_M3UPI_PMON_STATUS, PCI_UNC_ICX_M3UPI_PMON_STATUS, -1, 1, PCI_R3QPI_DEVICE_LINK_0, 48, 0, 0},
+    [SBOX1] = {PCI_UNC_ICX_M3UPI_PMON_CTRL, PCI_UNC_ICX_M3UPI_PMON_STATUS, PCI_UNC_ICX_M3UPI_PMON_STATUS, -1, 1, PCI_R3QPI_DEVICE_LINK_1, 48, 0, 0},
+    [SBOX2] = {PCI_UNC_ICX_M3UPI_PMON_CTRL, PCI_UNC_ICX_M3UPI_PMON_STATUS, PCI_UNC_ICX_M3UPI_PMON_STATUS, -1, 1, PCI_R3QPI_DEVICE_LINK_2, 48, 0, 0},
+    [QBOX0] = {PCI_UNC_ICX_UPI_PMON_CTRL, PCI_UNC_ICX_UPI_PMON_STATUS, PCI_UNC_ICX_UPI_PMON_STATUS, -1, 1, PCI_QPI_DEVICE_PORT_0, 48, 0, 0},
+    [QBOX1] = {PCI_UNC_ICX_UPI_PMON_CTRL, PCI_UNC_ICX_UPI_PMON_STATUS, PCI_UNC_ICX_UPI_PMON_STATUS, -1, 1, PCI_QPI_DEVICE_PORT_1, 48, 0, 0},
+    [QBOX2] = {PCI_UNC_ICX_UPI_PMON_CTRL, PCI_UNC_ICX_UPI_PMON_STATUS, PCI_UNC_ICX_UPI_PMON_STATUS, -1, 1, PCI_QPI_DEVICE_PORT_2, 48, 0, 0},
+    [PBOX] = {MSR_UNC_M2IOSF_M2PCIE0_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE0_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE0_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [PBOX1] = {MSR_UNC_M2IOSF_M2PCIE1_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE1_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE1_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [PBOX2] = {MSR_UNC_M2IOSF_M2PCIE2_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE2_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE2_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [PBOX3] = {MSR_UNC_M2IOSF_M2PCIE3_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE3_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE3_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [PBOX4] = {MSR_UNC_M2IOSF_M2PCIE4_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE4_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE4_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [PBOX5] = {MSR_UNC_M2IOSF_M2PCIE5_PMON_CTRL, MSR_UNC_M2IOSF_M2PCIE5_PMON_STATUS, MSR_UNC_M2IOSF_M2PCIE5_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [IBOX0] = {MSR_UNC_M2IOSF_IRP0_PMON_CTRL, MSR_UNC_M2IOSF_IRP0_PMON_STATUS, MSR_UNC_M2IOSF_IRP0_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [IBOX1] = {MSR_UNC_M2IOSF_IRP1_PMON_CTRL, MSR_UNC_M2IOSF_IRP1_PMON_STATUS, MSR_UNC_M2IOSF_IRP1_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [IBOX2] = {MSR_UNC_M2IOSF_IRP2_PMON_CTRL, MSR_UNC_M2IOSF_IRP2_PMON_STATUS, MSR_UNC_M2IOSF_IRP2_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [IBOX3] = {MSR_UNC_M2IOSF_IRP3_PMON_CTRL, MSR_UNC_M2IOSF_IRP3_PMON_STATUS, MSR_UNC_M2IOSF_IRP3_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [IBOX4] = {MSR_UNC_M2IOSF_IRP4_PMON_CTRL, MSR_UNC_M2IOSF_IRP4_PMON_STATUS, MSR_UNC_M2IOSF_IRP4_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [IBOX5] = {MSR_UNC_M2IOSF_IRP5_PMON_CTRL, MSR_UNC_M2IOSF_IRP5_PMON_STATUS, MSR_UNC_M2IOSF_IRP5_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX0] = {MSR_UNC_M2IOSF_TC0_PMON_CTRL, MSR_UNC_M2IOSF_TC0_PMON_STATUS, MSR_UNC_M2IOSF_TC0_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX1] = {MSR_UNC_M2IOSF_TC1_PMON_CTRL, MSR_UNC_M2IOSF_TC1_PMON_STATUS, MSR_UNC_M2IOSF_TC1_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX2] = {MSR_UNC_M2IOSF_TC2_PMON_CTRL, MSR_UNC_M2IOSF_TC2_PMON_STATUS, MSR_UNC_M2IOSF_TC2_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX3] = {MSR_UNC_M2IOSF_TC3_PMON_CTRL, MSR_UNC_M2IOSF_TC3_PMON_STATUS, MSR_UNC_M2IOSF_TC3_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX4] = {MSR_UNC_M2IOSF_TC4_PMON_CTRL, MSR_UNC_M2IOSF_TC4_PMON_STATUS, MSR_UNC_M2IOSF_TC4_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX5] = {MSR_UNC_M2IOSF_TC5_PMON_CTRL, MSR_UNC_M2IOSF_TC5_PMON_STATUS, MSR_UNC_M2IOSF_TC5_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX0FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX1FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX2FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX3FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX4FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [EUBOX5FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [IBOX0FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [IBOX1FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [IBOX2FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [IBOX3FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [IBOX4FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [IBOX5FIX] = {0, 0, 0, 0, 0, MSR_DEV, 48, 0, 0},
+    [WBOX] = {MSR_UNC_ICX_PCU_PMON_CTRL, MSR_UNC_ICX_PCU_PMON_STATUS, MSR_UNC_ICX_PCU_PMON_STATUS, -1, 0, MSR_DEV, 48, 0, 0},
+    [WBOX0FIX] = {0, 0, 0, -1, 0, MSR_DEV, 64, 0, 0},
+    [WBOX1FIX] = {0, 0, 0, -1, 0, MSR_DEV, 64, 0, 0},
+    [WBOX2FIX] = {0, 0, 0, -1, 0, MSR_DEV, 64, 0, 0},
+    [WBOX3FIX] = {0, 0, 0, -1, 0, MSR_DEV, 64, 0, 0},
 };
 
 static PciDevice icelakeX_pci_devices[MAX_NUM_PCI_DEVICES] = {
- [MSR_DEV] = {NODEVTYPE, "", "MSR", ""},
- [MMIO_IMC_DEVICE_0_CH_0] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX0", 0x3451},
- [MMIO_IMC_DEVICE_0_CH_1] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX1", 0x3451},
- [MMIO_IMC_DEVICE_0_CH_2] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX2", 0x3451},
- [MMIO_IMC_DEVICE_0_CH_3] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX3", 0x3451},
- [MMIO_IMC_DEVICE_0_CH_4] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX4", 0x3451},
- [MMIO_IMC_DEVICE_0_CH_5] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX5", 0x3451},
- [MMIO_IMC_DEVICE_0_CH_6] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX6", 0x3451},
- [MMIO_IMC_DEVICE_0_CH_7] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX7", 0x3451},
- [MMIO_IMC_DEVICE_0_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV0", 0x3451},
- [MMIO_IMC_DEVICE_1_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV1", 0x3451},
- [MMIO_IMC_DEVICE_2_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV2", 0x3451},
- [MMIO_IMC_DEVICE_3_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV3", 0x3451},
- [PCI_HA_DEVICE_0] = {HA, "0c.0", "PCI_HA_DEVICE_0", "BBOX0", 0x344A},
- [PCI_HA_DEVICE_1] = {HA, "0d.0", "PCI_HA_DEVICE_1", "BBOX1", 0x344A},
- [PCI_HA_DEVICE_2] = {HA, "0e.0", "PCI_HA_DEVICE_2", "BBOX2", 0x344A},
- [PCI_HA_DEVICE_3] = {HA, "0f.0", "PCI_HA_DEVICE_3", "BBOX3", 0x344A},
- [PCI_R3QPI_DEVICE_LINK_0] = {R3QPI, "05.1", "PCI_R3QPI_DEVICE_LINK_0", "SBOX0", 0x3446},
- [PCI_R3QPI_DEVICE_LINK_1] = {R3QPI, "06.1", "PCI_R3QPI_DEVICE_LINK_1", "SBOX1", 0x3446},
- [PCI_R3QPI_DEVICE_LINK_2] = {R3QPI, "07.1", "PCI_R3QPI_DEVICE_LINK_2", "SBOX2", 0x3446},
- [PCI_QPI_DEVICE_PORT_0] = {QPI, "02.1", "PCI_QPI_DEVICE_PORT_0", "QBOX0", 0x3441},
- [PCI_QPI_DEVICE_PORT_1] = {QPI, "03.1", "PCI_QPI_DEVICE_PORT_1", "QBOX1", 0x3441},
- [PCI_QPI_DEVICE_PORT_2] = {QPI, "04.1", "PCI_QPI_DEVICE_PORT_2", "QBOX2", 0x3441},
+ [MSR_DEV] = {NODEVTYPE, "", "MSR", "", 0, 0},
+ [MMIO_IMC_DEVICE_0_CH_0] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX0", 0x3451, 0},
+ [MMIO_IMC_DEVICE_0_CH_1] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX1", 0x3451, 0},
+ [MMIO_IMC_DEVICE_0_CH_2] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX2", 0x3451, 0},
+ [MMIO_IMC_DEVICE_0_CH_3] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX3", 0x3451, 0},
+ [MMIO_IMC_DEVICE_0_CH_4] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX4", 0x3451, 0},
+ [MMIO_IMC_DEVICE_0_CH_5] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX5", 0x3451, 0},
+ [MMIO_IMC_DEVICE_0_CH_6] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX6", 0x3451, 0},
+ [MMIO_IMC_DEVICE_0_CH_7] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX7", 0x3451, 0},
+ [MMIO_IMC_DEVICE_0_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV0", 0x3451, 0},
+ [MMIO_IMC_DEVICE_1_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV1", 0x3451, 0},
+ [MMIO_IMC_DEVICE_2_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV2", 0x3451, 0},
+ [MMIO_IMC_DEVICE_3_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV3", 0x3451, 0},
+ [PCI_HA_DEVICE_0] = {HA, "0c.0", "PCI_HA_DEVICE_0", "BBOX0", 0x344A, 0},
+ [PCI_HA_DEVICE_1] = {HA, "0d.0", "PCI_HA_DEVICE_1", "BBOX1", 0x344A, 0},
+ [PCI_HA_DEVICE_2] = {HA, "0e.0", "PCI_HA_DEVICE_2", "BBOX2", 0x344A, 0},
+ [PCI_HA_DEVICE_3] = {HA, "0f.0", "PCI_HA_DEVICE_3", "BBOX3", 0x344A, 0},
+ [PCI_R3QPI_DEVICE_LINK_0] = {R3QPI, "05.1", "PCI_R3QPI_DEVICE_LINK_0", "SBOX0", 0x3446, 0},
+ [PCI_R3QPI_DEVICE_LINK_1] = {R3QPI, "06.1", "PCI_R3QPI_DEVICE_LINK_1", "SBOX1", 0x3446, 0},
+ [PCI_R3QPI_DEVICE_LINK_2] = {R3QPI, "07.1", "PCI_R3QPI_DEVICE_LINK_2", "SBOX2", 0x3446, 0},
+ [PCI_QPI_DEVICE_PORT_0] = {QPI, "02.1", "PCI_QPI_DEVICE_PORT_0", "QBOX0", 0x3441, 0},
+ [PCI_QPI_DEVICE_PORT_1] = {QPI, "03.1", "PCI_QPI_DEVICE_PORT_1", "QBOX1", 0x3441, 0},
+ [PCI_QPI_DEVICE_PORT_2] = {QPI, "04.1", "PCI_QPI_DEVICE_PORT_2", "QBOX2", 0x3441, 0},
 };
 
 static char* icelakeX_translate_types[NUM_UNITS] = {
@@ -733,3 +735,5 @@ static char* registerTypeNamesIcelakeX[MAX_UNITS] = {
     [IBOX4FIX] = "IIO Bandwidth In Interface 4 Free-Running Counter",
     [IBOX5FIX] = "IIO Bandwidth In Interface 5 Free-Running Counter",
 };
+
+#endif //PERFMON_ICELAKEX_COUNTERS_H
