@@ -5,14 +5,14 @@
  *
  *      Description:  Counter Header File of perfmon module for AMD Interlagos
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -28,6 +28,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_INTERLAGOS_COUNTERS_H
+#define PERFMON_INTERLAGOS_COUNTERS_H
 
 #define NUM_COUNTERS_INTERLAGOS 10
 #define NUM_COUNTERS_CORE_INTERLAGOS 6
@@ -43,13 +45,15 @@ static RegisterMap interlagos_counter_map[NUM_COUNTERS_INTERLAGOS] = {
     {"PMC4",PMC4, PMC, MSR_AMD15_PERFEVTSEL4, MSR_AMD15_PMC4, 0, 0, ILG_VALID_OPTIONS_PMC},
     {"PMC5",PMC5, PMC, MSR_AMD15_PERFEVTSEL5, MSR_AMD15_PMC5, 0, 0, ILG_VALID_OPTIONS_PMC},
     /* Northbridge counters */
-    {"UPMC0",PMC6, UNCORE, MSR_AMD15_NB_PERFEVTSEL0, MSR_AMD15_NB_PMC0, 0, 0},
-    {"UPMC1",PMC7, UNCORE, MSR_AMD15_NB_PERFEVTSEL1, MSR_AMD15_NB_PMC1, 0, 0},
-    {"UPMC2",PMC8, UNCORE, MSR_AMD15_NB_PERFEVTSEL2, MSR_AMD15_NB_PMC2, 0, 0},
-    {"UPMC3",PMC9, UNCORE, MSR_AMD15_NB_PERFEVTSEL3, MSR_AMD15_NB_PMC3, 0, 0}
+    {"UPMC0",PMC6, UNCORE, MSR_AMD15_NB_PERFEVTSEL0, MSR_AMD15_NB_PMC0, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"UPMC1",PMC7, UNCORE, MSR_AMD15_NB_PERFEVTSEL1, MSR_AMD15_NB_PMC1, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"UPMC2",PMC8, UNCORE, MSR_AMD15_NB_PERFEVTSEL2, MSR_AMD15_NB_PMC2, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"UPMC3",PMC9, UNCORE, MSR_AMD15_NB_PERFEVTSEL3, MSR_AMD15_NB_PMC3, 0, 0, EVENT_OPTION_NONE_MASK}
 };
 
 static BoxMap interlagos_box_map[NUM_UNITS] = {
-    [PMC] = {0, 0, 0, 0, 0, 0, 48},
-    [UNCORE] = {0, 0, 0, 0, 0, 0, 48},
+    [PMC] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
+    [UNCORE] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
 };
+
+#endif //PERFMON_INTERLAGOS_COUNTERS_H
