@@ -5,14 +5,14 @@
  *
  *      Description:  Header file of perfmon module for AMD K10
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -28,6 +28,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_K10_H
+#define PERFMON_K10_H
 
 #include <perfmon_k10_events.h>
 #include <perfmon_k10_counters.h>
@@ -38,7 +40,7 @@ static int perfmon_numArchEventsK10 = NUM_ARCH_EVENTS_K10;
 
 int perfmon_init_k10(int cpu_id)
 {
-    cpu_id++;
+    (void)cpu_id;
     return 0;
 }
 
@@ -51,7 +53,7 @@ int k10_pmc_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
 
     if (event->numberOfOptions > 0)
     {
-        for(int j=0;j<event->numberOfOptions;j++)
+        for(uint64_t j=0;j<event->numberOfOptions;j++)
         {
             switch (event->options[j].type)
             {
@@ -77,7 +79,7 @@ int k10_pmc_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
     }
     if (flags != currentConfig[cpu_id][index])
     {
-        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, SETUP_PMC);
+        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, "SETUP_PMC");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter_map[index].configRegister, flags));
         currentConfig[cpu_id][index] = flags;
     }
@@ -125,12 +127,12 @@ int perfmon_startCountersThread_k10(int thread_id, PerfmonEventSet* eventSet)
             uint32_t counter = counter_map[index].counterRegister;
             eventSet->events[i].threadCounter[thread_id].startData = 0;
             eventSet->events[i].threadCounter[thread_id].counterData = 0;
-            VERBOSEPRINTREG(cpu_id, counter, 0x0ULL, CLEAR_PMC);
+            VERBOSEPRINTREG(cpu_id, counter, 0x0ULL, "CLEAR_PMC");
             CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter, 0x0ULL));
             CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, reg, &flags));
-            VERBOSEPRINTREG(cpu_id, reg, flags, READ_PMC_CTRL);
+            VERBOSEPRINTREG(cpu_id, reg, flags, "READ_PMC_CTRL");
             flags |= (1ULL<<22);  /* enable flag */
-            VERBOSEPRINTREG(cpu_id, reg, flags, START_PMC);
+            VERBOSEPRINTREG(cpu_id, reg, flags, "START_PMC");
             CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, reg, flags));
         }
     }
@@ -157,12 +159,12 @@ int perfmon_stopCountersThread_k10(int thread_id, PerfmonEventSet* eventSet)
             uint32_t reg = counter_map[index].configRegister;
             uint32_t counter = counter_map[index].counterRegister;
             CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, reg, &flags));
-            VERBOSEPRINTREG(cpu_id, reg, flags, READ_PMC_CTRL);
+            VERBOSEPRINTREG(cpu_id, reg, flags, "READ_PMC_CTRL");
             flags &= ~(1ULL<<22);  /* clear enable flag */
-            VERBOSEPRINTREG(cpu_id, reg, flags, STOP_PMC);
+            VERBOSEPRINTREG(cpu_id, reg, flags, "STOP_PMC");
             CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, reg, flags));
             CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &tmp));
-            VERBOSEPRINTREG(cpu_id, counter, tmp, READ_PMC);
+            VERBOSEPRINTREG(cpu_id, counter, tmp, "READ_PMC");
             if (tmp < eventSet->events[i].threadCounter[thread_id].counterData)
             {
                 eventSet->events[i].threadCounter[thread_id].overflows++;
@@ -191,7 +193,7 @@ int perfmon_readCountersThread_k10(int thread_id, PerfmonEventSet* eventSet)
             RegisterIndex index = eventSet->events[i].index;
             uint32_t counter = counter_map[index].counterRegister;
             CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &tmp));
-            VERBOSEPRINTREG(cpu_id, counter, tmp, READ_PMC);
+            VERBOSEPRINTREG(cpu_id, counter, tmp, "READ_PMC");
             if (tmp < eventSet->events[i].threadCounter[thread_id].counterData)
             {
                 eventSet->events[i].threadCounter[thread_id].overflows++;
@@ -218,12 +220,14 @@ int perfmon_finalizeCountersThread_k10(int thread_id, PerfmonEventSet* eventSet)
         uint32_t reg = counter_map[index].configRegister;
         if (reg)
         {
-            VERBOSEPRINTREG(cpu_id, reg, 0x0ULL, CLEAR_CTRL);
+            VERBOSEPRINTREG(cpu_id, reg, 0x0ULL, "CLEAR_CTRL");
             CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, reg, 0x0ULL));
-            VERBOSEPRINTREG(cpu_id, counter_map[index].counterRegister, 0x0ULL, CLEAR_CTR);
+            VERBOSEPRINTREG(cpu_id, counter_map[index].counterRegister, 0x0ULL, "CLEAR_CTR");
             CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter_map[index].counterRegister, 0x0ULL));
         }
         eventSet->events[i].threadCounter[thread_id].init = FALSE;
     }
     return 0;
 }
+
+#endif //PERFMON_K10_H
