@@ -5,14 +5,14 @@
  *
  *      Description:  AMD K10 performance counter definition. Also used for AMD K8.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -28,6 +28,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_K10_COUNTERS_H
+#define PERFMON_K10_COUNTERS_H
 
 #define NUM_COUNTERS_K10 4
 #define NUM_COUNTERS_CORE_K10 4
@@ -42,5 +44,7 @@ static RegisterMap k10_counter_map[NUM_COUNTERS_K10] = {
 };
 
 static BoxMap k10_box_map[NUM_UNITS] = {
-    [PMC] = {0, 0, 0, 0, 0, 0, 48}
+    [PMC] = {0, 0, 0, 0, 0, 0, 48, 0, 0}
 };
+
+#endif //PERFMON_K10_COUNTERS_H
