@@ -6,14 +6,14 @@
  *      Description:  Header File of perfmon module for AMD K8 support.
  *                    The setup routines and registers are similar to AMD K10
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -29,11 +29,12 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_K8_H
+#define PERFMON_K8_H
 
 #include <perfmon_k8_events.h>
 #include <error.h>
 
-
 static int perfmon_numArchEventsK8 = NUM_ARCH_EVENTS_K8;
 
-
+#endif //PERFMON_K8_H
