@@ -5,13 +5,13 @@
  *
  *      Description: Counter header file of perfmon module for Intel Atom (Silvermont)
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,9 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_KNL_COUNTERS_H
+#define PERFMON_KNL_COUNTERS_H
+
 #include <registers.h>
 
 #define NUM_COUNTERS_CORE_KNL 6
@@ -54,11 +57,11 @@ static RegisterMap knl_counter_map[NUM_COUNTERS_KNL] = {
     {"PMC0", PMC3, PMC, MSR_MIC2_PERFEVTSEL0, MSR_MIC2_PMC0, MSR_OFFCORE_RESP0, 0, KNL_VALID_OPTIONS_PMC},
     {"PMC1", PMC4, PMC, MSR_MIC2_PERFEVTSEL1, MSR_MIC2_PMC1, MSR_OFFCORE_RESP1, 0, KNL_VALID_OPTIONS_PMC},
     /* Temperature Sensor*/
-    {"TMP0", PMC5, THERMAL, 0, IA32_THERM_STATUS, 0, 0},
+    {"TMP0", PMC5, THERMAL, 0, IA32_THERM_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
     /* RAPL counters */
-    {"PWR0", PMC6, POWER, 0, MSR_PKG_ENERGY_STATUS, 0, 0},
-    {"PWR1", PMC7, POWER, 0, MSR_PP0_ENERGY_STATUS, 0, 0},
-    {"PWR3", PMC8, POWER, 0, MSR_DRAM_ENERGY_STATUS, 0, 0},
+    {"PWR0", PMC6, POWER, 0, MSR_PKG_ENERGY_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"PWR1", PMC7, POWER, 0, MSR_PP0_ENERGY_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"PWR3", PMC8, POWER, 0, MSR_DRAM_ENERGY_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
     {"UBOX0", PMC9, UBOX, MSR_MIC2_U_CTRL0, MSR_MIC2_U_CTR0, 0, 0, KNL_VALID_OPTIONS_UBOX},
     {"UBOX1", PMC10, UBOX, MSR_MIC2_U_CTRL1, MSR_MIC2_U_CTR1, 0, 0, KNL_VALID_OPTIONS_UBOX},
     {"UBOXFIX", PMC11, UBOXFIX, MSR_MIC2_U_FIXED_CTRL, MSR_MIC2_U_FIXED_CTR, 0, 0, EVENT_OPTION_NONE_MASK},
@@ -347,12 +350,12 @@ static RegisterMap knl_counter_map[NUM_COUNTERS_KNL] = {
 };
 
 static BoxMap knl_box_map[NUM_UNITS] = {
-    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, -1, 0, 0, 48},
-    [FIXED] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, -1, 0, 0, 48},
-    [THERMAL] = {0, 0, 0, 0, 0, MSR_DEV, 8},
-    [POWER] = {0, 0, 0, 0, 0, MSR_DEV, 32},
-    [UBOX] = {MSR_MIC2_U_GLOBAL_CTRL, MSR_MIC2_U_GLOBAL_STATUS, MSR_MIC2_U_GLOBAL_STATUS, 1, 0, 0, 48},
-    [UBOXFIX] = {MSR_MIC2_U_GLOBAL_CTRL, MSR_MIC2_U_GLOBAL_STATUS, MSR_MIC2_U_GLOBAL_STATUS, 0, 0, 0, 48},
+    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, -1, 0, 0, 48, 0, 0},
+    [FIXED] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, -1, 0, 0, 48, 0, 0},
+    [THERMAL] = {0, 0, 0, 0, 0, MSR_DEV, 8, 0, 0},
+    [POWER] = {0, 0, 0, 0, 0, MSR_DEV, 32, 0, 0},
+    [UBOX] = {MSR_MIC2_U_GLOBAL_CTRL, MSR_MIC2_U_GLOBAL_STATUS, MSR_MIC2_U_GLOBAL_STATUS, 1, 0, 0, 48, 0, 0},
+    [UBOXFIX] = {MSR_MIC2_U_GLOBAL_CTRL, MSR_MIC2_U_GLOBAL_STATUS, MSR_MIC2_U_GLOBAL_STATUS, 0, 0, 0, 48, 0, 0},
     [CBOX0] = {MSR_MIC2_C0_GLOBAL_CTRL, MSR_MIC2_C0_STATUS, MSR_MIC2_C0_STATUS, 3, 0, 0, 48, MSR_MIC2_C0_FILTER0, MSR_MIC2_C0_FILTER1},
     [CBOX1] = {MSR_MIC2_C1_GLOBAL_CTRL, MSR_MIC2_C0_STATUS, MSR_MIC2_C0_STATUS, 4, 0, 0, 48, MSR_MIC2_C0_FILTER0, MSR_MIC2_C0_FILTER1},
     [CBOX2] = {MSR_MIC2_C2_GLOBAL_CTRL, MSR_MIC2_C0_STATUS, MSR_MIC2_C0_STATUS, 5, 0, 0, 48, MSR_MIC2_C0_FILTER0, MSR_MIC2_C0_FILTER1},
@@ -391,87 +394,87 @@ static BoxMap knl_box_map[NUM_UNITS] = {
     [CBOX35] = {MSR_MIC2_C35_GLOBAL_CTRL, MSR_MIC2_C35_STATUS, MSR_MIC2_C35_STATUS, 38, 0, 0, 48, MSR_MIC2_C35_FILTER0, MSR_MIC2_C35_FILTER1},
     [CBOX36] = {MSR_MIC2_C36_GLOBAL_CTRL, MSR_MIC2_C36_STATUS, MSR_MIC2_C36_STATUS, 39, 0, 0, 48, MSR_MIC2_C36_FILTER0, MSR_MIC2_C36_FILTER1},
     [CBOX37] = {MSR_MIC2_C37_GLOBAL_CTRL, MSR_MIC2_C37_STATUS, MSR_MIC2_C37_STATUS, 40, 0, 0, 48, MSR_MIC2_C37_FILTER0, MSR_MIC2_C37_FILTER1},
-    [WBOX] = {MSR_MIC2_PCU_GLOBAL_CTRL, 0, 0, 2, 0, 0, 48},
-    [MBOX0] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_0, 48},
-    [MBOX1] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_1, 48},
-    [MBOX2] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_2, 48},
-    [MBOX3] = {PCI_MIC2_MC_U_BOX_CTRL, PCI_MIC2_MC_U_BOX_STATUS, PCI_MIC2_MC_U_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_3, 48},
-    [MBOX4] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_0, 48},
-    [MBOX5] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_1, 48},
-    [MBOX6] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_2, 48},
-    [MBOX7] = {PCI_MIC2_MC_U_BOX_CTRL, PCI_MIC2_MC_U_BOX_STATUS, PCI_MIC2_MC_U_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_3, 48},
-    [MBOX0FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_0, 48},
-    [MBOX1FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_1, 48},
-    [MBOX2FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_2, 48},
-    [MBOX3FIX] =  {PCI_MIC2_MC_U_BOX_CTRL, PCI_MIC2_MC_U_BOX_STATUS, PCI_MIC2_MC_U_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_3, 48},
-    [MBOX4FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_1_CH_0, 48},
-    [MBOX5FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_1_CH_1, 48},
-    [MBOX6FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_1_CH_2, 48},
-    [MBOX7FIX] = {PCI_MIC2_MC_U_BOX_CTRL, PCI_MIC2_MC_U_BOX_STATUS, PCI_MIC2_MC_U_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_3, 48},
-    [EUBOX0] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 43, 1, PCI_EDC0_UCLK_DEVICE, 48},
-    [EUBOX0FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 43, 1, PCI_EDC0_UCLK_DEVICE, 48},
-    [EDBOX0] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 43, 1, PCI_EDC0_DCLK_DEVICE, 48},
-    [EDBOX0FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 43, 1, PCI_EDC0_DCLK_DEVICE, 48},
-    [EUBOX1] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 44, 1, PCI_EDC1_UCLK_DEVICE, 48},
-    [EUBOX1FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 44, 1, PCI_EDC1_UCLK_DEVICE, 48},
-    [EDBOX1] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 44, 1, PCI_EDC1_DCLK_DEVICE, 48},
-    [EDBOX1FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 44, 1, PCI_EDC1_DCLK_DEVICE, 48},
-    [EUBOX2] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 45, 1, PCI_EDC2_UCLK_DEVICE, 48},
-    [EUBOX2FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 45, 1, PCI_EDC2_UCLK_DEVICE, 48},
-    [EDBOX2] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 45, 1, PCI_EDC2_DCLK_DEVICE, 48},
-    [EDBOX2FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 45, 1, PCI_EDC2_DCLK_DEVICE, 48},
-    [EUBOX3] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 46, 1, PCI_EDC3_UCLK_DEVICE, 48},
-    [EUBOX3FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 46, 1, PCI_EDC3_UCLK_DEVICE, 48},
-    [EDBOX3] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 46, 1, PCI_EDC3_DCLK_DEVICE, 48},
-    [EDBOX3FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 46, 1, PCI_EDC3_DCLK_DEVICE, 48},
-    [EUBOX4] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 47, 1, PCI_EDC4_UCLK_DEVICE, 48},
-    [EUBOX4FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 47, 1, PCI_EDC4_UCLK_DEVICE, 48},
-    [EDBOX4] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 47, 1, PCI_EDC4_DCLK_DEVICE, 48},
-    [EDBOX4FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 47, 1, PCI_EDC4_DCLK_DEVICE, 48},
-    [EUBOX5] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 48, 1, PCI_EDC5_UCLK_DEVICE, 48},
-    [EUBOX5FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 48, 1, PCI_EDC5_UCLK_DEVICE, 48},
-    [EDBOX5] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 48, 1, PCI_EDC5_DCLK_DEVICE, 48},
-    [EDBOX5FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 48, 1, PCI_EDC5_DCLK_DEVICE, 48},
-    [EUBOX6] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 49, 1, PCI_EDC6_UCLK_DEVICE, 48},
-    [EUBOX6FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 49, 1, PCI_EDC6_UCLK_DEVICE, 48},
-    [EDBOX6] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 49, 1, PCI_EDC6_DCLK_DEVICE, 48},
-    [EDBOX6FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 49, 1, PCI_EDC6_DCLK_DEVICE, 48},
-    [EUBOX7] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 50, 1, PCI_EDC7_UCLK_DEVICE, 48},
-    [EUBOX7FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 50, 1, PCI_EDC7_UCLK_DEVICE, 48},
-    [EDBOX7] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 50, 1, PCI_EDC7_DCLK_DEVICE, 48},
-    [EDBOX7FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 50, 1, PCI_EDC7_DCLK_DEVICE, 48},
-    [PBOX] = {PCI_MIC2_M2PCIE_BOX_CTRL, PCI_MIC2_M2PCIE_BOX_STATUS, PCI_MIC2_M2PCIE_BOX_STATUS, 51, 1, PCI_R2PCIE_DEVICE, 48},
-    [IBOX0] = {PCI_MIC2_IRP_BOX_CTRL, PCI_MIC2_IRP_BOX_STATUS, PCI_MIC2_IRP_BOX_STATUS, 52, 1, PCI_IRP_DEVICE, 48},
+    [WBOX] = {MSR_MIC2_PCU_GLOBAL_CTRL, 0, 0, 2, 0, 0, 48, 0, 0},
+    [MBOX0] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_0, 48, 0, 0},
+    [MBOX1] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_1, 48, 0, 0},
+    [MBOX2] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_2, 48, 0, 0},
+    [MBOX3] = {PCI_MIC2_MC_U_BOX_CTRL, PCI_MIC2_MC_U_BOX_STATUS, PCI_MIC2_MC_U_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_3, 48, 0, 0},
+    [MBOX4] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_0, 48, 0, 0},
+    [MBOX5] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_1, 48, 0, 0},
+    [MBOX6] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_2, 48, 0, 0},
+    [MBOX7] = {PCI_MIC2_MC_U_BOX_CTRL, PCI_MIC2_MC_U_BOX_STATUS, PCI_MIC2_MC_U_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_3, 48, 0, 0},
+    [MBOX0FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_0, 48, 0, 0},
+    [MBOX1FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_1, 48, 0, 0},
+    [MBOX2FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_2, 48, 0, 0},
+    [MBOX3FIX] =  {PCI_MIC2_MC_U_BOX_CTRL, PCI_MIC2_MC_U_BOX_STATUS, PCI_MIC2_MC_U_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_0_CH_3, 48, 0, 0},
+    [MBOX4FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_1_CH_0, 48, 0, 0},
+    [MBOX5FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_1_CH_1, 48, 0, 0},
+    [MBOX6FIX] = {PCI_MIC2_MC_D_BOX_CTRL, PCI_MIC2_MC_D_BOX_STATUS, PCI_MIC2_MC_D_BOX_STATUS, 41, 1, PCI_IMC_DEVICE_1_CH_2, 48, 0, 0},
+    [MBOX7FIX] = {PCI_MIC2_MC_U_BOX_CTRL, PCI_MIC2_MC_U_BOX_STATUS, PCI_MIC2_MC_U_BOX_STATUS, 42, 1, PCI_IMC_DEVICE_1_CH_3, 48, 0, 0},
+    [EUBOX0] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 43, 1, PCI_EDC0_UCLK_DEVICE, 48, 0, 0},
+    [EUBOX0FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 43, 1, PCI_EDC0_UCLK_DEVICE, 48, 0, 0},
+    [EDBOX0] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 43, 1, PCI_EDC0_DCLK_DEVICE, 48, 0, 0},
+    [EDBOX0FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 43, 1, PCI_EDC0_DCLK_DEVICE, 48, 0, 0},
+    [EUBOX1] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 44, 1, PCI_EDC1_UCLK_DEVICE, 48, 0, 0},
+    [EUBOX1FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 44, 1, PCI_EDC1_UCLK_DEVICE, 48, 0, 0},
+    [EDBOX1] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 44, 1, PCI_EDC1_DCLK_DEVICE, 48, 0, 0},
+    [EDBOX1FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 44, 1, PCI_EDC1_DCLK_DEVICE, 48, 0, 0},
+    [EUBOX2] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 45, 1, PCI_EDC2_UCLK_DEVICE, 48, 0, 0},
+    [EUBOX2FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 45, 1, PCI_EDC2_UCLK_DEVICE, 48, 0, 0},
+    [EDBOX2] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 45, 1, PCI_EDC2_DCLK_DEVICE, 48, 0, 0},
+    [EDBOX2FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 45, 1, PCI_EDC2_DCLK_DEVICE, 48, 0, 0},
+    [EUBOX3] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 46, 1, PCI_EDC3_UCLK_DEVICE, 48, 0, 0},
+    [EUBOX3FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 46, 1, PCI_EDC3_UCLK_DEVICE, 48, 0, 0},
+    [EDBOX3] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 46, 1, PCI_EDC3_DCLK_DEVICE, 48, 0, 0},
+    [EDBOX3FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 46, 1, PCI_EDC3_DCLK_DEVICE, 48, 0, 0},
+    [EUBOX4] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 47, 1, PCI_EDC4_UCLK_DEVICE, 48, 0, 0},
+    [EUBOX4FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 47, 1, PCI_EDC4_UCLK_DEVICE, 48, 0, 0},
+    [EDBOX4] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 47, 1, PCI_EDC4_DCLK_DEVICE, 48, 0, 0},
+    [EDBOX4FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 47, 1, PCI_EDC4_DCLK_DEVICE, 48, 0, 0},
+    [EUBOX5] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 48, 1, PCI_EDC5_UCLK_DEVICE, 48, 0, 0},
+    [EUBOX5FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 48, 1, PCI_EDC5_UCLK_DEVICE, 48, 0, 0},
+    [EDBOX5] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 48, 1, PCI_EDC5_DCLK_DEVICE, 48, 0, 0},
+    [EDBOX5FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 48, 1, PCI_EDC5_DCLK_DEVICE, 48, 0, 0},
+    [EUBOX6] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 49, 1, PCI_EDC6_UCLK_DEVICE, 48, 0, 0},
+    [EUBOX6FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 49, 1, PCI_EDC6_UCLK_DEVICE, 48, 0, 0},
+    [EDBOX6] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 49, 1, PCI_EDC6_DCLK_DEVICE, 48, 0, 0},
+    [EDBOX6FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 49, 1, PCI_EDC6_DCLK_DEVICE, 48, 0, 0},
+    [EUBOX7] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 50, 1, PCI_EDC7_UCLK_DEVICE, 48, 0, 0},
+    [EUBOX7FIX] = {PCI_MIC2_EDC_U_BOX_CTRL, PCI_MIC2_EDC_U_BOX_STATUS, PCI_MIC2_EDC_U_BOX_STATUS, 50, 1, PCI_EDC7_UCLK_DEVICE, 48, 0, 0},
+    [EDBOX7] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 50, 1, PCI_EDC7_DCLK_DEVICE, 48, 0, 0},
+    [EDBOX7FIX] = {PCI_MIC2_EDC_D_BOX_CTRL, PCI_MIC2_EDC_D_BOX_STATUS, PCI_MIC2_EDC_D_BOX_STATUS, 50, 1, PCI_EDC7_DCLK_DEVICE, 48, 0, 0},
+    [PBOX] = {PCI_MIC2_M2PCIE_BOX_CTRL, PCI_MIC2_M2PCIE_BOX_STATUS, PCI_MIC2_M2PCIE_BOX_STATUS, 51, 1, PCI_R2PCIE_DEVICE, 48, 0, 0},
+    [IBOX0] = {PCI_MIC2_IRP_BOX_CTRL, PCI_MIC2_IRP_BOX_STATUS, PCI_MIC2_IRP_BOX_STATUS, 52, 1, PCI_IRP_DEVICE, 48, 0, 0},
 };
 
 static PciDevice knl_pci_devices[MAX_NUM_PCI_DEVICES] = {
- [MSR_DEV] = {NODEVTYPE, "", "", ""},
- [PCI_IMC_DEVICE_0_CH_0] = {IMC, "08.2", "PCI_IMC_DEVICE_0_CH_0", "MBOX0", 0x7843},
- [PCI_IMC_DEVICE_0_CH_1] = {IMC, "08.3", "PCI_IMC_DEVICE_0_CH_1", "MBOX1", 0x7843},
- [PCI_IMC_DEVICE_0_CH_2] = {IMC, "08.4", "PCI_IMC_DEVICE_0_CH_2", "MBOX2", 0x7843},
- [PCI_IMC_DEVICE_0_CH_3] = {IMC, "0a.0", "PCI_IMC_DEVICE_0_CH_3", "MBOX3", 0x7843},
- [PCI_IMC_DEVICE_1_CH_0] = {IMC, "09.2", "PCI_IMC_DEVICE_1_CH_0", "MBOX4", 0x7843},
- [PCI_IMC_DEVICE_1_CH_1] = {IMC, "09.3", "PCI_IMC_DEVICE_1_CH_1", "MBOX5", 0x7843},
- [PCI_IMC_DEVICE_1_CH_2] = {IMC, "09.4", "PCI_IMC_DEVICE_1_CH_2", "MBOX6", 0x7843},
- [PCI_IMC_DEVICE_1_CH_3] = {IMC, "0b.0", "PCI_IMC_DEVICE_1_CH_3", "MBOX7", 0x7843},
- [PCI_R2PCIE_DEVICE] = {R2PCIE, "0c.1", "PCI_R2PCIE_DEVICE", "R2PCIE", 0x7817},
- [PCI_IRP_DEVICE] = {IRP, "05.6", "PCI_IRP_DEVICE", "IRP", 0x7814},
- [PCI_EDC0_UCLK_DEVICE] = {EDC, "0f.0", "PCI_EDC0_UCLK_DEVICE", "EDC", 0x7833},
- [PCI_EDC0_DCLK_DEVICE] = {EDC, "18.2", "PCI_EDC0_DCLK_DEVICE", "EDC", 0x7835},
- [PCI_EDC1_UCLK_DEVICE] = {EDC, "10.0", "PCI_EDC1_UCLK_DEVICE", "EDC", 0x7833},
- [PCI_EDC1_DCLK_DEVICE] = {EDC, "19.2", "PCI_EDC1_DCLK_DEVICE", "EDC", 0x7835},
- [PCI_EDC2_UCLK_DEVICE] = {EDC, "11.0", "PCI_EDC2_UCLK_DEVICE", "EDC", 0x7833},
- [PCI_EDC2_DCLK_DEVICE] = {EDC, "1a.2", "PCI_EDC2_DCLK_DEVICE", "EDC", 0x7835},
- [PCI_EDC3_UCLK_DEVICE] = {EDC, "12.0", "PCI_EDC3_UCLK_DEVICE", "EDC", 0x7833},
- [PCI_EDC3_DCLK_DEVICE] = {EDC, "1b.2", "PCI_EDC3_DCLK_DEVICE", "EDC", 0x7835},
- [PCI_EDC4_UCLK_DEVICE] = {EDC, "13.0", "PCI_EDC4_UCLK_DEVICE", "EDC", 0x7833},
- [PCI_EDC4_DCLK_DEVICE] = {EDC, "1c.2", "PCI_EDC4_DCLK_DEVICE", "EDC", 0x7835},
- [PCI_EDC5_UCLK_DEVICE] = {EDC, "14.0", "PCI_EDC5_UCLK_DEVICE", "EDC", 0x7833},
- [PCI_EDC5_DCLK_DEVICE] = {EDC, "1d.2", "PCI_EDC5_DCLK_DEVICE", "EDC", 0x7835},
- [PCI_EDC6_UCLK_DEVICE] = {EDC, "15.0", "PCI_EDC6_UCLK_DEVICE", "EDC", 0x7833},
- [PCI_EDC6_DCLK_DEVICE] = {EDC, "1e.2", "PCI_EDC6_DCLK_DEVICE", "EDC", 0x7835},
- [PCI_EDC7_UCLK_DEVICE] = {EDC, "16.0", "PCI_EDC7_UCLK_DEVICE", "EDC", 0x7833},
- [PCI_EDC7_DCLK_DEVICE] = {EDC, "1f.2", "PCI_EDC7_DCLK_DEVICE", "EDC", 0x7835},
+ [MSR_DEV] = {NODEVTYPE, "", "", "", 0, 0},
+ [PCI_IMC_DEVICE_0_CH_0] = {IMC, "08.2", "PCI_IMC_DEVICE_0_CH_0", "MBOX0", 0x7843, 0},
+ [PCI_IMC_DEVICE_0_CH_1] = {IMC, "08.3", "PCI_IMC_DEVICE_0_CH_1", "MBOX1", 0x7843, 0},
+ [PCI_IMC_DEVICE_0_CH_2] = {IMC, "08.4", "PCI_IMC_DEVICE_0_CH_2", "MBOX2", 0x7843, 0},
+ [PCI_IMC_DEVICE_0_CH_3] = {IMC, "0a.0", "PCI_IMC_DEVICE_0_CH_3", "MBOX3", 0x7843, 0},
+ [PCI_IMC_DEVICE_1_CH_0] = {IMC, "09.2", "PCI_IMC_DEVICE_1_CH_0", "MBOX4", 0x7843, 0},
+ [PCI_IMC_DEVICE_1_CH_1] = {IMC, "09.3", "PCI_IMC_DEVICE_1_CH_1", "MBOX5", 0x7843, 0},
+ [PCI_IMC_DEVICE_1_CH_2] = {IMC, "09.4", "PCI_IMC_DEVICE_1_CH_2", "MBOX6", 0x7843, 0},
+ [PCI_IMC_DEVICE_1_CH_3] = {IMC, "0b.0", "PCI_IMC_DEVICE_1_CH_3", "MBOX7", 0x7843, 0},
+ [PCI_R2PCIE_DEVICE] = {R2PCIE, "0c.1", "PCI_R2PCIE_DEVICE", "R2PCIE", 0x7817, 0},
+ [PCI_IRP_DEVICE] = {IRP, "05.6", "PCI_IRP_DEVICE", "IRP", 0x7814, 0},
+ [PCI_EDC0_UCLK_DEVICE] = {EDC, "0f.0", "PCI_EDC0_UCLK_DEVICE", "EDC", 0x7833, 0},
+ [PCI_EDC0_DCLK_DEVICE] = {EDC, "18.2", "PCI_EDC0_DCLK_DEVICE", "EDC", 0x7835, 0},
+ [PCI_EDC1_UCLK_DEVICE] = {EDC, "10.0", "PCI_EDC1_UCLK_DEVICE", "EDC", 0x7833, 0},
+ [PCI_EDC1_DCLK_DEVICE] = {EDC, "19.2", "PCI_EDC1_DCLK_DEVICE", "EDC", 0x7835, 0},
+ [PCI_EDC2_UCLK_DEVICE] = {EDC, "11.0", "PCI_EDC2_UCLK_DEVICE", "EDC", 0x7833, 0},
+ [PCI_EDC2_DCLK_DEVICE] = {EDC, "1a.2", "PCI_EDC2_DCLK_DEVICE", "EDC", 0x7835, 0},
+ [PCI_EDC3_UCLK_DEVICE] = {EDC, "12.0", "PCI_EDC3_UCLK_DEVICE", "EDC", 0x7833, 0},
+ [PCI_EDC3_DCLK_DEVICE] = {EDC, "1b.2", "PCI_EDC3_DCLK_DEVICE", "EDC", 0x7835, 0},
+ [PCI_EDC4_UCLK_DEVICE] = {EDC, "13.0", "PCI_EDC4_UCLK_DEVICE", "EDC", 0x7833, 0},
+ [PCI_EDC4_DCLK_DEVICE] = {EDC, "1c.2", "PCI_EDC4_DCLK_DEVICE", "EDC", 0x7835, 0},
+ [PCI_EDC5_UCLK_DEVICE] = {EDC, "14.0", "PCI_EDC5_UCLK_DEVICE", "EDC", 0x7833, 0},
+ [PCI_EDC5_DCLK_DEVICE] = {EDC, "1d.2", "PCI_EDC5_DCLK_DEVICE", "EDC", 0x7835, 0},
+ [PCI_EDC6_UCLK_DEVICE] = {EDC, "15.0", "PCI_EDC6_UCLK_DEVICE", "EDC", 0x7833, 0},
+ [PCI_EDC6_DCLK_DEVICE] = {EDC, "1e.2", "PCI_EDC6_DCLK_DEVICE", "EDC", 0x7835, 0},
+ [PCI_EDC7_UCLK_DEVICE] = {EDC, "16.0", "PCI_EDC7_UCLK_DEVICE", "EDC", 0x7833, 0},
+ [PCI_EDC7_DCLK_DEVICE] = {EDC, "1f.2", "PCI_EDC7_DCLK_DEVICE", "EDC", 0x7835, 0},
 };
 
 static char* knl_translate_types[NUM_UNITS] = {
@@ -545,3 +548,5 @@ static char* knl_translate_types[NUM_UNITS] = {
     [MBOX3FIX] = "/sys/bus/event_source/devices/uncore_imc_uclk_0",
     [MBOX7FIX] = "/sys/bus/event_source/devices/uncore_imc_uclk_1",
 };
+
+#endif //PERFMON_KNL_COUNTERS_H
