@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for ARM Neoverse N1
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,9 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_NEON1_H
+#define PERFMON_NEON1_H
+
 #include <perfmon_neon1_events.h>
 #include <perfmon_neon1_counters.h>
 
@@ -246,3 +249,5 @@ static int perfmon_numArchEventsNeoN1 = NUM_ARCH_EVENTS_NEON1;
 //    }
 //    return 0;
 //}
+
+#endif //PERFMON_NEON1_H
