@@ -5,13 +5,13 @@
  *
  *      Description:  Counter Header File of perfmon module for ARM Neoverse N1.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,7 +27,8 @@
  *
  * =======================================================================================
  */
-
+#ifndef PERFMON_NEON1_COUNTERS_H
+#define PERFMON_NEON1_COUNTERS_H
 
 #define NUM_COUNTERS_NEON1 6
 
@@ -41,7 +42,7 @@ static RegisterMap neon1_counter_map[NUM_COUNTERS_NEON1] = {
 };
 
 static BoxMap neon1_box_map[NUM_UNITS] = {
-    [PMC] = {0x0, 0x0, 0x0, 0, 0, 0, 32},
+    [PMC] = {0x0, 0x0, 0x0, 0, 0, 0, 32, 0, 0},
 };
 
 static char* neon1_translate_types[NUM_UNITS] = {
@@ -52,3 +53,4 @@ static char* a76_translate_types[NUM_UNITS] = {
     [PMC] = "/sys/bus/event_source/devices/armv8_cortex_a76",
 };
 
+#endif //PERFMON_NEON1_COUNTERS_H
