@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for IBM POWER8.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,7 +27,8 @@
  *
  * =======================================================================================
  */
-
+#ifndef PERFMON_POWER8_H
+#define PERFMON_POWER8_H
 
 #include <perfmon_power8_counters.h>
 #include <perfmon_power8_events.h>
@@ -35,3 +36,5 @@
 static int perfmon_numCountersPower8 = NUM_COUNTERS_POWER8;
 static int perfmon_numCoreCountersPower8 = NUM_COUNTERS_POWER8;
 static int perfmon_numArchEventsPower8 = NUM_ARCH_EVENTS_POWER8;
+
+#endif //PERFMON_POWER8_H
