@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for IBM POWER9.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,7 +27,8 @@
  *
  * =======================================================================================
  */
-
+#ifndef PERFMON_POWER9_H
+#define PERFMON_POWER9_H
 
 #include <perfmon_power9_counters.h>
 #include <perfmon_power9_events.h>
@@ -35,3 +36,5 @@
 static int perfmon_numCountersPower9 = NUM_COUNTERS_POWER9;
 static int perfmon_numCoreCountersPower9 = NUM_COUNTERS_POWER9;
 static int perfmon_numArchEventsPower9 = NUM_ARCH_EVENTS_POWER9;
+
+#endif //PERFMON_POWER9_H
