@@ -5,14 +5,14 @@
  *
  *      Description:  Counter Header File of perfmon module for Intel Skylake X.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -28,6 +28,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_SKYLAKEX_COUNTERS_H
+#define PERFMON_SKYLAKEX_COUNTERS_H
 
 #define NUM_COUNTERS_SKYLAKEX 337
 #define NUM_COUNTERS_CORE_SKYLAKEX 13
@@ -424,29 +426,29 @@ static RegisterMap skylakeX_counter_map[NUM_COUNTERS_SKYLAKEX] = {
 
 
 static BoxMap skylakeX_box_map[NUM_UNITS] = {
-    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48, MSR_PEBS_LD_LAT},
-    [THERMAL] = {0, 0, 0, 0, 0, 0, 8},
-    [VOLTAGE] = {0, 0, 0, 0, 0, 0, 16},
-    [FIXED] =  {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48},
-    [POWER] = {0, 0, 0, 0, 0, 0, 32},
-    [UBOX] = {0, MSR_UNC_V3_U_PMON_BOX_STATUS, MSR_UNC_V3_U_PMON_BOX_STATUS, 1, 0, 0, 48},
-    [UBOXFIX] = {0, MSR_UNC_V3_U_PMON_BOX_STATUS, MSR_UNC_V3_U_PMON_BOX_STATUS, 0, 0, 0, 48},
-    [MBOX0] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 39, 1, PCI_IMC_DEVICE_0_CH_0, 48},
-    [MBOX1] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 39, 1, PCI_IMC_DEVICE_0_CH_1, 48},
-    [MBOX2] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 39, 1, PCI_IMC_DEVICE_0_CH_2, 48},
-    [MBOX3] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 40, 1, PCI_IMC_DEVICE_1_CH_0, 48},
-    [MBOX4] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 40, 1, PCI_IMC_DEVICE_1_CH_1, 48},
-    [MBOX5] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 40, 1, PCI_IMC_DEVICE_1_CH_2, 48},
-    [SBOX0] = {MSR_UNC_SKX_UPI_PMON_BOX_CTL, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, 41, 1, PCI_QPI_DEVICE_PORT_0, 48},
-    [SBOX1] = {MSR_UNC_SKX_UPI_PMON_BOX_CTL, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, 42, 1, PCI_QPI_DEVICE_PORT_1, 48},
-    [SBOX2] = {MSR_UNC_SKX_UPI_PMON_BOX_CTL, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, 43, 1, PCI_QPI_DEVICE_PORT_2, 48},
-    [RBOX0] = {MSR_UNC_SKX_M3UPI_PMON_BOX_CTL, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, 46, 1, PCI_R3QPI_DEVICE_LINK_0, 48},
-    [RBOX1] = {MSR_UNC_SKX_M3UPI_PMON_BOX_CTL, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, 47, 1, PCI_R3QPI_DEVICE_LINK_1, 48},
-    [RBOX2] = {MSR_UNC_SKX_M3UPI_PMON_BOX_CTL, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, 0, 1, PCI_R3QPI_DEVICE_LINK_2, 48},
-    [BBOX0] = {MSR_UNC_SKX_M2M_PMON_BOX_CTL, MSR_UNC_SKX_M2M_PMON_BOX_STATUS, MSR_UNC_SKX_M2M_PMON_BOX_STATUS, 62, 1, PCI_HA_DEVICE_0, 48},
-    [BBOX1] = {MSR_UNC_SKX_M2M_PMON_BOX_CTL, MSR_UNC_SKX_M2M_PMON_BOX_STATUS, MSR_UNC_SKX_M2M_PMON_BOX_STATUS, 63, 1, PCI_HA_DEVICE_1, 48},
-    [WBOX] = {MSR_UNC_V3_PCU_PMON_BOX_CTL, MSR_UNC_V3_PCU_PMON_BOX_STATUS,MSR_UNC_V3_PCU_PMON_BOX_STATUS, 2, 0, 0, 48, MSR_UNC_V3_PCU_PMON_BOX_FILTER},
-    [WBOX0FIX] = {0,0,0,-1,0,0,64},
+    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48, MSR_PEBS_LD_LAT, 0},
+    [THERMAL] = {0, 0, 0, 0, 0, 0, 8, 0, 0},
+    [VOLTAGE] = {0, 0, 0, 0, 0, 0, 16, 0, 0},
+    [FIXED] =  {MSR_PERF_GLOBAL_CTRL, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS_RESET, 0, 0, 0, 48, 0, 0},
+    [POWER] = {0, 0, 0, 0, 0, 0, 32, 0, 0},
+    [UBOX] = {0, MSR_UNC_V3_U_PMON_BOX_STATUS, MSR_UNC_V3_U_PMON_BOX_STATUS, 1, 0, 0, 48, 0, 0},
+    [UBOXFIX] = {0, MSR_UNC_V3_U_PMON_BOX_STATUS, MSR_UNC_V3_U_PMON_BOX_STATUS, 0, 0, 0, 48, 0, 0},
+    [MBOX0] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 39, 1, PCI_IMC_DEVICE_0_CH_0, 48, 0, 0},
+    [MBOX1] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 39, 1, PCI_IMC_DEVICE_0_CH_1, 48, 0, 0},
+    [MBOX2] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 39, 1, PCI_IMC_DEVICE_0_CH_2, 48, 0, 0},
+    [MBOX3] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 40, 1, PCI_IMC_DEVICE_1_CH_0, 48, 0, 0},
+    [MBOX4] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 40, 1, PCI_IMC_DEVICE_1_CH_1, 48, 0, 0},
+    [MBOX5] = {PCI_UNC_SKX_MC_PMON_BOX_CTL, PCI_UNC_SKX_MC_PMON_BOX_STATUS, PCI_UNC_SKX_MC_PMON_BOX_STATUS, 40, 1, PCI_IMC_DEVICE_1_CH_2, 48, 0, 0},
+    [SBOX0] = {MSR_UNC_SKX_UPI_PMON_BOX_CTL, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, 41, 1, PCI_QPI_DEVICE_PORT_0, 48, 0, 0},
+    [SBOX1] = {MSR_UNC_SKX_UPI_PMON_BOX_CTL, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, 42, 1, PCI_QPI_DEVICE_PORT_1, 48, 0, 0},
+    [SBOX2] = {MSR_UNC_SKX_UPI_PMON_BOX_CTL, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, MSR_UNC_SKX_UPI_PMON_BOX_STATUS, 43, 1, PCI_QPI_DEVICE_PORT_2, 48, 0, 0},
+    [RBOX0] = {MSR_UNC_SKX_M3UPI_PMON_BOX_CTL, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, 46, 1, PCI_R3QPI_DEVICE_LINK_0, 48, 0, 0},
+    [RBOX1] = {MSR_UNC_SKX_M3UPI_PMON_BOX_CTL, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, 47, 1, PCI_R3QPI_DEVICE_LINK_1, 48, 0, 0},
+    [RBOX2] = {MSR_UNC_SKX_M3UPI_PMON_BOX_CTL, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, MSR_UNC_SKX_M3UPI_PMON_BOX_STATUS, 0, 1, PCI_R3QPI_DEVICE_LINK_2, 48, 0, 0},
+    [BBOX0] = {MSR_UNC_SKX_M2M_PMON_BOX_CTL, MSR_UNC_SKX_M2M_PMON_BOX_STATUS, MSR_UNC_SKX_M2M_PMON_BOX_STATUS, 62, 1, PCI_HA_DEVICE_0, 48, 0, 0},
+    [BBOX1] = {MSR_UNC_SKX_M2M_PMON_BOX_CTL, MSR_UNC_SKX_M2M_PMON_BOX_STATUS, MSR_UNC_SKX_M2M_PMON_BOX_STATUS, 63, 1, PCI_HA_DEVICE_1, 48, 0, 0},
+    [WBOX] = {MSR_UNC_V3_PCU_PMON_BOX_CTL, MSR_UNC_V3_PCU_PMON_BOX_STATUS,MSR_UNC_V3_PCU_PMON_BOX_STATUS, 2, 0, 0, 48, MSR_UNC_V3_PCU_PMON_BOX_FILTER, 0},
+    [WBOX0FIX] = {0,0,0,-1,0,0,64, 0, 0},
     [CBOX0] = {MSR_UNC_V3_C0_PMON_BOX_CTL, MSR_UNC_V3_C0_PMON_BOX_STATUS, MSR_UNC_V3_C0_PMON_BOX_STATUS, 3, 0, 0, 48, MSR_UNC_V3_C0_PMON_BOX_FILTER0, MSR_UNC_V3_C0_PMON_BOX_FILTER1},
     [CBOX1] = {MSR_UNC_V3_C1_PMON_BOX_CTL, MSR_UNC_V3_C1_PMON_BOX_STATUS, MSR_UNC_V3_C1_PMON_BOX_STATUS, 4, 0, 0, 48, MSR_UNC_V3_C1_PMON_BOX_FILTER0, MSR_UNC_V3_C1_PMON_BOX_FILTER1},
     [CBOX2] = {MSR_UNC_V3_C2_PMON_BOX_CTL, MSR_UNC_V3_C2_PMON_BOX_STATUS, MSR_UNC_V3_C2_PMON_BOX_STATUS, 5, 0, 0, 48, MSR_UNC_V3_C2_PMON_BOX_FILTER0, MSR_UNC_V3_C2_PMON_BOX_FILTER1},
@@ -475,42 +477,42 @@ static BoxMap skylakeX_box_map[NUM_UNITS] = {
     [CBOX25] = {MSR_UNC_V3_C25_PMON_BOX_CTL, MSR_UNC_V3_C25_PMON_BOX_STATUS, MSR_UNC_V3_C25_PMON_BOX_STATUS, 28, 0, 0, 48, MSR_UNC_V3_C25_PMON_BOX_FILTER0, MSR_UNC_V3_C25_PMON_BOX_FILTER1},
     [CBOX26] = {MSR_UNC_V3_C26_PMON_BOX_CTL, MSR_UNC_V3_C26_PMON_BOX_STATUS, MSR_UNC_V3_C26_PMON_BOX_STATUS, 29, 0, 0, 48, MSR_UNC_V3_C26_PMON_BOX_FILTER0, MSR_UNC_V3_C26_PMON_BOX_FILTER1},
     [CBOX27] = {MSR_UNC_V3_C27_PMON_BOX_CTL, MSR_UNC_V3_C27_PMON_BOX_STATUS, MSR_UNC_V3_C27_PMON_BOX_STATUS, 30, 0, 0, 48, MSR_UNC_V3_C27_PMON_BOX_FILTER0, MSR_UNC_V3_C27_PMON_BOX_FILTER1},
-    [IBOX0] = {MSR_UNC_SKX_II0_CBDMA_BOX_CTL, MSR_UNC_SKX_II0_CBDMA_BOX_STATUS, MSR_UNC_SKX_II0_CBDMA_BOX_STATUS, 56, 0, 0, 48},
-    [IBOX1] = {MSR_UNC_SKX_II0_PCIE0_BOX_CTL, MSR_UNC_SKX_II0_PCIE0_BOX_STATUS, MSR_UNC_SKX_II0_PCIE0_BOX_STATUS, 57, 0, 0, 48},
-    [IBOX2] = {MSR_UNC_SKX_II0_PCIE1_BOX_CTL, MSR_UNC_SKX_II0_PCIE1_BOX_STATUS, MSR_UNC_SKX_II0_PCIE1_BOX_STATUS, 58, 0, 0, 48},
-    [IBOX3] = {MSR_UNC_SKX_II0_PCIE2_BOX_CTL, MSR_UNC_SKX_II0_PCIE2_BOX_STATUS, MSR_UNC_SKX_II0_PCIE2_BOX_STATUS, 59, 0, 0, 48},
-    [IBOX4] = {MSR_UNC_SKX_II0_MCP0_BOX_CTL, MSR_UNC_SKX_II0_MCP0_BOX_STATUS, MSR_UNC_SKX_II0_MCP0_BOX_STATUS, 60, 0, 0, 48},
-    [IBOX5] = {MSR_UNC_SKX_II0_MCP1_BOX_CTL, MSR_UNC_SKX_II0_MCP1_BOX_STATUS, MSR_UNC_SKX_II0_MCP1_BOX_STATUS, -1, 0, 0, 48},
-    [IBOX0FIX] = {0, 0, 0, -1, 0, 0, 36},
-    [IBOX1FIX] = {0, 0, 0, -1, 0, 0, 36},
-    [IBOX2FIX] = {0, 0, 0, -1, 0, 0, 36},
-    [IBOX3FIX] = {0, 0, 0, -1, 0, 0, 36},
-    [IBOX4FIX] = {0, 0, 0, -1, 0, 0, 36},
-    [IBOX5FIX] = {0, 0, 0, -1, 0, 0, 36},
-    [EUBOX0] = {MSR_UNC_SKX_IRP_CBDMA_BOX_CTL, MSR_UNC_SKX_IRP_CBDMA_BOX_STATUS, MSR_UNC_SKX_IRP_CBDMA_BOX_STATUS, 56, 0, 0, 48},
-    [EUBOX1] = {MSR_UNC_SKX_IRP_PCIE0_BOX_CTL, MSR_UNC_SKX_IRP_PCIE0_BOX_STATUS, MSR_UNC_SKX_IRP_PCIE0_BOX_STATUS, 57, 0, 0, 48},
-    [EUBOX2] = {MSR_UNC_SKX_IRP_PCIE1_BOX_CTL, MSR_UNC_SKX_IRP_PCIE1_BOX_STATUS, MSR_UNC_SKX_IRP_PCIE1_BOX_STATUS, 58, 0, 0, 48},
-    [EUBOX3] = {MSR_UNC_SKX_IRP_PCIE2_BOX_CTL, MSR_UNC_SKX_IRP_PCIE2_BOX_STATUS, MSR_UNC_SKX_IRP_PCIE2_BOX_STATUS, 59, 0, 0, 48},
-    [EUBOX4] = {MSR_UNC_SKX_IRP_MCP0_BOX_CTL, MSR_UNC_SKX_IRP_MCP0_BOX_STATUS, MSR_UNC_SKX_IRP_MCP0_BOX_STATUS, 60, 0, 0, 48},
-    [EUBOX5] = {MSR_UNC_SKX_IRP_MCP1_BOX_CTL, MSR_UNC_SKX_IRP_MCP1_BOX_STATUS, MSR_UNC_SKX_IRP_MCP1_BOX_STATUS, 56, 0, 0, 48},
+    [IBOX0] = {MSR_UNC_SKX_II0_CBDMA_BOX_CTL, MSR_UNC_SKX_II0_CBDMA_BOX_STATUS, MSR_UNC_SKX_II0_CBDMA_BOX_STATUS, 56, 0, 0, 48, 0, 0},
+    [IBOX1] = {MSR_UNC_SKX_II0_PCIE0_BOX_CTL, MSR_UNC_SKX_II0_PCIE0_BOX_STATUS, MSR_UNC_SKX_II0_PCIE0_BOX_STATUS, 57, 0, 0, 48, 0, 0},
+    [IBOX2] = {MSR_UNC_SKX_II0_PCIE1_BOX_CTL, MSR_UNC_SKX_II0_PCIE1_BOX_STATUS, MSR_UNC_SKX_II0_PCIE1_BOX_STATUS, 58, 0, 0, 48, 0, 0},
+    [IBOX3] = {MSR_UNC_SKX_II0_PCIE2_BOX_CTL, MSR_UNC_SKX_II0_PCIE2_BOX_STATUS, MSR_UNC_SKX_II0_PCIE2_BOX_STATUS, 59, 0, 0, 48, 0, 0},
+    [IBOX4] = {MSR_UNC_SKX_II0_MCP0_BOX_CTL, MSR_UNC_SKX_II0_MCP0_BOX_STATUS, MSR_UNC_SKX_II0_MCP0_BOX_STATUS, 60, 0, 0, 48, 0, 0},
+    [IBOX5] = {MSR_UNC_SKX_II0_MCP1_BOX_CTL, MSR_UNC_SKX_II0_MCP1_BOX_STATUS, MSR_UNC_SKX_II0_MCP1_BOX_STATUS, -1, 0, 0, 48, 0, 0},
+    [IBOX0FIX] = {0, 0, 0, -1, 0, 0, 36, 0, 0},
+    [IBOX1FIX] = {0, 0, 0, -1, 0, 0, 36, 0, 0},
+    [IBOX2FIX] = {0, 0, 0, -1, 0, 0, 36, 0, 0},
+    [IBOX3FIX] = {0, 0, 0, -1, 0, 0, 36, 0, 0},
+    [IBOX4FIX] = {0, 0, 0, -1, 0, 0, 36, 0, 0},
+    [IBOX5FIX] = {0, 0, 0, -1, 0, 0, 36, 0, 0},
+    [EUBOX0] = {MSR_UNC_SKX_IRP_CBDMA_BOX_CTL, MSR_UNC_SKX_IRP_CBDMA_BOX_STATUS, MSR_UNC_SKX_IRP_CBDMA_BOX_STATUS, 56, 0, 0, 48, 0, 0},
+    [EUBOX1] = {MSR_UNC_SKX_IRP_PCIE0_BOX_CTL, MSR_UNC_SKX_IRP_PCIE0_BOX_STATUS, MSR_UNC_SKX_IRP_PCIE0_BOX_STATUS, 57, 0, 0, 48, 0, 0},
+    [EUBOX2] = {MSR_UNC_SKX_IRP_PCIE1_BOX_CTL, MSR_UNC_SKX_IRP_PCIE1_BOX_STATUS, MSR_UNC_SKX_IRP_PCIE1_BOX_STATUS, 58, 0, 0, 48, 0, 0},
+    [EUBOX3] = {MSR_UNC_SKX_IRP_PCIE2_BOX_CTL, MSR_UNC_SKX_IRP_PCIE2_BOX_STATUS, MSR_UNC_SKX_IRP_PCIE2_BOX_STATUS, 59, 0, 0, 48, 0, 0},
+    [EUBOX4] = {MSR_UNC_SKX_IRP_MCP0_BOX_CTL, MSR_UNC_SKX_IRP_MCP0_BOX_STATUS, MSR_UNC_SKX_IRP_MCP0_BOX_STATUS, 60, 0, 0, 48, 0, 0},
+    [EUBOX5] = {MSR_UNC_SKX_IRP_MCP1_BOX_CTL, MSR_UNC_SKX_IRP_MCP1_BOX_STATUS, MSR_UNC_SKX_IRP_MCP1_BOX_STATUS, 56, 0, 0, 48, 0, 0},
 };
 
 static PciDevice skylakeX_pci_devices[MAX_NUM_PCI_DEVICES] = {
- [MSR_DEV] = {NODEVTYPE, "", "", ""},
- [PCI_IMC_DEVICE_0_CH_0] = {IMC, "0a.2", "PCI_IMC_DEVICE_CH_0", "MBOX0", 0x2042},
- [PCI_IMC_DEVICE_0_CH_1] = {IMC, "0a.6", "PCI_IMC_DEVICE_CH_1", "MBOX1", 0x2046},
- [PCI_IMC_DEVICE_0_CH_2] = {IMC, "0b.2", "PCI_IMC_DEVICE_CH_2", "MBOX2", 0x204a},
- [PCI_IMC_DEVICE_1_CH_0] = {IMC, "0c.2", "PCI_IMC_DEVICE_CH_0", "MBOX3", 0x2042},
- [PCI_IMC_DEVICE_1_CH_1] = {IMC, "0c.6", "PCI_IMC_DEVICE_CH_1", "MBOX4", 0x2046},
- [PCI_IMC_DEVICE_1_CH_2] = {IMC, "0d.2", "PCI_IMC_DEVICE_CH_2", "MBOX5", 0x204a},
- [PCI_QPI_DEVICE_PORT_0] = {QPI, "0e.0", "PCI_QPI_DEVICE_PORT_0", "SBOX0", 0x2058},
- [PCI_QPI_DEVICE_PORT_1] = {QPI, "0f.0", "PCI_QPI_DEVICE_PORT_1", "SBOX1", 0x2058},
- [PCI_QPI_DEVICE_PORT_2] = {QPI, "10.0", "PCI_QPI_DEVICE_PORT_2", "SBOX1", 0x2058},
- [PCI_R3QPI_DEVICE_LINK_0] = {R3QPI, "12.0", "PCI_R3QPI_DEVICE_LINK_0", "RBOX0", 0x204c},
- [PCI_R3QPI_DEVICE_LINK_1] = {R3QPI, "12.1", "PCI_R3QPI_DEVICE_LINK_1", "RBOX1", 0x204d},
- [PCI_R3QPI_DEVICE_LINK_2] = {R3QPI, "12.4", "PCI_R3QPI_DEVICE_LINK_2", "RBOX2", 0x204c},
- [PCI_HA_DEVICE_0] = {HA, "08.0", "PCI_M2M_DEVICE_0", "BBOX0", 0x2066},
- [PCI_HA_DEVICE_1] = {HA, "09.0", "PCI_M2M_DEVICE_1", "BBOX1", 0x2066},
+ [MSR_DEV] = {NODEVTYPE, "", "", "", 0, 0},
+ [PCI_IMC_DEVICE_0_CH_0] = {IMC, "0a.2", "PCI_IMC_DEVICE_CH_0", "MBOX0", 0x2042, 0},
+ [PCI_IMC_DEVICE_0_CH_1] = {IMC, "0a.6", "PCI_IMC_DEVICE_CH_1", "MBOX1", 0x2046, 0},
+ [PCI_IMC_DEVICE_0_CH_2] = {IMC, "0b.2", "PCI_IMC_DEVICE_CH_2", "MBOX2", 0x204a, 0},
+ [PCI_IMC_DEVICE_1_CH_0] = {IMC, "0c.2", "PCI_IMC_DEVICE_CH_0", "MBOX3", 0x2042, 0},
+ [PCI_IMC_DEVICE_1_CH_1] = {IMC, "0c.6", "PCI_IMC_DEVICE_CH_1", "MBOX4", 0x2046, 0},
+ [PCI_IMC_DEVICE_1_CH_2] = {IMC, "0d.2", "PCI_IMC_DEVICE_CH_2", "MBOX5", 0x204a, 0},
+ [PCI_QPI_DEVICE_PORT_0] = {QPI, "0e.0", "PCI_QPI_DEVICE_PORT_0", "SBOX0", 0x2058, 0},
+ [PCI_QPI_DEVICE_PORT_1] = {QPI, "0f.0", "PCI_QPI_DEVICE_PORT_1", "SBOX1", 0x2058, 0},
+ [PCI_QPI_DEVICE_PORT_2] = {QPI, "10.0", "PCI_QPI_DEVICE_PORT_2", "SBOX1", 0x2058, 0},
+ [PCI_R3QPI_DEVICE_LINK_0] = {R3QPI, "12.0", "PCI_R3QPI_DEVICE_LINK_0", "RBOX0", 0x204c, 0},
+ [PCI_R3QPI_DEVICE_LINK_1] = {R3QPI, "12.1", "PCI_R3QPI_DEVICE_LINK_1", "RBOX1", 0x204d, 0},
+ [PCI_R3QPI_DEVICE_LINK_2] = {R3QPI, "12.4", "PCI_R3QPI_DEVICE_LINK_2", "RBOX2", 0x204c, 0},
+ [PCI_HA_DEVICE_0] = {HA, "08.0", "PCI_M2M_DEVICE_0", "BBOX0", 0x2066, 0},
+ [PCI_HA_DEVICE_1] = {HA, "09.0", "PCI_M2M_DEVICE_1", "BBOX1", 0x2066, 0},
 };
 
 static char* skylakeX_translate_types[NUM_UNITS] = {
@@ -565,3 +567,5 @@ static char* skylakeX_translate_types[NUM_UNITS] = {
     [UBOX] = "/sys/bus/event_source/devices/uncore_ubox",
     [UBOXFIX] = "/sys/bus/event_source/devices/uncore_ubox",
 };
+
+#endif //PERFMON_SKYLAKEX_COUNTERS_H
