@@ -5,14 +5,14 @@
  *
  *      Description:  Header File of perfmon module for Intel Westmere.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -28,8 +28,11 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_WESTMERE_H
+#define PERFMON_WESTMERE_H
 
 #include <perfmon_westmere_events.h>
 
 static int perfmon_numArchEventsWestmere = NUM_ARCH_EVENTS_WESTMERE;
 
+#endif //PERFMON_WESTMERE_H
