@@ -5,13 +5,13 @@
  *
  *      Description:  Counter Header File of perfmon module for AMD Family 19 (Zen3)
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2017 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,8 +27,14 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_ZEN3_COUNTERS_H
+#define PERFMON_ZEN3_COUNTERS_H
 
+#ifdef LIKWID_USE_PERFEVENT
+#define NUM_COUNTERS_ZEN3 20
+#else
 #define NUM_COUNTERS_ZEN3 21
+#endif
 #define NUM_COUNTERS_CORE_ZEN3 9
 
 #define AMD_K17_DF_EVSEL_SHIFT  0
@@ -48,11 +54,11 @@
 #define ZEN3_VALID_OPTIONS_PMC EVENT_OPTION_EDGE_MASK|EVENT_OPTION_COUNT_KERNEL_MASK|EVENT_OPTION_INVERT_MASK|EVENT_OPTION_THRESHOLD_MASK
 #define ZEN3_VALID_OPTIONS_L3 EVENT_OPTION_TID_MASK|EVENT_OPTION_CID_MASK|EVENT_OPTION_SLICE_MASK
 
-static RegisterMap zen3_counter_map[NUM_COUNTERS_ZEN2] = {
+static RegisterMap zen3_counter_map[NUM_COUNTERS_ZEN3] = {
     /* Fixed counters */
-    {"FIXC0", PMC0, FIXED, MSR_AMD17_HW_CONFIG, MSR_AMD17_RO_INST_RETIRED_CTR, 0, 0, 0},
-    {"FIXC1", PMC1, FIXED, 0, MSR_AMD17_RO_APERF, 0, 0, 0},
-    {"FIXC2", PMC2, FIXED, 0, MSR_AMD17_RO_MPERF, 0, 0, 0},
+    {"FIXC0", PMC0, FIXED, MSR_AMD17_HW_CONFIG, MSR_AMD17_RO_INST_RETIRED_CTR, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"FIXC1", PMC1, FIXED, 0, MSR_AMD17_RO_APERF, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"FIXC2", PMC2, FIXED, 0, MSR_AMD17_RO_MPERF, 0, 0, EVENT_OPTION_NONE_MASK},
     /* Core counters */
     {"PMC0",PMC3, PMC, MSR_AMD17_PERFEVTSEL0, MSR_AMD17_PMC0, 0, 0, ZEN3_VALID_OPTIONS_PMC},
     {"PMC1",PMC4, PMC, MSR_AMD17_PERFEVTSEL1, MSR_AMD17_PMC1, 0, 0, ZEN3_VALID_OPTIONS_PMC},
@@ -67,22 +73,27 @@ static RegisterMap zen3_counter_map[NUM_COUNTERS_ZEN2] = {
     {"CPMC3",PMC12, CBOX0, MSR_AMD17_L3_PERFEVTSEL3, MSR_AMD17_L3_PMC3, 0, 0, ZEN3_VALID_OPTIONS_L3},
     {"CPMC4",PMC13, CBOX0, MSR_AMD17_L3_PERFEVTSEL4, MSR_AMD17_L3_PMC4, 0, 0, ZEN3_VALID_OPTIONS_L3},
     {"CPMC5",PMC14, CBOX0, MSR_AMD17_L3_PERFEVTSEL5, MSR_AMD17_L3_PMC5, 0, 0, ZEN3_VALID_OPTIONS_L3},
-    /* Energy counters */
-    {"PWR0", PMC15, POWER, 0, MSR_AMD17_RAPL_CORE_STATUS, 0, 0},
-    {"PWR1", PMC16, POWER, 0, MSR_AMD17_RAPL_PKG_STATUS, 0, 0},
     /* Data fabric counters */
-    {"DFC0",PMC17, MBOX0, MSR_AMD17_2_DF_PERFEVTSEL0, MSR_AMD17_2_DF_PMC0, 0, 0},
-    {"DFC1",PMC18, MBOX0, MSR_AMD17_2_DF_PERFEVTSEL1, MSR_AMD17_2_DF_PMC1, 0, 0},
-    {"DFC2",PMC19, MBOX0, MSR_AMD17_2_DF_PERFEVTSEL2, MSR_AMD17_2_DF_PMC2, 0, 0},
-    {"DFC3",PMC20, MBOX0, MSR_AMD17_2_DF_PERFEVTSEL3, MSR_AMD17_2_DF_PMC3, 0, 0},
+    {"DFC0",PMC15, MBOX0, MSR_AMD17_2_DF_PERFEVTSEL0, MSR_AMD17_2_DF_PMC0, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"DFC1",PMC16, MBOX0, MSR_AMD17_2_DF_PERFEVTSEL1, MSR_AMD17_2_DF_PMC1, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"DFC2",PMC17, MBOX0, MSR_AMD17_2_DF_PERFEVTSEL2, MSR_AMD17_2_DF_PMC2, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"DFC3",PMC18, MBOX0, MSR_AMD17_2_DF_PERFEVTSEL3, MSR_AMD17_2_DF_PMC3, 0, 0, EVENT_OPTION_NONE_MASK},
+#ifdef LIKWID_USE_PERFEVENT
+    /* Energy counters */
+    {"PWR1", PMC19, POWER, 0, MSR_AMD17_RAPL_PKG_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
+#else
+    /* Energy counters */
+    {"PWR0", PMC19, POWER, 0, MSR_AMD17_RAPL_CORE_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"PWR1", PMC20, POWER, 0, MSR_AMD17_RAPL_PKG_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
+#endif
 };
 
 static BoxMap zen3_box_map[NUM_UNITS] = {
-    [FIXED] = {0, 0, 0, 0, 0, 0, 64},
-    [PMC] = {0, 0, 0, 0, 0, 0, 48},
-    [CBOX0] = {0, 0, 0, 0, 0, 0, 48},
-    [MBOX0] = {0, 0, 0, 0, 0, 0, 48},
-    [POWER] = {0, 0, 0, 0, 0, 0, 32},
+    [FIXED] = {0, 0, 0, 0, 0, 0, 64, 0, 0},
+    [PMC] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
+    [CBOX0] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
+    [MBOX0] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
+    [POWER] = {0, 0, 0, 0, 0, 0, 32, 0, 0},
 };
 
 static char* zen3_translate_types[NUM_UNITS] = {
@@ -92,3 +103,5 @@ static char* zen3_translate_types[NUM_UNITS] = {
     [CBOX0] = "/sys/bus/event_source/devices/amd_l3",
     [MBOX0] = "/sys/bus/event_source/devices/amd_df",
 };
+
+#endif //PERFMON_ZEN3_COUNTERS_H
