@@ -30,11 +30,7 @@
 #ifndef PERFMON_ZEN4_COUNTERS_H
 #define PERFMON_ZEN4_COUNTERS_H
 
-#ifdef LIKWID_USE_PERFEVENT
-#define NUM_COUNTERS_ZEN4 32
-#else
 #define NUM_COUNTERS_ZEN4 33
-#endif
 #define NUM_COUNTERS_CORE_ZEN4 9
 
 #define AMD_K19_DF_EVSEL_SHIFT  0
@@ -101,12 +97,8 @@ static RegisterMap zen4_counter_map[NUM_COUNTERS_ZEN4] = {
     {"DFC14",PMC29, MBOX0, MSR_AMD19_DF_PERFEVTSEL14, MSR_AMD19_DF_PMC14, 0, 0, EVENT_OPTION_NONE_MASK},
     {"DFC15",PMC30, MBOX0, MSR_AMD19_DF_PERFEVTSEL15, MSR_AMD19_DF_PMC15, 0, 0, EVENT_OPTION_NONE_MASK},
     /* Energy counters */
-#ifdef LIKWID_USE_PERFEVENT
-    {"PWR1", PMC31, POWER, 0x0, 0x0, 0x0, 0x0, EVENT_OPTION_NONE_MASK},
-#else
     {"PWR0", PMC31, POWER, 0, MSR_AMD17_RAPL_CORE_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
-    {"PWR2", PMC32, POWER, 0, MSR_AMD19_RAPL_L3_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
-#endif
+    {"PWR1", PMC32, POWER, 0, MSR_AMD19_RAPL_L3_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
     /* UMC Performance counters are added at runtime depending on values from CPUID */
 };
 
