@@ -5,13 +5,13 @@
  *
  *      Description:  Counter Header File of perfmon module for AMD Family 17
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2017 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_ZEN_COUNTERS_H
+#define PERFMON_ZEN_COUNTERS_H
 
 #define NUM_COUNTERS_ZEN 19
 #define NUM_COUNTERS_CORE_ZEN 7
@@ -65,9 +67,9 @@
 
 static RegisterMap zen_counter_map[NUM_COUNTERS_ZEN] = {
     /* Fixed counters */
-    {"FIXC0", PMC0, FIXED, MSR_AMD17_HW_CONFIG, MSR_AMD17_RO_INST_RETIRED_CTR, 0, 0, 0},
-    {"FIXC1", PMC1, FIXED, 0, MSR_AMD17_RO_APERF, 0, 0, 0},
-    {"FIXC2", PMC2, FIXED, 0, MSR_AMD17_RO_MPERF, 0, 0, 0},
+    {"FIXC0", PMC0, FIXED, MSR_AMD17_HW_CONFIG, MSR_AMD17_RO_INST_RETIRED_CTR, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"FIXC1", PMC1, FIXED, 0, MSR_AMD17_RO_APERF, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"FIXC2", PMC2, FIXED, 0, MSR_AMD17_RO_MPERF, 0, 0, EVENT_OPTION_NONE_MASK},
     /* Core counters */
     {"PMC0",PMC3, PMC, MSR_AMD17_PERFEVTSEL0, MSR_AMD17_PMC0, 0, 0, ZEN_VALID_OPTIONS_PMC},
     {"PMC1",PMC4, PMC, MSR_AMD17_PERFEVTSEL1, MSR_AMD17_PMC1, 0, 0, ZEN_VALID_OPTIONS_PMC},
@@ -81,21 +83,21 @@ static RegisterMap zen_counter_map[NUM_COUNTERS_ZEN] = {
     {"CPMC4",PMC11, CBOX0, MSR_AMD17_L3_PERFEVTSEL4, MSR_AMD17_L3_PMC4, 0, 0, ZEN_VALID_OPTIONS_L3},
     {"CPMC5",PMC12, CBOX0, MSR_AMD17_L3_PERFEVTSEL5, MSR_AMD17_L3_PMC5, 0, 0, ZEN_VALID_OPTIONS_L3},
     /* Energy counters */
-    {"PWR0", PMC13, POWER, 0, MSR_AMD17_RAPL_CORE_STATUS, 0, 0},
-    {"PWR1", PMC14, POWER, 0, MSR_AMD17_RAPL_PKG_STATUS, 0, 0},
+    {"PWR0", PMC13, POWER, 0, MSR_AMD17_RAPL_CORE_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"PWR1", PMC14, POWER, 0, MSR_AMD17_RAPL_PKG_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
     /* Northbridge counters */
-    {"DFC0",PMC15, MBOX0, MSR_AMD16_NB_PERFEVTSEL0, MSR_AMD16_NB_PMC0, 0, 0},
-    {"DFC1",PMC16, MBOX0, MSR_AMD16_NB_PERFEVTSEL1, MSR_AMD16_NB_PMC1, 0, 0},
-    {"DFC2",PMC17, MBOX0, MSR_AMD16_NB_PERFEVTSEL2, MSR_AMD16_NB_PMC2, 0, 0},
-    {"DFC3",PMC18, MBOX0, MSR_AMD16_NB_PERFEVTSEL3, MSR_AMD16_NB_PMC3, 0, 0}
+    {"DFC0",PMC15, MBOX0, MSR_AMD16_NB_PERFEVTSEL0, MSR_AMD16_NB_PMC0, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"DFC1",PMC16, MBOX0, MSR_AMD16_NB_PERFEVTSEL1, MSR_AMD16_NB_PMC1, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"DFC2",PMC17, MBOX0, MSR_AMD16_NB_PERFEVTSEL2, MSR_AMD16_NB_PMC2, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"DFC3",PMC18, MBOX0, MSR_AMD16_NB_PERFEVTSEL3, MSR_AMD16_NB_PMC3, 0, 0, EVENT_OPTION_NONE_MASK}
 };
 
 static BoxMap zen_box_map[NUM_UNITS] = {
-    [FIXED] = {0, 0, 0, 0, 0, 0, 64},
-    [PMC] = {0, 0, 0, 0, 0, 0, 48},
-    [CBOX0] = {0, 0, 0, 0, 0, 0, 48},
-    [MBOX0] = {0, 0, 0, 0, 0, 0, 48},
-    [POWER] = {0, 0, 0, 0, 0, 0, 32},
+    [FIXED] = {0, 0, 0, 0, 0, 0, 64, 0, 0},
+    [PMC] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
+    [CBOX0] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
+    [MBOX0] = {0, 0, 0, 0, 0, 0, 48, 0, 0},
+    [POWER] = {0, 0, 0, 0, 0, 0, 32, 0, 0},
 };
 
 static char* zen_translate_types[NUM_UNITS] = {
@@ -105,3 +107,5 @@ static char* zen_translate_types[NUM_UNITS] = {
     [CBOX0] = "/sys/bus/event_source/devices/amd_l3",
     [MBOX0] = "/sys/bus/event_source/devices/amd_df",
 };
+
+#endif //PERFMON_ZEN_COUNTERS_H
