@@ -6,14 +6,14 @@
  *      Description:  Header File Power Module
  *                    Implements Intel RAPL Interface.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -94,20 +94,20 @@ power_start(PowerData* data, int cpuId, PowerType type)
         {
             uint64_t result = 0;
             data->before = 0;
-            CHECK_MSR_READ_ERROR(HPMread(cpuId, MSR_DEV, power_regs[type], &result))
+            CHECK_MSR_READ_ERROR(HPMread(cpuId, MSR_DEV, power_regs[type], &result));
             data->before = field64(result, 0, power_info.statusRegWidth);
             data->domain = type;
             return 0;
         }
         else
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, RAPL domain %s not supported, power_names[type]);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "RAPL domain %s not supported", power_names[type]);
             return -EFAULT;
         }
     }
     else
     {
-        DEBUG_PLAIN_PRINT(DEBUGLEV_DEVELOP, No RAPL support);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "No RAPL support");
         return -EIO;
     }
 }
@@ -121,26 +121,26 @@ power_stop(PowerData* data, int cpuId, PowerType type)
         {
             uint64_t result = 0;
             data->after = 0;
-            CHECK_MSR_READ_ERROR(HPMread(cpuId, MSR_DEV, power_regs[type], &result))
+            CHECK_MSR_READ_ERROR(HPMread(cpuId, MSR_DEV, power_regs[type], &result));
             data->after = field64(result, 0, power_info.statusRegWidth);
             data->domain = type;
             return 0;
         }
         else
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, RAPL domain %s not supported, power_names[type]);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "RAPL domain %s not supported", power_names[type]);
             return -EFAULT;
         }
     }
     else
     {
-        DEBUG_PLAIN_PRINT(DEBUGLEV_DEVELOP, No RAPL support);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "No RAPL support");
         return -EIO;
     }
 }
 
 int
-power_read(int cpuId, uint64_t reg, uint32_t *data)
+power_read(int cpuId, uint64_t reg, uint64_t *data)
 {
     int i;
     PowerType type = -1;
@@ -159,28 +159,30 @@ power_read(int cpuId, uint64_t reg, uint32_t *data)
         {
             uint64_t result = 0;
             *data = 0;
-            CHECK_MSR_READ_ERROR(HPMread(cpuId, MSR_DEV, reg, &result))
+            CHECK_MSR_READ_ERROR(HPMread(cpuId, MSR_DEV, reg, &result));
             *data = field64(result, 0, power_info.statusRegWidth);
             return 0;
         }
         else
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, RAPL domain %s not supported, power_names[type]);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "RAPL domain %s not supported", power_names[type]);
             return -EFAULT;
         }
     }
     else
     {
-        DEBUG_PLAIN_PRINT(DEBUGLEV_DEVELOP, No RAPL support);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "No RAPL support");
         return -EIO;
     }
 }
 
 int
-power_tread(int socket_fd, int cpuId, uint64_t reg, uint32_t *data)
+power_tread(int socket_fd, int cpuId, uint64_t reg, uint64_t *data)
 {
+    (void)socket_fd;
+
     int i;
-    PowerType type;
+    PowerType type = 0;
     if (power_info.hasRAPL)
     {
         for (i = 0; i < NUM_POWER_DOMAINS; i++)
@@ -195,19 +197,19 @@ power_tread(int socket_fd, int cpuId, uint64_t reg, uint32_t *data)
         {
             uint64_t result = 0;
             *data = 0;
-            CHECK_MSR_READ_ERROR(HPMread(cpuId, MSR_DEV, reg, &result))
+            CHECK_MSR_READ_ERROR(HPMread(cpuId, MSR_DEV, reg, &result));
             *data = field64(result, 0, power_info.statusRegWidth);
             return 0;
         }
         else
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, RAPL domain %s not supported, power_names[type]);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "RAPL domain %s not supported", power_names[type]);
             return -EFAULT;
         }
     }
     else
     {
-        DEBUG_PLAIN_PRINT(DEBUGLEV_DEVELOP, No RAPL support);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "No RAPL support");
         return -EIO;
     }
 }
@@ -216,7 +218,6 @@ double
 power_getEnergyUnit(int domain)
 {
 #ifdef LIKWID_USE_PERFEVENT
-    int ret = 0;
     FILE* fd = NULL;
     char out[512];
     if (power_info.domains[domain].energyUnit == 0)
@@ -226,9 +227,12 @@ power_getEnergyUnit(int domain)
             fd = fopen(perf_power_names[domain], "r");
             if (fd != NULL)
             {
-                ret = fread(out, sizeof(char), 512, fd);
+                float energyUnit = 0.0f;
+                if (fgets(out, sizeof(out), fd)) {
+                    energyUnit = atof(out);
+                }
                 fclose(fd);
-                power_info.domains[domain].energyUnit = atof(out);
+                power_info.domains[domain].energyUnit = energyUnit;
             }
         }
     }
