@@ -7,13 +7,13 @@
  *                    Allows toggling of terminal escape sequences for
  *                    colored text.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -55,20 +55,24 @@ static void color_reset(void);
 static void
 color_on(int attr, int fg)
 {
-    char command[13];
+    // https://en.wikipedia.org/wiki/ANSI_escape_code#Select_Graphic_Rendition_parameters
+    if (attr < 0)
+        attr = 0;
+    else if (attr > 107)
+        attr = 107;
 
-    sprintf(command, "%c[%d;%dm", 0x1B, attr, fg + 30);
-    printf("%s", command);
+    if (fg < 0)
+        fg = 0;
+    else if (fg > 7)
+        fg = 7;
+
+    printf("\e[%d;%dm", attr, fg + 30);
 }
 
 static void
 color_reset()
 {
-    char command[13];
-
-    sprintf(command, "%c[%dm", 0x1B, 0);
-    printf("%s", command);
-
+    printf("\e[0m");
 }
 
 #endif /*TEXTCOLOR_H*/
