@@ -6,13 +6,13 @@
  *      Description:  Header File Thermal Module.
  *                    Implements Intel TM/TM2 Interface.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -57,6 +57,7 @@ thermal_read(int cpuId, uint32_t *data)
 int
 thermal_tread(int socket_fd, int cpuId, uint32_t *data)
 {
+    (void)socket_fd;
     uint64_t result = 0;
     uint32_t readout = 0;
     if (HPMread(cpuId, MSR_DEV, IA32_THERM_STATUS, &result))
