@@ -5,13 +5,13 @@
  *
  *      Description:  Code to look up Uncore perfmon units on Intel SPR and later.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -44,11 +44,13 @@
 #include <perfmon_sapphirerapids_counters.h>
 #include <perfmon_graniterapids_counters.h>
 #include <perfmon_sierraforrest_counters.h>
+#include <perfmon_emeraldrapids_counters.h>
 
 static PerfmonUncoreDiscovery* uncore_discovery_map = NULL;
 
 
 /* Functions for the same handling of PCI devices and their memory in user-space as in kernel-space */
+#define MAX_FILENAME_LENGTH 1024
 
 struct pci_dev {
     uint16_t domain;
@@ -56,15 +58,30 @@ struct pci_dev {
     uint16_t device;
     uint16_t func;
     int numa_node;
+    int socket;
+    int vendor;
+    int device_id;
+    int index;
+    char path[MAX_FILENAME_LENGTH];
 };
 
+static struct pci_dev* sysfs_pci_devices = NULL;
+static int num_sysfs_pci_devices = 0;
+
+// TODO remove all this ugly file handling here:
+// - fix missing error handling
+// - fix hardcoded constants at e.g. snprintf
+// - do not check if a file exists with 'access'. Just open the file and handle the error accordingly
+// - fix more unsigned/signed variables
+
+
 // glibc memcpy uses optimized versions but copies have to be bytewise
 // otherwise the data is incorrect. 
-void mymemcpy(void* dest, void* src, int size)
+void mymemcpy(void* dest, void* src, size_t size)
 {
-    uint8_t volatile* udest = (uint8_t*)dest;
-    uint8_t volatile* usrc = (uint8_t*)src;
-    for (int i = 0; i < size/sizeof(uint8_t); i++)
+    uint8_t volatile* udest = dest;
+    uint8_t volatile* usrc = src;
+    for (unsigned i = 0; i < size/sizeof(uint8_t); i++)
     {
         *(udest + i) = *(usrc + i);
     }
@@ -114,25 +131,26 @@ static int pci_find_next_ext_capability(struct pci_dev *dev, int start, int cap)
 
 /* Helper function to read files from sysfs */
 static int file_to_uint(char* path, unsigned int *data) {
+    // TODO use fopen/fgets here
     int ret = -1;
     char content[1025];
     int fp = open(path, O_RDONLY);
     if (fp >= 0)
     {
-        ret = read(fp, content, 1024 * sizeof(char));
-        if (ret >= 0) {
-            content[ret] = '\0';
+        ssize_t read_count = read(fp, content, 1024 * sizeof(char));
+        if (read_count >= 0) {
+            content[read_count] = '\0';
             u64 new = 0x0;
-            ret = sscanf(content, "0x%x", &new);
-            if (ret == 1)
+            int scan_count = sscanf(content, "0x%lx", &new);
+            if (scan_count == 1)
             {
                 *data = new;
                 ret = 0;
             }
             else
             {
-                ret = sscanf(content, "%d", &new);
-                if (ret == 1)
+                scan_count = sscanf(content, "%ld", &new);
+                if (scan_count == 1)
                 {
                     *data = new;
                     ret = 0;
@@ -141,228 +159,107 @@ static int file_to_uint(char* path, unsigned int *data) {
         }
         close(fp);
     }
+    else
+    {
+        ret = -errno;
+    }
     
     return ret;
 }
 
-// Test whether PCI domain and bus exist.
-static int pci_test_bus(int domain, int bus)
-{
-    char fname[1025];
-    int ret = snprintf(fname, 1024, "/sys/class/pci_bus/%.04x:%.02x", domain, bus);
-    if (ret > 0)
-    {
-        fname[ret] = '\0';
-    }
-    else
-    {
-        ERROR_PRINT(Cannot format path to PCI bus directory for domain %d and bus %d, domain, bus);
-    }
-    return !access(fname, R_OK);
-}
-
-// commonly only a few PCI domains are populated, so we get the max domain
-// to return from PCI device parsing early. Otherwise, we have to search
-// 65535 domains.
-static int get_max_pci_domain()
-{
-    int max_dom = 0;
-    DIR* dir = NULL;
-    struct dirent* dent = NULL;
-
-    dir = opendir("/sys/class/pci_bus");
-    if (!dir)
-    {
-        return -errno;
-    }
-    while((dent = readdir(dir)))
-    {
-        int dom = -1, bus = -1;
-        int c = sscanf(dent->d_name, "%X:%X", &dom, &bus);
-        if ((c == 2) && (dom > max_dom))
-        {
-            max_dom = dom;
-        }
-    }
-
-    closedir(dir);
-    return max_dom+1;
-}
-
-// Get the maximal CPU socket ID to stop parsing. This does not work if
-// sockets are not numbered consecutively. 
-static int max_socket_id(int* max_socket)
-{
-    int num_procs = sysconf (_SC_NPROCESSORS_CONF);
-    int cur_procs = 0;
-    int ret = -1;
-    int cur_max = 0;
-    char path[1025];
-    for (int i = 0; i < 100000 && cur_procs < num_procs; i++)
-    {
-        ret = snprintf(path, 1024, "/sys/devices/system/cpu/cpu%d/topology/physical_package_id", i);
-        if (ret >= 0)
-        {
-            path[ret] = '\0';
-            int id = 0;
-            ret = file_to_uint(path, &id);
-            if (ret == 0 && id > cur_max)
-            {
-                cur_max = id;
-            }
-        }
-    }
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Found max socket ID %d, cur_max);
-    *max_socket = cur_max;
+static int file_to_nonneg_int(char *path, int *data) {
+    unsigned uint_data = 0;
+    int retval = file_to_uint(path, &uint_data);
+    if (retval < 0)
+        return retval;
+    *data = (int)uint_data;
     return 0;
 }
 
-
-
-
-static int _max_pci_domain_id = -1;
-// This functions should mimic the behavior of pci_get_device in the kernel
-// It searches the whole PCI space for a specific device and defined by vendor
-// and device ID. Instead of vendor and device ID, the special PCI_ANY_ID can
-// be used to get any device. In order to not start from zero each time, the
-// function takes a device as input (from) to start from there.
-struct pci_dev * pci_get_device (unsigned int vendor, unsigned int device, struct pci_dev * from)
+static int read_sysfs_pci_devs()
 {
-    //struct pci_dev next = {from->domain, from->bus, from->device, from->func};
-    int domStart = (from ? from->domain : 0);
-    int busStart = (from ? from->bus : 0);
-    int devStart = (from ? from->device : 0);
-    int funcStart = (from ? from->func : 0);
-    char busbase[1025];
-    char devbase[1025];
-    char fname[1025];
-    
-    if (_max_pci_domain_id < 0)
-    {
-        int ret = get_max_pci_domain();
-        if (ret < 0)
-        {
-            return NULL;
-        }
-        _max_pci_domain_id = ret;
-    }
+    DIR *dp = NULL;
+    struct dirent *ep = NULL;
 
-    for (int dom = domStart; dom < _max_pci_domain_id; dom++) {
-        // if we are beyond the domain given in from, we start with bus=0 again
-        // instead of the bus given in from
-        if (from && dom > from->domain) busStart = 0;
-        for (int bus = busStart; bus < 0xff; bus++) {
+    if (sysfs_pci_devices == NULL)
+    {
+        dp = opendir("/sys/bus/pci/devices");
+        if (!dp)
+        {
+            return -1;
+        }
+        while ((ep = readdir(dp)) != NULL)
+        {
             int ret = 0;
-            // Early skip if PCI bus does not exist
-            if (!pci_test_bus(dom, bus)) {
-            
+            char devbase[MAX_FILENAME_LENGTH] = { [0 ... (MAX_FILENAME_LENGTH-1)] = '\0' };
+            char filename[MAX_FILENAME_LENGTH] = { [0 ... (MAX_FILENAME_LENGTH-1)] = '\0' };
+            uint32_t vendor = 0;
+            uint32_t device_id = 0;
+            int numa_node = -1;
+            int socket = -1;
+            int dom = 0;
+            int bus = 0;
+            int devid = 0;
+            int func = 0;
+            ret = sscanf(ep->d_name, "%04x:%02x:%02x.%01x", &dom, &bus, &devid, &func);
+            if (ret != 4)
+            {
                 continue;
             }
-            // if we are beyond the bus given in from, we start with devid=0 again
-            // instead of the device given in from
-            if (from && bus > from->bus) devStart = 0;
-            for (int devid = devStart; devid < 0xff; devid++) {
-                // if we are beyond the device given in from, we start with func=0 again
-                // instead of the func given in from
-                if (from && devid > from->device) funcStart = 0;
-                for (int func = funcStart; func < 0xf; func++) {
-                    // Skip the 'from' device
-                    if (from && dom == from->domain && bus == from->bus && devid == from->device && func ==  from->func)
-                    {
-                        continue;
-                    }
-                    // Create directory path to PCI device
-                    int ret = snprintf(devbase, 1024, "/sys/bus/pci/devices/%.04x:%.02x:%.02x.%.01x", dom, bus, devid, func);
-                    if (ret > 0)
-                    {
-                        devbase[ret] = '\0';
-                    }
-                    else
-                    {
-                        printf("Cannot create PCI device path\n");
-                        continue;
-                    }
-                    // If the device path does not exist, go to next one
-                    if (access(devbase, R_OK))
-                    {
-                        continue;
-                    }
-                    if (vendor != PCI_ANY_ID)
-                    {
-                        unsigned int hVend = 0x0;
-                        int ret = snprintf(fname, 1024, "%s/vendor", devbase);
-                        if (ret > 0)
-                        {
-                            fname[ret] = '\0';
-                            ret = file_to_uint(fname, &hVend);
-                            if (ret == 0 && hVend != vendor)
-                            {
-                                continue;
-                            }
-                        }
-                        else
-                        {
-                            continue;
-                        }
-                    }
-                    if (device != PCI_ANY_ID)
-                    {
-                        unsigned int hDev = 0x0;
-                        int ret = snprintf(fname, 1024, "%s/device", devbase);
-                        if (ret > 0)
-                        {
-                            fname[ret] = '\0';
-                            ret = file_to_uint(fname, &hDev);
-                            if (ret == 0 && hDev != device)
-                            {
-                                continue;
-                            }
-                        }
-                        else
-                        {
-                            continue;
-                        }
-                    }
-                    // We directly read the NUMA node ID if present
-                    int node = -1;
-                    ret = snprintf(fname, 1024, "%s/numa_node", devbase);
-                    if (ret > 0)
-                    {
-                        fname[ret] = '\0';
-                        ret = file_to_uint(fname, &node);
-                    }
-                    else
-                    {
-                        continue;
-                    }
-                    // Reuse space
-                    if (from)
-                    {
-                        from->domain = dom;
-                        from->bus = bus;
-                        from->device = devid;
-                        from->func = func;
-                        from->numa_node = node;
-                        return from;
-                    }
-                    else
-                    {
-                        // First find, allocate a new PCI device
-                        struct pci_dev* next = malloc(sizeof(struct pci_dev));
-                        if (next) {
-                            next->domain = dom;
-                            next->bus = bus;
-                            next->device = devid;
-                            next->func = func;
-                            next->numa_node = node;
-                            return next;
-                        }
-                    }
+            ret = snprintf(devbase, 1023, "/sys/bus/pci/devices/%s", ep->d_name);
+            devbase[ret] = '\0';
+
+            ret = snprintf(filename, 1023, "%s/vendor", devbase);
+            filename[ret] = '\0';
+            ret = file_to_uint(filename, &vendor);
+            if (vendor != PCI_VENDOR_ID_INTEL)
+            {
+                continue;
+            }
+            ret = snprintf(filename, 1023, "%s/device", devbase);
+            filename[ret] = '\0';
+            ret = file_to_uint(filename, &device_id);
+            ret = snprintf(filename, 1023, "%s/numa_node", devbase);
+            filename[ret] = '\0';
+            ret = file_to_nonneg_int(filename, &numa_node);
+
+            if (numa_node >= 0)
+            {
+                int cpuid = -1;
+                ret = snprintf(filename, 1023, "/sys/devices/system/node/node%d/cpulist", numa_node);
+                ret = file_to_nonneg_int(filename, &cpuid);
+                if (cpuid >= 0)
+                {
+                    ret = snprintf(filename, 1023, "/sys/devices/system/cpu/cpu%d/topology/physical_package_id", cpuid);
+                    ret = file_to_nonneg_int(filename, &socket);
                 }
             }
+
+            struct pci_dev* tmp = realloc(sysfs_pci_devices, (num_sysfs_pci_devices+1) * sizeof(struct pci_dev));
+            if (!tmp)
+            {
+                break;
+            }
+            sysfs_pci_devices = tmp;
+
+            struct pci_dev* p = &sysfs_pci_devices[num_sysfs_pci_devices];
+            p->domain = dom;
+            p->bus = bus;
+            p->device = devid;
+            p->func = func;
+            p->numa_node = numa_node;
+            p->socket = socket;
+            p->vendor = vendor;
+            p->device_id = device_id;
+            p->index = num_sysfs_pci_devices;
+            ret = snprintf(p->path, 1023, "%s", devbase);
+            p->path[ret] = '\0';
+            num_sysfs_pci_devices++;
         }
+
+        closedir(dp);
     }
-    return NULL;
+    return 0;
 }
 
 
@@ -401,7 +298,7 @@ static void print_unit(PciDeviceIndex idx, PerfmonDiscoveryUnit* unit)
     }
     if (name != NULL)
     {
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, PCIIDX %d Access %s NumRegs %d ID %d Type %s(%d) box_ctl 0x%X ctrl_offset 0x%X ctr_offset 0x%X mmap_addr 0x%X mmap_offset 0x%X,
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "PCIIDX %d Access %s NumRegs %d ID %d Type %s(%d) box_ctl 0x%lX ctrl_offset 0x%lX ctr_offset 0x%lX mmap_addr 0x%lX mmap_offset 0x%lX",
                 idx, AccessTypeNames[unit->access_type], unit->num_regs, unit->box_id, name, unit->box_type,
                 unit->box_ctl, unit->ctrl_offset, unit->ctr_offset, unit->mmap_addr, unit->mmap_offset);
     }
@@ -410,47 +307,57 @@ static void print_unit(PciDeviceIndex idx, PerfmonDiscoveryUnit* unit)
 static int perfmon_uncore_discovery_update_dev_location(PerfmonDiscoveryUnit* unit)
 {
     struct pci_dev* dev = NULL;
-    uint32_t device = 0;
-    uint32_t devfn = 0;
+    uint32_t check_device = 0;
+    uint32_t check_devfn = 0;
+    uint16_t mydevfn = 0;
+    uint16_t myid = 0;
+
     switch (unit->box_type)
     {
         case SPR_DEVICE_ID_UPI:
-            device = 0x3241;
-            devfn = 0x9;
+            check_device = 0x3241;
+            check_devfn = 0x9;
             break;
         case SPR_DEVICE_ID_M3UPI:
-            device = 0x3246;
-            devfn = 0x29;
+            check_device = 0x3246;
+            check_devfn = 0x29;
             break;
         default:
             return 0;
     }
 
-    while ((dev = pci_get_device(PCI_VENDOR_ID_INTEL, device, dev)) != NULL)
+    // TODO why do we need those variables?
+    (void)check_device;
+
+    for (int i = 0; i < num_sysfs_pci_devices; i++)
     {
+        struct pci_dev* dev = &sysfs_pci_devices[i];
         if (dev->numa_node < 0)
         {
             continue;
         }
-        unit->box_ctl = dev->domain  << UNCORE_DISCOVERY_PCI_DOMAIN_OFFSET |
+        mydevfn = PCI_DEV_TO_DEVFN(dev);
+        myid = PCI_SLOT(mydevfn) - PCI_SLOT(check_devfn);
+        if (myid == unit->box_id)
+        {
+            unit->box_ctl = dev->domain  << UNCORE_DISCOVERY_PCI_DOMAIN_OFFSET |
                         dev->bus << UNCORE_DISCOVERY_PCI_BUS_OFFSET |
-                        devfn << UNCORE_DISCOVERY_PCI_DEVFN_OFFSET |
+                        mydevfn << UNCORE_DISCOVERY_PCI_DEVFN_OFFSET |
                         unit->box_ctl;
+        }
     }
+    if (dev) free(dev);
     return 0;
 }
 
 int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
 {
     int ret = 0;
-    PerfmonDiscoverySocket* socks = NULL;
-    int socket_id = 0;
-    struct pci_dev* dev = NULL;
+    int num_sockets = 0;
     struct uncore_global_discovery global;
     int dvsec = 0;
     int PAGE_SIZE = sysconf (_SC_PAGESIZE);
     void * io_addr = NULL;
-    int max_sockets = 0;
     u32 val = 0;
     u32 entry_id = 0;
     u32 bir;
@@ -468,42 +375,101 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
         case SIERRAFORREST:
             uncore_discovery_map = sierraforrest_uncore_discovery_map;
             break;
+        case EMERALDRAPIDS:
+            uncore_discovery_map = emeraldrapids_uncore_discovery_map;
+            break;
         default:
-            ERROR_PRINT(Uncore discovery not supported for model 0x%X, model);
+            ERROR_PRINT("Uncore discovery not supported for model 0x%X", model);
             return -1;
     }
 
-    if (max_socket_id(&max_sockets) < 0)
+    ret = read_sysfs_pci_devs();
+    if (ret < 0)
     {
-        ERROR_PRINT(Failed to determine number of sockets);
+        ERROR_PRINT("Failed to read PCI devices from sysfs");
+        return -1;
+        uncore_discovery_map = NULL;
+    }
+
+    int num_tmp = 0;
+    int* tmp = malloc(num_sysfs_pci_devices * sizeof(int));
+    if (!tmp)
+    {
+        free(sysfs_pci_devices);
+        sysfs_pci_devices = NULL;
+        num_sysfs_pci_devices = 0;
+        uncore_discovery_map = NULL;
         return -1;
     }
+    memset(tmp, -1, num_sysfs_pci_devices * sizeof(int));
+
+    // Determine number of sockets based on the returned devices
+    for (int i = 0; i < num_sysfs_pci_devices; i++)
+    {
+        struct pci_dev* dev = &sysfs_pci_devices[i];
+        int found = 0;
+        for (int j = 0; j < num_tmp; j++)
+        {
+            if (tmp[j] == dev->socket)
+            {
+                found = 1;
+                break;
+            }
+        }
+        if (!found)
+        {
+            tmp[num_tmp++] = dev->socket;
+        }
+    }
+    num_sockets = num_tmp;
+    free(tmp);
 
     /* Open memory (requires root permissions) */
     int pcihandle = open("/dev/mem", O_RDWR);
     if (pcihandle < 0)
     {
-        ERROR_PRINT(Cannot open /dev/mem);
+        ERROR_PRINT("Cannot open /dev/mem");
+        free(sysfs_pci_devices);
+        sysfs_pci_devices = NULL;
+        num_sysfs_pci_devices = 0;
+        uncore_discovery_map = NULL;
         return -errno;
     }
     PerfmonDiscovery* perf = malloc(sizeof(PerfmonDiscovery));
     if (!perf)
     {
         close(pcihandle);
-        ERROR_PRINT(Cannot allocate space for device tables);
+        ERROR_PRINT("Cannot allocate space for device tables");
+        free(sysfs_pci_devices);
+        sysfs_pci_devices = NULL;
+        num_sysfs_pci_devices = 0;
+        uncore_discovery_map = NULL;
+        return -ENOMEM;
+    }
+    perf->sockets = malloc(num_sockets * sizeof(PerfmonDiscoverySocket));
+    if (!perf->sockets)
+    {
+        free(perf);
+        close(pcihandle);
+        ERROR_PRINT("Cannot allocate space for socket device tables");
+        free(sysfs_pci_devices);
+        sysfs_pci_devices = NULL;
+        num_sysfs_pci_devices = 0;
+        uncore_discovery_map = NULL;
         return -ENOMEM;
     }
-    perf->sockets = NULL;
     perf->num_sockets = 0;
 
-    while (((dev = pci_get_device(PCI_VENDOR_ID_INTEL, PCI_ANY_ID, dev)) != NULL)  && (socket_id < max_sockets+1)){
+    for (int i = 0; i < num_sysfs_pci_devices; i++)
+    {
+        struct pci_dev* dev = &sysfs_pci_devices[i];
         while ((dvsec = pci_find_next_ext_capability(dev, dvsec, UNCORE_EXT_CAP_ID_DISCOVERY))) {
             /* read the DVSEC_ID (15:0) */
             val = 0;
             ret = pci_read_config_dword(dev, dvsec + UNCORE_DISCOVERY_DVSEC_OFFSET, &val);
             if (ret < 0)
             {
-                ERROR_PRINT(Failed to read DVSEC offset from device %.04x:%.02x:%.02x.%.01x, dev->domain, dev->bus, dev->device, dev->func);
+                ERROR_PRINT("Failed to read DVSEC offset from device %.04x:%.02x:%.02x.%.01x", dev->domain, dev->bus, dev->device, dev->func);
                 continue;
             }
             entry_id = val & UNCORE_DISCOVERY_DVSEC_ID_MASK;
@@ -514,7 +480,7 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
                 ret = pci_read_config_dword(dev, dvsec + UNCORE_DISCOVERY_DVSEC2_OFFSET, &bir);
                 if (ret < 0)
                 {
-                    ERROR_PRINT(Failed to read DIR from device %.04x:%.02x:%.02x.%.01x, dev->domain, dev->bus, dev->device, dev->func);
+                    ERROR_PRINT("Failed to read DIR from device %.04x:%.02x:%.02x.%.01x", dev->domain, dev->bus, dev->device, dev->func);
                     continue;
                 }
                /* read BIR value (2:0) */
@@ -525,14 +491,14 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
                 ret = pci_read_config_dword(dev, bar_offset, &pci_dword);
                 if (ret < 0)
                 {
-                    ERROR_PRINT(Failed to read BAR offset from device %.04x:%.02x:%.02x.%.01x, dev->domain, dev->bus, dev->device, dev->func);
+                    ERROR_PRINT("Failed to read BAR offset from device %.04x:%.02x:%.02x.%.01x", dev->domain, dev->bus, dev->device, dev->func);
                     continue;
                 }
                 /* get page boundary address of pci_dword */
                 addr = pci_dword & ~(PAGE_SIZE - 1);
                 if ((pci_dword & PCI_BASE_ADDRESS_MEM_TYPE_MASK) == PCI_BASE_ADDRESS_MEM_TYPE_64)
                 {
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, Mem type 64);
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Mem type 64");
                     uint32_t pci_dword2;
                     ret = pci_read_config_dword(dev, bar_offset + sizeof(uint32_t), &pci_dword2);
                     if (ret > 0) addr |= ((uint64_t)pci_dword2) << 32;
@@ -543,7 +509,7 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
                 io_addr = mmap(NULL, UNCORE_DISCOVERY_MAP_SIZE, PROT_READ|PROT_WRITE, MAP_SHARED, pcihandle, addr);
                 if (io_addr == MAP_FAILED)
                 {
-                    ERROR_PRINT(Failed to mmap device %.04x:%.02x:%.02x.%.01x, dev->domain, dev->bus, dev->device, dev->func);
+                    ERROR_PRINT("Failed to mmap device %.04x:%.02x:%.02x.%.01x", dev->domain, dev->bus, dev->device, dev->func);
                     continue;
                 }
                 memset(&global, 0, sizeof(struct uncore_global_discovery));
@@ -554,22 +520,11 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
                     continue;
                 }
                 //printf("Global 1=0x%lX 2=0x%lX 3=0x%lX\n", global.table1, global.table2, global.table3);
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Device %.04x:%.02x:%.02x.%.01x usable with %d units, dev->domain, dev->bus, dev->device, dev->func, global.max_units);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Device %.04x:%.02x:%.02x.%.01x usable with %d units", dev->domain, dev->bus, dev->device, dev->func, global.max_units);
 
-                PerfmonDiscoverySocket* tmp = realloc(perf->sockets, (socket_id + 1) * sizeof(PerfmonDiscoverySocket));
-                if (!tmp)
-                {
-                    ERROR_PRINT(Cannot enlarge socket device table to %d, socket_id);
-                    if (perf->sockets) free(perf->sockets);
-                    free(perf);
-                    close(pcihandle);
-                    munmap(io_addr, UNCORE_DISCOVERY_MAP_SIZE);
-                    return -ENOMEM;
-                }
-                perf->sockets = tmp;
-                PerfmonDiscoverySocket* cur = &perf->sockets[socket_id];
+                PerfmonDiscoverySocket* cur = &perf->sockets[dev->socket];
 
-                cur->socket_id = socket_id;
+                cur->socket_id = dev->socket;
                 memset(cur->units, 0, MAX_NUM_PCI_DEVICES*sizeof(PerfmonDiscoveryUnit));
                 // record stuff from global struct in cur->global
                 cur->global.global_ctl = global.global_ctl;
@@ -608,6 +563,7 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
                         switch (model)
                         {
                             case SAPPHIRERAPIDS:
+                            case EMERALDRAPIDS:
                             case GRANITERAPIDS:
                                 if (unit.box_type == SPR_DEVICE_ID_CHA)
                                 {
@@ -626,6 +582,8 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
                         switch (model)
                         {
                             case SAPPHIRERAPIDS:
+                            case EMERALDRAPIDS:
+                            case GRANITERAPIDS:
                                 perfmon_uncore_discovery_update_dev_location(&cur->units[idx]);
                                 break;
                             default:
@@ -642,7 +600,6 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
                 /* Unmap PCI config space */
                 munmap(io_addr, UNCORE_DISCOVERY_MAP_SIZE);
                 io_addr = NULL;
-                socket_id++;
             }
         }
 /*        printf("Add M2IOSF devices \n");*/
@@ -665,10 +622,14 @@ int perfmon_uncore_discovery(int model, PerfmonDiscovery** perfmon)
 /*            print_unit(idx, &cur->units[idx]);*/
 /*        }*/
     }
-    if (dev) free(dev);
+
     close(pcihandle);
-    perf->num_sockets = socket_id+1;
+    perf->num_sockets = num_sockets;
+    free(sysfs_pci_devices);
+    sysfs_pci_devices = NULL;
+    num_sysfs_pci_devices = 0;
     *perfmon = perf;
+
     return 0;
 }
 
@@ -694,3 +655,4 @@ void perfmon_uncore_discovery_free(PerfmonDiscovery* perfmon)
     }
     free(perfmon);
 }
+
