@@ -5,13 +5,13 @@
  *
  *      Description:  Marker API interface of module nvmon
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Thomas Gruber (tg), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -56,11 +56,9 @@ static Map_t *cuda_maps = NULL;
 void nvmon_markerInit(void) {
   int i = 0;
   int setgpuinit = 0;
-  int gpuverbosity = 0;
   char *eventStr = getenv("LIKWID_NVMON_EVENTS");
   char *gpuStr = getenv("LIKWID_NVMON_GPUS");
   char *gpuFileStr = getenv("LIKWID_NVMON_FILEPATH");
-  char *verbosityStr = getenv("LIKWID_NVMON_VERBOSITY");
   char *debugStr = getenv("LIKWID_DEBUG");
   /*    char* cpu4gpuStr = getenv("LIKWID_CPU4GPUS");*/
   bstring bGpuStr;
@@ -86,7 +84,6 @@ void nvmon_markerInit(void) {
 
   if (debugStr != NULL) {
     nvmon_setVerbosity(ownatoi(debugStr));
-    gpuverbosity = perfmon_verbosity;
   }
   if (debugStr != NULL)
   {
@@ -220,13 +217,13 @@ void nvmon_markerClose(void) {
   file = fopen(markerfile, "w");
   if (file != NULL) {
     DEBUG_PRINT(DEBUGLEV_DEVELOP,
-                Creating GPU Marker file % s with % d regions % d groups and
-                    % d GPUs,
+                "Creating GPU Marker file %s with %d regions %d groups and "
+                    "%d GPUs",
                 markerfile, numberOfRegions, numberOfCudaGroups, numberOfGPUs);
     bstring thread_regs_grps =
         bformat("%d %d %d", numberOfGPUs, numberOfRegions, numberOfCudaGroups);
     fprintf(file, "%s\n", bdata(thread_regs_grps));
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, % s, bdata(thread_regs_grps));
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "%s", bdata(thread_regs_grps));
     bdestroy(thread_regs_grps);
 
     for (int j = 0; j < numberOfRegions; j++) {
@@ -235,7 +232,7 @@ void nvmon_markerClose(void) {
       if (ret == 0) {
         bstring tmp = bformat("%d:%s", j, bdata(results->label));
         fprintf(file, "%s\n", bdata(tmp));
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, % s, bdata(tmp));
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "%s", bdata(tmp));
         bdestroy(tmp);
       }
     }
@@ -256,7 +253,7 @@ void nvmon_markerClose(void) {
             bdestroy(tmp);
           }
           fprintf(file, "%s\n", bdata(l));
-          DEBUG_PRINT(DEBUGLEV_DEVELOP, % s, bdata(l));
+          DEBUG_PRINT(DEBUGLEV_DEVELOP, "%s", bdata(l));
           bdestroy(l);
         }
         free(results);
@@ -292,13 +289,13 @@ int nvmon_markerWriteFile(const char* markerfile)
   file = fopen(markerfile, "w");
   if (file != NULL) {
     DEBUG_PRINT(DEBUGLEV_DEVELOP,
-                Creating GPU Marker file % s with % d regions % d groups and
-                    % d GPUs,
+                "Creating GPU Marker file %s with %d regions %d groups and "
+                    "%d GPUs",
                 markerfile, numberOfRegions, numberOfCudaGroups, numberOfGPUs);
     bstring thread_regs_grps =
         bformat("%d %d %d", numberOfGPUs, numberOfRegions, numberOfCudaGroups);
     fprintf(file, "%s\n", bdata(thread_regs_grps));
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, % s, bdata(thread_regs_grps));
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "%s", bdata(thread_regs_grps));
     bdestroy(thread_regs_grps);
 
     for (int j = 0; j < numberOfRegions; j++) {
@@ -307,7 +304,7 @@ int nvmon_markerWriteFile(const char* markerfile)
       if (ret == 0) {
         bstring tmp = bformat("%d:%s", j, bdata(results->label));
         fprintf(file, "%s\n", bdata(tmp));
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, % s, bdata(tmp));
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "%s", bdata(tmp));
         bdestroy(tmp);
       }
     }
@@ -328,7 +325,7 @@ int nvmon_markerWriteFile(const char* markerfile)
             bdestroy(tmp);
           }
           fprintf(file, "%s\n", bdata(l));
-          DEBUG_PRINT(DEBUGLEV_DEVELOP, % s, bdata(l));
+          DEBUG_PRINT(DEBUGLEV_DEVELOP, "%s", bdata(l));
           bdestroy(l);
         }
         free(results);
@@ -368,6 +365,7 @@ int nvmon_markerRegisterRegion(const char *regionTag) {
     }
     add_smap(cuda_maps[i], bdata(res->label), res);
   }
+  return 0;
 }
 
 int nvmon_markerStartRegion(const char *regionTag) {
@@ -421,8 +419,8 @@ int nvmon_markerStartRegion(const char *regionTag) {
             nvmon_getLastResult(results->groupID, j, i);
       else if (device->backend == LIKWID_NVMON_PERFWORKS_BACKEND)
         results->StartPMcounters[j] = nvmon_getResult(results->groupID, j, i);
-      GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, START Device % d Event % d
-                     : % f, i, j, results->StartPMcounters[j]);
+      GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "START Device %d Event %d"
+                     ": %f", i, j, results->StartPMcounters[j]);
     }
     results->state = GPUMARKER_STATE_START;
     timer_start(&(results->startTime));
@@ -461,7 +459,7 @@ int nvmon_markerStopRegion(const char *regionTag) {
     results->count++;
     for (int j = 0; j < results->nevents; j++) {
       double end = nvmon_getResult(results->groupID, j, i);
-      NvmonDevice_t device = &nvGroupSet->gpus[i];
+      /*NvmonDevice_t device = &nvGroupSet->gpus[i];*/
       /*            if (device->backend == LIKWID_NVMON_CUPTI_BACKEND)*/
       /*                results->PMcounters[j] += end -
        * results->StartPMcounters[j];*/
@@ -471,8 +469,8 @@ int nvmon_markerStopRegion(const char *regionTag) {
       /*                */
       /*            }*/
       results->PMcounters[j] += end - results->StartPMcounters[j];
-      GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, STOP Device % d Event % d
-                     : % f - % f, i, j, end, results->StartPMcounters[j]);
+      GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "STOP Device %d Event %d"
+                     ": %f - %f", i, j, end, results->StartPMcounters[j]);
     }
     results->state = GPUMARKER_STATE_STOP;
   }
@@ -552,6 +550,7 @@ int nvmon_markerResetRegion(const char *regionTag) {
     results->time = 0;
     timer_reset(&results->startTime);
   }
+  return 0;
 }
 
 void nvmon_markerNextGroup(void) {
@@ -563,7 +562,7 @@ void nvmon_markerNextGroup(void) {
   }
   int next_group = (activeCudaGroup + 1) % numberOfCudaGroups;
   if (next_group != activeCudaGroup) {
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Switch from GPU group % d to group % d,
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Switch from GPU group %d to group %d",
                 activeCudaGroup, next_group);
     nvmon_switchActiveGroup(next_group);
   }
