@@ -5,14 +5,14 @@
  *
  *      Description:  Interface for LIKWID's device handling
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Thomas Gruber (tg), thomas.roehl@googlemail.com
  *                Michael Panzlaff, michael.panzlaff@fau.de
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -42,6 +42,23 @@
 #include <access.h>
 #include <error.h>
 
+static const char* LikwidDeviceTypeNames[MAX_DEVICE_TYPE] = {
+    [DEVICE_TYPE_INVALID] = "invalid",
+    [DEVICE_TYPE_HWTHREAD] = "hwthread",
+    [DEVICE_TYPE_CORE] = "core",
+    [DEVICE_TYPE_LLC] = "LLC",
+    [DEVICE_TYPE_NUMA] = "numa",
+    [DEVICE_TYPE_DIE] = "die",
+    [DEVICE_TYPE_SOCKET] = "socket",
+    [DEVICE_TYPE_NODE] = "node",
+#ifdef LIKWID_WITH_NVMON
+    [DEVICE_TYPE_NVIDIA_GPU] = "nvidia_gpu",
+#endif
+#ifdef LIKWID_WITH_ROCMON
+    [DEVICE_TYPE_AMD_GPU] = "amd_gpu",
+#endif
+};
+
 static int parse_pci_addr(const char *id, uint16_t *domain, uint8_t *bus, uint8_t *dev, uint8_t *func)
 {
     /* Try to parse PCI address string of type: 00000000:00:00.0
@@ -114,9 +131,9 @@ static int device_create_simple(LikwidDeviceType type, int id, LikwidDevice_t* d
     return 0;
 }
 
+#if defined(LIKWID_WITH_NVMON) || defined(LIKWID_WITH_ROCMON)
 static int device_create_pci(LikwidDeviceType type, int id, uint16_t domain, uint8_t bus, uint8_t dev, uint8_t func, LikwidDevice_t *device)
 {
-    int err = 0;
     LikwidDevice_t lw_dev = malloc(sizeof(_LikwidDevice));
     if (!lw_dev)
         return -ENOMEM;
@@ -130,6 +147,7 @@ static int device_create_pci(LikwidDeviceType type, int id, uint16_t domain, uin
     *device = lw_dev;
     return 0;
 }
+#endif
 
 static int device_create_hwthread(int id, LikwidDevice_t *device)
 {
@@ -265,7 +283,7 @@ static int device_create_amdgpu_by_index(int id, LikwidDevice_t *device)
             continue;
 
         // TODO we do not have the function ID, but it should usually be 0
-        return device_create_pci(DEVICE_TYPE_AMD_GPU, topo->devices[i].pciDom, topo->devices[i].pciBus, topo->devices[i].pciDev, 0, device);
+        return device_create_pci(DEVICE_TYPE_AMD_GPU, topo->devices[i].devid, topo->devices[i].pciDom, topo->devices[i].pciBus, topo->devices[i].pciDev, 0, device);
     }
 
     return -ENODEV;
@@ -277,14 +295,14 @@ static int device_create_amdgpu_by_pciaddr(uint16_t dom, uint8_t bus, uint8_t de
 
     for (int i = 0; i < topo->numDevices; i++)
     {
-        if (topo->devices[i].pciDom != domain)
+        if (topo->devices[i].pciDom != dom)
             continue;
         if (topo->devices[i].pciBus != bus)
             continue;
         if (topo->devices[i].pciDev != dev)
             continue;
 
-        return device_create_pci(DEVICE_TYPE_AMD_GPU, domain, bus, dev, func, device);
+        return device_create_pci(DEVICE_TYPE_AMD_GPU, topo->devices[i].devid, dom, bus, dev, func, device);
     }
 
     return -ENODEV;
@@ -347,7 +365,7 @@ int likwid_device_create(LikwidDeviceType type, int id, LikwidDevice_t* device)
             return device_create_amdgpu_by_index(id, device);
 #endif
         default:
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Unimplemented device type: %d, type);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Unimplemented device type: %d", type);
             break;
     }
     return -ENODEV;
@@ -385,7 +403,7 @@ int likwid_device_create_from_string(LikwidDeviceType type, const char *id, Likw
 
         if (type == DEVICE_TYPE_INVALID)
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Cannot create device from string type: %s, type_token);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Cannot create device from string type: %s", type_token);
             err = -EINVAL;
             goto cleanup;
         }
@@ -418,13 +436,13 @@ int likwid_device_create_from_string(LikwidDeviceType type, const char *id, Likw
                 break;
 #endif
 #ifdef LIKWID_WITH_ROCMON
-            case DEVICE_TYPE_NVIDIA_GPU:
+            case DEVICE_TYPE_AMD_GPU:
                 err = device_create_amdgpu_by_pciaddr(dom, bus, dev, func, device);
                 break;
 #endif
             default:
                 err = -EINVAL;
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Unable to use PCI address to create device type: %d, type);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Unable to use PCI address to create device type: %d", type);
                 break;
         }
     }
@@ -458,12 +476,12 @@ int likwid_device_create_from_string(LikwidDeviceType type, const char *id, Likw
 #endif
 #ifdef LIKWID_WITH_ROCMON
             case DEVICE_TYPE_AMD_GPU:
-                err = device_create_amdgpu_by_index(id, device);
+                err = device_create_amdgpu_by_index(int_id, device);
                 break;
 #endif
             default:
                 err = -EPERM;
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Unimplemented device type: %d, type);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Unimplemented device type: %d", type);
                 break;
         }
     }
@@ -474,7 +492,7 @@ int likwid_device_create_from_string(LikwidDeviceType type, const char *id, Likw
     }
     else
     {
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Unable to parse '%s' as valid PCI address or integer, id_token);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Unable to parse '%s' as valid PCI address or integer", id_token);
         err = -EINVAL;
     }
 
@@ -553,7 +571,7 @@ static bool device_in_cpuset(LikwidDeviceType type, size_t id)
             case DEVICE_TYPE_NODE:
                 return true;
             default:
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Unimplemented device type: %d, type);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Unimplemented device type: %d", type);
                 return false;
         }
     }
@@ -614,7 +632,7 @@ static int likwid_device_get_list(LikwidDeviceType type, char ***id_list, size_t
             break;
 #endif
         default:
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Unimplemented device type: %d, type);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Unimplemented device type: %d", type);
             return -EINVAL;
     }
 
