@@ -5,14 +5,14 @@
  *
  *      Description: F90 interface for marker API
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:  Jan Treibig (jt), jan.treibig@gmail.com,
  *               Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -35,6 +35,7 @@
 #include <string.h>
 
 #include <likwid.h>
+#include <lw_alloc.h>
 
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
@@ -59,7 +60,7 @@ likwid_markerclose_(void)
 void __attribute__ ((visibility ("default") ))
 likwid_markerwritefile_(char* markerfile, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, markerfile, len * sizeof(char));
 
     for (int i = (len - 1); len > 0; len--)
@@ -83,7 +84,7 @@ likwid_markernextgroup_(void)
 void __attribute__ ((visibility ("default") ))
 likwid_markerregisterregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char) );
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char) );
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -101,7 +102,7 @@ likwid_markerregisterregion_(char* regionTag, int len)
 void __attribute__ ((visibility ("default") ))
 likwid_markerstartregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char) );
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char) );
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -119,7 +120,7 @@ likwid_markerstartregion_(char* regionTag, int len)
 void __attribute__ ((visibility ("default") ))
 likwid_markerstopregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -143,7 +144,7 @@ likwid_markergetregion_(
         int *count,
         int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -160,7 +161,7 @@ likwid_markergetregion_(
 void __attribute__ ((visibility ("default") ))
 likwid_markerresetregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -199,7 +200,7 @@ likwid_nvmarkernextgroup_(void)
 void __attribute__ ((visibility ("default") ))
 likwid_nvmarkerregisterregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char) );
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char) );
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -217,7 +218,7 @@ likwid_nvmarkerregisterregion_(char* regionTag, int len)
 void __attribute__ ((visibility ("default") ))
 likwid_nvmarkerstartregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char) );
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char) );
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -235,7 +236,7 @@ likwid_nvmarkerstartregion_(char* regionTag, int len)
 void __attribute__ ((visibility ("default") ))
 likwid_nvmarkerstopregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -253,7 +254,7 @@ likwid_nvmarkerstopregion_(char* regionTag, int len)
 void __attribute__ ((visibility ("default") ))
 likwid_nvmarkerresetregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -270,7 +271,7 @@ likwid_nvmarkerresetregion_(char* regionTag, int len)
 int __attribute__ ((visibility ("default") ))
 likwid_nvmarkerwritefile_(char* filename, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, filename, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -308,7 +309,7 @@ likwid_rocmmarkernextgroup_(void)
 void __attribute__ ((visibility ("default") ))
 likwid_rocmmarkerregisterregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char) );
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char) );
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -326,7 +327,7 @@ likwid_rocmmarkerregisterregion_(char* regionTag, int len)
 void __attribute__ ((visibility ("default") ))
 likwid_rocmmarkerstartregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char) );
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char) );
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -344,7 +345,7 @@ likwid_rocmmarkerstartregion_(char* regionTag, int len)
 void __attribute__ ((visibility ("default") ))
 likwid_rocmmarkerstopregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -362,7 +363,7 @@ likwid_rocmmarkerstopregion_(char* regionTag, int len)
 void __attribute__ ((visibility ("default") ))
 likwid_rocmmarkerresetregion_(char* regionTag, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, regionTag, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
@@ -379,7 +380,7 @@ likwid_rocmmarkerresetregion_(char* regionTag, int len)
 int __attribute__ ((visibility ("default") ))
 likwid_rocmmarkerwritefile_(char* filename, int len)
 {
-    char* tmp = (char*) malloc((len+1) * sizeof(char));
+    char* tmp = (char*) lw_malloc((len+1) * sizeof(char));
     strncpy(tmp, filename, len * sizeof(char) );
 
     for (int i=(len-1); len > 0; len--)
