@@ -5,13 +5,13 @@
  *
  *      Description:  Implementation a hashmap in C using ghash as backend
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -156,7 +156,6 @@ int init_smap(Map_t* map)
 
 int add_smap(Map_t map, char* key, void* val)
 {
-    MapValue *mval = NULL;
 #ifndef WITH_BSTRING
     gpointer gval = g_hash_table_lookup(map->ghash, key);
 #else
