@@ -5,13 +5,13 @@
  *
  *      Description:  Implementation of sweeper module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -83,9 +83,7 @@ initMemory(size_t size, char* ptr, int domainId)
 static int
 findProcessor(uint32_t nodeId, uint32_t coreId)
 {
-    int i;
-
-    for (i=0; i<numa_info.nodes[nodeId].numberOfProcessors; i++)
+    for (size_t i=0; i<numa_info.nodes[nodeId].numberOfProcessors; i++)
     {
         if (numa_info.nodes[nodeId].processors[i] == coreId)
         {
@@ -105,7 +103,7 @@ cleanupCache(char* ptr)
         printf("Cleaning LLC with %g MB\n", (double)cachesize/(1024.0 * 1024.0));
     _loadData(cachesize,ptr);
 #else
-    ERROR_PLAIN_PRINT(Cleanup cache is currently only available on X86 systems.);
+    ERROR_PRINT("Cleanup cache is currently only available on X86 systems.");
 #endif
 }
 
