@@ -5,14 +5,14 @@
  *
  *      Description:  Get NUMA topology from procfs and sysfs
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -71,40 +71,42 @@ proc_findProcessor(uint32_t nodeId, uint32_t coreId)
     return 0;
 }
 
-static int
-setConfiguredNodes(void)
-{
-    DIR *dir = NULL;
-    struct dirent *de = NULL;
-    int maxIdConfiguredNode = 0;
-
-    dir = opendir("/sys/devices/system/node");
-
-    if (!dir)
-    {
-        maxIdConfiguredNode = 0;
-    }
-    else
-    {
-        while ((de = readdir(dir)) != NULL)
-        {
-            int nd;
-            if (strncmp(de->d_name, "node", 4))
-            {
-                continue;
-            }
-
-            nd = str2int(de->d_name+4);
-
-            if (maxIdConfiguredNode < nd)
-            {
-                maxIdConfiguredNode = nd;
-            }
-        }
-        closedir(dir);
-    }
-    return maxIdConfiguredNode;
-}
+// TODO do we still need this function?
+// At the time of commenting this out, this function was unused
+//static int
+//setConfiguredNodes(void)
+//{
+//    DIR *dir = NULL;
+//    struct dirent *de = NULL;
+//    int maxIdConfiguredNode = 0;
+//
+//    dir = opendir("/sys/devices/system/node");
+//
+//    if (!dir)
+//    {
+//        maxIdConfiguredNode = 0;
+//    }
+//    else
+//    {
+//        while ((de = readdir(dir)) != NULL)
+//        {
+//            int nd;
+//            if (strncmp(de->d_name, "node", 4))
+//            {
+//                continue;
+//            }
+//
+//            nd = str2int(de->d_name+4);
+//
+//            if (maxIdConfiguredNode < nd)
+//            {
+//                maxIdConfiguredNode = nd;
+//            }
+//        }
+//        closedir(dir);
+//    }
+//    return maxIdConfiguredNode;
+//}
 
 static int
 get_numaNodes(int* array, int maxlen)
@@ -152,6 +154,7 @@ get_numaNodes(int* array, int maxlen)
             i++;
         }
     }
+    closedir(dir);
     return count;
 }
 
@@ -248,7 +251,7 @@ nodeProcessorList(int node, uint32_t** list)
 
             if (endptr == (char*) tokens->entry[i]->data)
             {
-                ERROR_PLAIN_PRINT(No digits were found);
+                ERROR_PRINT("No digits were found");
                 return -EFAULT;
             }
 
@@ -264,7 +267,7 @@ nodeProcessorList(int node, uint32_t** list)
                         }
                         else
                         {
-                            ERROR_PRINT(Number Of threads %d too large for NUMA node %d, count, node);
+                            ERROR_PRINT("Number Of threads %d too large for NUMA node %d", count, node);
                             return -EFAULT;
                         }
                         count++;
@@ -319,7 +322,7 @@ nodeDistanceList(int node, int numberOfNodes, uint32_t** list)
             }
             else
             {
-                ERROR_PRINT(Number Of nodes %d too large,count);
+                ERROR_PRINT("Number Of nodes %d too large", count);
                 return -EFAULT;
             }
             count++;
@@ -342,7 +345,6 @@ int proc_numa_init(void)
 {
     int err = 0;
     uint32_t i;
-    uint64_t nrCPUs = 0;
     if (numaInitialized > 0 || numa_info.numberOfNodes > 0)
         return 0;
 
@@ -363,6 +365,7 @@ int proc_numa_init(void)
     numa_info.nodes = (NumaNode*) malloc(numa_info.numberOfNodes * sizeof(NumaNode));
     if (!numa_info.nodes)
     {
+        free(nodes);
         return -ENOMEM;
     }
 
@@ -398,6 +401,7 @@ int proc_numa_init(void)
     }
     if (err == 0)
         numaInitialized = 1;
+    free(nodes);
     return err;
 }
 
