@@ -6,13 +6,13 @@
  *      Description:  NVML implementation of the performance monitoring module
  *                    for NVIDIA GPUs
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tg), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -93,7 +93,7 @@ struct NvmlEvent_struct;
 typedef int (*NvmlMeasureFunc)(nvmlDevice_t device, struct NvmlEvent_struct* event, NvmlEventResult* result);
 
 #define LIKWID_NVML_NAME_LEN 40
-#define LIKWID_NVML_DESC_LEN 50
+#define LIKWID_NVML_DESC_LEN 128
 typedef struct NvmlEvent_struct {
     char name[LIKWID_NVML_NAME_LEN];
     char description[LIKWID_NVML_DESC_LEN];
@@ -155,55 +155,67 @@ static NvmlContext nvmlContext;
 
 
 // Macros
-#define FREE_IF_NOT_NULL(x) if (x) { free(x); }
-#define DLSYM_AND_CHECK( dllib, name ) name##_ptr = dlsym( dllib, #name ); if ( dlerror() != NULL ) { return -1; }
-#define NVML_CALL(call, args, handleerror)                                            \
-    do {                                                                           \
-        nvmlReturn_t _status = (*call##_ptr)args;                                         \
-        if (_status != NVML_SUCCESS) {                                            \
-            fprintf(stderr, "Error: function %s failed with error %d.\n", #call, _status);                    \
-            handleerror;                                                             \
-        }                                                                          \
-    } while (0)
-#define CUPTI_CALL(call, args, handleerror)                                            \
+#define DLSYM_AND_CHECK(dllib, name) name##_ptr = dlsym(dllib, #name);  \
     do {                                                                \
-        CUptiResult _status = (*call##_ptr)args;                                  \
-        if (_status != CUPTI_SUCCESS) {                                 \
-            const char *errstr;                                         \
-            (*cuptiGetResultString)(_status, &errstr);               \
-            fprintf(stderr, "Error: function %s failed with error %s.\n", #call, errstr); \
-            handleerror;                                                \
+        const char *err = dlerror();                                    \
+        if (err) {                                                      \
+            ERROR_PRINT("Error: dlsym on symbol '%s' failed with error: %s", #name, err); \
+            return -EINVAL;                                             \
         }                                                               \
     } while (0)
 
-// NVML function declarations
-#define NVMLWEAK __attribute__(( weak ))
-#define DECLAREFUNC_NVML(funcname, funcsig) nvmlReturn_t NVMLWEAK funcname funcsig;  nvmlReturn_t ( *funcname##_ptr ) funcsig;
+#define NVML_CALL(func, ...)                            \
+    do {                                                \
+        nvmlReturn_t s_ = (*func##_ptr)(__VA_ARGS__);    \
+        if (s_ != NVML_SUCCESS) {                        \
+            ERROR_PRINT("Error: function %s failed with error: '%s' (nvmlReturn=%d).", #func, nvmlErrorString_ptr(s_), s_);   \
+            return -EPERM;                              \
+        }                                               \
+    } while (0)
 
-DECLAREFUNC_NVML(nvmlInit_v2, (void));
-DECLAREFUNC_NVML(nvmlShutdown, (void));
-DECLAREFUNC_NVML(nvmlDeviceGetHandleByIndex_v2, (unsigned int  index, nvmlDevice_t* device));
-DECLAREFUNC_NVML(nvmlDeviceGetClockInfo, (nvmlDevice_t device, nvmlClockType_t type, unsigned int* clock));
-DECLAREFUNC_NVML(nvmlDeviceGetInforomVersion, (nvmlDevice_t device, nvmlInforomObject_t object, char* version, unsigned int  length));
-DECLAREFUNC_NVML(nvmlDeviceGetEccMode, (nvmlDevice_t device, nvmlEnableState_t* current, nvmlEnableState_t* pending));
-DECLAREFUNC_NVML(nvmlDeviceGetDetailedEccErrors, (nvmlDevice_t device, nvmlMemoryErrorType_t errorType, nvmlEccCounterType_t counterType, nvmlEccErrorCounts_t* eccCounts));
-DECLAREFUNC_NVML(nvmlDeviceGetTotalEccErrors, (nvmlDevice_t device, nvmlMemoryErrorType_t errorType, nvmlEccCounterType_t counterType, unsigned long long* eccCounts));
-DECLAREFUNC_NVML(nvmlDeviceGetFanSpeed_v2, (nvmlDevice_t device, unsigned int fan, unsigned int* speed));
-DECLAREFUNC_NVML(nvmlDeviceGetClock, (nvmlDevice_t device, nvmlClockType_t clockType, nvmlClockId_t clockId, unsigned int* clockMHz));
-DECLAREFUNC_NVML(nvmlDeviceGetMemoryInfo, (nvmlDevice_t device, nvmlMemory_t* memory));
-DECLAREFUNC_NVML(nvmlDeviceGetPerformanceState, (nvmlDevice_t device, nvmlPstates_t* pState));
-DECLAREFUNC_NVML(nvmlDeviceGetPowerUsage, (nvmlDevice_t device, unsigned int* power));
-DECLAREFUNC_NVML(nvmlDeviceGetTemperature, (nvmlDevice_t device, nvmlTemperatureSensors_t sensorType, unsigned int* temp));
-DECLAREFUNC_NVML(nvmlDeviceGetPowerManagementLimit, (nvmlDevice_t device, unsigned int* limit));
-DECLAREFUNC_NVML(nvmlDeviceGetPowerManagementLimitConstraints, (nvmlDevice_t device, unsigned int* minLimit, unsigned int* maxLimit));
-DECLAREFUNC_NVML(nvmlDeviceGetUtilizationRates, (nvmlDevice_t device, nvmlUtilization_t* utilization));
+#ifndef CUPTI_CALL
+#define CUPTI_CALL(func, ...)                            \
+    do {                                                \
+        CUptiResult s_ = (*func##_ptr)(__VA_ARGS__);    \
+        if (s_ != CUPTI_SUCCESS) {                        \
+            const char *errstr = NULL; \
+            cuptiGetResultString_ptr(s_, &errstr); \
+            ERROR_PRINT("Error: function %s failed with error: '%s' (CUptiResult=%d)", #func, errstr, s_);   \
+            return -EPERM;                              \
+        }                                               \
+    } while (0)
+#endif
+
+// NVML function declarations
+#define DECLAREFUNC_NVML(funcname, ...) nvmlReturn_t __attribute__((weak)) funcname(__VA_ARGS__);  static nvmlReturn_t (*funcname##_ptr)(__VA_ARGS__);
+
+DECLAREFUNC_NVML(nvmlInit_v2, void);
+DECLAREFUNC_NVML(nvmlShutdown, void);
+DECLAREFUNC_NVML(nvmlDeviceGetHandleByIndex_v2, unsigned int  index, nvmlDevice_t* device);
+DECLAREFUNC_NVML(nvmlDeviceGetClockInfo, nvmlDevice_t device, nvmlClockType_t type, unsigned int* clock);
+DECLAREFUNC_NVML(nvmlDeviceGetInforomVersion, nvmlDevice_t device, nvmlInforomObject_t object, char* version, unsigned int  length);
+DECLAREFUNC_NVML(nvmlDeviceGetEccMode, nvmlDevice_t device, nvmlEnableState_t* current, nvmlEnableState_t* pending);
+DECLAREFUNC_NVML(nvmlDeviceGetDetailedEccErrors, nvmlDevice_t device, nvmlMemoryErrorType_t errorType, nvmlEccCounterType_t counterType, nvmlEccErrorCounts_t* eccCounts);
+DECLAREFUNC_NVML(nvmlDeviceGetTotalEccErrors, nvmlDevice_t device, nvmlMemoryErrorType_t errorType, nvmlEccCounterType_t counterType, unsigned long long* eccCounts);
+DECLAREFUNC_NVML(nvmlDeviceGetFanSpeed_v2, nvmlDevice_t device, unsigned int fan, unsigned int* speed);
+DECLAREFUNC_NVML(nvmlDeviceGetClock, nvmlDevice_t device, nvmlClockType_t clockType, nvmlClockId_t clockId, unsigned int* clockMHz);
+DECLAREFUNC_NVML(nvmlDeviceGetMemoryInfo, nvmlDevice_t device, nvmlMemory_t* memory);
+DECLAREFUNC_NVML(nvmlDeviceGetPerformanceState, nvmlDevice_t device, nvmlPstates_t* pState);
+DECLAREFUNC_NVML(nvmlDeviceGetPowerUsage, nvmlDevice_t device, unsigned int* power);
+DECLAREFUNC_NVML(nvmlDeviceGetTemperature, nvmlDevice_t device, nvmlTemperatureSensors_t sensorType, unsigned int* temp);
+DECLAREFUNC_NVML(nvmlDeviceGetPowerManagementLimit, nvmlDevice_t device, unsigned int* limit);
+DECLAREFUNC_NVML(nvmlDeviceGetPowerManagementLimitConstraints, nvmlDevice_t device, unsigned int* minLimit, unsigned int* maxLimit);
+DECLAREFUNC_NVML(nvmlDeviceGetUtilizationRates, nvmlDevice_t device, nvmlUtilization_t* utilization);
+DECLAREFUNC_NVML(nvmlDeviceGetTotalEnergyConsumption, nvmlDevice_t device, unsigned long long *energy);
+__attribute__((weak)) const char *nvmlErrorString(nvmlReturn_t result);
+static const char *(*nvmlErrorString_ptr)(nvmlReturn_t result);
 
 // CUPTI function declarations
 #define CUPTIWEAK __attribute__(( weak ))
-#define DECLAREFUNC_CUPTI(funcname, funcsig) CUptiResult CUPTIWEAK funcname funcsig;  CUptiResult( *funcname##_ptr ) funcsig;
+#define DECLAREFUNC_CUPTI(funcname, ...) CUptiResult __attribute__((weak)) funcname(__VA_ARGS__);  static CUptiResult (*funcname##_ptr)(__VA_ARGS__);
 
-DECLAREFUNC_CUPTI(cuptiGetTimestamp, (uint64_t * timestamp));
-DECLAREFUNC_CUPTI(cuptiGetResultString, (CUptiResult result, const char **str));
+DECLAREFUNC_CUPTI(cuptiGetTimestamp, uint64_t * timestamp);
+DECLAREFUNC_CUPTI(cuptiGetResultString, CUptiResult result, const char **str);
 
 
 // ----------------------------------------------------
@@ -220,9 +232,9 @@ _nvml_resultAddMeasurement(NvmlEventResult* result, double value)
 static int
 _nvml_wrapper_getClockInfo(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
-    unsigned int clock;
+    unsigned int clock = 0;
 
-    NVML_CALL(nvmlDeviceGetClockInfo, (device, event->options.clock, &clock), return -1);
+    NVML_CALL(nvmlDeviceGetClockInfo, device, event->options.clock, &clock);
     _nvml_resultAddMeasurement(result, clock);
 
     return 0;
@@ -232,9 +244,9 @@ _nvml_wrapper_getClockInfo(nvmlDevice_t device, NvmlEvent* event, NvmlEventResul
 static int
 _nvml_wrapper_getMaxClock(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
-    unsigned int clock;
+    unsigned int clock = 0;
 
-    NVML_CALL(nvmlDeviceGetClock, (device, event->options.clock, NVML_CLOCK_ID_CUSTOMER_BOOST_MAX, &clock), return -1);
+    NVML_CALL(nvmlDeviceGetClock, device, event->options.clock, NVML_CLOCK_ID_CUSTOMER_BOOST_MAX, &clock);
     _nvml_resultAddMeasurement(result, clock);
 
     return 0;
@@ -246,7 +258,7 @@ _nvml_wrapper_getEccLocalErrors(nvmlDevice_t device, NvmlEvent* event, NvmlEvent
 {
     nvmlEccErrorCounts_t counts;
 
-    NVML_CALL(nvmlDeviceGetDetailedEccErrors, (device, event->options.ecc.type, NVML_VOLATILE_ECC, &counts), return -1);
+    NVML_CALL(nvmlDeviceGetDetailedEccErrors, device, event->options.ecc.type, NVML_VOLATILE_ECC, &counts);
     switch (event->options.ecc.counter)
     {
     case LOCAL_ECC_L1:      _nvml_resultAddMeasurement(result, counts.l1Cache);         break;
@@ -263,9 +275,9 @@ _nvml_wrapper_getEccLocalErrors(nvmlDevice_t device, NvmlEvent* event, NvmlEvent
 static int
 _nvml_wrapper_getEccTotalErrors(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
-    unsigned long long count;
+    unsigned long long count = 0;
 
-    NVML_CALL(nvmlDeviceGetTotalEccErrors, (device, event->options.ecc.type, NVML_VOLATILE_ECC, &count), return -1);
+    NVML_CALL(nvmlDeviceGetTotalEccErrors, device, event->options.ecc.type, NVML_VOLATILE_ECC, &count);
     _nvml_resultAddMeasurement(result, count);
 
     return 0;
@@ -275,9 +287,9 @@ _nvml_wrapper_getEccTotalErrors(nvmlDevice_t device, NvmlEvent* event, NvmlEvent
 static int
 _nvml_wrapper_getFanSpeed(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
-    unsigned int speed;
+    unsigned int speed = 0;
 
-    NVML_CALL(nvmlDeviceGetFanSpeed_v2, (device, event->options.fan, &speed), return -1);
+    NVML_CALL(nvmlDeviceGetFanSpeed_v2, device, event->options.fan, &speed);
     _nvml_resultAddMeasurement(result, speed);
     
     return 0;
@@ -289,7 +301,7 @@ _nvml_wrapper_getMemoryInfo(nvmlDevice_t device, NvmlEvent* event, NvmlEventResu
 {
     nvmlMemory_t memory;
 
-    NVML_CALL(nvmlDeviceGetMemoryInfo, (device, &memory), return -1);
+    NVML_CALL(nvmlDeviceGetMemoryInfo, device, &memory);
     switch (event->options.memory)
     {
     case MEMORY_FREE:   _nvml_resultAddMeasurement(result, memory.free);    break;
@@ -305,9 +317,10 @@ _nvml_wrapper_getMemoryInfo(nvmlDevice_t device, NvmlEvent* event, NvmlEventResu
 static int
 _nvml_wrapper_getPerformanceState(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
+    (void)event;
     nvmlPstates_t state;
 
-    NVML_CALL(nvmlDeviceGetPerformanceState, (device, &state), return -1);
+    NVML_CALL(nvmlDeviceGetPerformanceState, device, &state);
     _nvml_resultAddMeasurement(result, state);
 
     return 0;
@@ -317,21 +330,36 @@ _nvml_wrapper_getPerformanceState(nvmlDevice_t device, NvmlEvent* event, NvmlEve
 static int
 _nvml_wrapper_getPowerUsage(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
-    unsigned int power;
+    (void)event;
+    unsigned int power = 0;
 
-    NVML_CALL(nvmlDeviceGetPowerUsage, (device, &power), return -1);
+    NVML_CALL(nvmlDeviceGetPowerUsage, device, &power);
     _nvml_resultAddMeasurement(result, power);
 
     return 0;
 }
 
+static int
+_nvml_wrapper_getEnergyConsumption(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
+{
+    (void)event;
+    unsigned long long energy = 0;
+
+    NVML_CALL(nvmlDeviceGetTotalEnergyConsumption, device, &energy);
+    double last = ((double)energy) - result->fullValue;
+    result->fullValue = ((double)energy);
+    result->lastValue = last;
+
+    return 0;
+}
+
 
 static int
 _nvml_wrapper_getTemperature(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
-    unsigned int temp;
+    unsigned int temp = 0;
 
-    NVML_CALL(nvmlDeviceGetTemperature, (device, event->options.tempSensor, &temp), return -1);
+    NVML_CALL(nvmlDeviceGetTemperature, device, event->options.tempSensor, &temp);
     _nvml_resultAddMeasurement(result, temp);
 
     return 0;
@@ -341,9 +369,10 @@ _nvml_wrapper_getTemperature(nvmlDevice_t device, NvmlEvent* event, NvmlEventRes
 static int
 _nvml_wrapper_getPowerManagementLimit(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
-    unsigned int limit;
+    (void)event;
+    unsigned int limit = 0;
 
-    NVML_CALL(nvmlDeviceGetPowerManagementLimit, (device, &limit), return -1);
+    NVML_CALL(nvmlDeviceGetPowerManagementLimit, device, &limit);
     _nvml_resultAddMeasurement(result, limit);
 
     return 0;
@@ -353,10 +382,10 @@ _nvml_wrapper_getPowerManagementLimit(nvmlDevice_t device, NvmlEvent* event, Nvm
 static int
 _nvml_wrapper_getPowerManagementLimitConstraints(nvmlDevice_t device, NvmlEvent* event, NvmlEventResult* result)
 {
-    unsigned int maxLimit;
-    unsigned int minLimit;
+    unsigned int maxLimit = 0;
+    unsigned int minLimit = 0;
 
-    NVML_CALL(nvmlDeviceGetPowerManagementLimitConstraints, (device, &minLimit, &maxLimit), return -1);
+    NVML_CALL(nvmlDeviceGetPowerManagementLimitConstraints, device, &minLimit, &maxLimit);
     if (event->options.powerLimit == LIMIT_MIN)
     {
         _nvml_resultAddMeasurement(result, minLimit);
@@ -375,7 +404,7 @@ _nvml_wrapper_getUtilization(nvmlDevice_t device, NvmlEvent* event, NvmlEventRes
 {
     nvmlUtilization_t utilization;
 
-    NVML_CALL(nvmlDeviceGetUtilizationRates, (device, &utilization), return -1);
+    NVML_CALL(nvmlDeviceGetUtilizationRates, device, &utilization);
     switch (event->options.utilization)
     {
     case UTILIZATION_GPU:       _nvml_resultAddMeasurement(result, utilization.gpu);        break;
@@ -395,11 +424,14 @@ static int
 _nvml_linkLibraries()
 {
     // Load NVML libary and link functions
-    GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, Init NVML Libaries);
+    GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "Init NVML Libaries");
     dl_nvml = dlopen("libnvidia-ml.so", RTLD_NOW | RTLD_GLOBAL);
-    if (!dl_nvml || dlerror() != NULL)
+    if (!dl_nvml)
+        dl_nvml = dlopen("libnvidia-ml.so.1", RTLD_NOW | RTLD_GLOBAL);
+
+    if (!dl_nvml)
     {
-        fprintf(stderr, "NVML library libnvidia-ml.so not found.");
+        fprintf(stderr, "Unable to open NVML library libnvidia-ml.so: %s", dlerror());
         return -1;
     }
 
@@ -420,9 +452,11 @@ _nvml_linkLibraries()
     DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetPowerManagementLimit);
     DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetPowerManagementLimitConstraints);
     DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetUtilizationRates);
+    DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetTotalEnergyConsumption);
+    DLSYM_AND_CHECK(dl_nvml, nvmlErrorString);
 
     // Load CUPTI library and link functions
-    GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, Init NVML Libaries);
+    GPUDEBUG_PRINT(DEBUGLEV_DEVELOP, "Init NVML Libaries");
     dl_cupti = dlopen("libcupti.so", RTLD_NOW | RTLD_GLOBAL);
     if (!dl_cupti || dlerror() != NULL)
     {
@@ -574,9 +608,9 @@ _nvml_getEventsForDevice(NvmlDevice* device)
 
     if (device->features & FEATURE_FAN_SPEED)
     {
-        for (int i = 0; i < device->numFans; i++)
+        for (unsigned i = 0; i < device->numFans; i++)
         {
-            snprintf(event->name, LIKWID_NVML_NAME_LEN, "FAN_SPEED[%d]", i);
+            snprintf(event->name, LIKWID_NVML_NAME_LEN, "FAN_SPEED[%u]", i);
             snprintf(event->description, LIKWID_NVML_DESC_LEN, "Indended fan speed represented as a percentage of the maximum noise tolerance fan speed. May exceed 100 in certain cases");
             event->measureFunc = &_nvml_wrapper_getFanSpeed;
             event->options.fan = i;
@@ -619,13 +653,18 @@ _nvml_getEventsForDevice(NvmlDevice* device)
         snprintf(event->description, LIKWID_NVML_DESC_LEN, "Power usage for this GPU in milliwatts and its associated circuitry (e.g. memory)");
         event->measureFunc = &_nvml_wrapper_getPowerUsage;
         event++;
+
+        snprintf(event->name, LIKWID_NVML_NAME_LEN, "ENERGY_CONSUMPTION");
+        snprintf(event->description, LIKWID_NVML_DESC_LEN, "Energy consumption for this GPU in milliJoules");
+        event->measureFunc = &_nvml_wrapper_getEnergyConsumption;
+        event++;
     }
 
     if (device->features & FEATURE_TEMP)
     {
         snprintf(event->name, LIKWID_NVML_NAME_LEN, "TEMP_GPU");
         snprintf(event->description, LIKWID_NVML_DESC_LEN, "Current temperature readings for the device, in degrees C");
-        event->measureFunc = &_nvml_wrapper_getPowerUsage;
+        event->measureFunc = &_nvml_wrapper_getTemperature;
         event->options.tempSensor = NVML_TEMPERATURE_GPU;
         event++;
     }
@@ -767,7 +806,7 @@ _nvml_getFeaturesOfDevice(NvmlDevice* device)
     if ((*nvmlDeviceGetPowerUsage_ptr)(device->nvmlDevice, &value) == NVML_SUCCESS)
     {
         device->features |= FEATURE_POWER;
-        device->numAllEvents += 1;
+        device->numAllEvents += 2;
     }
 
     // Check FEATURE_TEMP
@@ -817,10 +856,7 @@ _nvml_createDevice(int idx, NvmlDevice* device)
     device->numFans = 0;
 
     // Get NVML device handle
-    NVML_CALL(nvmlDeviceGetHandleByIndex_v2, (device->nvDevice->deviceId, &device->nvmlDevice), {
-        ERROR_PRINT(Failed to get device handle for GPU %d, device->nvDevice->deviceId);
-        return -1;
-    });
+    NVML_CALL(nvmlDeviceGetHandleByIndex_v2, device->nvDevice->deviceId, &device->nvmlDevice);
 
     ret = _nvml_getFeaturesOfDevice(device);
     if (ret < 0) return ret;
@@ -829,7 +865,7 @@ _nvml_createDevice(int idx, NvmlDevice* device)
     device->allEvents = (NvmlEvent*) malloc(device->numAllEvents * sizeof(NvmlEvent));
     if (device->allEvents == NULL)
     {
-        ERROR_PRINT(Failed to allocate memory for event list of GPU %d, device->nvDevice->deviceId);
+        ERROR_PRINT("Failed to allocate memory for event list of GPU %d", device->nvDevice->deviceId);
         return -ENOMEM;
     }
 
@@ -843,15 +879,9 @@ _nvml_createDevice(int idx, NvmlDevice* device)
 static int
 _nvml_readCounters(void (*saveTimestamp)(NvmlDevice* device, uint64_t timestamp), void (*afterMeasure)(NvmlEventResult* result))
 {
-    int ret;
-
     // Get timestamp
     uint64_t timestamp;
-    CUPTI_CALL(cuptiGetTimestamp, (&timestamp), return -EFAULT);
-    if (ret < 0)
-    {
-        return -EFAULT;
-    }
+    CUPTI_CALL(cuptiGetTimestamp, &timestamp);
 
     for (int i = 0; i < nvmlContext.numDevices; i++)
     {
@@ -871,8 +901,9 @@ _nvml_readCounters(void (*saveTimestamp)(NvmlDevice* device, uint64_t timestamp)
             NvmlEventResult* result = &eventSet->results[i];
             if (event->measureFunc)
             {
-                ret = event->measureFunc(device->nvmlDevice, event, result);
-                if (ret < 0) return ret;
+                int ret = event->measureFunc(device->nvmlDevice, event, result);
+                if (ret < 0)
+                    return ret;
 
                 if (afterMeasure)
                 {
@@ -932,7 +963,7 @@ nvml_init()
     ret = _nvml_linkLibraries();
     if (ret < 0)
     {
-        ERROR_PLAIN_PRINT(Failed to link libraries);
+        ERROR_PRINT("Failed to link libraries");
         return -1;
     }
 
@@ -941,12 +972,12 @@ nvml_init()
     nvmlContext.devices = (NvmlDevice*) malloc(nvmlContext.numDevices * sizeof(NvmlDevice));
     if (nvmlContext.devices == NULL)
     {   
-        ERROR_PLAIN_PRINT(Cannot allocate NVML device structures);
+        ERROR_PRINT("Cannot allocate NVML device structures");
         return -ENOMEM;
     }
 
     // Init NVML
-    NVML_CALL(nvmlInit_v2, (), return -1);
+    NVML_CALL(nvmlInit_v2);
 
     // Do device specific setup
     for (int i = 0; i < nvmlContext.numDevices; i++)
@@ -955,7 +986,7 @@ nvml_init()
         ret = _nvml_createDevice(i, device);
         if (ret < 0)
         {
-            ERROR_PRINT(Failed to create device #%d, i);
+            ERROR_PRINT("Failed to create device #%d", i);
             return ret;
         }
     }
@@ -974,19 +1005,19 @@ nvml_finalize()
         {
             NvmlDevice* device = &nvmlContext.devices[i];
 
-            FREE_IF_NOT_NULL(device->allEvents);
+            free(device->allEvents);
             for (int j = 0; j < device->numEventSets; j++)
             {
-                FREE_IF_NOT_NULL(device->eventSets[j].events);
-                FREE_IF_NOT_NULL(device->eventSets[j].results);
+                free(device->eventSets[j].events);
+                free(device->eventSets[j].results);
             }
-            FREE_IF_NOT_NULL(device->eventSets);
+            free(device->eventSets);
         }
         free(nvmlContext.devices);
     }
 
     // Shutdown NVML
-    NVML_CALL(nvmlShutdown, (), return);
+    nvmlShutdown_ptr();
 }
 
 
@@ -1002,20 +1033,20 @@ nvml_addEventSet(char** events, int numEvents)
         NvmlEvent* tmpEvents = (NvmlEvent*) malloc(numEvents * sizeof(NvmlEvent));
         if (tmpEvents == NULL)
         {
-            ERROR_PLAIN_PRINT(Cannot allocate events for new event set);
+            ERROR_PRINT("Cannot allocate events for new event set");
             return -ENOMEM;
         }
         NvmlEventResult* tmpResults = (NvmlEventResult*) malloc(numEvents * sizeof(NvmlEventResult));
         if (tmpResults == NULL)
         {
-            ERROR_PLAIN_PRINT(Cannot allocate event results);
+            ERROR_PRINT("Cannot allocate event results");
             free(tmpEvents);
             return -ENOMEM;
         }
         NvmlEventSet* tmpEventSets = (NvmlEventSet*) realloc(device->eventSets, (device->numEventSets+1) * sizeof(NvmlEventSet));
         if (tmpEventSets == NULL)
         {
-            ERROR_PLAIN_PRINT(Cannot allocate new event set);
+            ERROR_PRINT("Cannot allocate new event set");
             free(tmpEvents);
             free(tmpResults);
             return -ENOMEM;
@@ -1038,7 +1069,7 @@ nvml_addEventSet(char** events, int numEvents)
             // Check if event was found
             if (idx < 0)
             {
-                ERROR_PRINT(Could not find event %s, events[j]);
+                ERROR_PRINT("Could not find event %s", events[j]);
                 return -EINVAL;
             }
 
@@ -1097,13 +1128,13 @@ nvml_getEventsOfGpu(int gpuId, NvmonEventList_t* output)
     NvmonEventListEntry* entries = (NvmonEventListEntry*) malloc(device->numAllEvents * sizeof(NvmonEventListEntry));
     if (entries == NULL)
     {
-        ERROR_PLAIN_PRINT(Cannot allocate event list entries);
+        ERROR_PRINT("Cannot allocate event list entries");
         return -ENOMEM;
     }
     NvmonEventList* list = (NvmonEventList*) malloc(sizeof(NvmonEventList));
     if (list == NULL)
     {
-        ERROR_PLAIN_PRINT(Cannot allocate event list);
+        ERROR_PRINT("Cannot allocate event list");
         free(entries);
         return -ENOMEM;
     }
@@ -1113,7 +1144,6 @@ nvml_getEventsOfGpu(int gpuId, NvmonEventList_t* output)
     {
         NvmlEvent* event = &device->allEvents[i];
         NvmonEventListEntry* entry = &entries[i];
-        int len;
 
         entry->name = event->name;
         entry->desc = "No description"; // TODO: Add event descriptions
@@ -1379,4 +1409,4 @@ nvml_getTimeToLastReadOfGroup(int groupId)
 
     // Return time as seconds
     return time*1E-9;
-}
\ No newline at end of file
+}
