@@ -5,13 +5,13 @@
  *
  *      Description:  Interface to procfs/sysfs for PCI device lookup
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -40,6 +40,7 @@
 #include <affinity.h>
 #include <topology.h>
 #include <error.h>
+#include <lw_alloc.h>
 
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
@@ -97,8 +98,6 @@ static int getBusFromSocketByDevid(const uint32_t socket, uint16_t testDevice)
 {
     int ret = 0;
     int cur_socket = (int)socket;
-    int out_bus_id = -1;
-    uint32_t out_devfn = 0x0;
     int bufflen = 1024;
     char buff[1024];
     FILE* fp = NULL;
@@ -124,7 +123,7 @@ static int getBusFromSocketByDevid(const uint32_t socket, uint16_t testDevice)
     }
     else
     {
-        ERROR_PLAIN_PRINT(Failed read file /proc/bus/pci/devices);
+        ERROR_PRINT("Failed read file /proc/bus/pci/devices");
     }
 
     while (cur_socket >= 0)
@@ -183,15 +182,14 @@ proc_pci_init(uint16_t testDevice, char** socket_bus, int* nrSockets)
         if ( sscanf(buf, "%02x%02x\t%04x%04x", &sbus, &sdevfn, &svend, &sdev) == 4 &&
              svend == testVendor && sdev == testDevice )
         {
-            socket_bus[cntr] = (char*)malloc(4);
             busID = getBusFromSocketByDevid(cntr, testDevice);
             if (busID == sbus)
             {
-                sprintf(socket_bus[cntr], "%02x/", sbus);
+                socket_bus[cntr] = lw_asprintf("%02x/", sbus);
             }
             else
             {
-                sprintf(socket_bus[cntr], "%02x/", busID);
+                socket_bus[cntr] = lw_asprintf("%02x/", busID);
             }
             cntr++;
         }
