@@ -5,14 +5,14 @@
  *
  *      Description:  Handler for performance groups and event sets
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -50,25 +50,18 @@
 #include <calculator.h>
 #include <bstrlib.h>
 #include <bstrlib_helper.h>
+#include <lw_alloc.h>
 
+static size_t totalgroups = 0;
 
-
-static int totalgroups = 0;
-
-/* #####   FUNCTION DEFINITIONS  -  INTERNAL FUNCTIONS   ################## */
-
-static inline void *realloc_buffer(void *ptrmem, size_t size) {
-    void *ptr = realloc(ptrmem, size);
-    if (!ptr)  {
-        fprintf(stderr, "realloc(%p, %lu): errno=%d\n", ptrmem, size, errno);
-        free (ptrmem);
-    }
-    if (!ptrmem)
-    {
-        memset(ptr, 0, size);
-    }
-    return ptr;
-}
+const char *groupFileSectionNames[MAX_GROUP_FILE_SECTIONS] = {
+    "NONE",
+    "SHORT",
+    "EVENTSET",
+    "METRICS",
+    "LONG",
+    "LUA"
+};
 
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
@@ -88,13 +81,12 @@ isdir(char* dirname)
 void
 perfgroup_returnGroups(int groups, char** groupnames, char** groupshort, char** grouplong)
 {
-    int i;
-    int freegroups = (totalgroups < groups ? groups : totalgroups);
-    for (i = 0; i <freegroups; i++)
+    size_t freegroups = (totalgroups < (size_t)groups ? (size_t)groups : totalgroups);
+    for (size_t i = 0; i <freegroups; i++)
     {
         free(groupnames[i]);
         groupnames[i] = NULL;
-        if (i < groups)
+        if (i < (size_t)groups)
         {
             if (groupshort[i] != NULL)
             {
@@ -134,7 +126,8 @@ perfgroup_getGroups(
         char*** groupshort,
         char*** grouplong)
 {
-    int i = 0, j = 0, s = 0;
+    int i = 0;
+    size_t s = 0;
     int fsize = 0, hsize = 0;
     DIR *dp = NULL;
     FILE* fp = NULL;
@@ -270,7 +263,7 @@ perfgroup_getGroups(
         return -ENOMEM;
     }
     memset(*grouplong, 0, totalgroups * sizeof(char**));
-    for (j=0; j < totalgroups; j++)
+    for (size_t j=0; j < totalgroups; j++)
     {
         (*groupnames)[j] = malloc((s+1) * sizeof(char));
         if ((*groupnames)[j] == NULL)
@@ -331,7 +324,7 @@ perfgroup_getGroups(
                             continue;
                         }
                         s = 1;
-                        for (j=s;j<linelist->qty; j++)
+                        for (size_t j=s;j<(size_t)linelist->qty; j++)
                         {
                             btrimws(linelist->entry[j]);
                             if (blength(linelist->entry[j]) == 0)
@@ -341,7 +334,7 @@ perfgroup_getGroups(
                         }
                         btrimws(linelist->entry[s]);
                         sinfo = bformat("%s", bdata(linelist->entry[s]));
-                        for (j=s+1;j<linelist->qty; j++)
+                        for (size_t j=s+1;j<(size_t)linelist->qty; j++)
                         {
                             btrimws(linelist->entry[j]);
                             bstring tmp = bformat(" %s", bdata(linelist->entry[j]));
@@ -390,13 +383,7 @@ perfgroup_getGroups(
                 }
                 if (read_long)
                 {
-
-                    (*grouplong)[i] = malloc((blength(long_info) + 1) * sizeof(char) );
-                    if ((*grouplong)[i] != NULL)
-                    {
-                        j = sprintf((*grouplong)[i], "%s", bdata(long_info));
-                        (*grouplong)[i][j] = '\0';
-                    }
+                    (*grouplong)[i] = bstr2cstr(long_info, ' ');
                 }
                 fclose(fp);
                 if (skip_group)
@@ -478,7 +465,7 @@ skip_cur_def_group:
                                 continue;
                             }
                             s = 1;
-                            for (j=s;j<linelist->qty; j++)
+                            for (size_t j=s;j<(size_t)linelist->qty; j++)
                             {
                                 btrimws(linelist->entry[j]);
                                 if (blength(linelist->entry[j]) == 0)
@@ -488,7 +475,7 @@ skip_cur_def_group:
                             }
                             btrimws(linelist->entry[s]);
                             sinfo = bformat("%s", bdata(linelist->entry[s]));
-                            for (j=s+1;j<linelist->qty; j++)
+                            for (size_t j=s+1;j<(size_t)linelist->qty; j++)
                             {
                                 btrimws(linelist->entry[j]);
                                 bstring tmp = bformat(" %s", bdata(linelist->entry[j]));
@@ -536,12 +523,7 @@ skip_cur_def_group:
                     }
                     if (read_long)
                     {
-                        (*grouplong)[i] = malloc((blength(long_info) + 1) * sizeof(char) );
-                        if ((*grouplong)[i] != NULL)
-                        {
-                            j = sprintf((*grouplong)[i], "%s", bdata(long_info));
-                            (*grouplong)[i][j] = '\0';
-                        }
+                        (*grouplong)[i] = bstr2cstr(long_info, ' ');
                     }
                     fclose(fp);
                     if (skip_group)
@@ -610,7 +592,7 @@ int perfgroup_customGroup(const char* eventStr, GroupInfo* ginfo)
     ginfo->metricnames = NULL;
     ginfo->longinfo = NULL;
     bstring eventBstr;
-    struct bstrList * eventList;
+    struct bstrList * eventList = NULL;
 #if defined(__i386__) || defined(__i486__) || defined(__i586__) || defined(__i686__) || defined(__x86_64)
     bstring fix0 = bformat("FIXC0");
     bstring fix1 = bformat("FIXC1");
@@ -628,7 +610,7 @@ int perfgroup_customGroup(const char* eventStr, GroupInfo* ginfo)
 #ifdef LIKWID_WITH_NVMON
     bstring gpu = bformat("GPU");
 #endif
-    DEBUG_PRINT(DEBUGLEV_INFO, Creating custom group for event string %s, eventStr);
+    DEBUG_PRINT(DEBUGLEV_INFO, "Creating custom group for event string %s", eventStr);
     ginfo->shortinfo = malloc(7 * sizeof(char));
     if (ginfo->shortinfo == NULL)
     {
@@ -708,7 +690,6 @@ int perfgroup_customGroup(const char* eventStr, GroupInfo* ginfo)
     }
     for (i = 0; i< eventList->qty; i++)
     {
-        int s;
         struct bstrList * elist;
         elist = bsplit(eventList->entry[i], ':');
         ginfo->events[i] = malloc((blength(elist->entry[0]) + 1) * sizeof(char));
@@ -752,35 +733,27 @@ int perfgroup_customGroup(const char* eventStr, GroupInfo* ginfo)
     {
         if ((!has_fix0) && cpuid_info.perf_num_fixed_ctr > 0)
         {
-            ginfo->events[i] = malloc(18 * sizeof(char));
-            ginfo->counters[i] = malloc(6 * sizeof(char));
-            sprintf(ginfo->events[i], "%s", "INSTR_RETIRED_ANY");
-            sprintf(ginfo->counters[i], "%s", "FIXC0");
+            ginfo->events[i] = lw_strdup("INSTR_RETIRED_ANY");
+            ginfo->counters[i] = lw_strdup("FIXC0");
             i++;
         }
         if ((!has_fix1) && cpuid_info.perf_num_fixed_ctr > 1)
         {
-            ginfo->events[i] = malloc(22 * sizeof(char));
-            ginfo->counters[i] = malloc(6 * sizeof(char));
-            sprintf(ginfo->events[i], "%s", "CPU_CLK_UNHALTED_CORE");
-            sprintf(ginfo->counters[i], "%s", "FIXC1");
+            ginfo->events[i] = lw_strdup("CPU_CLK_UNHALTED_CORE");
+            ginfo->counters[i] = lw_strdup("FIXC1");
             i++;
         }
         if ((!has_fix2) && cpuid_info.perf_num_fixed_ctr > 2)
         {
-            ginfo->events[i] = malloc(21 * sizeof(char));
-            ginfo->counters[i] = malloc(6 * sizeof(char));
-            sprintf(ginfo->events[i], "%s", "CPU_CLK_UNHALTED_REF");
-            sprintf(ginfo->counters[i], "%s", "FIXC2");
+            ginfo->events[i] = lw_strdup("CPU_CLK_UNHALTED_REF");
+            ginfo->counters[i] = lw_strdup("FIXC2");
             i++;
         }
         if ((!has_fix3) && cpuid_info.perf_num_fixed_ctr > 3 && 
-            (cpuid_info.model == ICELAKE1 || cpuid_info.model == ICELAKE2 || cpuid_info.model == ICELAKEX1 || cpuid_info.model == ICELAKEX2 || cpuid_info.model == ROCKETLAKE || cpuid_info.model == SAPPHIRERAPIDS || cpuid_info.model == TIGERLAKE1 || cpuid_info.model == TIGERLAKE2 || cpuid_info.model == GRANITERAPIDS))
+            (cpuid_info.model == ICELAKE1 || cpuid_info.model == ICELAKE2 || cpuid_info.model == ICELAKEX1 || cpuid_info.model == ICELAKEX2 || cpuid_info.model == ROCKETLAKE || cpuid_info.model == SAPPHIRERAPIDS || cpuid_info.model == EMERALDRAPIDS || cpuid_info.model == TIGERLAKE1 || cpuid_info.model == TIGERLAKE2 || cpuid_info.model == GRANITERAPIDS))
         {
-            ginfo->events[i] = malloc(14 * sizeof(char));
-            ginfo->counters[i] = malloc(6 * sizeof(char));
-            sprintf(ginfo->events[i], "%s", "TOPDOWN_SLOTS");
-            sprintf(ginfo->counters[i], "%s", "FIXC3");
+            ginfo->events[i] = lw_strdup("TOPDOWN_SLOTS");
+            ginfo->counters[i] = lw_strdup("FIXC3");
             i++;
         }
     }
@@ -789,18 +762,14 @@ int perfgroup_customGroup(const char* eventStr, GroupInfo* ginfo)
 #ifdef _ARCH_PPC
     if (!has_fix0)
     {
-        ginfo->events[i] = malloc(18 * sizeof(char));
-        ginfo->counters[i] = malloc(6 * sizeof(char));
-        sprintf(ginfo->events[i], "%s", "PM_RUN_INST_CMPL");
-        sprintf(ginfo->counters[i], "%s", "PMC4");
+        ginfo->events[i] = lw_strdup("PM_RUN_INST_CMPL");
+        ginfo->counters[i] = lw_strdup("PMC4");
         i++;
     }
     if (!has_fix1)
     {
-        ginfo->events[i] = malloc(22 * sizeof(char));
-        ginfo->counters[i] = malloc(6 * sizeof(char));
-        sprintf(ginfo->events[i], "%s", "PM_RUN_CYC");
-        sprintf(ginfo->counters[i], "%s", "PMC5");
+        ginfo->events[i] = lw_strdup("PM_RUN_CYC");
+        ginfo->counters[i] = lw_strdup("PMC5");
         i++;
     }
 #endif
@@ -840,7 +809,7 @@ perfgroup_readGroup(
         GroupInfo* ginfo)
 {
     FILE* fp;
-    int i, s, e, err = 0;
+    int s, err = 0;
     char buf[1024];
     GroupFileSections sec = GROUP_NONE;
     bstring REQUIRE = bformat("REQUIRE_NOHT");
@@ -852,12 +821,13 @@ perfgroup_readGroup(
     bstring fullpath = bformat("%s/%s/%s.txt", grouppath,architecture, groupname);
     bstring homepath = bformat("%s/.likwid/groups/%s/%s.txt", Home,architecture, groupname);
 
-    if (access(bdata(fullpath), R_OK))
+#pragma GCC diagnostic ignored "-Wnonnull"
+    if (bdata(fullpath) && access(bdata(fullpath), R_OK))
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, Cannot read group file %s. Trying %s, bdata(fullpath), bdata(homepath));
+        DEBUG_PRINT(DEBUGLEV_INFO, "Cannot read group file %s. Trying %s", bdata(fullpath), bdata(homepath));
         if (access(bdata(homepath), R_OK))
         {
-            ERROR_PRINT(Cannot read group file %s.txt. Searched in %s and %s, groupname, bdata(fullpath), bdata(homepath));
+            ERROR_PRINT("Cannot read group file %s.txt. Searched in %s and %s", groupname, bdata(fullpath), bdata(homepath));
             bdestroy(REQUIRE);
             bdestroy(fullpath);
             bdestroy(homepath);
@@ -870,7 +840,7 @@ perfgroup_readGroup(
         }
     }
 
-    DEBUG_PRINT(DEBUGLEV_INFO, Reading group %s from %s, groupname, bdata(fullpath));
+    DEBUG_PRINT(DEBUGLEV_INFO, "Reading group %s from %s", groupname, bdata(fullpath));
 
     ginfo->shortinfo = NULL;
     ginfo->nevents = 0;
@@ -880,15 +850,12 @@ perfgroup_readGroup(
     ginfo->metricformulas = NULL;
     ginfo->metricnames = NULL;
     ginfo->longinfo = NULL;
-    ginfo->groupname = (char*)malloc((strlen(groupname)+10)*sizeof(char));
+    ginfo->groupname = strdup(groupname);
     if (ginfo->groupname == NULL)
     {
         err = -ENOMEM;
         goto cleanup;
     }
-    //strncpy(ginfo->groupname, groupname, strlen(groupname));
-    i = sprintf(ginfo->groupname, "%s", groupname);
-    ginfo->groupname[i] = '\0';
 
     fp = fopen(bdata(fullpath), "r");
     if (fp == NULL)
@@ -906,14 +873,15 @@ perfgroup_readGroup(
         if (strncmp(groupFileSectionNames[GROUP_SHORT], buf, strlen(groupFileSectionNames[GROUP_SHORT])) == 0)
         {
             sec = GROUP_SHORT;
+            size_t i;
             for (i=strlen(groupFileSectionNames[GROUP_SHORT]); i < strlen(buf); i++)
             {
                 if (buf[i] == ' ')
                     continue;
                 break;
             }
-            ginfo->shortinfo = malloc(strlen(&(buf[i])) * sizeof(char));
-            sprintf(ginfo->shortinfo, "%.*s", (int)strlen(&(buf[i]))-1, &(buf[i]));
+            size_t l = strlen(&buf[i]);
+            ginfo->shortinfo = (l >= 1) ? lw_strndup(&buf[i], l-1) : lw_strdup("");
             continue;
         }
         else if (strncmp(bdata(REQUIRE), buf, blength(REQUIRE)) == 0)
@@ -949,7 +917,6 @@ perfgroup_readGroup(
             continue;
         if (sec == GROUP_EVENTSET)
         {
-            i = 0;
             bstring bbuf = bfromcstr(buf);
             btrimws(bbuf);
             if (blength(bbuf) == 0)
@@ -959,11 +926,11 @@ perfgroup_readGroup(
                 continue;
             }
             linelist = bsplit(bbuf, ' ');
-            for (i=0; i<linelist->qty; i++)
+            for (int i=0; i<linelist->qty; i++)
                 btrimws(linelist->entry[i]);
             bdestroy(bbuf);
             bbuf = bstrcpy(linelist->entry[0]);
-            for (i=1; i<linelist->qty; i++)
+            for (int i=1; i<linelist->qty; i++)
             {
                 if (blength(linelist->entry[i]) > 0)
                 {
@@ -1029,7 +996,7 @@ perfgroup_readGroup(
             bstrListDestroy(linelist);
             linelist = bsplit(bbuf, ' ');
             bdestroy(bbuf);
-            for (i=0; i<linelist->qty; i++)
+            for (int i=0; i<linelist->qty; i++)
                 btrimws(linelist->entry[i]);
             ginfo->counters[ginfo->nevents] = malloc((blength(linelist->entry[0])+1) * sizeof(char));
             if (ginfo->counters[ginfo->nevents] == NULL)
@@ -1051,7 +1018,6 @@ perfgroup_readGroup(
         }
         else if (sec == GROUP_METRICS)
         {
-            i = 0;
             bstring bbuf = bfromcstr(buf);
             btrimws(bbuf);
             if (blength(bbuf) == 0)
@@ -1061,11 +1027,11 @@ perfgroup_readGroup(
                 continue;
             }
             linelist = bsplit(bbuf, ' ');
-            for (i=0; i<linelist->qty; i++)
+            for (int i=0; i<linelist->qty; i++)
                 btrimws(linelist->entry[i]);
             bdestroy(bbuf);
             bbuf = bstrcpy(linelist->entry[0]);
-            for (i=1; i<linelist->qty; i++)
+            for (int i=1; i<linelist->qty; i++)
             {
                 if (blength(linelist->entry[i]) > 0)
                 {
@@ -1122,7 +1088,7 @@ perfgroup_readGroup(
             bdestroy(bbuf);
             sprintf(ginfo->metricformulas[ginfo->nmetrics], "%s", bdata(linelist->entry[linelist->qty - 1]));
             bbuf = bstrcpy(linelist->entry[0]);
-            for (i=1; i<linelist->qty - 1; i++)
+            for (int i=1; i<linelist->qty - 1; i++)
             {
                 if (blength(linelist->entry[i]) > 0)
                 {
@@ -1174,7 +1140,7 @@ cleanup:
         free(ginfo->longinfo);
     if (ginfo->nevents > 0)
     {
-        for(i=0;i<ginfo->nevents; i++)
+        for(int i=0;i<ginfo->nevents; i++)
         {
             if (ginfo->counters[i])
                 free(ginfo->counters[i]);
@@ -1184,7 +1150,7 @@ cleanup:
     }
     if (ginfo->nmetrics > 0)
     {
-        for(i=0;i<ginfo->nmetrics; i++)
+        for(int i=0;i<ginfo->nmetrics; i++)
         {
             if (ginfo->metricformulas[i])
                 free(ginfo->metricformulas[i]);
@@ -1279,7 +1245,7 @@ perfgroup_addEvent(GroupInfo* ginfo, char* counter, char* event)
         return -ENOMEM;
     sprintf(ginfo->events[ginfo->nevents], "%s", event);
     sprintf(ginfo->counters[ginfo->nevents], "%s", counter);
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Event %s:%s at pos %d, ginfo->events[ginfo->nevents], ginfo->counters[ginfo->nevents], ginfo->nevents);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Event %s:%s at pos %d", ginfo->events[ginfo->nevents], ginfo->counters[ginfo->nevents], ginfo->nevents);
     ginfo->nevents++;
     return 0;
 }
@@ -1292,7 +1258,7 @@ int perfgroup_removeEvent(GroupInfo* ginfo, char* counter)
     {
         if (strncmp(counter, ginfo->counters[i], strlen(ginfo->counters[i])) == 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, Removing event %s:%s at pos %d, ginfo->events[i], ginfo->counters[i], i);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Removing event %s:%s at pos %d", ginfo->events[i], ginfo->counters[i], i);
             free(ginfo->events[i]);
             free(ginfo->counters[i]);
             for (int j = i+1; j < ginfo->nevents; j++)
@@ -1315,28 +1281,28 @@ perfgroup_addMetric(GroupInfo* ginfo, char* mname, char* mcalc)
     ginfo->metricnames = realloc(ginfo->metricnames, (ginfo->nmetrics + 1) * sizeof(char*));
     if (!ginfo->metricnames)
     {
-        ERROR_PRINT(Cannot increase space for metricnames to %d bytes, (ginfo->nmetrics + 1) * sizeof(char*));
+        ERROR_PRINT("Cannot increase space for metricnames to %zu bytes", (ginfo->nmetrics + 1) * sizeof(char*));
         return -ENOMEM;
     }
     ginfo->metricformulas = realloc(ginfo->metricformulas, (ginfo->nmetrics + 1) * sizeof(char*));
     if (!ginfo->metricformulas)
     {
-        ERROR_PRINT(Cannot increase space for metricformulas to %d bytes, (ginfo->nmetrics + 1) * sizeof(char*));
+        ERROR_PRINT("Cannot increase space for metricformulas to %zu bytes", (ginfo->nmetrics + 1) * sizeof(char*));
         return -ENOMEM;
     }
     ginfo->metricnames[ginfo->nmetrics] = malloc((strlen(mname) + 1) * sizeof(char));
     if (!ginfo->metricnames[ginfo->nmetrics])
     {
-        ERROR_PRINT(Cannot increase space for metricname to %d bytes, (strlen(mname) + 1) * sizeof(char));
+        ERROR_PRINT("Cannot increase space for metricname to %zu bytes", (strlen(mname) + 1) * sizeof(char));
         return -ENOMEM;
     }
     ginfo->metricformulas[ginfo->nmetrics] = malloc((strlen(mcalc) + 1) * sizeof(char));
     if (!ginfo->metricformulas[ginfo->nmetrics])
     {
-        ERROR_PRINT(Cannot increase space for metricformula to %d bytes, (strlen(mcalc) + 1) * sizeof(char));
+        ERROR_PRINT("Cannot increase space for metricformula to %zu bytes", (strlen(mcalc) + 1) * sizeof(char));
         return -ENOMEM;
     }
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Adding metric %s = %s, mname, mcalc);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Adding metric %s = %s", mname, mcalc);
     int ret = sprintf(ginfo->metricnames[ginfo->nmetrics], "%s", mname);
     if (ret > 0)
     {
@@ -1359,7 +1325,7 @@ int perfgroup_removeMetric(GroupInfo* ginfo, char* mname)
     {
         if (strncmp(mname, ginfo->metricnames[i], strlen(ginfo->metricnames[i])) == 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, Removing metric %s at pos %d, ginfo->metricnames[i], i);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Removing metric %s at pos %d", ginfo->metricnames[i], i);
             free(ginfo->metricnames[i]);
             free(ginfo->metricformulas[i]);
             for (int j = i+1; j < ginfo->nmetrics; j++)
@@ -1403,14 +1369,14 @@ perfgroup_setGroupName(GroupInfo* ginfo, char* groupName)
 {
     if ((ginfo == NULL) || (groupName == NULL))
         return -EINVAL;
-    int size = strlen(groupName)+1;
+    size_t size = strlen(groupName)+1;
     ginfo->groupname = realloc(ginfo->groupname, size * sizeof(char));
     if (ginfo->groupname == NULL)
     {
-        ERROR_PRINT(Cannot increase space for groupname to %d bytes, size * sizeof(char));
+        ERROR_PRINT("Cannot increase space for groupname to %zu bytes", size * sizeof(char));
         return -ENOMEM;
     }
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Setting group name to %s, groupName);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Setting group name to %s", groupName);
     int ret = sprintf(ginfo->groupname, "%s", groupName);
     if (ret > 0)
     {
@@ -1548,12 +1514,12 @@ int perfgroup_mergeGroups(GroupInfo* grp1, GroupInfo* grp2)
             {
                 if (strncmp(grp1->events[i], grp2->events[j], strlen(grp1->events[i])) != 0)
                 {
-                    DEBUG_PRINT(DEBUGLEV_INFO, Cannot merge groups because counter %s is used for different events: %s and %s, grp1->counters[i], grp1->events[i], grp2->events[j]);
+                    DEBUG_PRINT(DEBUGLEV_INFO, "Cannot merge groups because counter %s is used for different events: %s and %s", grp1->counters[i], grp1->events[i], grp2->events[j]);
                     return -EFAULT;
                 }
                 else
                 {
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, Counter %s used in both groups but measure the same event %s, grp1->counters[i], grp1->events[i]);
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Counter %s used in both groups but measure the same event %s", grp1->counters[i], grp1->events[i]);
                 }
             }
         }
@@ -1575,7 +1541,7 @@ int perfgroup_mergeGroups(GroupInfo* grp1, GroupInfo* grp2)
             if (ret < 0)
             {
                 errno = -ret;
-                ERROR_PRINT(Cannot add event %s:%s, grp2->events[i], grp2->counters[i]);
+                ERROR_PRINT("Cannot add event %s:%s", grp2->events[i], grp2->counters[i]);
                 return ret;
             }
         }
@@ -1586,7 +1552,7 @@ int perfgroup_mergeGroups(GroupInfo* grp1, GroupInfo* grp2)
         if (ret < 0)
         {
             errno = -ret;
-            ERROR_PRINT(Cannot add metric %s, grp2->metricnames[i]);
+            ERROR_PRINT("Cannot add metric %s", grp2->metricnames[i]);
             return ret;
         }
     }
@@ -1647,7 +1613,6 @@ update_clist(CounterList* clist, char* counter, double result)
 void
 destroy_clist(CounterList* clist)
 {
-    int i;
     if (clist != NULL)
     {
         bstrListDestroy(clist->cnames);
