@@ -6,13 +6,13 @@
  *      Description:  Overloaded library for pthread_create call. 
  *                    Implements pinning of threads together with likwid-pin.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:  Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -34,7 +34,6 @@
 #include <stdint.h>
 #include <dlfcn.h>
 #include <sched.h>
-#include <bits/pthreadtypes.h>
 #include <sys/types.h>
 #include <errno.h>
 #include <dirent.h>
@@ -153,7 +152,7 @@ pthread_create(pthread_t* thread,
     static int overflow = 0;
     static int overflowed = 0;
     static long online_cpus = 0;
-    static int shepard = 0;
+    static int shepherd = 0;
     online_cpus = sysconf(_SC_NPROCESSORS_ONLN);
     pthread_mutex_lock(&mutex);
 
@@ -204,28 +203,35 @@ pthread_create(pthread_t* thread,
         FILE* fpipe;
         char cmd[512];
         char buff[512];
-        char file[256];
+        char file[64];
         unsigned int ptr = ((void*)start_routine) - info.dli_fbase;
 
         buff[0] = '\0';
-        snprintf(file, 255, "/tmp/likwidpin.%d", gettid());
-        snprintf(cmd, 511, "rm -f %s; nm %s 2>/dev/null | grep %x > %s",
-                 file, info.dli_fname, ptr, file);
+        snprintf(file, sizeof(file), "/tmp/likwidpin.%ld", gettid());
+        if (info.dli_fname[0] != '/') {
+            snprintf(cmd, sizeof(cmd), "rm -f %s; nm $(which %s) 2>/dev/null | grep %x > %s",
+                     file, info.dli_fname, ptr, file);
+        } else {
+            snprintf(cmd, sizeof(cmd), "rm -f %s; nm %s 2>/dev/null | grep %x > %s",
+                     file, info.dli_fname, ptr, file);
+        }
         ret = system(cmd);
-        if (!access(file, R_OK))
+        fpipe = fopen(file, "r");
+        if (!fpipe)
         {
-            fpipe = fopen(file, "r");
-            if (!fpipe)
-            {
-                fprintf(stderr, "Problems reading symbols for shepard thread detection\n");
-            }
-            else
-            {
-                char* t = fgets(buff, 512, fpipe);
+            fprintf(stderr, "Problems reading symbols for shepherd thread detection: %s\n", strerror(errno));
+        }
+        else
+        {
+            if (fgets(buff, sizeof(buff), fpipe) == NULL) {
+                // TODO, how should we handle this error correctly?
+                fprintf(stderr, "Problems reading symbols for shepherd thread detection: %s\n", strerror(errno));
+                fclose(fpipe);
+            } else {
                 char* tmp = strstr(buff, "monitor");
                 if (tmp != NULL)
                 {
-                    shepard = 1;
+                    shepherd = 1;
                     skipMask |= 1ULL<<(ncalled);
                 }
                 fclose(fpipe);
@@ -233,10 +239,6 @@ pthread_create(pthread_t* thread,
                 ret = system(cmd);
             }
         }
-        else
-        {
-            fprintf(stderr, "Problems reading symbols for shepard thread detection\n");
-        }
     }
 
     /* Handle dll related stuff */
@@ -287,11 +289,11 @@ pthread_create(pthread_t* thread,
             pthread_setaffinity_np(*thread, sizeof(cpu_set_t), &cpuset);
             if (!silent)
             {
-                if (shepard)
+                if (shepherd)
                     color_print("\tthreadid %lu -> SKIP SHEPHERD\n", *thread);
                 else
                     color_print("\tthreadid %lu -> SKIP \n", *thread);
-                shepard = 0;
+                shepherd = 0;
             }
         }
         else
