@@ -5,13 +5,13 @@
  *
  *      Description:  Marker API interface of module rocmon
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Thomas Gruber (tg), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -40,6 +40,7 @@
 
 #include <likwid.h>
 #include <rocmon_types.h>
+#include <lw_alloc.h>
 
 #define gettid() syscall(SYS_gettid)
 
@@ -485,7 +486,7 @@ rocmon_markerStartRegion(const char* regionTag)
 
     // Read counters (for all devices)
     TimerData timestamp;
-    ROCMON_DEBUG_PRINT(DEBUGLEV_DETAIL, START REGION '%s' (group %d), regionTag, active_group);
+    ROCMON_DEBUG_PRINT(DEBUGLEV_DETAIL, "START REGION '%s' (group %d)", regionTag, active_group);
     timer_start(&timestamp);
     rocmon_readCounters();
 
@@ -544,7 +545,7 @@ rocmon_markerStopRegion(const char* regionTag)
 
     // Read counters (for all devices)
     TimerData timestamp;
-    ROCMON_DEBUG_PRINT(DEBUGLEV_DETAIL, STOP REGION '%s' (group %d), regionTag, active_group);
+    ROCMON_DEBUG_PRINT(DEBUGLEV_DETAIL, "STOP REGION '%s' (group %d)", regionTag, active_group);
     timer_stop(&timestamp);
     rocmon_readCounters();
 
@@ -612,6 +613,8 @@ rocmon_markerGetRegion(
 
     // TODO: implement this function
     fprintf(stderr, "WARN: Function 'rocmon_markerGetRegion' is not implemented.\n");
+
+    (void)regionTag;
     
     *nr_gpus = 0;
     *nr_events = 0;
@@ -696,7 +699,7 @@ int rocmMarkerRegions = 0;
 int
 rocmon_readMarkerFile(const char* filename)
 {
-    int ret = 0, i = 0;
+    int ret = 0;
     FILE* fp = NULL;
     char buf[2048];
     buf[0] = '\0';
@@ -737,7 +740,7 @@ rocmon_readMarkerFile(const char* filename)
         return -ENOMEM;
     }
     rocmMarkerRegions = regions;
-    for ( uint32_t i=0; i < regions; i++ )
+    for ( int i=0; i < regions; i++ )
     {
         regionGPUs[i] = 0;
         rocmMarkerResults[i].gpuCount = gpus;
@@ -810,7 +813,7 @@ rocmon_readMarkerFile(const char* filename)
                 rocmMarkerResults[regionid].eventCount = nevents;
                 rocmMarkerResults[regionid].time[gpuidx] = time;
                 rocmMarkerResults[regionid].count[gpuidx] = count;
-                rocmMarkerResults[regionid].counters[gpuidx] = malloc(nevents * sizeof(double));
+                rocmMarkerResults[regionid].counters[gpuidx] = lw_calloc(nevents, sizeof(double));
 
                 eventidx = 0;
                 ptr = strtok(remain, " ");
@@ -824,7 +827,7 @@ rocmon_readMarkerFile(const char* filename)
             }
         }
     }
-    for ( uint32_t i=0; i < regions; i++ )
+    for ( int i=0; i < regions; i++ )
     {
         rocmMarkerResults[i].gpuCount = regionGPUs[i];
     }
@@ -863,7 +866,7 @@ rocmon_getCountOfRegion(int region, int gpu)
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -886,7 +889,7 @@ rocmon_getTimeOfRegion(int region, int gpu)
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -910,7 +913,7 @@ rocmon_getGpulistOfRegion(int region, int count, int* gpulist)
     int i;
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -933,7 +936,7 @@ rocmon_getGpusOfRegion(int region)
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -948,7 +951,7 @@ rocmon_getMetricsOfRegion(int region)
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -963,7 +966,7 @@ rocmon_getNumberOfRegions()
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     return rocmMarkerRegions;
@@ -974,7 +977,7 @@ rocmon_getGroupOfRegion(int region)
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -989,7 +992,7 @@ rocmon_getTagOfRegion(int region)
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return NULL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -1004,7 +1007,7 @@ rocmon_getEventsOfRegion(int region)
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -1019,7 +1022,7 @@ rocmon_getResultOfRegionGpu(int region, int eventId, int gpuId)
 {
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return -EINVAL;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -1049,7 +1052,7 @@ rocmon_getMetricOfRegionGpu(int region, int metricId, int gpuId)
     CounterList clist;
     if (rocmMarkerResults == NULL)
     {
-        ERROR_PLAIN_PRINT(Rocmon module not properly initialized);
+        ERROR_PRINT("Rocmon module not properly initialized");
         return NAN;
     }
     if (region < 0 || region >= rocmMarkerRegions)
@@ -1086,7 +1089,7 @@ rocmon_getMetricOfRegionGpu(int region, int metricId, int gpuId)
     err = calc_metric(f, &clist, &result);
     if (err < 0)
     {
-        ERROR_PRINT(Cannot calculate formula %s, f);
+        ERROR_PRINT("Cannot calculate formula %s", f);
         return NAN;
     }
     destroy_clist(&clist);
