@@ -5,13 +5,13 @@
  *
  *      Description:  Implementation of timer module
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:  Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -49,7 +49,9 @@ static uint64_t baseline = 0ULL;
 static uint64_t cpuClock = 0ULL;
 static uint64_t cyclesClock = 0ULL;
 static uint64_t sleepbase = 0ULL;
+#if defined(__ARM_ARCH_7A__) || defined(__ARM_ARCH_8A)
 static uint8_t fixedFreq = 0;
+#endif
 static int timer_initialized = 0;
 
 void (*TSTART)(TscCounter*) = NULL;
@@ -60,24 +62,29 @@ void (*TSTOP)(TscCounter*) = NULL;
 static void
 fRDTSC(TscCounter* cpu_c)
 {
-    __asm__ volatile("xor %%eax,%%eax\n\t"           \
-    "cpuid\n\t"           \
-    "rdtsc\n\t"           \
-    "movl %%eax, %0\n\t"  \
-    "movl %%edx, %1\n\t"  \
+    __asm__ volatile(
+    "mfence\n\t"            \
+    "lfence\n\t"            \
+    "rdtsc\n\t"             \
+    "movl %%eax, %0\n\t"    \
+    "movl %%edx, %1\n\t"    \
+    "lfence\n\t"            \
     : "=r" ((cpu_c)->int32.lo), "=r" ((cpu_c)->int32.hi) \
-    : : "%eax","%ebx","%ecx","%edx");
+    : : "%rax", "rbx", "rcx", "%rdx", "memory");
 }
 
 static void
 fRDTSC_CR(TscCounter* cpu_c)
 {
-    __asm__ volatile(   \
-    "rdtsc\n\t"           \
-    "movl %%eax, %0\n\t"  \
-    "movl %%edx, %1\n\t"  \
+    __asm__ volatile(
+    "lfence\n\t"            \
+    "rdtscp\n\t"            \
+    "movl %%eax, %0\n\t"    \
+    "movl %%edx, %1\n\t"    \
+    "lfence\n\t"            \
+    "cpuid\n\t"             \
     : "=r" ((cpu_c)->int32.lo), "=r" ((cpu_c)->int32.hi) \
-    : : "%eax","%ebx","%ecx","%edx");
+    : : "%rax", "rbx", "rcx", "%rdx", "memory");
 }
 #ifndef __MIC__
 static void
@@ -155,7 +162,7 @@ TIMER(TscCounter* cpu_c)
 }
 #endif
 
-
+#if defined(__ARM_ARCH_7A__) || defined(__ARM_ARCH_8A)
 static int os_timer(TscCounter* time)
 {
     int ret;
@@ -178,7 +185,7 @@ static void os_timer_stop(TscCounter* time)
 {
     os_timer(time);
 }
-
+#endif
 
 static void
 _timer_start( TimerData* time )
@@ -261,8 +268,7 @@ getCpuSpeed(void)
 #if defined(__x86_64) || defined(__i386__)
     int i;
     TimerData data;
-    TscCounter start;
-    TscCounter stop;
+    unsigned int eax = 0, ebx = 0, ecx = 0, edx = 0;
     uint64_t result = 0xFFFFFFFFFFFFFFFFULL;
     struct timeval tv1;
     struct timeval tv2;
@@ -275,26 +281,40 @@ getCpuSpeed(void)
         _timer_stop(&data);
         result = MIN(result,_timer_printCycles(&data));
     }
-
     baseline = result;
-    result = 0xFFFFFFFFFFFFFFFFULL;
-    data.stop.int64 = 0;
-    data.start.int64 = 0;
 
-    for (i=0; i< 2; i++)
+    // Determine the maximal available CPUID Leaf
+    eax = 0, ebx = 0, ecx = 0, edx = 0;
+    CPUID(eax, ebx, ecx, edx);
+    if (eax >= 0x16)
     {
-        _timer_start(&data);
-        gettimeofday( &tv1, &tzp);
-        nanosleep( &delay, NULL);
-        _timer_stop(&data);
-        gettimeofday( &tv2, &tzp);
-
-        result = MIN(result,(data.stop.int64 - data.start.int64));
+        // Processor Frequency Information Leaf (0x16) is available
+        eax = 0x16, ebx = 0, ecx = 0, edx = 0;
+        CPUID(eax, ebx, ecx, edx);
+        cpuClock = (eax & 0xFFFF) * 1000000;
     }
+    else
+    {
+        // Frequency not provided by the system, measure it.
+        result = 0xFFFFFFFFFFFFFFFFULL;
+        data.stop.int64 = 0;
+        data.start.int64 = 0;
 
-    cpuClock = (result) * 1000000 /
-        (((uint64_t)tv2.tv_sec * 1000000 + tv2.tv_usec) -
-         ((uint64_t)tv1.tv_sec * 1000000 + tv1.tv_usec));
+        for (i=0; i< 2; i++)
+        {
+            _timer_start(&data);
+            gettimeofday( &tv1, &tzp);
+            nanosleep( &delay, NULL);
+            _timer_stop(&data);
+            gettimeofday( &tv2, &tzp);
+
+            result = MIN(result,(data.stop.int64 - data.start.int64));
+        }
+
+        cpuClock = (result) * 1000000 /
+            (((uint64_t)tv2.tv_sec * 1000000 + tv2.tv_usec) -
+             ((uint64_t)tv1.tv_sec * 1000000 + tv1.tv_usec));
+    }
     cyclesClock = cpuClock;
 #endif
 #ifdef _ARCH_PPC
@@ -437,7 +457,6 @@ _timer_init( void )
 void
 init_sleep()
 {
-    int status;
     TimerData timer;
     _timer_init();
     struct timespec req = {0,1};
@@ -445,7 +464,7 @@ init_sleep()
     for (int i=0; i<10; ++i)
     {
         _timer_start(&timer);
-        status = clock_nanosleep(CLOCK_REALTIME,0,&req, &rem);
+        clock_nanosleep(CLOCK_REALTIME,0,&req, &rem);
         _timer_stop(&timer);
         if (_timer_print(&timer)*1E6 > sleepbase)
         {
@@ -470,7 +489,7 @@ timer_printCycles( const TimerData* time )
 {
     if (timer_initialized != 1)
     {
-        ERROR_PLAIN_PRINT(Timer module not properly initialized);
+        ERROR_PRINT("Timer module not properly initialized");
         return 0ULL;
     }
     return _timer_printCycles(time);
@@ -480,10 +499,9 @@ timer_printCycles( const TimerData* time )
 double
 timer_print( const TimerData* time )
 {
-    uint64_t cycles;
     if (timer_initialized != 1)
     {
-        ERROR_PLAIN_PRINT(Timer module not properly initialized);
+        ERROR_PRINT("Timer module not properly initialized");
         return 0ULL;
     }
     return _timer_print(time);
@@ -494,7 +512,7 @@ timer_getCpuClock( void )
 {
     if (timer_initialized != 1)
     {
-        ERROR_PLAIN_PRINT(Timer module not properly initialized);
+        ERROR_PRINT("Timer module not properly initialized");
         return 0ULL;
     }
     return cpuClock;
@@ -503,27 +521,26 @@ timer_getCpuClock( void )
 uint64_t
 timer_getCpuClockCurrent( int cpu_id )
 {
-    int err;
     uint64_t clock = 0x0ULL;
     FILE *fpipe;
     char cmd[256];
-    char buff[256];
+    char buff[128];
     char* eptr, *rptr;
 
-    sprintf(buff, "/sys/devices/system/cpu/cpu%d/cpufreq/scaling_cur_freq", cpu_id);
+    snprintf(buff, sizeof(buff), "/sys/devices/system/cpu/cpu%d/cpufreq/scaling_cur_freq", cpu_id);
     if (access(buff, R_OK))
     {
-        ERROR_PRINT(File %s not readable, buff);
+        ERROR_PRINT("File %s not readable", buff);
         return clock;
     }
-    sprintf(cmd, "cat %s", buff);
+    snprintf(cmd, sizeof(cmd), "cat %s", buff);
     if ( !(fpipe = (FILE*)popen(cmd,"r")) )
     {  // If fpipe is NULL
-        ERROR_PRINT(Problems reading cpu frequency of CPU %d, cpu_id);
+        ERROR_PRINT("Problems reading cpu frequency of CPU %d", cpu_id);
         return clock;
     }
 
-    rptr = fgets(buff, 256, fpipe);
+    rptr = fgets(buff, sizeof(buff), fpipe);
     pclose(fpipe);
     if (rptr != NULL)
     {
@@ -537,7 +554,7 @@ timer_getCycleClock( void )
 {
     if (timer_initialized != 1)
     {
-        ERROR_PLAIN_PRINT(Timer module not properly initialized);
+        ERROR_PRINT("Timer module not properly initialized");
         return 0ULL;
     }
     return cyclesClock;
@@ -548,7 +565,7 @@ timer_getBaseline( void )
 {
     if (timer_initialized != 1)
     {
-        ERROR_PLAIN_PRINT(Timer module not properly initialized);
+        ERROR_PRINT("Timer module not properly initialized");
         return 0ULL;
     }
     return baseline;
@@ -559,7 +576,7 @@ timer_start( TimerData* time )
 {
     if (timer_initialized != 1)
     {
-        ERROR_PLAIN_PRINT(Timer module not properly initialized);
+        ERROR_PRINT("Timer module not properly initialized");
         return;
     }
     _timer_start(time);
@@ -570,7 +587,7 @@ timer_stop( TimerData* time )
 {
     if (timer_initialized != 1)
     {
-        ERROR_PLAIN_PRINT(Timer module not properly initialized);
+        ERROR_PRINT("Timer module not properly initialized");
         return;
     }
     _timer_stop(time);
@@ -610,7 +627,7 @@ timer_finalize(void)
 {
     if (timer_initialized != 1)
     {
-        ERROR_PLAIN_PRINT(Timer module not properly initialized);
+        ERROR_PRINT("Timer module not properly initialized");
         return;
     }
     baseline = 0ULL;
