@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to the cpuid based topology backend
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -45,6 +45,7 @@
 #include <cpuid.h>
 #endif
 #include <affinity.h>
+#include <lw_alloc.h>
 
 /* #####   MACROS  -  LOCAL TO THIS SOURCE FILE   ######################### */
 
@@ -53,7 +54,6 @@
 /* #####   VARIABLES  -  LOCAL TO THIS SOURCE FILE   ###################### */
 
 static int largest_function = 0;
-static uint32_t eax, ebx, ecx, edx;
 
 /* Dirty hack to avoid nonull warnings */
 char* (*ownstrcpy)(char *__restrict __dest, const char *__restrict __src);
@@ -63,15 +63,13 @@ char* (*ownstrcpy)(char *__restrict __dest, const char *__restrict __src);
 static int
 intelCpuidFunc_4(CacheLevel** cachePool)
 {
-    int i;
-    int level=0;
-    int maxNumLevels=0;
+    uint32_t level=0;
+    uint32_t maxNumLevels=0;
     uint32_t valid=1;
     CacheLevel* pool;
     while (valid)
     {
-        eax = 0x04;
-        ecx = level;
+        uint32_t eax = 4, ebx, ecx = level, edx;
         CPUID(eax, ebx, ecx, edx);
         valid = extractBitField(eax,5,0);
         if (!valid)
@@ -82,13 +80,12 @@ intelCpuidFunc_4(CacheLevel** cachePool)
     }
 
     maxNumLevels = level;
-    *cachePool = (CacheLevel*) malloc(maxNumLevels * sizeof(CacheLevel));
+    *cachePool = lw_malloc(maxNumLevels * sizeof(CacheLevel));
     pool = *cachePool;
 
-    for (i=0; i < maxNumLevels; i++)
+    for (size_t i=0; i < maxNumLevels; i++)
     {
-        eax = 0x04;
-        ecx = i;
+        uint32_t eax = 4, ebx, ecx = i, edx;
         CPUID(eax, ebx, ecx, edx);
 
         pool[i].level = extractBitField(eax,3,5);
@@ -130,9 +127,7 @@ intelCpuidFunc_4(CacheLevel** cachePool)
         /* :WORKAROUND:08/13/2009 08:34:15 AM:jt: For L3 caches the value is sometimes
          * too large in here. Ask Intel what is wrong here!
          * Limit threads per Socket then to the maximum possible value.*/
-        if(pool[i].threads > (int)
-                (cpuid_topology.numCoresPerSocket*
-                 cpuid_topology.numThreadsPerCore))
+        if(pool[i].threads > cpuid_topology.numCoresPerSocket * cpuid_topology.numThreadsPerCore)
         {
             pool[i].threads = cpuid_topology.numCoresPerSocket*
                 cpuid_topology.numThreadsPerCore;
@@ -208,21 +203,18 @@ amdGetAssociativity(uint32_t flag)
 void
 cpuid_printTlbTopology()
 {
-    int i;
-    uint32_t loop = 1;
-
     if (cpuid_info.isIntel)
     {
-        eax = 0x02;
+        uint32_t eax = 2, ebx, ecx = 0, edx;
         CPUID(eax, ebx, ecx, edx);
-        loop = extractBitField(eax,8,0);
-        for(i=1;i<loop;i++)
+        uint32_t loop = extractBitField(eax,8,0);
+        for(size_t i=1;i<loop;i++)
         {
             eax = 0x02;
             CPUID(eax, ebx, ecx, edx);
         }
 
-        for(i=8;i<32;i+=8)
+        for(size_t i=8;i<32;i+=8)
         {
             if (extractBitField(eax,8,i) != 0x0)
             {
@@ -230,7 +222,7 @@ cpuid_printTlbTopology()
                     printf("%s\n",intel_tlb_info[extractBitField(eax,8,i)]);
             }
         }
-        for(i=0;i<32;i+=8)
+        for(size_t i=0;i<32;i+=8)
         {
             if (extractBitField(eax,8,i) != 0x0)
             {
@@ -238,7 +230,7 @@ cpuid_printTlbTopology()
                     printf("%s\n",intel_tlb_info[extractBitField(ebx,8,i)]);
             }
         }
-        for(i=0;i<32;i+=8)
+        for(size_t i=0;i<32;i+=8)
         {
             if (extractBitField(eax,8,i) != 0x0)
             {
@@ -246,7 +238,7 @@ cpuid_printTlbTopology()
                     printf("%s\n",intel_tlb_info[extractBitField(ecx,8,i)]);
             }
         }
-        for(i=0;i<32;i+=8)
+        for(size_t i=0;i<32;i+=8)
         {
             if (extractBitField(eax,8,i) != 0x0)
             {
@@ -257,7 +249,7 @@ cpuid_printTlbTopology()
     }
     else
     {
-        eax = 0x80000005;
+        uint32_t eax = 0x80000005, ebx, ecx = 0, edx;
         CPUID(eax, ebx, ecx, edx);
         printf("L1DTlb2and4MAssoc: 0x%x\n",extractBitField(eax,8,24));
         printf("L1DTlb2and4MSize: %d entries for 2MB pages\n",(uint32_t)extractBitField(eax,8,16));
@@ -294,7 +286,7 @@ cpuid_set_osname(void)
 {
     FILE *fp;
     bstring nameString = bformat("model name");
-    cpuid_info.osname = malloc(MAX_MODEL_STRING_LENGTH * sizeof(char));
+    cpuid_info.osname = lw_malloc(MAX_MODEL_STRING_LENGTH * sizeof(char));
     memset(cpuid_info.osname, '\0', MAX_MODEL_STRING_LENGTH);
     ownstrcpy = strcpy;
     int i;
@@ -329,10 +321,9 @@ cpuid_set_osname(void)
 int
 cpuid_init_cpuInfo(cpu_set_t cpuSet)
 {
-    int cpus_in_set = 0;
     cpuid_info.isIntel = 1;
 
-    eax = 0x00;
+    uint32_t eax = 0, ebx, ecx = 0, edx;
     CPUID(eax, ebx, ecx, edx);
 
     largest_function = eax;
@@ -348,25 +339,25 @@ cpuid_init_cpuInfo(cpu_set_t cpuSet)
     cpuid_info.stepping =  (eax&0xFU);
     cpuid_set_osname();
     cpuid_topology.numHWThreads = sysconf(_SC_NPROCESSORS_CONF);
-    cpus_in_set = cpu_count(&cpuSet);
-    if (cpus_in_set < cpuid_topology.numHWThreads)
+    int cpus_in_set = cpu_count(&cpuSet);
+    if (cpus_in_set >= 0 && (uint32_t)cpus_in_set < cpuid_topology.numHWThreads)
     {
         cpuid_topology.numHWThreads = cpus_in_set;
     }
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, CPU-ID CpuInfo Family %d Model %d Stepping %d isIntel %d numHWThreads %d activeHWThreads %d,
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "CPU-ID CpuInfo Family %d Model %d Stepping %d isIntel %d numHWThreads %d activeHWThreads %d",
                             cpuid_info.family,
                             cpuid_info.model,
                             cpuid_info.stepping,
                             cpuid_info.isIntel,
                             cpuid_topology.numHWThreads,
-                            cpuid_topology.activeHWThreads)
+                            cpuid_topology.activeHWThreads);
     return 0;
 }
 
 int
 cpuid_init_cpuFeatures(void)
 {
-    eax = 0x01;
+    uint32_t eax = 1, ebx, ecx = 0, edx;
     CPUID(eax, ebx, ecx, edx);
 
     cpuid_info.featureFlags = 0;
@@ -548,8 +539,7 @@ cpuid_init_nodeTopology(cpu_set_t cpuSet)
     /* check if 0x0B cpuid leaf is supported */
     if (largest_function >= 0x0B)
     {
-        eax = 0x0B;
-        ecx = 0;
+        uint32_t eax = 0x0B, ebx, ecx = 0, edx;
         CPUID(eax, ebx, ecx, edx);
 
         if (ebx)
@@ -566,8 +556,7 @@ cpuid_init_nodeTopology(cpu_set_t cpuSet)
             CPU_ZERO(&set);
             CPU_SET(i,&set);
             sched_setaffinity(0, sizeof(cpu_set_t), &set);
-            eax = 0x0B;
-            ecx = 0;
+            uint32_t eax = 0x0B, ebx, ecx = 0, edx;
             CPUID(eax, ebx, ecx, edx);
             apicId = edx;
             id = i;
@@ -611,16 +600,16 @@ cpuid_init_nodeTopology(cpu_set_t cpuSet)
                 }
                 prevOffset = currOffset;
             }
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, I[%d] ID[%d] APIC[%d] T[%d] C[%d] P [%d], i, id,
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "I[%d] ID[%d] APIC[%d] T[%d] C[%d] P [%d]", i, id,
                                     hwThreadPool[id].apicId, hwThreadPool[id].threadId,
                                     hwThreadPool[id].coreId, hwThreadPool[id].packageId);
         }
     }
     else
     {
+        uint32_t eax = 0, ebx, ecx = 0, edx;
         switch ( cpuid_info.family )
         {
-
             case MIC_FAMILY:
 
             case P6_FAMILY:
@@ -668,7 +657,7 @@ cpuid_init_nodeTopology(cpu_set_t cpuSet)
                                 8-getBitFieldWidth(maxNumLogicalProcs),
                                 getBitFieldWidth(maxNumLogicalProcs));
 
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, I[%d] ID[%d] APIC[%d] T[%d] C[%d] P [%d], i, id,
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "I[%d] ID[%d] APIC[%d] T[%d] C[%d] P [%d]", i, id,
                                     hwThreadPool[id].apicId, hwThreadPool[id].threadId,
                                     hwThreadPool[id].coreId, hwThreadPool[id].packageId);
                 }
@@ -719,7 +708,7 @@ cpuid_init_nodeTopology(cpu_set_t cpuSet)
                         extractBitField(hwThreadPool[i].apicId,
                                 8-getBitFieldWidth(maxNumCores),
                                 getBitFieldWidth(maxNumCores));
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, I[%d] ID[%d] APIC[%d] T[%d] C[%d] P [%d], i, id,
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "I[%d] ID[%d] APIC[%d] T[%d] C[%d] P [%d]", i, id,
                                     hwThreadPool[id].apicId, hwThreadPool[id].threadId,
                                     hwThreadPool[id].coreId, hwThreadPool[id].packageId);
                 }
@@ -767,7 +756,7 @@ cpuid_init_nodeTopology(cpu_set_t cpuSet)
                     hwThreadPool[id].packageId =
                         extractBitField(hwThreadPool[i].apicId,
                                 (8-width), width);
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, I[%d] ID[%d] APIC[%d] T[%d] C[%d] P [%d], i, id,
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "I[%d] ID[%d] APIC[%d] T[%d] C[%d] P [%d]", i, id,
                                     hwThreadPool[id].apicId, hwThreadPool[id].threadId,
                                     hwThreadPool[id].coreId, hwThreadPool[id].packageId);
                 }
@@ -787,6 +776,7 @@ cpuid_init_cacheTopology(void)
     CacheLevel* cachePool = NULL;
     CacheType type = DATACACHE;
 
+    uint32_t eax = 0, ebx, ecx = 0, edx;
 
     switch ( cpuid_info.family )
     {
@@ -943,7 +933,7 @@ cpuid_init_cacheTopology(void)
             }
             break;
         default:
-            ERROR_PLAIN_PRINT(Processor is not supported);
+            ERROR_PRINT("Processor is not supported");
             break;
     }
 
@@ -955,7 +945,8 @@ cpuid_init_cacheTopology(void)
 
 int cpuid_get_hwthread_data(int cpu_id, HWThread* hwt)
 {
-    eax = 0x01;
+    (void)cpu_id;
+    uint32_t eax = 1, ebx, ecx = 0, edx;
     CPUID(eax, ebx, ecx, edx);
     hwt->apicId = extractBitField(ebx,8,24);
     return 0;
