@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to the hwloc based topology backend
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Thomas Gruber (tr), thomas.roehl@googlemail.com
  *
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -44,6 +44,7 @@
 #include <hwloc.h>
 #include <topology_hwloc.h>
 #endif
+#include <lw_alloc.h>
 
 /* #####  EXPORTED VARIABLESE   ########################################### */
 
@@ -216,12 +217,11 @@ likwid_hwloc_record_objs_of_type_below_obj(
         int* index,
         uint32_t **list)
 {
-    int i;
     int count = 0;
     hwloc_obj_t walker;
     if (!obj) return 0;
     if (!obj->arity) return 0;
-    for (i=0;i<obj->arity;i++)
+    for (uint32_t i=0;i<obj->arity;i++)
     {
         walker = obj->children[i];
         if (walker->type == type)
@@ -242,7 +242,7 @@ likwid_hwloc_record_objs_of_type_below_obj(
 int
 hwloc_init_cpuInfo(cpu_set_t cpuSet)
 {
-    int i;
+    (void)cpuSet;
     uint32_t count = 0;
     hwloc_obj_t obj;
     if (perfmon_verbosity <= 1)
@@ -269,7 +269,7 @@ hwloc_init_cpuInfo(cpu_set_t cpuSet)
     cpuid_info.stepping = 0;
     cpuid_info.vendor = 0;
     cpuid_info.part = 0;
-    cpuid_info.osname = malloc(MAX_MODEL_STRING_LENGTH * sizeof(char));
+    cpuid_info.osname = lw_malloc(MAX_MODEL_STRING_LENGTH * sizeof(char));
     cpuid_info.osname[0] = '\0';
     if (!obj)
     {
@@ -358,7 +358,7 @@ hwloc_init_cpuInfo(cpu_set_t cpuSet)
             cpuid_topology.numHWThreads = cpuid_topology.activeHWThreads;
         }
     }
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, HWLOC CpuInfo Family %d Model %d Stepping %d Vendor 0x%X Part 0x%X isIntel %d numHWThreads %d activeHWThreads %d,
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "HWLOC CpuInfo Family %d Model %d Stepping %d Vendor 0x%X Part 0x%X isIntel %d numHWThreads %d activeHWThreads %d",
                             cpuid_info.family,
                             cpuid_info.model,
                             cpuid_info.stepping,
@@ -366,7 +366,7 @@ hwloc_init_cpuInfo(cpu_set_t cpuSet)
                             cpuid_info.part,
                             cpuid_info.isIntel,
                             cpuid_topology.numHWThreads,
-                            cpuid_topology.activeHWThreads)
+                            cpuid_topology.activeHWThreads);
     return 0;
 }
 
@@ -381,28 +381,10 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
     int maxNumDies = 0;
     int maxNumCoresPerSocket = 0;
     hwloc_obj_t obj = NULL;
-    int poolsize = 0;
-    int nr_sockets = 1;
-    int id = 0;
-    int consecutive_cores = -1;
     int from_file = (getenv("HWLOC_FSROOT") != NULL);
     hwloc_obj_type_t socket_type = HWLOC_OBJ_SOCKET;
     hwloc_obj_type_t die_type = HWLOC_OBJ_DIE;
-    if (!from_file)
-    {
-        for (uint32_t i=0;i<cpuid_topology.numHWThreads;i++)
-        {
-            if (CPU_ISSET(i, &cpuSet))
-            {
-                poolsize = i+1;
-            }
-        }
-    }
-    else
-    {
-        poolsize = cpuid_topology.numHWThreads;
-    }
-    hwThreadPool = (HWThread*) malloc(cpuid_topology.numHWThreads * sizeof(HWThread));
+    hwThreadPool = lw_malloc(cpuid_topology.numHWThreads * sizeof(HWThread));
     for (uint32_t i=0;i<cpuid_topology.numHWThreads;i++)
     {
         hwThreadPool[i].apicId = -1;
@@ -450,9 +432,9 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
         {
             continue;
         }
-        id = obj->os_index;
 
-        if (id < 0 || id >= cpuid_topology.numHWThreads)
+        uint32_t id = obj->os_index;
+        if (id >= cpuid_topology.numHWThreads)
             continue;
 
         if (CPU_ISSET(id, &cpuSet))
@@ -547,31 +529,26 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
 #endif
         if (maxNumSockets < maxNumDies)
         {
-            printf("Searching for socket of die\n");
             hwloc_obj_t t = obj->parent;
             while (t->type != die_type) {
                 t = t->parent;
                 if (!t)
                 {
-                    printf("Cannot find type %d\n", die_type);
                     skip = 1;
                     break;
                 }
             }
             if (skip)
             {
-                printf("setting die id = 0\n");
                 hwThreadPool[id].dieId = 0;
                 continue;
             }
             if (t->type == die_type)
             {
-                printf("setting die id = %d\n", t->os_index);
                 hwThreadPool[id].dieId = t->os_index;
             }
             else
             {
-                printf("setting die id = 0 (else)\n");
                 hwThreadPool[id].dieId = 0;
             }
         }
@@ -579,17 +556,17 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
         {
             hwThreadPool[id].dieId = 0;
         }
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, HWLOC Thread Pool PU %d Thread %d Core %d Die %d Socket %d inCpuSet %d,
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "HWLOC Thread Pool PU %d Thread %d Core %d Die %d Socket %d inCpuSet %d",
                             hwThreadPool[id].apicId,
                             hwThreadPool[id].threadId,
                             hwThreadPool[id].coreId,
                             hwThreadPool[id].dieId,
                             hwThreadPool[id].packageId,
-                            hwThreadPool[id].inCpuSet)
+                            hwThreadPool[id].inCpuSet);
     }
 
-    int socket_nums[MAX_NUM_NODES];
-    int num_sockets = 0;
+    uint32_t socket_nums[MAX_NUM_NODES];
+    uint32_t num_sockets = 0;
     int has_zero_id = 0;
     for (uint32_t i=0; i< cpuid_topology.numHWThreads; i++)
     {
@@ -616,7 +593,6 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
     {
         for (uint32_t i=0; i< cpuid_topology.numHWThreads; i++)
         {
-            HWThread* t = &hwThreadPool[i];
             for (uint32_t j=0; j < num_sockets; j++)
             {
                 if (hwThreadPool[i].packageId == socket_nums[j])
@@ -809,7 +785,7 @@ hwloc_init_cacheTopology(void)
 #if defined(_ARCH_PPC) || defined(__ARM_ARCH_7A__) || defined(__ARM_ARCH_8A)
         cachePool[id].inclusive = 0;
 #endif
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, HWLOC Cache Pool ID %d Level %d Size %d Threads %d,
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "HWLOC Cache Pool ID %d Level %d Size %d Threads %d",
                                       id, cachePool[id].level,
                                       cachePool[id].size,
                                       cachePool[id].threads);
