@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to the procfs/sysfs based topology backend
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2019 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -40,6 +40,7 @@
 #include <dirent.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <lw_alloc.h>
 
 #include <bstrlib.h>
 #include <bstrlib_helper.h>
@@ -101,15 +102,6 @@ get_listPosition(int ownid, bstring list)
     return -1;
 }
 
-static int
-get_listLength(bstring list)
-{
-    struct bstrList* tokens = bsplit(list,(char) ',');
-    int len = tokens->qty;
-    bstrListDestroy(tokens);
-    return len;
-}
-
 static int
 fillList(int* outList, int outOffset, bstring list)
 {
@@ -183,8 +175,10 @@ static int readCacheInclusiveAMD(int level)
 int
 proc_init_cpuInfo(cpu_set_t cpuSet)
 {
+    (void)cpuSet;
+
     int i = 0;
-    int HWthreads = 0;
+    uint32_t HWthreads = 0;
     FILE *fp = NULL;
 
     int (*ownatoi)(const char*);
@@ -226,7 +220,7 @@ proc_init_cpuInfo(cpu_set_t cpuSet)
 #endif
     cpuid_info.stepping = 0;
     cpuid_topology.numHWThreads = 0;
-    cpuid_info.osname = malloc(MAX_MODEL_STRING_LENGTH * sizeof(char));
+    cpuid_info.osname = lw_malloc(MAX_MODEL_STRING_LENGTH * sizeof(char));
     cpuid_info.osname[0] = '\0';
 
     if (NULL != (fp = fopen ("/proc/cpuinfo", "r")))
@@ -328,12 +322,12 @@ proc_init_cpuInfo(cpu_set_t cpuSet)
         }
 
 #endif
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, PROC CpuInfo Family %d Model %d Stepping %d isIntel %d numHWThreads %d,
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "PROC CpuInfo Family %d Model %d Stepping %d isIntel %d numHWThreads %d",
                             cpuid_info.family,
                             cpuid_info.model,
                             cpuid_info.stepping,
                             cpuid_info.isIntel,
-                            cpuid_topology.numHWThreads)
+                            cpuid_topology.numHWThreads);
     }
     return 0;
 }
@@ -343,11 +337,6 @@ int
 proc_init_cpuFeatures(void)
 {
     int ret = 0;
-    FILE* file;
-    char buf[1024];
-    char ident[30];
-    char delimiter[] = " ";
-    char* cptr;
 #ifdef _ARCH_PPC
     return 0;
 #endif
@@ -613,12 +602,12 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
     ownatoi = &atoi;
     int last_socket = -1;
     int last_coreid = -1;
+#ifdef __ARM_ARCH_8A
     int num_sockets = 0;
-    int num_cores_per_socket = 0;
+#endif
     int num_threads_per_core = 0;
-    int num_cores_per_die = 0;
 
-    hwThreadPool = (HWThread*) malloc(cpuid_topology.numHWThreads * sizeof(HWThread));
+    hwThreadPool = lw_malloc(cpuid_topology.numHWThreads * sizeof(HWThread));
     for (uint32_t i=0;i<cpuid_topology.numHWThreads;i++)
     {
         hwThreadPool[i].apicId = i;
@@ -637,10 +626,13 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         {
             bstring src = bread ((bNread) fread, fp);
             int packageId = ownatoi(bdata(src));
+            bdestroy(src);
             hwThreadPool[i].packageId = packageId;
             if (packageId > last_socket)
             {
+#ifdef __ARM_ARCH_8A
                 num_sockets++;
+#endif
                 last_socket = packageId;
                 last_coreid = -1;
             }
@@ -650,12 +642,10 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         file = bformat("%s/core_id", bdata(cpudir));
         if (NULL != (fp = fopen (bdata(file), "r")))
         {
+            // TODO why are we reading this file if we don't use it?
             bstring src = bread ((bNread) fread, fp);
+            bdestroy(src);
             hwThreadPool[i].coreId = (++last_coreid);
-            if (hwThreadPool[i].packageId == 0)
-            {
-                num_cores_per_socket++;
-            }
             fclose(fp);
         }
         bdestroy(file);
@@ -664,10 +654,7 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         {
             bstring src = bread ((bNread) fread, fp);
             hwThreadPool[i].dieId = ownatoi(bdata(src));
-            if (hwThreadPool[i].packageId == 0 && hwThreadPool[i].dieId == 0)
-            {
-                num_cores_per_die++;
-            }
+            bdestroy(src);
             fclose(fp);
         }
         bdestroy(file);
@@ -676,6 +663,7 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         {
             bstring src = bread ((bNread) fread, fp);
             hwThreadPool[i].threadId = get_listPosition(i, src);
+            bdestroy(src);
             if (hwThreadPool[i].packageId == 0 &&
                 hwThreadPool[i].coreId == 0)
             {
@@ -716,27 +704,26 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         if (hwThreadPool[i].dieId == -1)
             hwThreadPool[i].dieId = 0;
 #endif
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, PROC Thread Pool PU %d Thread %d Core %d Die %d Socket %d inCpuSet %d,
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "PROC Thread Pool PU %d Thread %d Core %d Die %d Socket %d inCpuSet %d",
                             hwThreadPool[i].apicId,
                             hwThreadPool[i].threadId,
                             hwThreadPool[i].coreId,
                             hwThreadPool[i].dieId,
                             hwThreadPool[i].packageId,
-                            hwThreadPool[i].inCpuSet)
+                            hwThreadPool[i].inCpuSet);
         bdestroy(cpudir);
     }
-    int* helper = malloc(cpuid_topology.numHWThreads * sizeof(int));
+    uint32_t* helper = calloc(cpuid_topology.numHWThreads, sizeof(*helper));
     if (!helper)
-    {
         return -ENOMEM;
-    }
+
     cpuid_topology.threadPool = hwThreadPool;
-    int hidx = 0;
-    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    uint32_t hidx = 0;
+    for (size_t i = 0; i < cpuid_topology.numHWThreads; i++)
     {
-        int pid = hwThreadPool[i].packageId;
+        const uint32_t pid = hwThreadPool[i].packageId;
         int found = 0;
-        for (int j = 0; j < hidx; j++)
+        for (size_t j = 0; j < hidx; j++)
         {
             if (pid == helper[j])
             {
@@ -749,13 +736,14 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
             helper[hidx++] = pid;
         }
     }
-    int tmp_numSockets = hidx;
+
+    const uint32_t tmp_numSockets = hidx;
     hidx = 0;
-    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    for (size_t i = 0; i < cpuid_topology.numHWThreads; i++)
     {
-        int pid = hwThreadPool[i].dieId;
+        const uint32_t pid = hwThreadPool[i].dieId;
         int found = 0;
-        for (int j = 0; j < hidx; j++)
+        for (size_t j = 0; j < hidx; j++)
         {
             if (pid == helper[j])
             {
@@ -768,7 +756,7 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
             helper[hidx++] = pid;
         }
     }
-    int tmp_numDies = hidx;
+    const uint32_t  tmp_numDies = hidx;
     if (tmp_numSockets == 1 && tmp_numDies == 1)
     {
         for (uint32_t i=0;i<cpuid_topology.numHWThreads;i++)
@@ -782,7 +770,6 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
                 hwThreadPool[i].packageId = packageId;
                 if (packageId > last_socket)
                 {
-                    num_sockets++;
                     last_socket = packageId;
                 }
                 fclose(fp);
@@ -791,11 +778,11 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         }
     }
     hidx = 0;
-    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    for (size_t i = 0; i < cpuid_topology.numHWThreads; i++)
     {
-        int pid = hwThreadPool[i].packageId;
+        const uint32_t pid = hwThreadPool[i].packageId;
         int found = 0;
-        for (int j = 0; j < hidx; j++)
+        for (size_t j = 0; j < hidx; j++)
         {
             if (pid == helper[j])
             {
@@ -812,11 +799,11 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
     /* Traverse all sockets to get maximal thread count per socket.
      * This should fix the code for architectures with "empty" sockets.
      */
-    int num_threads_per_socket = 0;
-    for (int i = 0; i < cpuid_topology.numSockets; i++)
+    uint32_t  num_threads_per_socket = 0;
+    for (size_t i = 0; i < cpuid_topology.numSockets; i++)
     {
-        int threadCount = 0;
-        for (int j = 0; j < cpuid_topology.numHWThreads; j++)
+        uint32_t threadCount = 0;
+        for (size_t j = 0; j < cpuid_topology.numHWThreads; j++)
         {
             if (helper[i] == hwThreadPool[j].packageId)
             {
@@ -829,15 +816,16 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
         }
     }
 
-    int first_socket_id = helper[0];
+    const uint32_t first_socket_id = helper[0];
     hidx = 0;
-    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    for (size_t i = 0; i < cpuid_topology.numHWThreads; i++)
     {
-        int did = hwThreadPool[i].dieId;
-        int pid = hwThreadPool[i].packageId;
-        if (pid != first_socket_id) continue;
+        const uint32_t did = hwThreadPool[i].dieId;
+        const uint32_t pid = hwThreadPool[i].packageId;
+        if (pid != first_socket_id)
+            continue;
         int found = 0;
-        for (int j = 0; j < hidx; j++)
+        for (size_t j = 0; j < hidx; j++)
         {
             if (did == helper[j])
             {
@@ -856,8 +844,8 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
     {
         cpuid_topology.numDies = 0;
     }
-    int max_thread_sibling_id = 0;
-    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    uint32_t max_thread_sibling_id = 0;
+    for (size_t i = 0; i < cpuid_topology.numHWThreads; i++)
     {
         if (hwThreadPool[i].threadId > max_thread_sibling_id)
         {
@@ -1100,7 +1088,7 @@ proc_init_cacheTopology(void)
                 cachePool[i].inclusive = 0;
                 break;
             default:
-                ERROR_PLAIN_PRINT(Processor is not supported);
+                ERROR_PRINT("Processor is not supported");
                 break;
         }
     }
