@@ -6,13 +6,13 @@
  *      Description:  Implementation of the Voltage Module.
  *                    Implements Intel Core Voltage Interface.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jimmy Situ web@jimmystone.cn
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 Jimmy Situ
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -53,6 +53,8 @@ voltage_read(int cpuId, uint64_t *data)
 int
 voltage_tread(int socket_fd, int cpuId, uint64_t *data)
 {
+    (void)socket_fd;
+
     uint64_t result = 0;
     if (HPMread(cpuId, MSR_DEV, MSR_PERF_STATUS, &result))
     {
