@@ -6,7 +6,7 @@
 #
 #      Description:  Basic checks for performance group files
 #
-#      Author:   Thomas Roehl (tr), thomas.roehl@googlemail.com
+#      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
 #      Project:  likwid
 #
 #      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
@@ -27,8 +27,7 @@
 
 import sys, os, re, glob, os.path, subprocess
 
-#SRCPATH="/home/rrze/unrz/unrz139/Work/likwid"
-SRCPATH="/home/tom/Work/likwid-branch-4.3.0"
+SRCPATH="/home/rrze/unrz/unrz139/Work/likwid"
 GROUPPATH=os.path.join(SRCPATH, "groups")
 EVENTHEADERPATH=os.path.join(SRCPATH, "src/includes")
 PERFCTR="likwid-perfctr"
